'''
# AWS::QuickSight Construct Library

This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.

```python
import monocdk as quicksight
```

<!--BEGIN CFNONLY DISCLAIMER-->

There are no official hand-written ([L2](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) constructs for this service yet. Here are some suggestions on how to proceed:

* Search [Construct Hub for QuickSight construct libraries](https://constructs.dev/search?q=quicksight)
* Use the automatically generated [L1](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_l1_using) constructs, in the same way you would use [the CloudFormation AWS::QuickSight resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/AWS_QuickSight.html) directly.

<!--BEGIN CFNONLY DISCLAIMER-->

There are no hand-written ([L2](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) constructs for this service yet.
However, you can still use the automatically generated [L1](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_l1_using) constructs, and use this service exactly as you would using CloudFormation directly.

For more information on the resources and properties available for this service, see the [CloudFormation documentation for AWS::QuickSight](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/AWS_QuickSight.html).

(Read the [CDK Contributing Guide](https://github.com/aws/aws-cdk/blob/master/CONTRIBUTING.md) and submit an RFC if you are interested in contributing to this construct library.)

<!--END CFNONLY DISCLAIMER-->
'''
import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

from .._jsii import *

from .. import (
    CfnResource as _CfnResource_e0a482dc,
    CfnTag as _CfnTag_95fbdc29,
    Construct as _Construct_e78e779f,
    IInspectable as _IInspectable_82c04a63,
    IResolvable as _IResolvable_a771d0ef,
    TagManager as _TagManager_0b7ab120,
    TreeInspector as _TreeInspector_1cd1894e,
)


@jsii.implements(_IInspectable_82c04a63)
class CfnAnalysis(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnAnalysis",
):
    '''A CloudFormation ``AWS::QuickSight::Analysis``.

    Creates an analysis in Amazon QuickSight.

    :cloudformationResource: AWS::QuickSight::Analysis
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        # data_driven: Any
        
        cfn_analysis = quicksight.CfnAnalysis(self, "MyCfnAnalysis",
            analysis_id="analysisId",
            aws_account_id="awsAccountId",
            name="name",
        
            # the properties below are optional
            definition=quicksight.CfnAnalysis.AnalysisDefinitionProperty(
                data_set_identifier_declarations=[quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )],
        
                # the properties below are optional
                analysis_defaults=quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                ),
                calculated_fields=[quicksight.CfnAnalysis.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )],
                column_configurations=[quicksight.CfnAnalysis.ColumnConfigurationProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
        
                    # the properties below are optional
                    colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                            color="color",
        
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )],
                filter_groups=[quicksight.CfnAnalysis.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnAnalysis.FilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
        
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
        
                    # the properties below are optional
                    status="status"
                )],
                parameter_declarations=[quicksight.CfnAnalysis.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                        name="name",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
        
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )],
                sheets=[quicksight.CfnAnalysis.SheetDefinitionProperty(
                    sheet_id="sheetId",
        
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnAnalysis.LayoutProperty(
                        configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
        
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
        
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                        configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
        
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnAnalysis.VisualProperty(
                        bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                computations=[quicksight.CfnAnalysis.ComputationProperty(
                                    forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
        
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
        
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
        
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )]
            ),
            parameters=quicksight.CfnAnalysis.ParametersProperty(
                date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )],
                decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )],
                integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )],
                string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                    name="name",
                    values=["values"]
                )]
            ),
            permissions=[quicksight.CfnAnalysis.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            source_entity=quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            ),
            status="status",
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            theme_arn="themeArn"
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        analysis_id: builtins.str,
        aws_account_id: builtins.str,
        name: builtins.str,
        definition: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        parameters: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        source_entity: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AnalysisSourceEntityProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Analysis``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param analysis_id: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        :param aws_account_id: The ID of the AWS account where you are creating an analysis.
        :param name: A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
        :param definition: ``AWS::QuickSight::Analysis.Definition``.
        :param parameters: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
        :param permissions: A structure that describes the principals and the resource-level permissions on an analysis. You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN). To specify no permissions, omit ``Permissions`` .
        :param source_entity: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param status: Status associated with the analysis.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
        :param theme_arn: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__94713b0e25f6fb44da0e5708561fbb388ab27894952dc9180b090ad973fedb64)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnAnalysisProps(
            analysis_id=analysis_id,
            aws_account_id=aws_account_id,
            name=name,
            definition=definition,
            parameters=parameters,
            permissions=permissions,
            source_entity=source_entity,
            status=status,
            tags=tags,
            theme_arn=theme_arn,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a277acf1bf3d5fa079c94d01280ebdfc15738a792f0755991a8e2ee749f1b617)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6f8c9493ca5edcffe9b4b0ae7a2f962f5abb5196f9599a5290f4093ab8908832)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the analysis.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that the analysis was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrDataSetArns")
    def attr_data_set_arns(self) -> typing.List[builtins.str]:
        '''The ARNs of the datasets of the analysis.

        :cloudformationAttribute: DataSetArns
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "attrDataSetArns"))

    @builtins.property
    @jsii.member(jsii_name="attrErrors")
    def attr_errors(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Errors
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the analysis was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrSheets")
    def attr_sheets(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Sheets
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrSheets"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="analysisId")
    def analysis_id(self) -> builtins.str:
        '''The ID for the analysis that you're creating.

        This ID displays in the URL of the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
        '''
        return typing.cast(builtins.str, jsii.get(self, "analysisId"))

    @analysis_id.setter
    def analysis_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b63dd2ef2d013078cd4f95a2a87cf9df1991fb860975faba156b39fed0046087)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "analysisId", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you are creating an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__973802336e8a95c38ae0fc40f7bcc9e7809bd05fe43b084a98ab3dbe08870bd3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''A descriptive name for the analysis that you're creating.

        This name displays for the analysis in the Amazon QuickSight console.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
        '''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a50f221b67eca3e3dbd4f669b01de869d050af55b0865f217b20bdf256ab7a3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", _IResolvable_a771d0ef]]:
        '''``AWS::QuickSight::Analysis.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
        '''
        return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", _IResolvable_a771d0ef]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union["CfnAnalysis.AnalysisDefinitionProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c051a165f191bcf70ebc87b79d0e99dfe367c2b1e394774b42750d0dc0c76f9e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(
        self,
    ) -> typing.Optional[typing.Union["CfnAnalysis.ParametersProperty", _IResolvable_a771d0ef]]:
        '''The parameter names and override values that you want to use.

        An analysis can have any parameter type, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
        '''
        return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParametersProperty", _IResolvable_a771d0ef]], jsii.get(self, "parameters"))

    @parameters.setter
    def parameters(
        self,
        value: typing.Optional[typing.Union["CfnAnalysis.ParametersProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__138e4944c872b7dc4398d7338a0a78c65becb9d6e22de7d3cd2fe4a800b1b6c5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ResourcePermissionProperty", _IResolvable_a771d0ef]]]]:
        '''A structure that describes the principals and the resource-level permissions on an analysis.

        You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).

        To specify no permissions, omit ``Permissions`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ResourcePermissionProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ResourcePermissionProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7cb1e49f31d389ff3dd53df5668dbb6443bfcf1576635017254421f73bafa43c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union["CfnAnalysis.AnalysisSourceEntityProperty", _IResolvable_a771d0ef]]:
        '''A source entity to use for the analysis that you're creating.

        This metadata structure contains details that describe a source template and one or more datasets.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
        '''
        return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AnalysisSourceEntityProperty", _IResolvable_a771d0ef]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union["CfnAnalysis.AnalysisSourceEntityProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f3f7da47ef2ef2a95c12c58a700b56d3e16ac66ef40b8ad7b736fe872040f86c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[builtins.str]:
        '''Status associated with the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "status"))

    @status.setter
    def status(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6832fc6a28a99a31804550e91c2f0aaf8bc624abc6f811f49eb57914000a2aa5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="themeArn")
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN for the theme to apply to the analysis that you're creating.

        To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "themeArn"))

    @theme_arn.setter
    def theme_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1cae791aff2259aec117cab6d8f48dd161a81128a8c099068f5de1f1fd08fb97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeArn", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnAnalysis.AggregationFunctionProperty(
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__441589f4166c673ce28509120a312121ac16be405fc13d820a46b6935e1e4011)
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_function": "aggregationFunction",
            "column": "column",
            "sort_direction": "sortDirection",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            aggregation_function: typing.Union[typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            sort_direction: builtins.str,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param aggregation_function: The function that aggregates the values in ``Column`` .
            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f8b4634cfd5d6e81d30d066c7f9efca5aacd2f53941db99653eff80c78786f1)
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_function": aggregation_function,
                "column": column,
                "sort_direction": sort_direction,
            }

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The function that aggregates the values in ``Column`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            assert result is not None, "Required property 'aggregation_function' is missing"
            return typing.cast(typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that determines the sort order of aggregated values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[typing.Union["CfnAnalysis.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b23dd539ace7bb8ea3a8a1f8e39918514b4a2cc41cad382259dce482b4d50c89)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.DefaultNewSheetConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html#cfn-quicksight-analysis-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DefaultNewSheetConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AnalysisDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier_declarations": "dataSetIdentifierDeclarations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class AnalysisDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_identifier_declarations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataSetIdentifierDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            analysis_defaults: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            column_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            filter_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The definition of an analysis.

            :param data_set_identifier_declarations: An array of dataset identifier declarations. This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.
            :param analysis_defaults: ``CfnAnalysis.AnalysisDefinitionProperty.AnalysisDefaults``.
            :param calculated_fields: An array of calculated field definitions for the analysis.
            :param column_configurations: An array of analysis-level column configurations. Column configurations can be used to set default formatting for a column to be used throughout an analysis.
            :param filter_groups: Filter definitions for an analysis. For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .
            :param parameter_declarations: An array of parameter declarations for an analysis. Parameters are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for an analysis. Each ``SheetDefinition`` provides detailed information about a sheet within this analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                analysis_definition_property = quicksight.CfnAnalysis.AnalysisDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
                
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnAnalysis.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnAnalysis.ColumnConfigurationProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                                color="color",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnAnalysis.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnAnalysis.FilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
                
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
                
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnAnalysis.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                            name="name",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnAnalysis.SheetDefinitionProperty(
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnAnalysis.LayoutProperty(
                            configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
                
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                            configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
                
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnAnalysis.VisualProperty(
                            bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                    computations=[quicksight.CfnAnalysis.ComputationProperty(
                                        forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                        arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
                
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                                column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnAnalysis.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
                
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__813a271fde414637ef85e6d924dbed35e7767836cac1126afe34b2ebb5cabe6a)
                check_type(argname="argument data_set_identifier_declarations", value=data_set_identifier_declarations, expected_type=type_hints["data_set_identifier_declarations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier_declarations": data_set_identifier_declarations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_identifier_declarations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataSetIdentifierDeclarationProperty", _IResolvable_a771d0ef]]]:
            '''An array of dataset identifier declarations.

            This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-datasetidentifierdeclarations
            '''
            result = self._values.get("data_set_identifier_declarations")
            assert result is not None, "Required property 'data_set_identifier_declarations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataSetIdentifierDeclarationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AnalysisDefaultsProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.AnalysisDefinitionProperty.AnalysisDefaults``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AnalysisDefaultsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.CalculatedFieldProperty", _IResolvable_a771d0ef]]]]:
            '''An array of calculated field definitions for the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.CalculatedFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''An array of analysis-level column configurations.

            Column configurations can be used to set default formatting for a column to be used throughout an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilterGroupProperty", _IResolvable_a771d0ef]]]]:
            '''Filter definitions for an analysis.

            For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilterGroupProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ParameterDeclarationProperty", _IResolvable_a771d0ef]]]]:
            '''An array of parameter declarations for an analysis.

            Parameters are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ParameterDeclarationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetDefinitionProperty", _IResolvable_a771d0ef]]]]:
            '''An array of sheet definitions for an analysis.

            Each ``SheetDefinition`` provides detailed information about a sheet within this analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetDefinitionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AnalysisErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class AnalysisErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.EntityProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Analysis error.

            :param message: The message associated with the analysis error.
            :param type: The type of the analysis error.
            :param violated_entities: Lists the violated entities that caused the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                analysis_error_property = quicksight.CfnAnalysis.AnalysisErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnAnalysis.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__311857a65fb40985dd2b496f122b3d63ce49d6673a6fab9fc013c8b49832966a)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''The message associated with the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.EntityProperty", _IResolvable_a771d0ef]]]]:
            '''Lists the violated entities that caused the analysis error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.EntityProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AnalysisSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={"source_template": "sourceTemplate"},
    )
    class AnalysisSourceEntityProperty:
        def __init__(
            self,
            *,
            source_template: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AnalysisSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The source entity of an analysis.

            :param source_template: The source template for the source entity of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                analysis_source_entity_property = quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                    source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b60bdfbf9fb7937127801dd3d259559ba7def61dbaa3009ea53909a916ee12f)
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AnalysisSourceTemplateProperty", _IResolvable_a771d0ef]]:
            '''The source template for the source entity of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html#cfn-quicksight-analysis-analysissourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AnalysisSourceTemplateProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AnalysisSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class AnalysisSourceTemplateProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The source template of an analysis.

            :param arn: The Amazon Resource Name (ARN) of the source template of an analysis.
            :param data_set_references: The dataset references of the source template of an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                analysis_source_template_property = quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc261445b37c22b2efa052372f4d6884a6145c4552ef4443eb3fd587c184d308)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the source template of an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataSetReferenceProperty", _IResolvable_a771d0ef]]]:
            '''The dataset references of the source template of an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataSetReferenceProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95dc095a7fcc6e3e17b44d7ebebb50e95cf0f215b62f256c5f7f0c51676743d1)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                    range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1be9bbfe183931af2d408c0b1bc9baf7eaf42e44d67f3694f49901b14f953a85)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ArcAxisDisplayRangeProperty", _IResolvable_a771d0ef]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ArcAxisDisplayRangeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e86fff568482aaa262339f111dd551a38ae4d1e7b70d839e4f06643cb1670c1)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnAnalysis.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c0d00ee9f04b734b443b76244b8119d1e50fb7e866acc3e16149f7fc2684209)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnAnalysis.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36b8b6f08fdb25056e9933f3676e2fb3531abf3dd392b388ab0c42d2c2117dee)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html#cfn-quicksight-analysis-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_axis_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnAnalysis.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d2f1460463c494a752e81682025f4ce70cec155f764bdb70642c88451e51222)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateAxisOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for an axis with a date field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateAxisOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericAxisOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericAxisOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d2e702dabb6aca8df1fc86ef1c4b0cbe9ad326d31328fd4b05513c94560ea4b)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tick_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e767bae7ed69b919bdd8d1b956f2c3fbab219bcb7bf4b8dd9df39ebbf60ba1ef)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDataOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDataOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ScrollBarOptionsProperty", _IResolvable_a771d0ef]]:
            '''The scroll bar options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ScrollBarOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisTickLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisTickLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86821bd5952bf93a791d8536701d852c79abbd67a509cfa32ae4859c636f48a4)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayMinMaxRangeProperty", _IResolvable_a771d0ef]]:
            '''The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayMinMaxRangeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4691f428046cb1b921f216ed620f88e0e4fcb7c71a8c303936505cf2c1e8926)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisLabelReferenceOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that indicate which field the label belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisLabelReferenceOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d6707b1563657b293d751dac569d0ed64ed8cc1b7cf5cc94e9a83222e8c385a)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnAnalysis.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__47271f1e300655bd947ec0739f62a9f56e56b49dc143118b832fa6a7766c3355)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68c90071acd0088b6b114ba5f9229973d80fe7d1ee87510afa7d204f0af2b591)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html#cfn-quicksight-analysis-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            logarithmic: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnAnalysis.AxisScaleProperty(
                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04b217598c11c2e62b2c89b9a9bd83b1ab693039b7db196aa4088373324f3c86)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisLinearScaleProperty", _IResolvable_a771d0ef]]:
            '''The linear axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisLinearScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisLogarithmicScaleProperty", _IResolvable_a771d0ef]]:
            '''The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisLogarithmicScaleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27986ae4a81a2c3b3442f97c2f5b86c0f7ce46117238c7fb51d27416796a6b6b)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines whether or not the axis ticks are visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__612aee6195edaa64617c9fbab328c93e6fa327094e6553a6fcc711b093e9ee60)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category (y-axis) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color (group/color) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_configuration_property = quicksight.CfnAnalysis.BarChartConfigurationProperty(
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                        bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    orientation="orientation",
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b8c92d1acd9748578f0e84a2103d48fdd790bad5c05d6b8119f143600fb44cf)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BarChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BarChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BarChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BarChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_field_wells_property = quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                    bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b190d55cedffa33ec145a65b821e3cc49c5a692d13815dba1878c037a73f58f)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html#cfn-quicksight-analysis-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79416a0e477da6890fc36374497a3fc541a442ef62f4c078737f38587da5075f)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of values displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of color fields in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_visual_property = quicksight.CfnAnalysis.BarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                            bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        orientation="orientation",
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5be9c71bc4f0d654ac20a5bbe6da636d760d30d24f31ceeafa656d3740e8ebb3)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BarChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BarChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnAnalysis.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9882c44c00b98f84244934928b97576d14928fcaca4cd137de204e890787507a)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html#cfn-quicksight-analysis-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnAnalysis.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bac8aef8e91d470ad7d6600c725555358beca88d2564e0ca1989fc07d33a624)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[typing.Union["CfnAnalysis.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f2e6a0e2f21010f1a21ee7a338dbf4b15b8400726bdd51f0bb565e3b3baaf02)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union["CfnAnalysis.BodySectionContentProperty", _IResolvable_a771d0ef]:
            '''The configuration of content in a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union["CfnAnalysis.BodySectionContentProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionPageBreakConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a page break for a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionPageBreakConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionStyleProperty", _IResolvable_a771d0ef]]:
            '''The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnAnalysis.BodySectionContentProperty(
                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b159076103ac83aeb9afe3cc5234805775e6f54de89783d4ec3965da2ecf5c0)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html#cfn-quicksight-analysis-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80b3f66b1c8db3c0853180de2c02bdabde8dbe2f24f04345afd99d3c3212dfeb)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: ``CfnAnalysis.BoxPlotChartConfigurationProperty.Legend``.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_chart_configuration_property = quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                    box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                        all_data_points_visibility="allDataPointsVisibility",
                        outlier_visibility="outlierVisibility",
                        style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                            fill_style="fillStyle"
                        )
                    ),
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                        box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        )
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__09401b735548bb1c8f51501cc986fbafe8b5d0eb633caa22df4fc0d9c40aea95)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotOptionsProperty", _IResolvable_a771d0ef]]:
            '''The box plot chart options for a box plot visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.BoxPlotChartConfigurationProperty.Legend``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69f1d25071eeb04ee6a5a1ca10e199d929e70ad8d300799af42d83484921e650)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html#cfn-quicksight-analysis-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d64237c90b4cecc7a1048a1e1957642c56217ff8868c333de97cb002cb93bae)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23e21cbd1df61db249465260628453c24d3d228a4848a6cdc3b30c9cdf856875)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of a group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PaginationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PaginationConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6151b8e00edf3a7641ba92b320d0ecff03622895ed48a30b9dc8dbd3b533ce24)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html#cfn-quicksight-analysis-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_visual_property = quicksight.CfnAnalysis.BoxPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                        box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                            all_data_points_visibility="allDataPointsVisibility",
                            outlier_visibility="outlierVisibility",
                            style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                fill_style="fillStyle"
                            )
                        ),
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                            box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            )
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db8cce8fdf5d00ac0b647f1595cf9d506a6a284a6c8431fa47191d0a30961842)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnAnalysis.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7bfd6f661b6cfd4e97f658c5d48104ad384981d9726808eea867cfe6fc0501bd)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__645312aff352ca0a79d8f2ad15df329bfae6cc0352650a11f03ba8df635d3ddb)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc6660ec97236be1685deac267e9a218f5772a5cf8a7847d5614f5961005c3a2)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.CascadingControlSourceProperty", _IResolvable_a771d0ef]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html#cfn-quicksight-analysis-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.CascadingControlSourceProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnAnalysis.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1d749221df183a33fb273249f8fe0c27e23a416ee1a10fc83ed6e5ffb2488d2)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5afb72a523ea06746a9cb7709a1869f21e65ce596c0cc08e2b431a859697b40)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0d70bc90ff9dff58dd8969cb388357560fbd33c712364709136e9a9e6d62a0d)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35a665e669156cdf92fba11790e51baa45536fbbbe89e15f2d09f78a13f45eba)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filter_list_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75a3857a59f643f7359071da924f9680251e0e60538633352c351a09c2d190c8)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomFilterConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomFilterConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomFilterListConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomFilterListConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterListConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterListConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            configuration: typing.Union[typing.Union["CfnAnalysis.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnAnalysis.CategoryFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65020b1fd7f14d714e833c65bd179182689890771c31f28f0005f36de27f12a0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnAnalysis.CategoryFilterConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration for a ``CategoryFilter`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.CategoryFilterConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2485ce955642cf1f6bca219011a24cf15c434b38b96fddba4c2ae4f3711b62d6)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.AxisLabelOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The label options for a chart axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.AxisLabelOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1da19d720a2dc7542b2198ba2d62bc53558adf9c8a6767731ad46c21aa280bf1)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ClusterMarkerProperty", _IResolvable_a771d0ef]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html#cfn-quicksight-analysis-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ClusterMarkerProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnAnalysis.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f904fbb8d2b31dcff7c4c69b07e2faad1dd0f2a233c57874638bbea6845043fb)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SimpleClusterMarkerProperty", _IResolvable_a771d0ef]]:
            '''The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html#cfn-quicksight-analysis-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SimpleClusterMarkerProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            null_value_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnAnalysis.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e5f5ec65ff51308b2e5915c41a999b23acd0e838cf4e4d6a35d6898dc34f634)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataColorProperty", _IResolvable_a771d0ef]]]:
            '''Determines the list of colors that are applied to the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataColorProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataColorProperty", _IResolvable_a771d0ef]]:
            '''Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.CustomColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''
            :param custom_colors: ``CfnAnalysis.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnAnalysis.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0279af7796959bffcf152faea87105bc5ac16303734f6389027c2794d86ac325)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.CustomColorProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnAnalysis.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html#cfn-quicksight-analysis-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.CustomColorProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            colors_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: ``CfnAnalysis.ColumnConfigurationProperty.ColorsConfiguration``.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnAnalysis.ColumnConfigurationProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8d8abf51c8bb04b77c369793bb76858a0fa26ac24580011732c1ab02bfe9113)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColorsConfigurationProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.ColumnConfigurationProperty.ColorsConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColorsConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnAnalysis.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__351024e921e575e48eedc8664b908d18ca08dba1b9203dabef14a74c269b7bc0)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeHierarchyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ExplicitHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ExplicitHierarchyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PredefinedHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PredefinedHierarchyProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnAnalysis.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22b5dc28b60853167659a080d0d5c8c337cb97a332ca139bb3bb120f3ee702dc)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: ``CfnAnalysis.ColumnSortProperty.SortBy``.
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnAnalysis.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d77c6c419ab078a54e80be4b91b5089b7101daf6dacec08cac01a93f3cc2a36)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''``CfnAnalysis.ColumnSortProperty.SortBy``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            aggregation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e709600fba2f99734f3770c61c8184252bbb22a83375e6ad89a0c6dd2785bc7)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The target column of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the column tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            line_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                    bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d42bdea20392b73c45d1ddcbeaf043aca91f44dda1cec880f7573ff741829b4d)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated category field wells of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated colors field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            line_data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_configuration_property = quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                    bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                        combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                            bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f4500b20ac9b1551eb7546d42f67e6c2e8ddad7335fb5a243b5bc4f2f6c19511)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category axis of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComboChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComboChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComboChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComboChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_field_wells_property = quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                    combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                        bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__16a60f14e196fa5024649227b332a50670e171c097863cf05cab57dd488de322)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComboChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html#cfn-quicksight-analysis-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComboChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__abccf99e6b0a53c6ea18786a4e53bb3bf2984d52159a625db5b6f11ecd7d63ea)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The item limit configuration for the category field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The item limit configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_visual_property = quicksight.CfnAnalysis.ComboChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                        bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                            combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98590459d8df4f8ed5afce6680d35ca57653c9aac4b8568773fafa5612b0b8dc)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComboChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComboChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__682cef295d706e92941c15c8551c3e2c3daba0ef5e105c7228dacd26bdc90c62)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComparisonFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format of the comparison.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComparisonFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__682d99eefb4963bd6ef6176b99514a8474d96ac99665fe8dc30de337dfac4dc7)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The number display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            growth_rate: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maximum_minimum: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            metric_comparison: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            period_over_period: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            period_to_date: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_movers: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_aggregation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            unique_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                computation_property = quicksight.CfnAnalysis.ComputationProperty(
                    forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        custom_seasonality_value=123,
                        lower_boundary=123,
                        name="name",
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality="seasonality",
                        upper_boundary=123,
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_size=123,
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                        computation_id="computationId",
                        from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_time_granularity="periodTimeGranularity",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        mover_size=123,
                        name="name",
                        sort_order="sortOrder",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        result_size=123,
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                        computation_id="computationId",
                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                
                        # the properties below are optional
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62f64a292e536c9335c188006ca8c9f36e3903acd05eb907ebe34d9e021dc50e)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ForecastComputationProperty", _IResolvable_a771d0ef]]:
            '''The forecast computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ForecastComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GrowthRateComputationProperty", _IResolvable_a771d0ef]]:
            '''The growth rate computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GrowthRateComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MaximumMinimumComputationProperty", _IResolvable_a771d0ef]]:
            '''The maximum and minimum computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MaximumMinimumComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MetricComparisonComputationProperty", _IResolvable_a771d0ef]]:
            '''The metric comparison computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MetricComparisonComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PeriodOverPeriodComputationProperty", _IResolvable_a771d0ef]]:
            '''The period over period computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PeriodOverPeriodComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PeriodToDateComputationProperty", _IResolvable_a771d0ef]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PeriodToDateComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TopBottomMoversComputationProperty", _IResolvable_a771d0ef]]:
            '''The top movers and bottom movers computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TopBottomMoversComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TopBottomRankedComputationProperty", _IResolvable_a771d0ef]]:
            '''The top ranked and bottom ranked computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TopBottomRankedComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TotalAggregationComputationProperty", _IResolvable_a771d0ef]]:
            '''The total aggregation computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TotalAggregationComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.UniqueValuesComputationProperty", _IResolvable_a771d0ef]]:
            '''The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.UniqueValuesComputationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            solid: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnAnalysis.GradientColorProperty(
                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e76b611c8ca56927ac5c4865b3a3014d60ff601b9f47abc22d846009146a0aca)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingGradientColorProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingGradientColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingSolidColorProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingSolidColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7df3f45f65b6cf57a3561fc3bb719da73c90d809fb18ce43a8939b735120b3db)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union["CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty", _IResolvable_a771d0ef]:
            '''Custom icon options for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f806b1355a495734ae9e83eb07350a5f22234e77cad875cf5cd7b838fa66b969)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[typing.Union["CfnAnalysis.GradientColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnAnalysis.GradientColorProperty(
                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59843d34a1d9e56cc8102590c6f33b3fe4d4a93c9091d1c3b7b4f52b82785092)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union["CfnAnalysis.GradientColorProperty", _IResolvable_a771d0ef]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union["CfnAnalysis.GradientColorProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__239eb497ddfe4666e87b0ff9ca2c56ca71ae66ee4f0603e1d35accb913c4d572)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-analysis-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            icon_set: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40bf78b1527d478f0602991f2696254ce0217b0bcc9686128bb4084a603c7ea2)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingCustomIconConditionProperty", _IResolvable_a771d0ef]]:
            '''Determines the custom condition for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingCustomIconConditionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconSetProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconSetProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bebee13a63606a749964190fa5844b5bbb0ba9fbdd8f6d809f8697b86a61be10)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ce89ca867f206cf0eef0c8b1cacdae6c1ef99c284dcb85977047954a2ef6895)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d26580f9aed18e6f5b9d8ee6eebf4d3330d147fc18381aa5258ccfdce92e490)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa7fe695ec288dba7d9b9fcc425613ee5401b04f66c0f9199927285202694500)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[typing.Union["CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target_visuals_configuration: typing.Union[typing.Union["CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0423f6bf8e7ccb6d4c1dbdab70a3f38ec144057ea3b152bc220f3cfd8cbff603)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that chooses the fields to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6be7e44f397b511b49225a11fdaa284cfc00b5ed929ec79f8b763c141eba032a)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LocalNavigationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html#cfn-quicksight-analysis-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LocalNavigationConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2a429e32dde5c07c1f8c455f0b3e620158faa6275ca16222d552bb07380a212)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SetParameterValueConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html#cfn-quicksight-analysis-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SetParameterValueConfigurationProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1aa70755f38eee20ca627a2439faf92da4e11c82256f373e169a2f84b154021d)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param color: ``CfnAnalysis.CustomColorProperty.Color``.
            :param field_value: ``CfnAnalysis.CustomColorProperty.FieldValue``.
            :param special_value: ``CfnAnalysis.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnAnalysis.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8566f6a3bc8520cae7cb85a406b8beff98064a531dd65aa07565dbece414af1c)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''``CfnAnalysis.CustomColorProperty.Color``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''``CfnAnalysis.CustomColorProperty.FieldValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''``CfnAnalysis.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62e8951e1d28fa8a78b6f80e13ba53e3bc46a89e076ea54f562d0d170366b63b)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnAnalysis.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccc5671c89a0456bbc22979a97553e30042ed13b4bfefc86cf5ec16ea8f3baff)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomContentConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``CustomContentVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomContentConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00768fad52642912baf50643607ba52dffaf992d8c8faf071bf0d252c5149010)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41118b5e69e4c03375c683ffe4f60144c69e89801e1231214b4515bd2215527f)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57f6d0fc7a75c60544b0338760d38f94cf72934df89053d710784833d2145774)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html#cfn-quicksight-analysis-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnAnalysis.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcf723c81d5d8d32f360f6ecdd30e47ea87f29e7de87e71b26b8df340ac3ea84)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[typing.Union["CfnAnalysis.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: ``CfnAnalysis.CustomValuesConfigurationProperty.CustomValues``.
            :param include_null_value: Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2ba7731fb545cbded8dbc6e5b48904169ace796baccd5597789dfad6f354b2e)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union["CfnAnalysis.CustomParameterValuesProperty", _IResolvable_a771d0ef]:
            '''``CfnAnalysis.CustomValuesConfigurationProperty.CustomValues``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union["CfnAnalysis.CustomParameterValuesProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnAnalysis.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ecf40732730e24b9319a09a45bf4e3dc2176c140368f2f7783545ceb408e8b88)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnAnalysis.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90de61c177153edbd899b5825d8f7d732aa16df3542ef31ce3fd25c6dad481bd)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d441fb462d64eedbafd74716c3c06d6e4f29cf1cf44f330644af189d63c7d05f)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param visibility: Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnAnalysis.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66e0fa2e530d1ace3b21559d4101409f15ddc2f4ff0510c1bacfaae3c8d3405a)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataLabelTypeProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the data label type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataLabelTypeProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Determines the font configuration of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_label_type: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maximum_label_type: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            minimum_label_type: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_ends_label_type: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnAnalysis.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bbc6ae98f605c19e60a88b2510ec872375ef1e56ec7644100c45528a8ac2090c)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataPathLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''The option that specifies individual data values for labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataPathLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FieldLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the entire field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FieldLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MaximumLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the maximum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MaximumLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MinimumLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the minimum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MinimumLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RangeEndsLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RangeEndsLabelTypeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnAnalysis.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b9d8953dccc6499b2135ceaf21c1049c06506e06d61c3e165a4860d0b5e3389)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union["CfnAnalysis.DataPathValueProperty", _IResolvable_a771d0ef]:
            '''The element that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DataPathValueProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b09a64eceb6cb69ed5c6a955433b2d9263228e5d005de6f106862553f4a15c93)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnAnalysis.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e6b106036bc2b3ac9052f080a5219e5dd1b7412d782e555ef85e8dbde88a588)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataPathValueProperty", _IResolvable_a771d0ef]]]:
            '''The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataPathValueProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "field_value": "fieldValue"},
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            field_value: builtins.str,
        ) -> None:
            '''The data path that needs to be sorted.

            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnAnalysis.DataPathValueProperty(
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__298e07536e948e00dbacd78d1692ac143808db0fb37aee934bec572e2f419115)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "field_value": field_value,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> builtins.str:
            '''The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            assert result is not None, "Required property 'field_value' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_set_arn": "dataSetArn", "identifier": "identifier"},
    )
    class DataSetIdentifierDeclarationProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            identifier: builtins.str,
        ) -> None:
            '''A data set.

            :param data_set_arn: The Amazon Resource Name (ARN) of the data set.
            :param identifier: The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_identifier_declaration_property = quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d60a1340d7a156e8506a919181e6b3e00abdc9b650553a02eb31215d288c22f)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "identifier": identifier,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def identifier(self) -> builtins.str:
            '''The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-identifier
            '''
            result = self._values.get("identifier")
            assert result is not None, "Required property 'identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetIdentifierDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnAnalysis.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f058446b10406aee16fc1f5a5d863b779c510706b5ddbbe5bbe2b296e4614fe8)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnAnalysis.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d3c638cf4e6ad675c29276b1b7a0e7a7734850ad86761fdae0ed3d1e281ad6d)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html#cfn-quicksight-analysis-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnAnalysis.DateDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c38a1ab2c4d2403b5f46d07fbfb4fdda6000c90556256d583f75b16b8e69c97)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``DateDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnAnalysis.DateMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7eef7426bd5a3bbba12b8015a14dc6dff0e9114ad85432497da7276516161a54)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``DateMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rolling_date: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc68cc4b44182fb270edb27691fedfe8353e7d33fc7d7164037829eff51fdffc)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RollingDateConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RollingDateConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85473c86a1a255b90de6bc6e57417f31d7e506474c7c0a2494c682a0f43f5c28)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12bc810e2440ff358854e0e6b28638ab9f14a29b15e53e36d0cad66d0e725d2e)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__215bc3d836ba80156c1d09050fb61a4ac14687c483d1f9898b96930dd5f8c2ac)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnAnalysis.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimeParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DateTimeParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A date-time parameter.

            :param name: A display name for the date-time parameter.
            :param values: The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_parameter_property = quicksight.CfnAnalysis.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90c38037b70752fc760d926efa18be9c7e893ed9da177445114b0ee46f29907a)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__650f02af439c5263accb9696ad579428ffb5e17b926240b4ef633f148cfa97ae)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9c1eb7bd72d4631979e43530390cd40366f425965677f236f931aa45cb6d404)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c322e0caf9e5a767d0bd137ae84120e34bfcc734a3d658620313ee14d746b2f)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.DecimalParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d26b7eb6485113c1fdf15f502ddd91b466696e9c49265a01502e2dabe1f6d391)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DecimalDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DecimalDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnAnalysis.DecimalParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DecimalParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DecimalParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
        ) -> None:
            '''A decimal parameter.

            :param name: A display name for the decimal parameter.
            :param values: The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_parameter_property = quicksight.CfnAnalysis.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__652eed12a68ef9b9b4990f823ad3a67229565474d9e1b173d0e80decad69836c)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]:
            '''The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2c0dc1ccafc3f97fdab40bb9e003a63a9ac774f79bd7789f5f0e4a2a8bdeb4a)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html#cfn-quicksight-analysis-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7dad66fcbb0c7b497d09467d1b77270f6c4b6522edab3505c59c082a3fc9aca5)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95df51aca1084f074b94a4f4709af37a474cb4e9af1afaf77822a76ecc95a005)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html#cfn-quicksight-analysis-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd37d8eabc8bfec95ed4b58b81155df777ab165077b4efd54e6f1dfc04f9b3d5)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html#cfn-quicksight-analysis-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__556ea9505b528e261ec32965610d0e91b6f85015cb9c25d4ae15d47334adfb7e)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DefaultGridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DefaultGridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8911a947c977b10c2a2a68056f982f496dfd746874067609f8c6d444d1276eff)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for interactive layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b28bc8b0eb019bd9ccf611d0a57c4f1f632364d72ecda1bd852620509911c67d)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-analysis-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23be3dbd69b3e258c5e038afaf6d0f0c64f453022269967190b318b727557245)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__532d4f54bf744fe5b8d37880e79c350887cadae5b9ea9fa72542af3a68fb75ef)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomValuesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomValuesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            date_dimension_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnAnalysis.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b610f908e79aaf15fa2663699448c61694ca017115bbe3a23312fc19ec0742c)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CategoricalDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CategoricalDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericalDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericalDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a054c60616e4456c14aadd17a0239fec854060b84e1ed909d318d0853718a10)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html#cfn-quicksight-analysis-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            donut_center_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnAnalysis.DonutOptionsProperty(
                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc51f4747a2cd1ef04ccfda67b6d10c6283180ac939f1c563ccaefdf5443e95c)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ArcOptionsProperty", _IResolvable_a771d0ef]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ArcOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DonutCenterOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DonutCenterOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_range_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnAnalysis.DrillDownFilterProperty(
                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ecb6731fb1e8c725764d12b90f4a66d57279842a8d7d12f5f615007448625a2)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CategoryDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CategoryDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericEqualityDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericEqualityDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TimeRangeDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TimeRangeDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            select_all_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f51501f49b26832df8b172250adbd3de0016118dc154b557d7d710eecc93292f)
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            group_name_column: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            user_name_column: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1754ded9164236abb5f4e07ed739f4a6e1fb4706dd2d278dbbaaf1d32c16270c)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that contains the default value of each user or group.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column that contains the group name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnAnalysis.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93bab7069456b6fc2704172867034473cfddbc2f5c84a6d617caca914dbf52f4)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                entity_property = quicksight.CfnAnalysis.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e984d6b504bbbc522408ebf5a05a3ca55554f3a7466d8181ef9662471b5a2e10)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html#cfn-quicksight-analysis-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce759234b535c1eca0eea5fd23dbbfc67639d262b6c795f78d10bb537e90bbb3)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2480a5070d15fd21023f9d3b134d410bf3c98ad768d30d8fa19a4266dc6740b8)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The list of columns that define the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b831e64c60237dcfc735e6a15fe88d2b2a014337863495585f80d09c33df4f9f)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TooltipItemProperty", _IResolvable_a771d0ef]]]]:
            '''The fields configuration in the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TooltipItemProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnAnalysis.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8012ead27d550c0980c4ccbb1883e73749204435b06c49145606a132fe3830ae)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnAnalysis.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de1a8481c168e03c44d6ce8ffccf3b4b4a153ce2a8400ee7c8b9641eddbb042d)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_sort: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FieldSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnAnalysis.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__beb0832639b263b4c786585563c24c8227a0ea2ad8542b29ec38917ca8bccb1f)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnSortProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a column that is not used in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FieldSortProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FieldSortProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnAnalysis.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1cad1ad95d7c8278bb57d2ae388569b2fc47fc4a0e4c9b70da73804123dc40f5)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnAnalysis.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d49b7f6119094b47d7c3f702dc3a09a681617dc75e3c8b7121f7fe130154b3fc)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ddc61cc5ed05bea21b9556c9a4edb59718aab29a9f70189a4ecc27726188199)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[typing.Union["CfnAnalysis.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__892c5cd415731015d172e9510780d0cfb2949109c4ae12679a06229db3d6f3d4)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union["CfnAnalysis.FilledMapShapeConditionalFormattingProperty", _IResolvable_a771d0ef]:
            '''The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html#cfn-quicksight-analysis-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FilledMapShapeConditionalFormattingProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b23f41a632049ca35c080b29bc38536e01cd184ebc8e373acd3943695d5dccd)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilledMapConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html#cfn-quicksight-analysis-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilledMapConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_style_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            window_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_configuration_property = quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                    field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                        filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1632e9f6701ac65e9bab30f541852434d3af064352024f1ec60c7e3d2281e98)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilledMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilledMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The map style options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilledMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilledMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bf27367e7b552317f2584b4a66ab9a7640ea058c7820d8c52bbde9aef1b1fb8)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilledMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html#cfn-quicksight-analysis-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilledMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c63bac9d23e36f661fd998066e4a8d228db192a93b6d0d824e6c105271d62af2)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ShapeConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ShapeConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2bccda02cff591eaec2d68cc09c6f38991b0a584cff334e067227a58d72806d2)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html#cfn-quicksight-analysis-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_visual_property = quicksight.CfnAnalysis.FilledMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                        field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                            filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                            shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce04807350b7e095877a3bb608d4661f077f6b2e6070f06c3361b9759eca187b)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilledMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilledMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilledMapConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilledMapConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            dropdown: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            list: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_date_time: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            slider: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_area: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnAnalysis.FilterControlProperty(
                    date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnAnalysis.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2fe2227bad93bd042d834f88099cd07e5ac4c742a3dffd833afaf7601cf09c8)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterDateTimePickerControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date filter that is used to specify date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterDateTimePickerControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterDropDownControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterDropDownControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterListControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterListControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterRelativeDateTimeControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date filter that is used to specify the relative date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterRelativeDateTimeControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterSliderControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterSliderControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterTextAreaControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterTextAreaControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterTextFieldControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterTextFieldControlProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af1310e52f1fe058fe6864e5c686c953d0bfe5bd870c9c6450843edcb6be192a)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnAnalysis.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__894a7482d4620719c3e5c37e5b3354bf6ba7e6b13407f045ce033b3829c6db50)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            scope_configuration: typing.Union[typing.Union["CfnAnalysis.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_group_property = quicksight.CfnAnalysis.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnAnalysis.FilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0cad743a793c8938913f7296b9b44e64305ce8e4ebacc534f49fe92867dfbcb)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilterProperty", _IResolvable_a771d0ef]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilterProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.FilterScopeConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FilterScopeConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnAnalysis.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd242678159eae1db6298e77984712eff2126d709601f844e5b5a82940fc3278)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnAnalysis.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f05e5432f01b720471b698ee317bef523bc0fd233680ea3a02ba6ee02d2260d6)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da8225524d681f79d86c40f7f34f6536eb74cb837e28f4a1f6de4a10f7ed14c6)
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd3ddb0f83f2fcb19b265f1f209a8143d47cf88909ee824f3c5d16d76cc49d80)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SameSheetTargetVisualConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-analysis-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SameSheetTargetVisualConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_range_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_dates_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_equality_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_range_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_filter: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_property = quicksight.CfnAnalysis.FilterProperty(
                    category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection"
                        )],
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4adc43c90ecbe9167d209e3a5dda471c694ba167e1b994985c17fb610dfb4510)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CategoryFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CategoryFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericEqualityFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericEqualityFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericRangeFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericRangeFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RelativeDatesFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RelativeDatesFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TimeEqualityFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TimeEqualityFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TimeRangeFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TimeRangeFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TopBottomFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TopBottomFilterProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1419b1e1dc95b6b8bd0d44a95ab71dbb2cd55ab54918f9a06878935f588fd7f2)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            selected_sheets: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_scope_configuration_property = quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                    selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e52317128bb33fb4d030bfb601ad11d86e19228e9824be1fb4d6821a56805a9b)
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__588b56f04c6a4481108ee74544d1c0cc9d60ae5d83889e49891b7497b18f8c16)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html#cfn-quicksight-analysis-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnAnalysis.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__640851d91ec07732a2a822be542adcb96fc6251b53208fb577aadafe482230b3)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35ba14eb21d1758a62c8b39419901e47a41169a72a0a6ca951a568628845f91f)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f9848fb8f7cfed636317939402fb560b21fd710769007a6339352eee5689282)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontSizeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontWeightProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnAnalysis.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff292b59f91cdecd5d8b04ace2132873679de34d29f798dc62a5783102e4ca4c)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontSizeProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the text display size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontSizeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontWeightProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontWeightProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnAnalysis.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__411edb61c9362aeaee9a4091af90cc20542d3b666284c34838a03cec6c4bb42d)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html#cfn-quicksight-analysis-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnAnalysis.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c1b2a9aa6bb3d687bcd0169fb03f34ca0fdfcf645101e0974a8d97f69a95ad3)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html#cfn-quicksight-analysis-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_computation_property = quicksight.CfnAnalysis.ForecastComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    custom_seasonality_value=123,
                    lower_boundary=123,
                    name="name",
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality="seasonality",
                    upper_boundary=123,
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f565280044f0435704d45e9ad5a88e94868f5206d156de896e57dfcf07a0d542)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scenario: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnAnalysis.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa60baf7b756220760f00d8fac6a78fc80cabe9fde935f87f3c867df31f9fd24)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TimeBasedForecastPropertiesProperty", _IResolvable_a771d0ef]]:
            '''The forecast properties setup of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TimeBasedForecastPropertiesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ForecastScenarioProperty", _IResolvable_a771d0ef]]:
            '''The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ForecastScenarioProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnAnalysis.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d65ce0dec6eab3e3eabd565a21e513ec56e250c822180474bc6278096b0665af)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WhatIfPointScenarioProperty", _IResolvable_a771d0ef]]:
            '''The what-if analysis forecast setup with the target date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WhatIfPointScenarioProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WhatIfRangeScenarioProperty", _IResolvable_a771d0ef]]:
            '''The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WhatIfRangeScenarioProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            string_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnAnalysis.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7f892a89f8b7f4bab1995d12b95f22a697d6b152000702a161fb8dae024df42)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for number fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8256a6c9379474c289275e0900e25b2639cce3839a683606966ada2bbd9feaf7)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: ``CfnAnalysis.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d8c9190438b56832176295290920e07dba3b5cf17f71eb698ada5bf9f625155)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c201e761738bfa24ea2246e4322018d2033440178bfef4262f512148a2696de6)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__877d3ec0c7b38dd958df159597169252cfcf484c5580aeab44c705d2e6597b29)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            border_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            loading_animation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rendering_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            selected_border_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9fd740a8b63e82a6063cc7b5d61e01d714922deb79cc177bdb68e3550294c91e)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty", _IResolvable_a771d0ef]]:
            '''The background style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LoadingAnimationProperty", _IResolvable_a771d0ef]]:
            '''The loading animation configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LoadingAnimationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetElementRenderingRuleProperty", _IResolvable_a771d0ef]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetElementRenderingRuleProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9b2fcd65cc44705d5f024a8732b2fba67ff1a87216d9438f1ce599bbde2144c)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3420223f38c7519fd61e1e6887bd491271e2536dbf7285207d6134cc3fd93f1)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html#cfn-quicksight-analysis-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2933bdc1dea07007617576d8a4f5cf6a6f373b190358b785757716429e221b50)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_configuration_property = quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        label_color="labelColor",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_data_label_style="measureDataLabelStyle",
                        measure_label_visibility="measureLabelVisibility",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                        funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3945152b6a7a4ca1827ea7fe83f4c8e8032f486da046f3897a84b0e666258888)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FunnelChartDataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FunnelChartDataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FunnelChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FunnelChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FunnelChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FunnelChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14fe6d244a0b386f413e8942ca91aa67dfbc803bb47692efa5b7434d963ce34b)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8a414747eb2f1fbd3c5b194cbe49662c2177d6ab79da32cd9885ae81020cedb)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FunnelChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html#cfn-quicksight-analysis-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FunnelChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6dc8cdb1531ae382e2f7bbfb83f495b137a29a2984dbed08fc6a592d8058f3b)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_visual_property = quicksight.CfnAnalysis.FunnelChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            label_color="labelColor",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_data_label_style="measureDataLabelStyle",
                            measure_label_visibility="measureLabelVisibility",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                            funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9d816303d366cfe2ff8314a6e844322076e8645c3e525d3de55602180fab1215)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FunnelChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FunnelChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c3fa62a14e6e214db7be498151486eeda9b906f7c6e64939fc4a2a3d0f13c22)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html#cfn-quicksight-analysis-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e86ea78440a51da451a5763e4417ae8eecb9164d3ddde2b3555c5de835e9251a)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartArcConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartArcConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d275515ebd3a341f8748b13cb49b24877bbf483c1d2346700a09ea427c0d2f34)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.GaugeChartConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html#cfn-quicksight-analysis-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.GaugeChartConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            gauge_chart_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_configuration_property = quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                        arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                            arc_angle=123,
                            arc_thickness="arcThickness"
                        ),
                        arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                            range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                max=123,
                                min=123
                            ),
                            reserve_range=123
                        ),
                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        )
                    ),
                    tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d80c970544a22d7bf778955ad32cf57017f72bb7a468a9e24de7e34f7b301adb)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_field_wells_property = quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f758fbc36e0cb888a922b977ed89082c0122722999188b0440a912f4496db99c)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            arc_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            comparison: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f46b192dbfe22619341a75f9e4746458d8a28d84aa81a94e39f20e4cbb283527)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ArcConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ArcConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ArcAxisConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ArcAxisConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComparisonConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComparisonConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7fa5c30d8fd436ee37ea535aa08069bfeec82d3a1ed05dc5e7b7a8feeff71164)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_visual_property = quicksight.CfnAnalysis.GaugeChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                            target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                            arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                arc_angle=123,
                                arc_thickness="arcThickness"
                            ),
                            arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                    max=123,
                                    min=123
                                ),
                                reserve_range=123
                            ),
                            comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        ),
                        tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                            arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d98982b6ebe2494ea2c36af3f6ae0b796496069c456d197787af1a3ec9ddaa45)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02333dc189af20f712cd5bbf2b3255523578efceda7a3cdd05c8ba2812e6c076)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_aggregated_field_wells_property = quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76dba5af45784ec2dd551fc875a34c13059ff95c36bb0d37962f48485e23761c)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field wells of a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_style_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            point_style_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            window_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: ``CfnAnalysis.GeospatialMapConfigurationProperty.VisualPalette``.
            :param window_options: The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_configuration_property = quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                    field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                        geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                        cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                            cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                    color="color"
                                )
                            )
                        ),
                        selected_point_style="selectedPointStyle"
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f3b362d91fa9343feee3a01a06f46caf5d15bd851901933c4231d26cd9956288)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The map style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialPointStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The point style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialPointStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.GeospatialMapConfigurationProperty.VisualPalette``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_field_wells_property = quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                    geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ecce52236a28a16d71cbf639780d05e3d382234b062997aa802ca2e63f852684)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html#cfn-quicksight-analysis-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e430915449a89989ea2c21470dd0ae53fc61708a07e47c3932a2b7cca30ae62)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html#cfn-quicksight-analysis-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_visual_property = quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                        field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                            geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                            cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                    simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                        color="color"
                                    )
                                )
                            ),
                            selected_point_style="selectedPointStyle"
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cbc319112c0c441e1ef1a3cca707bcf5d01743f300a1497825a00438293bcbd)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ec5903443c5ff711d384260e886d4f650c86f361f5ba87ff242fcd484be2fe4)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ClusterMarkerConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The cluster marker configuration of the geospatial point style.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ClusterMarkerConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04fcffa2217c2f3743e4dc6f7aecf3b11eb2cc588b0e50af8e615e24884a360c)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialCoordinateBoundsProperty", _IResolvable_a771d0ef]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialCoordinateBoundsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            uniform_border: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8155fd68f28f9430f87d73a687b0afe29327e6e7467d3fe7b6fc97430090f3a0)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableSideBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines the options for side specific border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableSideBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.GradientStopProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnAnalysis.GradientColorProperty(
                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00a735f8edd0fb593aad9b3315f3321ae115ec4c45630e92208e5ccdc9d3583b)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.GradientStopProperty", _IResolvable_a771d0ef]]]]:
            '''The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html#cfn-quicksight-analysis-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.GradientStopProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value.
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnAnalysis.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6fccd8dcb764e31e23d89ca6cb7131d866e2f1490512d4b179a315a75f241b4)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af7a6713a39bf8fc0cdff25aaa609f84189527234a7e191a8f1f6d29939fe733)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: ``CfnAnalysis.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9ab8ea8bc5a1d472d11e9a461b8f033b789db6f839a00252cbacace4f0464d1)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.GridLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.GridLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnAnalysis.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ad24404aa2878c80858f4f1de3c30e67a2d9adbf7cf7792a485de35d87c5008)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91ce74986bc59019fd3ac6a1f475bdddeb6894ff7bfa5458b4883a2393a17d79)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_size": "periodSize",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnAnalysis.GrowthRateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9423e946bbd45a2a6283b00d7771dc7bb8844aae578c9f4c3e976a14de2b3b93)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e3cea29b7336b509b93191dfac0fd832d2c191d1b6cd0541d34156792d43ec6)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The layout configuration of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union["CfnAnalysis.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionStyleProperty", _IResolvable_a771d0ef]]:
            '''The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_aggregated_field_wells_property = quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__215a381413cbf86cbf3543c40c76148cde251896d980d58c42b82f2b3c197c99)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The columns field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The rows field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_configuration_property = quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                        heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                        heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f579c2d814c01729dec18d52a8696e1e23cc2dbdd84a4625b947cd12aab3645)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColorScaleProperty", _IResolvable_a771d0ef]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColorScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the column that is displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HeatMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HeatMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HeatMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HeatMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_field_wells_property = quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                    heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45d9cd75868764cfdb40dd52dc0962b783ec39bdf1988e8c8db23b60958ce7d6)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HeatMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html#cfn-quicksight-analysis-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HeatMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b126166e544643a33201e1a043799ab91762b3636d845100839cdc378f760c3)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_visual_property = quicksight.CfnAnalysis.HeatMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                        color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                            heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                            heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b168fca3b7ab01dc4c3e1b2bccf10ed988c1b719627c201665866a890760e518)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HeatMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HeatMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3daa060ee9cc8312c472ca370953aae68813c235fdf3bb9413124d5c7cb4007)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html#cfn-quicksight-analysis-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            bin_width: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5019cb990a3a1f70353f91139b3ac1257d8e404a35edd4db4da8ff1e4c5a8dc2)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BinCountOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the bin count of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BinCountOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BinWidthOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the bin width of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BinWidthOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_configuration_property = quicksight.CfnAnalysis.HistogramConfigurationProperty(
                    bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                        bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                            value=123
                        ),
                        bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                            bin_count_limit=123,
                            value=123
                        ),
                        selected_bin_type="selectedBinType",
                        start_value=123
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                        histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a54b563b48da23bdc9d671134bda86143896565c2f4fecf3c4e53201f07a42cd)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HistogramBinOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of histogram bins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HistogramBinOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HistogramFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HistogramFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5561572424a2f728f3c8526ab3ad13cdc48d835d784327351ac32170cc6e7854)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HistogramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html#cfn-quicksight-analysis-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HistogramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_visual_property = quicksight.CfnAnalysis.HistogramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                        bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                            bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                value=123
                            ),
                            bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                bin_count_limit=123,
                                value=123
                            ),
                            selected_bin_type="selectedBinType",
                            start_value=123
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                            histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        )
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ef5c52194094d79ff91e4847f5b3803faefda163605f0bae98ddf060e165d9e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HistogramConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for a ``HistogramVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HistogramConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            custom_narrative: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                insight_configuration_property = quicksight.CfnAnalysis.InsightConfigurationProperty(
                    computations=[quicksight.CfnAnalysis.ComputationProperty(
                        forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            custom_seasonality_value=123,
                            lower_boundary=123,
                            name="name",
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality="seasonality",
                            upper_boundary=123,
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_size=123,
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                            computation_id="computationId",
                            from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_time_granularity="periodTimeGranularity",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            mover_size=123,
                            name="name",
                            sort_order="sortOrder",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            result_size=123,
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                            computation_id="computationId",
                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                
                            # the properties below are optional
                            name="name"
                        )
                    )],
                    custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                        narrative="narrative"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e99716ac0d8901aed28d2f14a53c2c228771bcda558fa896d5e56a331ead1e85)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ComputationProperty", _IResolvable_a771d0ef]]]]:
            '''The computations configurations of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ComputationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomNarrativeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomNarrativeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            insight_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                insight_visual_property = quicksight.CfnAnalysis.InsightVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                        computations=[quicksight.CfnAnalysis.ComputationProperty(
                            forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                custom_seasonality_value=123,
                                lower_boundary=123,
                                name="name",
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality="seasonality",
                                upper_boundary=123,
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_size=123,
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                computation_id="computationId",
                                from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_time_granularity="periodTimeGranularity",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                mover_size=123,
                                name="name",
                                sort_order="sortOrder",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                result_size=123,
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                computation_id="computationId",
                                value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                
                                # the properties below are optional
                                name="name"
                            )
                        )],
                        custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                            narrative="narrative"
                        )
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__87be197f1b8ddc00ddee843af95c500f3691c83c18279f319c73b3f4e9af3612)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.InsightConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of an insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.InsightConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be8cd521f7fadad88e20e1059f4d2a41535fefd8da90f16cb536955184c993f4)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.IntegerParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3bf525c201063a19747a5e1797e139c1a14f211de809356872e7f2c68f00dea1)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.IntegerDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.IntegerDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnAnalysis.IntegerParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.IntegerParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class IntegerParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
        ) -> None:
            '''An integer parameter.

            :param name: The name of the integer parameter.
            :param values: The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_parameter_property = quicksight.CfnAnalysis.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e5658f80863f15a78ea397efb6e375a57b8582cf08b46140c79153452ce1c07)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]:
            '''The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27ff0fb7edc54d24385911265e11bc5f5495724278fba79cc95dab00cd2a341e)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e51a0f5aa6922d5fe928fedf21e9f73bc04f48ad3b9d07186c64aaf2a734c636)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"primary_value": "primaryValue", "progress_bar": "progressBar"},
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            primary_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            progress_bar: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__417dbc6cf68856a089b9865d7db129b5a3b990db90ed98a98c26350b1f26f957)
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIProgressBarConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIProgressBarConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__639d31d517c2ccefe2aaa4b42519e66c63401e77855ebffafc034779bc395aff)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.KPIConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html#cfn-quicksight-analysis-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.KPIConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            kpi_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConfiguration_property = quicksight.CfnAnalysis.KPIConfigurationProperty(
                    field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                            visibility="visibility"
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                        trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd72ecad4ca14cd031e822265c96c00b6aac2a2c24d33fbe8e68d5e3e667c7c1)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPISortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPISortConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            trend_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIField_wells_property = quicksight.CfnAnalysis.KPIFieldWellsProperty(
                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__438e6598a83da91d5b1647fdf99d9f89e3dd1ec74ea5210525cc9e0463820257)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The target value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The trend group field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "trend_arrows": "trendArrows",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            progress_bar: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            trend_arrows: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnAnalysis.KPIOptionsProperty(
                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0086e5ad4f12b3d38df98a4d4b35000f0a83ba1c151592e5b875324cf1e0846d)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComparisonConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The comparison configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComparisonConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ProgressBarOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ProgressBarOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SecondaryValueOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SecondaryValueOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the secondary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TrendArrowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TrendArrowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28b4b072f48698e88384ebb6a4b482131a4cae2e6bb8f59342ff52d24836ba05)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value's icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6aeb9f101d9fda4aef98f8deb1c966b8a920c6738c0b6556e1a66c130151ab5)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html#cfn-quicksight-analysis-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnAnalysis.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e95a2be833aac9177a3dc61cdf2f6b73af942e358d3ccef7b7e057687ab4c74b)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html#cfn-quicksight-analysis-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIVisual_property = quicksight.CfnAnalysis.KPIVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                        field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                            target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                            comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                visibility="visibility"
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                            trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                            primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__049ac2f0f73aace01ae9537bdff4c09cfa4fa497012fe41cb394fcceae32eeba)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnAnalysis.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69bc668401cbdac94031184eed05ef1d6615cf2cf0e4a6cd218a20ac5c1a2ad2)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid_layout: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            section_based_layout: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnAnalysis.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                            content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnAnalysis.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnAnalysis.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d910114ac6b35b763696775fb943168f337e2dcba3a670dadca6ed67acb5fc7)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[typing.Union["CfnAnalysis.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                layout_property = quicksight.CfnAnalysis.LayoutProperty(
                    configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnAnalysis.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnAnalysis.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__161fd02786fb24ad982328bde216dd1aed4821f4931682a9b978ac86df412bf9)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnAnalysis.LayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html#cfn-quicksight-analysis-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.LayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnAnalysis.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__147c5a9c400ba3c744a07cf5fc319a9236bbb47fbe2d26c58d61c60a497844ca)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The custom title for the legend.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5c55a7d483e6c06130495e9fc8b2c5cde7054f59b6af57a656912eb8f188bb1b)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            default_series_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            forecast_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            series: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_configuration_property = quicksight.CfnAnalysis.LineChartConfigurationProperty(
                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                        axis_binding="axisBinding",
                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                        line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                        forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                            lower_boundary=123,
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality=123,
                            upper_boundary=123
                        ),
                        scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                            what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                date="date",
                                value=123
                            ),
                            what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                end_date="endDate",
                                start_date="startDate",
                                value=123
                            )
                        )
                    )],
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    series=[quicksight.CfnAnalysis.SeriesItemProperty(
                        data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        ),
                        field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        )
                    )],
                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                        category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    type="type",
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52cdfe8ce1226c104752c7cda292d3d38a62a435b229c207e089664c0af5750e)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartDefaultSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartDefaultSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ForecastConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The forecast configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ForecastConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference lines configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SeriesItemProperty", _IResolvable_a771d0ef]]]]:
            '''The series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SeriesItemProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            marker_style_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__532f101ba59b6ae500421a96edd2253fa287fb029083b4a563c2ff810889d5bd)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Line styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_field_wells_property = quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                    line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3824f70a439f1d6054f49ec93e76ecd231c4bd5d4fc2e755543015abdb82ec0)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html#cfn-quicksight-analysis-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f73139b3e75d78825269f0ce460d33b3518101781a6f4d76c15473dc10561e91)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__425352a4700680287a24d341a398f5a75b982c8fcab574d455bae844333e50e7)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            marker_style_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__996bf8cdb08f1f86264f9fc9c1bcdb8854c9200086785feacf03d84659ca72b0)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__190cba373e078cab131ac042a82935bf348b4d6c795058ad20b988ec29838a42)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_visual_property = quicksight.CfnAnalysis.LineChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                        contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                            axis_binding="axisBinding",
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                            line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                            forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                lower_boundary=123,
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality=123,
                                upper_boundary=123
                            ),
                            scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                    date="date",
                                    value=123
                                ),
                                what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                    end_date="endDate",
                                    start_date="startDate",
                                    value=123
                                )
                            )
                        )],
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                            data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        series=[quicksight.CfnAnalysis.SeriesItemProperty(
                            data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            ),
                            field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            )
                        )],
                        small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                            category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        type="type",
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1170f6d9a3bf20455146f69c585396abe87561411c24c18b731a77048840ad4)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2302f0b46bff1f5c9e446d0d4ac051b141993001095b996bdb1b423592b56aa)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the line series axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MissingDataConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MissingDataConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            search_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f10289047022a7f828518d52af4ced380e632f244c6b363fcdcf6001ddaba74c)
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ListControlSearchOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ListControlSearchOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b67dfb7d1f03aaaff7f88639feb1894972a0d76266bb603e9c67a9c8ad3ac5b8)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html#cfn-quicksight-analysis-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a1c0626c3cb2d7a4257e96fe1718006a4b42e6c612f0db6f5a62e76a428df1c)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html#cfn-quicksight-analysis-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnAnalysis.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd830ca7ead0f4493c80ab9a601c222384021ef1fa35dfa5f897519e853b2838)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html#cfn-quicksight-analysis-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da87290757fa719668a3dffb9c28299808825fbe461b4e19db3f7d467ae016ec)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html#cfn-quicksight-analysis-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnAnalysis.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69bd96f2d4a96b2084086d87b49b9f1cde967370756b047fdbd292bc7f730276)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''A dataset parameter that is mapped to an analysis parameter.

            :param data_set_identifier: A unique name that identifies a dataset within the analysis or dashboard.
            :param data_set_parameter_name: The name of the dataset parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e35916c7a4e35ca4db751bbff9ccf32d0964841ff6ae843441ae11c32a4ceaba)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''A unique name that identifies a dataset within the analysis or dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''The name of the dataset parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__16653aa16e239e0c7c9ac20fe3ec68e87d59863bbbfa03e318ec051358f63d5f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html#cfn-quicksight-analysis-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "name": "name",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__54884ebef2e6b170d447ec5cc31ca484fc66be31f854d92c6be0421382c4181d)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            categorical_measure_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            date_measure_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numerical_measure_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnAnalysis.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e83ef96400cffcba5b395f1bb9748cfd07bec1227dc1a3d3fb7cde42edb10b6c)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CalculatedMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The calculated measure field only used in pivot tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CalculatedMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CategoricalMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CategoricalMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericalMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericalMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "target_value": "targetValue",
            "time": "time",
            "name": "name",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target_value: typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                metric_comparison_computation_property = quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                    computation_id="computationId",
                    from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bbe1df5c0b5c82f535456b96aef811b16c21d69a214d3f219b5c4d7220be3006)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "from_value": from_value,
                "target_value": target_value,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The field that is used in a metric comparison from value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            assert result is not None, "Required property 'from_value' is missing"
            return typing.cast(typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The field that is used in a metric comparison to value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            assert result is not None, "Required property 'target_value' is missing"
            return typing.cast(typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__34d1c26c06a1371c70b32906d0c70ecb615aa68027628d49e107feea60549df1)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html#cfn-quicksight-analysis-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a743eb1150f9cba0a92cd3c03d082c9789239bc203e6408df1c40c70d1f742f)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html#cfn-quicksight-analysis-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__364c822c55d87fda32eddb927358c05290a3e37899b5292121f94fa89712ceaa)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html#cfn-quicksight-analysis-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7d44813a127a7e6d24ced9e8e8a843eee3845908d7ca6fafcf20e7b30171a63)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html#cfn-quicksight-analysis-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ba87f731fc70065fe71c83dd0e51448a2340f44cc0d0f2cce91019779053b9c)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e85bee9b9a9c6778f2a8625b12da9959db137c08188b191948ed8d27bec3f6e)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html#cfn-quicksight-analysis-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scale: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73ecad0da270316ab79b7505243f7ee26f198fdc7936908258452bf6cbb91fc0)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayRangeProperty", _IResolvable_a771d0ef]]:
            '''The range setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayRangeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisScaleProperty", _IResolvable_a771d0ef]]:
            '''The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisScaleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b7899b4fc311359c5bc341d680e0156997a0e2249cb08251561e5b75e11602b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__193cdd7fba9a7cef83319ba94f6196936a20b1c5e325a2dbcb14ccd09a0d3676)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac78401a9ec97451087c4578c7106b555dfe71bd7fcc847de1da54adcc42c9e7)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CurrencyDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the currency display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CurrencyDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the number display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            range_maximum: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_minimum: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnAnalysis.NumericRangeFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__952507b15807956513dc092a796bb026503ec28fe31e4ef9cc0eea64eecad459)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2783b823c83cc0a81211a8d12015ff4946619b069518a15034c17bde78d94244)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__632e0dde8ea6790c62878c84f1117e8c0387b58d886cd303f240287226a814a4)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ThousandSeparatorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ThousandSeparatorOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b35daecccd1437373a11df8c4f1c38c38c97ab3e9839b303b2ed45e3f831f8dd)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PercentileAggregationProperty", _IResolvable_a771d0ef]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PercentileAggregationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__352e5d243884b93609022264f578c2b39b4d7977690bb52c9f10a0def16b133a)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc2064cdd5bb3b1a1f9e5113c61efbd77714f104078bdd92e4dc17756a4f3668)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnAnalysis.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afa5b7e930b8eba6edf1680d6cb7f238cbfa2a0cdcf0d4b192491b5902ac1bef)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnAnalysis.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd84aaf59f81c5bfa25ab92df6498f23e62e9044f83c6fea5094e158c96cc46e)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PanelTitleOptionsProperty", _IResolvable_a771d0ef]]:
            '''Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PanelTitleOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: ``CfnAnalysis.PanelTitleOptionsProperty.FontConfiguration``.
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6f7bde8af8efd8c89de68569cb6197c006a823bcaf0717519c7a5076cb051e3)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''``CfnAnalysis.PanelTitleOptionsProperty.FontConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            dropdown: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            list: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            slider: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_area: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnAnalysis.ParameterControlProperty(
                    date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnAnalysis.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7dfed7e92137787a1ece7e0ec4cdb30be0e01446501cc7291862b2eaa90f47ca)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterDateTimePickerControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date parameter that specifies date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterDateTimePickerControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterDropDownControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterDropDownControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterListControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterListControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterSliderControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterSliderControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterTextAreaControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterTextAreaControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterTextFieldControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterTextFieldControlProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c1a61a415a63db6ff976e3da9eb5961660a4e6b4b0b7c06dcbac5948d8fe067)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnAnalysis.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fe1b456c49135ec684218a76c87c87ce32e51db10319ace5b90544d4e05aa3a)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DateTimeParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DateTimeParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DecimalParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DecimalParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.IntegerParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.IntegerParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.StringParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.StringParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__532b3ad5ff674f8e8bdbb90eff53fa26907e020acde5dce444b32aefebb88907)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnAnalysis.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ca2a22d5725cc20c31c2ad89ae9177e76fb89e6e73f6c9345facdef45666f695)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c10a2ae83981b7ca1a0e814c85f6000c36b36fbd14f49435d21f4305ef0b903)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column identifier that fetches values from the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnAnalysis.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6e0697bccbec7ec50e5370ed3eaf459b57a4a4a453d149ccdffe83ba93ddbd5)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0fda00d2eb32c8c3fe4848eeb136d6676dcd03da02def16e371dce62d533bd6)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9e1763bab130ffccfc174a927be70f2e66f3993efe2ce822255d6e048169bb6)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameters": "dateTimeParameters",
            "decimal_parameters": "decimalParameters",
            "integer_parameters": "integerParameters",
            "string_parameters": "stringParameters",
        },
    )
    class ParametersProperty:
        def __init__(
            self,
            *,
            date_time_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DateTimeParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            decimal_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DecimalParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            integer_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.IntegerParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            string_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.StringParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''A list of Amazon QuickSight parameters and the list's override values.

            :param date_time_parameters: The parameters that have a data type of date-time.
            :param decimal_parameters: The parameters that have a data type of decimal.
            :param integer_parameters: The parameters that have a data type of integer.
            :param string_parameters: The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameters_property = quicksight.CfnAnalysis.ParametersProperty(
                    date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__56ebac68d7cd0e8036f4d0cf9c38b190cc2af4c3a1a87e6dcb1b327baa5f4d7c)
                check_type(argname="argument date_time_parameters", value=date_time_parameters, expected_type=type_hints["date_time_parameters"])
                check_type(argname="argument decimal_parameters", value=decimal_parameters, expected_type=type_hints["decimal_parameters"])
                check_type(argname="argument integer_parameters", value=integer_parameters, expected_type=type_hints["integer_parameters"])
                check_type(argname="argument string_parameters", value=string_parameters, expected_type=type_hints["string_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameters is not None:
                self._values["date_time_parameters"] = date_time_parameters
            if decimal_parameters is not None:
                self._values["decimal_parameters"] = decimal_parameters
            if integer_parameters is not None:
                self._values["integer_parameters"] = integer_parameters
            if string_parameters is not None:
                self._values["string_parameters"] = string_parameters

        @builtins.property
        def date_time_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DateTimeParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of date-time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-datetimeparameters
            '''
            result = self._values.get("date_time_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DateTimeParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def decimal_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DecimalParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of decimal.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-decimalparameters
            '''
            result = self._values.get("decimal_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DecimalParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def integer_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.IntegerParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of integer.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-integerparameters
            '''
            result = self._values.get("integer_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.IntegerParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def string_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.StringParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-stringparameters
            '''
            result = self._values.get("string_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.StringParameterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0cba9c68e60004055ab8416ffe8c535e2d5ef9d0e92b03c2e4b3cd96c873120f)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccc0fcae130d2f938c090b03ebf67529d5a22107fbb4b1f60d615da3be9f1f55)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnAnalysis.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9eb88081dccf9506c2ae987ebe5cdd92d8438f0712ffa0d2bada5abab4a1c6ce)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html#cfn-quicksight-analysis-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50b08f6cef9d625a0a4eb097a1daa6f6b0fb8bcac7daf5be676a1e6783da2b81)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afba38e5252a8b699247da21cd33d38070d510e660b723ac6e6ae143ddf6e098)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e4c58cbd0c609435ec3b756fd52769c90ed28345648f41ed74755a099bd099e)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category (group/color) field wells of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            donut_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_configuration_property = quicksight.CfnAnalysis.PieChartConfigurationProperty(
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                        arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                            arc_thickness="arcThickness"
                        ),
                        donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                            label_visibility="labelVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                        pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__219e9d716153a7802293c53c16c03f4547ff41e892906f7fce84798cda96c063)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DonutOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DonutOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PieChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PieChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PieChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PieChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options for the value that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_field_wells_property = quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                    pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d0c538053967fd93d94a9626b140bdc0716614a01d10c900322f2cb19f3cab9d)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PieChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html#cfn-quicksight-analysis-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PieChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c20836e677e6bb054210a41451e5a3fdd644e5fa6fa27c9ff80bb716b01c023d)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_visual_property = quicksight.CfnAnalysis.PieChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                            arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                arc_thickness="arcThickness"
                            ),
                            donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                label_visibility="labelVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                            pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc054670c55f2c22cf66e74c17d09225bf1b769db66f98ade0760541ab55cca7)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PieChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PieChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[typing.Union["CfnAnalysis.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                        column=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3c895d7781478a8a40540913cd7c5a446c1f604f55fb0eb997bdd176a24a2f7)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union["CfnAnalysis.PivotTableSortByProperty", _IResolvable_a771d0ef]:
            '''The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union["CfnAnalysis.PivotTableSortByProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_aggregated_field_wells_property = quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86e9ce0c938f72344bbb7a8f4b5dca8b5e9ab0461533fdb29d878fedd3d86272)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_format: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c128688b80c54f9a62e73b255029d85b26f9c17b7ffb1a76bd4abbdedb632e1f)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableConditionalFormattingScopeProperty", _IResolvable_a771d0ef]]:
            '''The scope of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableConditionalFormattingScopeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b834876c9934a0c861b6105ef2ca0fc86d63eccfb245987a04347614704656f3)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableCellConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html#cfn-quicksight-analysis-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableCellConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df727ea8b81f33b8718158593865e60472593b52da1d108a8670a2ae83071a04)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html#cfn-quicksight-analysis-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99f8e464c7a1a83265b0554ebc053b3f8855d0d864acbf5569a48fa23534bc6f)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html#cfn-quicksight-analysis-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_report_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_configuration_property = quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                    field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                        data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                            data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                
                            # the properties below are optional
                            width="width"
                        )],
                        selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            visibility="visibility"
                        )]
                    ),
                    field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                        pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                        field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                            field_id="fieldId",
                            sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                column=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                    direction="direction",
                                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )]
                                ),
                                field=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )
                        )]
                    ),
                    table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_names_visibility="columnNamesVisibility",
                        metric_placement="metricPlacement",
                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        ),
                        row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        single_metric_visibility="singleMetricVisibility",
                        toggle_buttons_visibility="toggleButtonsVisibility"
                    ),
                    total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                        column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5d01745eb35692c6eed2d28885b60b3a1fcb8640ecec50f02021f470403c39b)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableFieldOptionsProperty", _IResolvable_a771d0ef]]:
            '''The field options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableFieldOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]]:
            '''The paginated report options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3c6f8c74fc4fb2358e91e0e64a404139f38e4e4d627ac2b7cd987ccc1f89581)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataPathValueProperty", _IResolvable_a771d0ef]]]:
            '''The list of data path values for the data path options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataPathValueProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0f536fe09ef699a9be2b2db62c17da033b565f608f5d810db87a4e444d9dbda)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            data_path_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4dbf232ee14d267be6dc7b906c544685a1e04f3bd7983c99ee3aa51e4000c5aa)
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableDataPathOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The data path options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableDataPathOptionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableFieldOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableFieldOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__165ac908689e0067085aba2425489c14564bb770f0fc7727eeaf0f908becd25d)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html#cfn-quicksight-analysis-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_wells_property = quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                    pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__866fca67731086e83489bf24678d9b184e71493efaf2f6393d2e3ca4a78e8554)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html#cfn-quicksight-analysis-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_header_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_field_names_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_header_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnAnalysis.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    ),
                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9fab3e43a29d518629fb1e161e91f2b250a2401844822d1dd16868d8eddbc3cc)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of the column header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row alternate color options (widget status, row alternate colors).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of row field names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of the row headers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4ee0fe1710f284707423c79bdae4867698da34304564beeeab822a92e81f911)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_path: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FieldSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnAnalysis.PivotTableSortByProperty(
                    column=quicksight.CfnAnalysis.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnAnalysis.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__497446937ab59022572ad0e0b7c3978b30b79c37f89cac9c1a02c95440e82265)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnSortProperty", _IResolvable_a771d0ef]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataPathSortProperty", _IResolvable_a771d0ef]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataPathSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FieldSortProperty", _IResolvable_a771d0ef]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FieldSortProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7642afcb3aba8d176e79420145ebcd9c0e683035dca5d990b3c36fb1f109422d)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotFieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html#cfn-quicksight-analysis-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotFieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_total_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_subtotal_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_total_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_total_options_property = quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                    column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2d5d390f6e62d3ad9661f28f4b15527cc795cdd2f422b48e4edf831f9485ba8)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SubtotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The column subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SubtotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The column total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SubtotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SubtotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_visual_property = quicksight.CfnAnalysis.PivotTableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                        field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                            data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )],
                
                                # the properties below are optional
                                width="width"
                            )],
                            selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                visibility="visibility"
                            )]
                        ),
                        field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                            pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                            field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                field_id="fieldId",
                                sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                    column=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                        direction="direction",
                                        sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )]
                                    ),
                                    field=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )
                            )]
                        ),
                        table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                            cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_names_visibility="columnNamesVisibility",
                            metric_placement="metricPlacement",
                            row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            ),
                            row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            single_metric_visibility="singleMetricVisibility",
                            toggle_buttons_visibility="toggleButtonsVisibility"
                        ),
                        total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                            column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        )
                    ),
                    conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                    role="role"
                                ),
                                text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb0a7a7ab8f5ae247cf0de31f213288dc0a3123ae83b455a5657577cf8c64771)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf01a7d8c012b1bd3780c58beb57469765ffc03f4dd02a9e2a840343380b1f47)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the total of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b93c78dd2c080fa1445c5be44254e98d787bbc09da580bc1a61cbc77f9e4696b)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The list of columns that define the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23291cba3a82cdcf381ddd80b04bd309e2dea2c1b9da0f52aca1baee41acfb44)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html#cfn-quicksight-analysis-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e81223821459860adad268dcdaaa93bca49816d94cc9a130994f8984199cd1f)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated field well categories of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__613682b582ee5ec2b853ec66b98d24ccda843526b886bde043165944ef844363)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html#cfn-quicksight-analysis-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_axis: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_configuration_property = quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                    alternate_band_even_color="alternateBandEvenColor",
                    alternate_band_odd_color="alternateBandOddColor",
                    base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                        area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                            visibility="visibility"
                        )
                    ),
                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                        radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    shape="shape",
                    sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    start_angle=123,
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fee252f1be91d868b6e1ee6cf8f11245b8625f40afe4c616746cc159c55b48e)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The base sreies settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The color axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The color label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_field_wells_property = quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                    radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17e44a0ac8c70d8308e28bdd7c9fc5dd388c33c6cc0283b8d2ce40ec1f83b300)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html#cfn-quicksight-analysis-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f3b4d982004d14d06b3b7d4cde2c23c76830f0f6cec3684c792750a2fb2adaf)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartAreaStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html#cfn-quicksight-analysis-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartAreaStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9288bc257596ce3da15434f695f590e4e6878fb9a20031bd447ccbfddd0de9a2)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The category items limit for a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The category sort options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The color items limit of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_visual_property = quicksight.CfnAnalysis.RadarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                        alternate_band_colors_visibility="alternateBandColorsVisibility",
                        alternate_band_even_color="alternateBandEvenColor",
                        alternate_band_odd_color="alternateBandOddColor",
                        base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                            area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                visibility="visibility"
                            )
                        ),
                        category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                            radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        shape="shape",
                        sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        start_angle=123,
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__239c38d68955efbd10f72b79fdfb21aa562d87ad7ecb0a684f87914ec7baffb5)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6b625b07a9d04e03513e4f702bf251d2b0195f68b81b1d6230f84022e510cdc4)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html#cfn-quicksight-analysis-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3ace008ca4f454a1ebcf34d52f19d88866c1d1ff168dfa04df362476a3c6ee0f)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html#cfn-quicksight-analysis-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - PrimaryY - SecondaryY
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param static_configuration: The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5488889e805168f64fe1fbaeefed2d2d6be4c256a62f6e640d40010d8ca0a9d0)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - PrimaryY
            - SecondaryY

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The dynamic configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ReferenceLineStaticDataConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ReferenceLineStaticDataConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            measure_aggregation_function: typing.Union[typing.Union["CfnAnalysis.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__437413ee6a3ea5ba0dede6fba33e08b02930c647b5072cf08b1aff23c159ea73)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
                "measure_aggregation_function": measure_aggregation_function,
            }

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The calculation that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union["CfnAnalysis.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the dynamic data targets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            assert result is not None, "Required property 'measure_aggregation_function' is missing"
            return typing.cast(typing.Union["CfnAnalysis.AggregationFunctionProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d716700f7216b94eb6fef27203ecb4efbb6a1db0fe87ca8d0e87bee6869fa26d)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The custom label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ReferenceLineValueLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The value label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ReferenceLineValueLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[typing.Union["CfnAnalysis.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            label_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnAnalysis.ReferenceLineProperty(
                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__274a1bf16c18c921b81b95e77acbb45afbe1cd93ce5560721a62b287ac90c9a8)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.ReferenceLineDataConfigurationProperty", _IResolvable_a771d0ef]:
            '''The data configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ReferenceLineDataConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ReferenceLineLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The label configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ReferenceLineLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ReferenceLineStyleConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ReferenceLineStyleConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33f0917fd7d4ec916f826043eb91bfbeab575247ea4991bd306c87fa771fb003)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html#cfn-quicksight-analysis-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__629ebe691af875b072acbdb07ff54759a24aaebb7d752b9af502bc3c002068b5)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25f385f53197390a715c2e542993550e4ee18effe61827f5a612c5d081860b9d)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the value label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9575afcc1c75b947752590e754af898d8f90399c981a4911537b7eb4fd874db4)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[typing.Union["CfnAnalysis.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21e75b815de00654daecbabd669a86b1b43eb2c711cf04a45a76c9c7378ef8cc)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.AnchorDateConfigurationProperty", _IResolvable_a771d0ef]:
            '''The date configuration of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.AnchorDateConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for the exclude period of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: ``CfnAnalysis.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnAnalysis.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6897ba3012b1fd8b2d83e273fd6da84b371f95de34d0e852c4ea8fd24a96e21b)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''``CfnAnalysis.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0886436ce2d1906d81da56dea91198353e26f65965f9b7f869a040dbeff3585)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5b3fed424058253841db2086923c23815d62c4ada6254cfaad30e1f0e059b48)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__50bc6d74645a12142bb9eb097c1ede5ab0a710a8bdadf3d7ef2fcbb163c7354c)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            source: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            weight: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_aggregated_field_wells_property = quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                    destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f558ae96887355362bff4b411c669526df2e8fef593b3506b16aa5aeadb0cb6)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The destination field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The source field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_chart_configuration_property = quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                        sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                            destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                        destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__208aee0c9685573a83b0456b188de02e981fbc0abf683295e4314250121dffc3)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_field_wells_property = quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                    sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                        destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7727d5ddd7be0e2aa40e66bd0c9b44d2bf853c34fe93ebf06d17b2d8df5db60f)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html#cfn-quicksight-analysis-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            weight_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ebe0ea3ea55270302f8ce415fc45d4f3b3dc07c802f9aa50e35caea48a8eaf3)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_visual_property = quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                            sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                            destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2df527e0d29a27455c9cc9ba1d1dab814dae012e024db5631cf728b816a466a)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_categorically_aggregated_field_wells_property = quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e7a43361693799fdde90c59fbb3ee9c785d28b441d9c03aa34b8e830a591328)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_configuration_property = quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8aaf6a2959f0296e4bccec059f5909770f7ac447992828d7f36e003d5c5d7d2e)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ScatterPlotFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ScatterPlotFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_field_wells_property = quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2002f09c27b11c3de76b46732021204b5372dba4a6d3210d4d434c025d19f990)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a scatter plot.

            The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The unaggregated field wells of a scatter plot.

            The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"size": "size", "x_axis": "xAxis", "y_axis": "yAxis"},
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_unaggregated_field_wells_property = quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ab8d48162530a7fd9e608b82bf571cb620a4ddce14c26ceb28d2f872b1145eef)
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_visual_property = quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                            scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c17e7cbaf237a61875e6f3c8dda6803d6fb3e4e7ced7a297b1b8b2d13fe57a43)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ScatterPlotConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ScatterPlotConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94d5311f418b22de54b0eb18bcb66cebb2667fd60b3cb17127d3573f5122ed62)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisibleRangeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisibleRangeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3070510bdd41c9d6776beb4ac47d7d9af2e727361f036f935ae12f8312ad0ced)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html#cfn-quicksight-analysis-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f5e1a8c73583eeaaf95af7c15ae410b0855c64e3a50b3d389abf6f6d31d251f)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html#cfn-quicksight-analysis-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__18affa96795b2cd847f5977ea054d4d222173dd13085d855138cf15e66402c80)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Union[typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            footer_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            header_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a544e966caf4b8ffb472ff244840de3e86628dbcdd1ee266f4f8ca828f9f4db)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.BodySectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of body section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.BodySectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''The options for the canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of footer section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SpacingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3a59846c9ad2cb43b837ddf0addf7cd1547ab93cdf35b690fa7c7bd969f9871)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SpacingProperty", _IResolvable_a771d0ef]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SpacingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[typing.Union["CfnAnalysis.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0f399d3e7683998f2ea0418053524d6cce3d06ebd2179acfecf8058476dd412)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union["CfnAnalysis.FreeFormSectionLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html#cfn-quicksight-analysis-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FreeFormSectionLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b57148f369645b54e8525641e9aa97fd949e4366e7c718cd6138b2722981f700)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SectionAfterPageBreakProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html#cfn-quicksight-analysis-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SectionAfterPageBreakProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SpacingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnAnalysis.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnAnalysis.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc2f1233dc87e151cc24908940d97aef0e30def0490c3a49fbefaa9a5e572183)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SpacingProperty", _IResolvable_a771d0ef]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SpacingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3117840ba0958c5c1758d533ebfcdbc6719fdf58818ced7ce210e62e13f859c5)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetVisualScopingConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-analysis-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetVisualScopingConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_series_item: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnAnalysis.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a88cb81b68976094f39d27ef75882dc6ba29cbbaecbf1c7f389c3ba206e96595)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataFieldSeriesItemProperty", _IResolvable_a771d0ef]]:
            '''The data field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataFieldSeriesItemProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FieldSeriesItemProperty", _IResolvable_a771d0ef]]:
            '''The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FieldSeriesItemProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[typing.Union["CfnAnalysis.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: ``CfnAnalysis.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a04c41f5bb6dcaca0538e8d8bcd49d38d5756cc8069514f67be80ce6f7885ada)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union["CfnAnalysis.DestinationParameterValueConfigurationProperty", _IResolvable_a771d0ef]:
            '''``CfnAnalysis.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DestinationParameterValueConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f33f126166bad9cd596ef5482693a2ee91f15b567cf9f0c0f1643c695f854b59)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html#cfn-quicksight-analysis-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d61a0584dbd3aaac4a3049fde1d227ab86b40cb15ad684d6372966de0d3e8a3a)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html#cfn-quicksight-analysis-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[typing.Union["CfnAnalysis.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnAnalysis.SheetControlLayoutProperty(
                    configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2882a2bdb9e1ff422a89f32132a7bf43ccc9d10918361938c1902f29bd73245d)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnAnalysis.SheetControlLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html#cfn-quicksight-analysis-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.SheetControlLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FilterControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.LayoutProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            text_boxes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                sheet_definition_property = quicksight.CfnAnalysis.SheetDefinitionProperty(
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnAnalysis.LayoutProperty(
                        configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                    content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnAnalysis.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnAnalysis.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                        date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnAnalysis.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                        configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
                
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnAnalysis.VisualProperty(
                        bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                computations=[quicksight.CfnAnalysis.ComputationProperty(
                                    forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                        category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                    comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                    arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
                
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                            column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
                
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c938711f4b1a7ecbcd3ab129fa90aa5f7d1e72c74d756b8da5b59aab5d2331b2)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilterControlProperty", _IResolvable_a771d0ef]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FilterControlProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.LayoutProperty", _IResolvable_a771d0ef]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.LayoutProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ParameterControlProperty", _IResolvable_a771d0ef]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ParameterControlProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetControlLayoutProperty", _IResolvable_a771d0ef]]]]:
            '''The control layouts of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetControlLayoutProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetTextBoxProperty", _IResolvable_a771d0ef]]]]:
            '''The text boxes that are on a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.SheetTextBoxProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualProperty", _IResolvable_a771d0ef]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f88b26dd8bede76a00044fe70ec4b4b4b0e3a941eb8365140ebe2891046242f7)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html#cfn-quicksight-analysis-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[typing.Union["CfnAnalysis.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__776469b8ca93494164bbfe31c4b905a79719ecb6acddf7d35bb0951256abde2a)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union["CfnAnalysis.SheetElementConfigurationOverridesProperty", _IResolvable_a771d0ef]:
            '''The override configuration of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union["CfnAnalysis.SheetElementConfigurationOverridesProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnAnalysis.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0d0e6bd491de28ac37746a6ee8aee65fee5e1447bf3d354db401dcc7b5e1c2c)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnAnalysis.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae89e881a9d98552f36327e627cb97237db168efb57ca3acd42ca7be5cf63137)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2e67fea2caad222df15bf152adc485d70ddcb54dc7dab458423539b34b3b5a3e)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnAnalysis.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__05abaa7584f60d2a5535faf62da8319ff1f296c8fe3cdedd1f3bc4db82edbaa9)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__21bba48f9b74e416c8596a8890169cf2b5d7721072d9d3bd592352b3c2f80059)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html#cfn-quicksight-analysis-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"title_options": "titleOptions"},
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__29fcf100cb934fb3a833f67140ba57d03a873282a2111679e9b6b7ea281b4004)
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ffcc1353f8affc1bbf60db1171f0033d801c0a0ce4c5e58a8e6c7b0f35e470a)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PanelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PanelConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnAnalysis.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76b927838a9ba986419c6c750d0e51c475c5aa65441dca1f7885612a63c7aec9)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnAnalysis.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77f5f340694f1eb76364e7de966d37683de9b4614f45bb7e0f90b75ec038a8ef)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f785535dc9be68f484596402e37946dd3c7d1e5f22d3918f6dd8a010e4389c86)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnAnalysis.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnAnalysis.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnAnalysis.StringParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d26cf1640385cfba0488d55dfe24bbb7d698e6b2bad6e3708f5d71c974a35665)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.StringDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.StringDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnAnalysis.StringParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.StringValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.StringValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.StringParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class StringParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A string parameter.

            :param name: A display name for a string parameter.
            :param values: The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_parameter_property = quicksight.CfnAnalysis.StringParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__19f65aae86dae49e938d248e6b07771ea752541529f7ca57e7c16c9c1b0d2252)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__107b895aedb4ecaa8b75bc69ce9949190b0e1aa935facadeb37f573d89ceee7e)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnAnalysis.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__338ee318c9fb13ddd20547af794a565272672327db516d9b90c62dc2db1ed347)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableFieldSubtotalOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The optional configuration of subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.PivotTableFieldSubtotalOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotals of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f734855f249d26e634d74a03cc13e1c4f298d8ecf2aad9d6784053c71d0af4ed)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnAnalysis.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e66e0c38a5aba6363cc88a55866813c70f90770b949329975539d14239100eaf)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8bc87e2466575ed3745b58bd8c4e858bc91fcf15a022accc9aeb92cbbd146dd2)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0e3c765906d193385c188f50a9cb1eca4b270bae9e1ac4f8d91d3be35ccf9f7)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html#cfn-quicksight-analysis-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnAnalysis.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b3757384d39ed8826423df69c7221eb7655efe4d89772ef1f163c9a937e8195)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GlobalTableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The borders for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GlobalTableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b2fba82af742d00ecd079121eb54810d9e1a026bf9c7d3912ad6319c6243706)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The cell conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableRowConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableRowConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6aabe436667164f9894460569ccd0f43739212ebc339d4bee5fb71938531b58d)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html#cfn-quicksight-analysis-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_report_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            table_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_configuration_property = quicksight.CfnAnalysis.TableConfigurationProperty(
                    field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                        order=["order"],
                        selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                    )
                                ),
                                link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                            icon="icon"
                                        ),
                                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            value="value"
                                        )
                                    ),
                                    target="target"
                                )
                            ),
                            visibility="visibility",
                            width="width"
                        )]
                    ),
                    field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                        table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                            values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        ),
                        row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                        data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            negative_color="negativeColor",
                            positive_color="positiveColor"
                        )
                    )],
                    table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        orientation="orientation",
                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        )
                    ),
                    total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                        custom_label="customLabel",
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b24619e8da18e43e613b5a1283c32b54c7cc7f75fae764928220566bde74310)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldOptionsProperty", _IResolvable_a771d0ef]]:
            '''The field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]]:
            '''The paginated report options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a ``TableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TableInlineVisualizationProperty", _IResolvable_a771d0ef]]]]:
            '''A collection of inline visualizations to display within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TableInlineVisualizationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6c7e79826f7211413ba2d02ddb4e164438f612b2ef17fdcb7d2f5c50d10f2aa)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html#cfn-quicksight-analysis-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[typing.Union["CfnAnalysis.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e90bb67b5e3ef2a957699ae94eb90056fca87ca02fe7d0bb2ed0091d1835f301)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef]:
            '''The font configuration of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union["CfnAnalysis.FontConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e0373553ea502c66bda7dc4ef05a6377333ffca4faf6c44efe05ae72d25c436)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellImageSizingConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html#cfn-quicksight-analysis-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellImageSizingConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[typing.Union["CfnAnalysis.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1cf8e7b80eb6fe6e27ee26401e4e5d4bd51ec99a6ec637b4b058dd35ff466110)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union["CfnAnalysis.TableFieldLinkContentConfigurationProperty", _IResolvable_a771d0ef]:
            '''The URL content (text, icon) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union["CfnAnalysis.TableFieldLinkContentConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_text_content: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__457a45f82c594eed34f71cd0e30760a7722e2b104ee494288ccae739c59e8091)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldCustomIconContentProperty", _IResolvable_a771d0ef]]:
            '''The custom icon content for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldCustomIconContentProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldCustomTextContentProperty", _IResolvable_a771d0ef]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldCustomTextContentProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnAnalysis.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13090dc6d2bfa86d8713dfdfd4b995356d87113fe44a0ca264696c887f6cc0bb)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldURLConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The URL configuration for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldURLConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field options for a table visual.

            :param order: The order of field IDs of the field options for a table visual.
            :param selected_field_options: The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnAnalysis.TableFieldOptionsProperty(
                    order=["order"],
                    selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__821c0cec1facd5049897b1301aa0443074ef99aed58a818a706f6b5a8d1ad205)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of field IDs of the field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TableFieldOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.TableFieldOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            link_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a186bacbec76d84ff2f56a0c350721a0b4daae06a348bffe349acd62ede6c6ee)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldImageConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The image configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldImageConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableFieldLinkConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableFieldLinkConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_wells_property = quicksight.CfnAnalysis.TableFieldWellsProperty(
                    table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                        values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e38efb8a30e02e7ad3fe1fe0c3701ca4c2d5504eb32e10019f7b81623bc6b267)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62c5d046bcd293681b865db46fc2d73ad944afebe5fb87d6b5cf5340129d1eff)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataBarsOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html#cfn-quicksight-analysis-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataBarsOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            header_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnAnalysis.TableOptionsProperty(
                    cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce6aa4ab792489a3cdab9047788a943d52dd2f54b9fba078a7a797193754cc21)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of a table header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e74c449074a522c02c06062cd89d5276ca2e7bff65e3f2c380fd19412bcc408a)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c81e088cdfa4caa973e79cee4499ca1ee8ebc47b51d3b53d2083b6084b7dcdb0)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            inner_horizontal: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            inner_vertical: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            left: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            right: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86d2a2be9b4ae6e64dee62f5dfa82aa2b6f4215027bf139cf153e4a3dae85574)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the bottom border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the inner horizontal border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the inner vertical border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the left border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the right border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnAnalysis.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2926875694cfa970f79b095c8f2e8eea85c1c0b48114d68b3bd202ed52f0fd72)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PaginationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The pagination configuration (page size, page number) for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PaginationConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a217d901fcb5e3e5c553c55bd2c7342537d80324a2784475637e59b7580ffa10)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.UnaggregatedFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html#cfn-quicksight-analysis-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.UnaggregatedFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_visual_property = quicksight.CfnAnalysis.TableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                        field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                            order=["order"],
                            selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                    image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                        sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                        )
                                    ),
                                    link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                        content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                            custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                icon="icon"
                                            ),
                                            custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                
                                                # the properties below are optional
                                                value="value"
                                            )
                                        ),
                                        target="target"
                                    )
                                ),
                                visibility="visibility",
                                width="width"
                            )]
                        ),
                        field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                            table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                            pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            ),
                            row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                            data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                negative_color="negativeColor",
                                positive_color="positiveColor"
                            )
                        )],
                        table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                            cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            orientation="orientation",
                            row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            )
                        ),
                        total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                            custom_label="customLabel",
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility"
                        )
                    ),
                    conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            ),
                            row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ca6f5164b5f0871a8050093137a20978c938ff65d9e350995679baaaa6174ca)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e75a97f6ce9564ef15860e3fc60a7a277638b0fe57fad98ae085f81bf2cdc8b9)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the placeholder options in a text area control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            icon: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnAnalysis.TextConditionalFormatProperty(
                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65f1208b58152dc9f5d5774adb04a8dffb8cfd9a8d3d12516d3bbb45318ac318)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the text background color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc1c35467b00ada0611d774551a4a3f50f55fe2fe8316bccbd2ccdaea5cefd3c)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html#cfn-quicksight-analysis-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9074e2f647df15f22a97cb177cb95f394d82b84dde9b6a863f4170715048ba39)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the placeholder options in a text field control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e072e282014fda925c195d701db9d1d66e6fc4f7a8e592ef7523fa0de3267458)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ff58cf9c9036a37099e184deac523183e4baebc1581a0c2db372604c45c4f46)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__61968e68213059f8344a79ebf7804d236291a32ee491834b70c9b74615e27c13)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b2356da4f991bfefdfbdc8d478acef795e4cb5c7f2c5eafdfa9f7f5bcbe9ef0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            range_maximum_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_minimum_value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnAnalysis.TimeRangeFilterProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a23cfd561aee781b2ed78435b340afa511642db6498cac8ffd26ef9629a3c5ea)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The exclude period of the time range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24211c9c3d9786fc4071a486b5514e83b6ea5bff916c8b192201c2c5996a87e0)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RollingDateConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The rolling date input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RollingDateConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_tooltip_item: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnAnalysis.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d0a621a3b4653d8fcc166f294edb897d7f289ce0eb7373b2d4aa8b71a2fb9a7c)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColumnTooltipItemProperty", _IResolvable_a771d0ef]]:
            '''The tooltip item for the columns that are not part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColumnTooltipItemProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FieldTooltipItemProperty", _IResolvable_a771d0ef]]:
            '''The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FieldTooltipItemProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnAnalysis.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__399683125ff09870e7531b585cf93e480ef91abee0318095e6d0d52c966b51df)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FieldBasedTooltipProperty", _IResolvable_a771d0ef]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FieldBasedTooltipProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnAnalysis.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection"
                    )],
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63690b00a9dd0d167013f694baef776de83b34cf58d54c8b31ff12d0cf6192a2)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.AggregationSortConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.AggregationSortConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            type: builtins.str,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param mover_size: The mover size setup of the top and bottom movers computation.
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_movers_computation_property = quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    mover_size=123,
                    name="name",
                    sort_order="sortOrder",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02bcc5a57bb72f7f33f46f02efce9b62e8e401cb5231400add400ecf639d48ec)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_ranked_computation_property = quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    result_size=123,
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__65d3249a90e066a14a046d15d937e11856695f615268c90f1210277fcb987a7e)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "value": "value",
            "name": "name",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            value: typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param value: The value field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                    computation_id="computationId",
                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a917d26488177956053494c5696a161d0fa419bc4d4ce486b54e3ab0bb17b1d)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "value": value,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnAnalysis.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2780192ddc65888b0f5824bdc533b55d3c512dcbe86b0421f76b7ada4912c23d)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''Cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sizes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_aggregated_field_wells_property = quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffd1f777f858822f88ad835727962ca85d81400cdb26135346db6d5a07f188dc)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_scale: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            group_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            size_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_configuration_property = quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                        tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                        tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27238c47817beaed571aefade8d051f4505788530c4dda97ddffcacc273b675e)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ColorScaleProperty", _IResolvable_a771d0ef]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ColorScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TreeMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TreeMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TreeMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TreeMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_field_wells_property = quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                    tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__08a5bfe2ff1a99de5efcdcb240057efac677f483f2b95c2f47a548d74b635871)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TreeMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html#cfn-quicksight-analysis-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TreeMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tree_map_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e9300467063bcb7de264bfa0d0d40c038722b50a6ea8a94d41317be28e4fb45)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_visual_property = quicksight.CfnAnalysis.TreeMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                        color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                            tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                            tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c6132041dee279f6a22af8d31dcd138da06d50c2d76ed754e91fd925b34f5c8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TreeMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TreeMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43aa43188ebb4a9aa6944fe6a5713779910284d75dd38d6485af31a1ab53213f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html#cfn-quicksight-analysis-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnAnalysis.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6391f4830118bb541e0db8923d50f0d6cbdaa6f8583af4c20a3a220bceb56ad)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``UnaggregatedField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnAnalysis.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bb762812fc5e23f3f0d1a0b91eb54b28721289e6738482ed3f7badc5cc07a1a)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d1490552a5edd0682ea5b270b662493a9257e14e5882eb15010b986be15eebd)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PercentVisibleRangeProperty", _IResolvable_a771d0ef]]:
            '''The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html#cfn-quicksight-analysis-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PercentVisibleRangeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            navigation_operation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            set_parameters_operation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            url_operation: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70aec55c7b812db55a0d43b7fbcdec8738ee109e86eb5642de46c7cbbc5c87b6)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomActionFilterOperationProperty", _IResolvable_a771d0ef]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomActionFilterOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomActionNavigationOperationProperty", _IResolvable_a771d0ef]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomActionNavigationOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomActionSetParametersOperationProperty", _IResolvable_a771d0ef]]:
            '''The set parameter operation that sets parameters in custom action.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomActionSetParametersOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomActionURLOperationProperty", _IResolvable_a771d0ef]]:
            '''The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomActionURLOperationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnAnalysis.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__148280f0f28dee637dd7053bdefead99b00168e1839619c7bb571c5146bfcb40)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionOperationProperty", _IResolvable_a771d0ef]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionOperationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnAnalysis.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnAnalysis.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1423958e6a9d35ff96d3892a67fb230ba945a317e0ba5f287b48e50d0953921c)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataPathColorProperty", _IResolvable_a771d0ef]]]]:
            '''The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DataPathColorProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            box_plot_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            combo_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_content_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            empty_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filled_map_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            histogram_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            insight_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            kpi_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            line_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            pie_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            pivot_table_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            radar_chart_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TableVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tree_map_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            waterfall_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            word_cloud_visual: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                visual_property = quicksight.CfnAnalysis.VisualProperty(
                    bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            orientation="orientation",
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                            box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                all_data_points_visibility="allDataPointsVisibility",
                                outlier_visibility="outlierVisibility",
                                style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                    fill_style="fillStyle"
                                )
                            ),
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                )
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                            bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                    bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                            content_type="contentType",
                            content_url="contentUrl",
                            image_scaling="imageScaling"
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )]
                    ),
                    filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                            field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                label_color="labelColor",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_data_label_style="measureDataLabelStyle",
                                measure_label_visibility="measureLabelVisibility",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                    arc_angle=123,
                                    arc_thickness="arcThickness"
                                ),
                                arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                    range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                        max=123,
                                        min=123
                                    ),
                                    reserve_range=123
                                ),
                                comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            ),
                            tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                            field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                    cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                        simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                            color="color"
                                        )
                                    )
                                ),
                                selected_point_style="selectedPointStyle"
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                            color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                            bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                    value=123
                                ),
                                bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                    bin_count_limit=123,
                                    value=123
                                ),
                                selected_bin_type="selectedBinType",
                                start_value=123
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            )
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                            computations=[quicksight.CfnAnalysis.ComputationProperty(
                                forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    custom_seasonality_value=123,
                                    lower_boundary=123,
                                    name="name",
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality="seasonality",
                                    upper_boundary=123,
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_size=123,
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                    computation_id="computationId",
                                    from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_time_granularity="periodTimeGranularity",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    mover_size=123,
                                    name="name",
                                    sort_order="sortOrder",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    result_size=123,
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                    computation_id="computationId",
                                    value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                    category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                
                                    # the properties below are optional
                                    name="name"
                                )
                            )],
                            custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                narrative="narrative"
                            )
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                            field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                    visibility="visibility"
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                            contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                axis_binding="axisBinding",
                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                    lower_boundary=123,
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality=123,
                                    upper_boundary=123
                                ),
                                scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                    what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                        date="date",
                                        value=123
                                    ),
                                    what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                        end_date="endDate",
                                        start_date="startDate",
                                        value=123
                                    )
                                )
                            )],
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                            range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    field_value="fieldValue",
                                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                ),
                                field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                )
                            )],
                            small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            type="type",
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                    arc_thickness="arcThickness"
                                ),
                                donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                    label_visibility="labelVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                            field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                    data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )],
                
                                    # the properties below are optional
                                    width="width"
                                )],
                                selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    visibility="visibility"
                                )]
                            ),
                            field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                    field_id="fieldId",
                                    sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                        column=quicksight.CfnAnalysis.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                            direction="direction",
                                            sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )]
                                        ),
                                        field=quicksight.CfnAnalysis.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )
                                )]
                            ),
                            table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_names_visibility="columnNamesVisibility",
                                metric_placement="metricPlacement",
                                row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                ),
                                row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                single_metric_visibility="singleMetricVisibility",
                                toggle_buttons_visibility="toggleButtonsVisibility"
                            ),
                            total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            )
                        ),
                        conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                        role="role"
                                    ),
                                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                            alternate_band_colors_visibility="alternateBandColorsVisibility",
                            alternate_band_even_color="alternateBandEvenColor",
                            alternate_band_odd_color="alternateBandOddColor",
                            base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                    visibility="visibility"
                                )
                            ),
                            category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            shape="shape",
                            sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            start_angle=123,
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                    destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                            field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                order=["order"],
                                selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                        image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                            sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                            )
                                        ),
                                        link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                            content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                    icon="icon"
                                                ),
                                                custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                
                                                    # the properties below are optional
                                                    value="value"
                                                )
                                            ),
                                            target="target"
                                        )
                                    ),
                                    visibility="visibility",
                                    width="width"
                                )]
                            ),
                            field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                    values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                ),
                                row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    negative_color="negativeColor",
                                    positive_color="positiveColor"
                                )
                            )],
                            table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                orientation="orientation",
                                row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                )
                            ),
                            total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                custom_label="customLabel",
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility"
                            )
                        ),
                        conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnAnalysis.GradientColorProperty(
                                                    stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                ),
                                row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                    background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnAnalysis.GradientColorProperty(
                                                stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                            color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                            category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                    breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                        range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                            linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnAnalysis.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                total_bar_label="totalBarLabel"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                            category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                cloud_layout="cloudLayout",
                                maximum_string_length=123,
                                word_casing="wordCasing",
                                word_orientation="wordOrientation",
                                word_padding="wordPadding",
                                word_scaling="wordScaling"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee3896991a5a3394b7bb38ff5a1d4180def07a73decaac035f10f14d4f048f5d)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BarChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BarChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.BoxPlotVisualProperty", _IResolvable_a771d0ef]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.BoxPlotVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ComboChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ComboChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.CustomContentVisualProperty", _IResolvable_a771d0ef]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.CustomContentVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.EmptyVisualProperty", _IResolvable_a771d0ef]]:
            '''An empty visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.EmptyVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FilledMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FilledMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.FunnelChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.FunnelChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GaugeChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GaugeChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.GeospatialMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.GeospatialMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HeatMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HeatMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.HistogramVisualProperty", _IResolvable_a771d0ef]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.HistogramVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.InsightVisualProperty", _IResolvable_a771d0ef]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.InsightVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.KPIVisualProperty", _IResolvable_a771d0ef]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.KPIVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LineChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LineChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PieChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PieChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.PivotTableVisualProperty", _IResolvable_a771d0ef]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.PivotTableVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.RadarChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.RadarChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramVisualProperty", _IResolvable_a771d0ef]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.SankeyDiagramVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ScatterPlotVisualProperty", _IResolvable_a771d0ef]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ScatterPlotVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TableVisualProperty", _IResolvable_a771d0ef]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TableVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.TreeMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.TreeMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WaterfallVisualProperty", _IResolvable_a771d0ef]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WaterfallVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WordCloudVisualProperty", _IResolvable_a771d0ef]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WordCloudVisualProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4a8eda71327018da4bafcbc45018ceb497e8c83cdf654085488271b051d977df)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LongFormatTextProperty", _IResolvable_a771d0ef]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LongFormatTextProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__000bba8127c60b03afa9f7c6cc0e4d11142a6ad0322398bfb5c4ab002816d4b8)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ShortFormatTextProperty", _IResolvable_a771d0ef]]:
            '''The short text format of the title label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ShortFormatTextProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            categories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_aggregated_field_wells_property = quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                    breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1770292d4307ae2952af012a35cef2cb9eef5a8791f2ae22269004d69a121dc5)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The breakdown field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnAnalysis.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnAnalysis.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_chart_configuration_property = quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                    category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                        waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                            breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                        breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                        total_bar_label="totalBarLabel"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__566294a268f3641186c4eff014e8be36a935671aad4e3cf9b1d703e3ac1a9716)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the category axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the category axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WaterfallChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WaterfallChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WaterfallChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WaterfallChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WaterfallChartOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WaterfallChartOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_field_wells_property = quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                    waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                        breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__17414ad40bdb603c1550765f7afa200c6742643f7a721c4d7c02054cdab536b6)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html#cfn-quicksight-analysis-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5bab4a9e82562095a50159cfc83b11b133c763c15c39e5dffd5342d11e06226)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html#cfn-quicksight-analysis-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b61f1e46b7a0f42f445726a8df6f36743506eca0511b0928ce1babf4d2a67a1)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of bar groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_visual_property = quicksight.CfnAnalysis.WaterfallVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                        category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                            waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                            breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnAnalysis.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                            total_bar_label="totalBarLabel"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04cbff721f654c7c4df1caad6820ec7b376222d32b6301eeb8928be9ce23a881)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WaterfallChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WaterfallChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7502d0273db4b5c5befa524ba7a3234c314dba26b0a93305148657455d5dd8e3)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__543473df3c38c0970331f7446f5fe7622e643dd02e5f49995d552df8449bf151)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                            column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f3b6de738b2d9f56fb47f74ca8a418d00c2175473f7f6911f1f523f884c37dc)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            word_cloud_options: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_chart_configuration_property = quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                        word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                        cloud_layout="cloudLayout",
                        maximum_string_length=123,
                        word_casing="wordCasing",
                        word_orientation="wordOrientation",
                        word_padding="wordPadding",
                        word_scaling="wordScaling"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__754ae217b5eb8be3a592db2009f7d6942e32a9ead6f368c3322575b785a5d7dc)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WordCloudFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WordCloudFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WordCloudSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WordCloudSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WordCloudOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WordCloudOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75f82c42bb93b7a150d1f2c4343016d5e5fc0572ca3b84cf6a3ad559fb7d186c)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WordCloudAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html#cfn-quicksight-analysis-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WordCloudAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnAnalysis.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f39ff21005933d4d221060cbb8c8f02a5102f355eafbbf934a2941aa5998bba0)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec316243b676233d9ea1a7521def4480000048110539f4065f4a3c0d79d765b7)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnAnalysis.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnAnalysis.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnAnalysis.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_visual_property = quicksight.CfnAnalysis.WordCloudVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                        category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                            word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                            category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                            cloud_layout="cloudLayout",
                            maximum_string_length=123,
                            word_casing="wordCasing",
                            word_orientation="wordOrientation",
                            word_padding="wordPadding",
                            word_scaling="wordScaling"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa70dc6910bb90a5405f5af23bcf089a8f8615839a457c9f2e10559c9989a32c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.WordCloudChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.WordCloudChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnAnalysis.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnAnalysis.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnAnalysisProps",
    jsii_struct_bases=[],
    name_mapping={
        "analysis_id": "analysisId",
        "aws_account_id": "awsAccountId",
        "name": "name",
        "definition": "definition",
        "parameters": "parameters",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "status": "status",
        "tags": "tags",
        "theme_arn": "themeArn",
    },
)
class CfnAnalysisProps:
    def __init__(
        self,
        *,
        analysis_id: builtins.str,
        aws_account_id: builtins.str,
        name: builtins.str,
        definition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        parameters: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        source_entity: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        status: typing.Optional[builtins.str] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnAnalysis``.

        :param analysis_id: The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
        :param aws_account_id: The ID of the AWS account where you are creating an analysis.
        :param name: A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
        :param definition: ``AWS::QuickSight::Analysis.Definition``.
        :param parameters: The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
        :param permissions: A structure that describes the principals and the resource-level permissions on an analysis. You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN). To specify no permissions, omit ``Permissions`` .
        :param source_entity: A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param status: Status associated with the analysis.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
        :param theme_arn: The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            # data_driven: Any
            
            cfn_analysis_props = quicksight.CfnAnalysisProps(
                analysis_id="analysisId",
                aws_account_id="awsAccountId",
                name="name",
            
                # the properties below are optional
                definition=quicksight.CfnAnalysis.AnalysisDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnAnalysis.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
            
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnAnalysis.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnAnalysis.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnAnalysis.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnAnalysis.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnAnalysis.ColumnConfigurationProperty(
                        column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
            
                        # the properties below are optional
                        colors_configuration=quicksight.CfnAnalysis.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnAnalysis.CustomColorProperty(
                                color="color",
            
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnAnalysis.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnAnalysis.FilterProperty(
                            category_filter=quicksight.CfnAnalysis.CategoryFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnAnalysis.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnAnalysis.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnAnalysis.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnAnalysis.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnAnalysis.NumericRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnAnalysis.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnAnalysis.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnAnalysis.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnAnalysis.TimeEqualityFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnAnalysis.TimeRangeFilterProperty(
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnAnalysis.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnAnalysis.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnAnalysis.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnAnalysis.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnAnalysis.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnAnalysis.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
            
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
            
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnAnalysis.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnAnalysis.DateTimeParameterDeclarationProperty(
                            name="name",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnAnalysis.RollingDateConfigurationProperty(
                                    expression="expression",
            
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnAnalysis.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnAnalysis.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnAnalysis.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnAnalysis.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnAnalysis.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnAnalysis.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnAnalysis.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnAnalysis.SheetDefinitionProperty(
                        sheet_id="sheetId",
            
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnAnalysis.FilterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnAnalysis.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnAnalysis.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnAnalysis.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnAnalysis.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnAnalysis.LayoutProperty(
                            configuration=quicksight.CfnAnalysis.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnAnalysis.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
            
                                        # the properties below are optional
                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnAnalysis.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnAnalysis.BodySectionConfigurationProperty(
                                        content=quicksight.CfnAnalysis.BodySectionContentProperty(
                                            layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
            
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnAnalysis.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnAnalysis.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnAnalysis.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnAnalysis.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnAnalysis.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnAnalysis.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnAnalysis.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnAnalysis.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnAnalysis.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnAnalysis.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnAnalysis.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnAnalysis.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnAnalysis.ParameterControlProperty(
                            date_time_picker=quicksight.CfnAnalysis.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnAnalysis.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnAnalysis.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnAnalysis.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnAnalysis.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnAnalysis.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnAnalysis.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnAnalysis.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnAnalysis.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnAnalysis.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnAnalysis.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnAnalysis.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnAnalysis.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnAnalysis.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnAnalysis.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnAnalysis.SheetControlLayoutProperty(
                            configuration=quicksight.CfnAnalysis.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnAnalysis.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnAnalysis.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnAnalysis.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnAnalysis.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
            
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnAnalysis.VisualProperty(
                            bar_chart_visual=quicksight.CfnAnalysis.BarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnAnalysis.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnAnalysis.BoxPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnAnalysis.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnAnalysis.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnAnalysis.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnAnalysis.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnAnalysis.ComboChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnAnalysis.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnAnalysis.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnAnalysis.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnAnalysis.FilledMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnAnalysis.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnAnalysis.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            format=quicksight.CfnAnalysis.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnAnalysis.FunnelChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnAnalysis.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnAnalysis.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnAnalysis.GaugeChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnAnalysis.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnAnalysis.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnAnalysis.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnAnalysis.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnAnalysis.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnAnalysis.GeospatialMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnAnalysis.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnAnalysis.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnAnalysis.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnAnalysis.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnAnalysis.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnAnalysis.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnAnalysis.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnAnalysis.HeatMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnAnalysis.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnAnalysis.HistogramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnAnalysis.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnAnalysis.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnAnalysis.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnAnalysis.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnAnalysis.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnAnalysis.InsightConfigurationProperty(
                                    computations=[quicksight.CfnAnalysis.ComputationProperty(
                                        forecast=quicksight.CfnAnalysis.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnAnalysis.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnAnalysis.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnAnalysis.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnAnalysis.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnAnalysis.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnAnalysis.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnAnalysis.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnAnalysis.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnAnalysis.UniqueValuesComputationProperty(
                                            category=quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
            
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnAnalysis.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnAnalysis.KPIVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnAnalysis.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnAnalysis.KPIOptionsProperty(
                                        comparison=quicksight.CfnAnalysis.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnAnalysis.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnAnalysis.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnAnalysis.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnAnalysis.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnAnalysis.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnAnalysis.LineChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnAnalysis.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnAnalysis.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnAnalysis.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnAnalysis.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnAnalysis.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnAnalysis.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnAnalysis.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnAnalysis.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnAnalysis.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnAnalysis.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnAnalysis.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnAnalysis.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnAnalysis.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnAnalysis.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                        linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnAnalysis.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnAnalysis.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnAnalysis.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnAnalysis.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            settings=quicksight.CfnAnalysis.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnAnalysis.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnAnalysis.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnAnalysis.PieChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnAnalysis.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnAnalysis.DonutOptionsProperty(
                                        arc_options=quicksight.CfnAnalysis.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnAnalysis.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnAnalysis.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnAnalysis.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnAnalysis.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnAnalysis.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnAnalysis.PivotTableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnAnalysis.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
            
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnAnalysis.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnAnalysis.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnAnalysis.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnAnalysis.PivotTableSortByProperty(
                                                column=quicksight.CfnAnalysis.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnAnalysis.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnAnalysis.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnAnalysis.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnAnalysis.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnAnalysis.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnAnalysis.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnAnalysis.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnAnalysis.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            scope=quicksight.CfnAnalysis.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnAnalysis.RadarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnAnalysis.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnAnalysis.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnAnalysis.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnAnalysis.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnAnalysis.SankeyDiagramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnAnalysis.ScatterPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnAnalysis.TableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TableConfigurationProperty(
                                    field_options=quicksight.CfnAnalysis.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnAnalysis.TableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnAnalysis.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnAnalysis.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnAnalysis.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnAnalysis.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnAnalysis.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnAnalysis.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnAnalysis.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
            
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnAnalysis.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnAnalysis.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnAnalysis.UnaggregatedFieldProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnAnalysis.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnAnalysis.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnAnalysis.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnAnalysis.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnAnalysis.DataBarsOptionsProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnAnalysis.TableOptionsProperty(
                                        cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnAnalysis.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnAnalysis.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnAnalysis.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnAnalysis.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnAnalysis.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnAnalysis.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnAnalysis.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnAnalysis.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnAnalysis.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            text_format=quicksight.CfnAnalysis.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnAnalysis.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnAnalysis.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnAnalysis.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnAnalysis.GradientColorProperty(
                                                            stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnAnalysis.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnAnalysis.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnAnalysis.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnAnalysis.GradientColorProperty(
                                                        stops=[quicksight.CfnAnalysis.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnAnalysis.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnAnalysis.TreeMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnAnalysis.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnAnalysis.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnAnalysis.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnAnalysis.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnAnalysis.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnAnalysis.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnAnalysis.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnAnalysis.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnAnalysis.WaterfallVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnAnalysis.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnAnalysis.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnAnalysis.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnAnalysis.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnAnalysis.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnAnalysis.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnAnalysis.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnAnalysis.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnAnalysis.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnAnalysis.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnAnalysis.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnAnalysis.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnAnalysis.NumericAxisOptionsProperty(
                                                range=quicksight.CfnAnalysis.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnAnalysis.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnAnalysis.AxisScaleProperty(
                                                    linear=quicksight.CfnAnalysis.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnAnalysis.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnAnalysis.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnAnalysis.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnAnalysis.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnAnalysis.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnAnalysis.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnAnalysis.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnAnalysis.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnAnalysis.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnAnalysis.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnAnalysis.WordCloudVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnAnalysis.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnAnalysis.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnAnalysis.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnAnalysis.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnAnalysis.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnAnalysis.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnAnalysis.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnAnalysis.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnAnalysis.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnAnalysis.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnAnalysis.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnAnalysis.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnAnalysis.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnAnalysis.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnAnalysis.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnAnalysis.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnAnalysis.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnAnalysis.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnAnalysis.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnAnalysis.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnAnalysis.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnAnalysis.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnAnalysis.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnAnalysis.DateDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnAnalysis.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnAnalysis.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnAnalysis.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnAnalysis.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnAnalysis.DateMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnAnalysis.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnAnalysis.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnAnalysis.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnAnalysis.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnAnalysis.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnAnalysis.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnAnalysis.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnAnalysis.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnAnalysis.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnAnalysis.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnAnalysis.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnAnalysis.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnAnalysis.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnAnalysis.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnAnalysis.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnAnalysis.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnAnalysis.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnAnalysis.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnAnalysis.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnAnalysis.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnAnalysis.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnAnalysis.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnAnalysis.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnAnalysis.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnAnalysis.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnAnalysis.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnAnalysis.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnAnalysis.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnAnalysis.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnAnalysis.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnAnalysis.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnAnalysis.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnAnalysis.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                ),
                parameters=quicksight.CfnAnalysis.ParametersProperty(
                    date_time_parameters=[quicksight.CfnAnalysis.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnAnalysis.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnAnalysis.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnAnalysis.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                ),
                permissions=[quicksight.CfnAnalysis.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                source_entity=quicksight.CfnAnalysis.AnalysisSourceEntityProperty(
                    source_template=quicksight.CfnAnalysis.AnalysisSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnAnalysis.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                ),
                status="status",
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                theme_arn="themeArn"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__650e13e8507f010a1e2263cfb168e2f149f581434bd73b1fdb42e2073bac1cbc)
            check_type(argname="argument analysis_id", value=analysis_id, expected_type=type_hints["analysis_id"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "analysis_id": analysis_id,
            "aws_account_id": aws_account_id,
            "name": name,
        }
        if definition is not None:
            self._values["definition"] = definition
        if parameters is not None:
            self._values["parameters"] = parameters
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if theme_arn is not None:
            self._values["theme_arn"] = theme_arn

    @builtins.property
    def analysis_id(self) -> builtins.str:
        '''The ID for the analysis that you're creating.

        This ID displays in the URL of the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
        '''
        result = self._values.get("analysis_id")
        assert result is not None, "Required property 'analysis_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you are creating an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''A descriptive name for the analysis that you're creating.

        This name displays for the analysis in the Amazon QuickSight console.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, _IResolvable_a771d0ef]]:
        '''``AWS::QuickSight::Analysis.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[CfnAnalysis.ParametersProperty, _IResolvable_a771d0ef]]:
        '''The parameter names and override values that you want to use.

        An analysis can have any parameter type, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Union[CfnAnalysis.ParametersProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnAnalysis.ResourcePermissionProperty, _IResolvable_a771d0ef]]]]:
        '''A structure that describes the principals and the resource-level permissions on an analysis.

        You can use the ``Permissions`` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).

        To specify no permissions, omit ``Permissions`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnAnalysis.ResourcePermissionProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, _IResolvable_a771d0ef]]:
        '''A source entity to use for the analysis that you're creating.

        This metadata structure contains details that describe a source template and one or more datasets.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        '''Status associated with the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
        '''
        result = self._values.get("status")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    @builtins.property
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN for the theme to apply to the analysis that you're creating.

        To see the theme in the Amazon QuickSight console, make sure that you have access to it.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
        '''
        result = self._values.get("theme_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnAnalysisProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnDashboard(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnDashboard",
):
    '''A CloudFormation ``AWS::QuickSight::Dashboard``.

    Creates a dashboard from a template. To first create a template, see the ``CreateTemplate`` API operation.

    A dashboard is an entity in Amazon QuickSight that identifies Amazon QuickSight reports, created from analyses. You can share Amazon QuickSight dashboards. With the right permissions, you can create scheduled email reports from them. If you have the correct permissions, you can create a dashboard from a template that exists in a different AWS account .

    :cloudformationResource: AWS::QuickSight::Dashboard
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        # data_driven: Any
        
        cfn_dashboard = quicksight.CfnDashboard(self, "MyCfnDashboard",
            aws_account_id="awsAccountId",
            dashboard_id="dashboardId",
            name="name",
        
            # the properties below are optional
            dashboard_publish_options=quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                    availability_status="availabilityStatus"
                ),
                data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                    availability_status="availabilityStatus"
                ),
                data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                    availability_status="availabilityStatus"
                ),
                data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                    availability_status="availabilityStatus"
                ),
                export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                    availability_status="availabilityStatus"
                ),
                export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                ),
                sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                    visibility_state="visibilityState"
                ),
                sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                    availability_status="availabilityStatus"
                ),
                visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                    availability_status="availabilityStatus"
                ),
                visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                    availability_status="availabilityStatus"
                ),
                visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                    export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    )
                )
            ),
            definition=quicksight.CfnDashboard.DashboardVersionDefinitionProperty(
                data_set_identifier_declarations=[quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )],
        
                # the properties below are optional
                analysis_defaults=quicksight.CfnDashboard.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                ),
                calculated_fields=[quicksight.CfnDashboard.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )],
                column_configurations=[quicksight.CfnDashboard.ColumnConfigurationProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
        
                    # the properties below are optional
                    colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                            color="color",
        
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )],
                filter_groups=[quicksight.CfnDashboard.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnDashboard.FilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
        
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
        
                    # the properties below are optional
                    status="status"
                )],
                parameter_declarations=[quicksight.CfnDashboard.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                        name="name",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
        
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )],
                sheets=[quicksight.CfnDashboard.SheetDefinitionProperty(
                    sheet_id="sheetId",
        
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnDashboard.LayoutProperty(
                        configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
        
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
        
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                        configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
        
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnDashboard.VisualProperty(
                        bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                computations=[quicksight.CfnDashboard.ComputationProperty(
                                    forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
        
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnDashboard.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
        
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnDashboard.TableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
        
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )]
            ),
            parameters=quicksight.CfnDashboard.ParametersProperty(
                date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )],
                decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )],
                integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )],
                string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                    name="name",
                    values=["values"]
                )]
            ),
            permissions=[quicksight.CfnDashboard.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            source_entity=quicksight.CfnDashboard.DashboardSourceEntityProperty(
                source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            theme_arn="themeArn",
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        dashboard_id: builtins.str,
        name: builtins.str,
        dashboard_publish_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DashboardPublishOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        definition: typing.Optional[typing.Union[typing.Union["CfnDashboard.DashboardVersionDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        parameters: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        source_entity: typing.Optional[typing.Union[typing.Union["CfnDashboard.DashboardSourceEntityProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Dashboard``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The ID of the AWS account where you want to create the dashboard.
        :param dashboard_id: The ID for the dashboard, also added to the IAM policy.
        :param name: The display name of the dashboard.
        :param dashboard_publish_options: Options for publishing the dashboard when you create it:. - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default. - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default. - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.
        :param definition: ``AWS::QuickSight::Dashboard.Definition``.
        :param parameters: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
        :param permissions: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN. To specify no permissions, omit the permissions list.
        :param source_entity: The entity that you are using as a source when you create the dashboard. In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
        :param theme_arn: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
        :param version_description: A description for the first version of the dashboard being created.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__680eeb61bf68aab9f7efc5447530f7aec64a0ee6b8b8811232cc7ea9282be91b)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDashboardProps(
            aws_account_id=aws_account_id,
            dashboard_id=dashboard_id,
            name=name,
            dashboard_publish_options=dashboard_publish_options,
            definition=definition,
            parameters=parameters,
            permissions=permissions,
            source_entity=source_entity,
            tags=tags,
            theme_arn=theme_arn,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cccc46154085828872a1b942f1bbefba592fe7597f95bf8ae4cb065bf2581dbf)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2aa8c5650bc3211ff1db5b0ae262e9333ac94b28c04c8a8b39558575f6eba359)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dashboard.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this dashboard version was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastPublishedTime")
    def attr_last_published_time(self) -> builtins.str:
        '''The time that the dashboard was last published.

        :cloudformationAttribute: LastPublishedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastPublishedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time that the dashboard was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionArn")
    def attr_version_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDataSetArns")
    def attr_version_data_set_arns(self) -> typing.List[builtins.str]:
        '''
        :cloudformationAttribute: Version.DataSetArns
        '''
        return typing.cast(typing.List[builtins.str], jsii.get(self, "attrVersionDataSetArns"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSheets")
    def attr_version_sheets(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.Sheets
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionSheets"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSourceEntityArn")
    def attr_version_source_entity_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.SourceEntityArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionSourceEntityArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionThemeArn")
    def attr_version_theme_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.ThemeArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionThemeArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a33bd4b7d61cae8176a478b9c40a4ae74b2f2542e973521f41ca0b1b0c5c572a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardId")
    def dashboard_id(self) -> builtins.str:
        '''The ID for the dashboard, also added to the IAM policy.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
        '''
        return typing.cast(builtins.str, jsii.get(self, "dashboardId"))

    @dashboard_id.setter
    def dashboard_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5301c495ef1da983fed04f9a79dafdfcdbcf5f93d9b80a95ec40d4bbce9f96de)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dashboardId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        '''The display name of the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
        '''
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__730a11f7cdb02ebc45d7edd30fc4a772ba1242c7d725576629010c388a0cf799)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardPublishOptions")
    def dashboard_publish_options(
        self,
    ) -> typing.Optional[typing.Union["CfnDashboard.DashboardPublishOptionsProperty", _IResolvable_a771d0ef]]:
        '''Options for publishing the dashboard when you create it:.

        - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default.
        - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default.
        - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDashboard.DashboardPublishOptionsProperty", _IResolvable_a771d0ef]], jsii.get(self, "dashboardPublishOptions"))

    @dashboard_publish_options.setter
    def dashboard_publish_options(
        self,
        value: typing.Optional[typing.Union["CfnDashboard.DashboardPublishOptionsProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7396ee87e03c05a902bfe34113d6e73b88d00551f37146130baff454c2f3d0dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dashboardPublishOptions", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union["CfnDashboard.DashboardVersionDefinitionProperty", _IResolvable_a771d0ef]]:
        '''``AWS::QuickSight::Dashboard.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDashboard.DashboardVersionDefinitionProperty", _IResolvable_a771d0ef]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union["CfnDashboard.DashboardVersionDefinitionProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45ddce7b891f3ac7f46f2d165695fb3dd5e32db8045c36cdc937497a871fc245)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(
        self,
    ) -> typing.Optional[typing.Union["CfnDashboard.ParametersProperty", _IResolvable_a771d0ef]]:
        '''The parameters for the creation of the dashboard, which you want to use to override the default settings.

        A dashboard can have any type of parameters, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParametersProperty", _IResolvable_a771d0ef]], jsii.get(self, "parameters"))

    @parameters.setter
    def parameters(
        self,
        value: typing.Optional[typing.Union["CfnDashboard.ParametersProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__31f151d03ebda269486f5636f6a6ad053c6dfd6ee31f857e760a5ba0380a4ca5)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ResourcePermissionProperty", _IResolvable_a771d0ef]]]]:
        '''A structure that contains the permissions of the dashboard.

        You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.

        To specify no permissions, omit the permissions list.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ResourcePermissionProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ResourcePermissionProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__92d106ff1b2a25daaf75374f6e6573c1247a1ecb92d1342051148ed7723ca312)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union["CfnDashboard.DashboardSourceEntityProperty", _IResolvable_a771d0ef]]:
        '''The entity that you are using as a source when you create the dashboard.

        In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDashboard.DashboardSourceEntityProperty", _IResolvable_a771d0ef]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union["CfnDashboard.DashboardSourceEntityProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7b29cacfc7182ab6363c0bf43ef88f2e8030f3de4d7db7bffab801daa62cecc2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="themeArn")
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.

        If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "themeArn"))

    @theme_arn.setter
    def theme_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7a9ac3ccaa022efa1cac072700176ccb4dacaef3b71b97da0396d3679162a21c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeArn", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description for the first version of the dashboard being created.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4eb8035f2879f71edfb344180e4670c1330ed0f81ee294235d43810a64247224)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AdHocFilteringOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class AdHocFilteringOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An ad hoc (one-time) filtering option.

            :param availability_status: Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                ad_hoc_filtering_option_property = quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4dfa1ef920e589a2e4fbc13091836f2392b639a09fa1a645a8b144420e99a65)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html#cfn-quicksight-dashboard-adhocfilteringoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AdHocFilteringOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnDashboard.AggregationFunctionProperty(
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cb97c0064165f20ffab51850ae4862d72198efb0f3410728190476990f398396)
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_function": "aggregationFunction",
            "column": "column",
            "sort_direction": "sortDirection",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            aggregation_function: typing.Union[typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            sort_direction: builtins.str,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param aggregation_function: The function that aggregates the values in ``Column`` .
            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6b9bfda7e713b8da572198869bfab194434e51f68501f1fc94e77aae04aa4c0)
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_function": aggregation_function,
                "column": column,
                "sort_direction": sort_direction,
            }

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The function that aggregates the values in ``Column`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            assert result is not None, "Required property 'aggregation_function' is missing"
            return typing.cast(typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that determines the sort order of aggregated values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[typing.Union["CfnDashboard.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnDashboard.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c84a70192ae99e55472eaf0ef9de90eaf8afab6d8451bf2101614c1e4164d78e)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union["CfnDashboard.DefaultNewSheetConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html#cfn-quicksight-dashboard-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.DefaultNewSheetConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__909cb3e8f99bbd4b88258264751547e5aebc6c3cf22a39b28c199c9059be7af3)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[typing.Union["CfnDashboard.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                    range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7f3b231df90c9e5461604f0c44004c92c724bd08249cd9cd4adc7cc27b9682c)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ArcAxisDisplayRangeProperty", _IResolvable_a771d0ef]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ArcAxisDisplayRangeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a8bac5787083212b62f824c94e42420d0fbf2b6900fbbf1d812b3b0f45614566)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnDashboard.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a02e331dea32aac051c4e773d7427bd8d1b8a700306d83b29127d8101c100c45)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnDashboard.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb92c9ab08d08f855601355a00a3767c200bd757c4a1c683e885680fb7de773b)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html#cfn-quicksight-dashboard-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_axis_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnDashboard.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5fe905cb4eec44ae877753b58706b183a29a35b34228851a0396b90b96569081)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateAxisOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for an axis with a date field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateAxisOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericAxisOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericAxisOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a4b0f4c4dcfcf51b93952d7b5c224e95448f0b170e796a4dbfee7b30151200f)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tick_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e96376beae3f8fdc5bf6e2c819a38e7bac549ee0cf77f0f2cc9762f3dcb8c69)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDataOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDataOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ScrollBarOptionsProperty", _IResolvable_a771d0ef]]:
            '''The scroll bar options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ScrollBarOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisTickLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisTickLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnDashboard.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d54500a0be4d2d2d38ee59011faff429f3f52f54e43c1302840b2ecb0346ee66)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayMinMaxRangeProperty", _IResolvable_a771d0ef]]:
            '''The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayMinMaxRangeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnDashboard.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec616a0c4183cc3e0cfef5a259dc2ee67d1bf74fc5e22f45169517a90ae1a25b)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisLabelReferenceOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that indicate which field the label belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisLabelReferenceOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ebd6114268b78fb7f73113055f755a6ade3d3994fd6870bb792075befa1bead8)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnDashboard.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e73da89bbf26c0741917b0f0fc3debe5644233f626d9e2f4fc31a704bf645c80)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0a79903b0b74b55b9283b4c4f3c713dec760534188a08f13507f44d5bcddd9b)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html#cfn-quicksight-dashboard-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            logarithmic: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnDashboard.AxisScaleProperty(
                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e1f05a0d27fed41c8676ca0bbd6640dcf334b8eb901853ba5a5a6e5ae902a6c)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisLinearScaleProperty", _IResolvable_a771d0ef]]:
            '''The linear axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisLinearScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisLogarithmicScaleProperty", _IResolvable_a771d0ef]]:
            '''The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisLogarithmicScaleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99f8d4dfbed10bf2df8879ec1fda99532fd137630cacfec7f5330870283b7496)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines whether or not the axis ticks are visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_aggregated_field_wells_property = quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4654c555a5e72d37b2de0dfbc87c5387ac27a3e7d68bd6d05abebbff6bb30fa4)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category (y-axis) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color (group/color) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_configuration_property = quicksight.CfnDashboard.BarChartConfigurationProperty(
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                        bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    orientation="orientation",
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22514ea70cb51894c2e9751cba44a306bcaa090fbcc774991de12a812297adff)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BarChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BarChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BarChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BarChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_field_wells_property = quicksight.CfnDashboard.BarChartFieldWellsProperty(
                    bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55170086347690041cc9c79d7e96dc02cdb90af9b495ba326c4d801ce19e992e)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html#cfn-quicksight-dashboard-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__647fa37868b0610cea0d4ecf9b811af20335bd80f0c9b7ae7c404bb5333bed28)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of values displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of color fields in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_visual_property = quicksight.CfnDashboard.BarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                            bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        orientation="orientation",
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d372b2339c4765cc558d57d4fd2a13fbbafdc5afa56a7eb1fa2c9fc25d5f550f)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BarChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BarChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnDashboard.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb1e06c1c2bdc3845f0ac1cd695aabecd7f296e936a44659395d8721897d0ed2)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html#cfn-quicksight-dashboard-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnDashboard.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__379db281a6d09f9856995b7e2b0d1aa61e435c83657dd6962252102ec4daa6c5)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[typing.Union["CfnDashboard.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            style: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnDashboard.BodySectionConfigurationProperty(
                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnDashboard.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6142ff2269d23575bf404a5b436d0dbec950b79d5bbc1754cc1c30a6736980d)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union["CfnDashboard.BodySectionContentProperty", _IResolvable_a771d0ef]:
            '''The configuration of content in a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union["CfnDashboard.BodySectionContentProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionPageBreakConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a page break for a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionPageBreakConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionStyleProperty", _IResolvable_a771d0ef]]:
            '''The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnDashboard.BodySectionContentProperty(
                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fde9ba053987101020efcb8eca96eda01d034eb9b9358e7ac42e7a90dfd7e730)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html#cfn-quicksight-dashboard-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67625cc6a51178f2526ac4a5a2067bc2cb4304ef72229dc85ec9004c2e5ca4ac)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: ``CfnDashboard.BoxPlotChartConfigurationProperty.Legend``.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_chart_configuration_property = quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                    box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                        all_data_points_visibility="allDataPointsVisibility",
                        outlier_visibility="outlierVisibility",
                        style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                            fill_style="fillStyle"
                        )
                    ),
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                        box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        )
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3a25cd7bb4b6ad6a56cc903abc0f68a11bc62908e120fa2320e877623dd87b8)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotOptionsProperty", _IResolvable_a771d0ef]]:
            '''The box plot chart options for a box plot visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.BoxPlotChartConfigurationProperty.Legend``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__301dd661aeeab3012053b6c6642da9909e4b194786997f5ee4dffdd44b8ee86d)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html#cfn-quicksight-dashboard-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnDashboard.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ee06140e0a2d02984b6c3a00e9f8d9d7f013cf158dfd50e639770ee664f08bb)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1b06cd4e7ac52a30564cb4f8a9f5a7faed6b818cd5d0f058ca558db6c7965f0a)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of a group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PaginationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PaginationConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da2f3994884ebc6f952c0f2967194d8d660e370e5ab587c58c4b0837f5dcaf5c)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html#cfn-quicksight-dashboard-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_visual_property = quicksight.CfnDashboard.BoxPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                        box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                            all_data_points_visibility="allDataPointsVisibility",
                            outlier_visibility="outlierVisibility",
                            style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                fill_style="fillStyle"
                            )
                        ),
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                            box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            )
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9105639d730530a60e1af79cb946b2d032926c53dcf1268b07083a923b2ee871)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnDashboard.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__332a55157515a42a181ebc3bdad830321797d88781ac76fe6b51cde8a6d3a645)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0095e20a5495ebf932f1a63e3cb0de46e6c94f92a7d415eab217cd4895e394a2)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c65623178b2ff4db29478d3cd2f6d6221e33638765800bb224dbe8b54ee23119)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.CascadingControlSourceProperty", _IResolvable_a771d0ef]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html#cfn-quicksight-dashboard-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.CascadingControlSourceProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnDashboard.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5bcbd104426d13db3612d853aaad48eab3730a80c9ab7e424f549999f488f987)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d6b2b1515dd7ef57aad2be08b4029d22704d37d48938f9edbee52d01628b1487)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6da96a77134fcac6237a980856bddb24526d6ec0de070b60f7f3a30e735c2691)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b01c5fbad36c204f197c990d62d65e9d0c2c4bc602ef4c4374605dee29e55f8)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filter_list_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f9d07b256a4b37a411e6cc0fe869f67003cf02c57581fd5ef45605129e9ac9c)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomFilterConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomFilterConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomFilterListConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomFilterListConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterListConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterListConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            configuration: typing.Union[typing.Union["CfnDashboard.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnDashboard.CategoryFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1de37bd80db27a90003f8108e43a7aab75c0a2c53a1fdbd6455a03a984f40923)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnDashboard.CategoryFilterConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration for a ``CategoryFilter`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.CategoryFilterConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99dac514cea0a1491ea4b4adbfd7953ddb28d8c78ac2148de8c8cb4a9f936f71)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.AxisLabelOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The label options for a chart axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.AxisLabelOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[typing.Union["CfnDashboard.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23bd85afa1dfb517f88840b0c80cf50332722e5c0d23fcaacf9d243fe805b57c)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ClusterMarkerProperty", _IResolvable_a771d0ef]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html#cfn-quicksight-dashboard-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ClusterMarkerProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[typing.Union["CfnDashboard.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnDashboard.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa062eb55e634c336431d3c096682ae95112d0349bf0957f1c8753a42d57956c)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SimpleClusterMarkerProperty", _IResolvable_a771d0ef]]:
            '''The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html#cfn-quicksight-dashboard-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SimpleClusterMarkerProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            null_value_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnDashboard.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnDashboard.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6e1e23d89d50d95b98fa8dd6f596ee1ba35ddbe113cf9021276f03368188c46)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataColorProperty", _IResolvable_a771d0ef]]]:
            '''Determines the list of colors that are applied to the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataColorProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataColorProperty", _IResolvable_a771d0ef]]:
            '''Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.CustomColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''
            :param custom_colors: ``CfnDashboard.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnDashboard.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c25d31f5f6d13b184b20d84d346505a64e943bd5aef472be2efeca2d48df4e48)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.CustomColorProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnDashboard.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html#cfn-quicksight-dashboard-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.CustomColorProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            colors_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: ``CfnDashboard.ColumnConfigurationProperty.ColorsConfiguration``.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnDashboard.ColumnConfigurationProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7981e3cbc6fe90b5523bee80b128b0181ec43755b2dcb4059e25a334ecebb564)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColorsConfigurationProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.ColumnConfigurationProperty.ColorsConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColorsConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[typing.Union["CfnDashboard.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[typing.Union["CfnDashboard.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnDashboard.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b340863e3ced361fe48b2bacc3838348804ad403b1d49e11fe727c1a12cbf913)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeHierarchyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ExplicitHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ExplicitHierarchyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PredefinedHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PredefinedHierarchyProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnDashboard.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__beab3a1ed755be578788c099d8f74ba209e4e24def4550b2b8ae0e8198db39a1)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: ``CfnDashboard.ColumnSortProperty.SortBy``.
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnDashboard.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0dda260e997e7560a75707e65303e2be908461401ef5126a83c64bb838d66861)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''``CfnDashboard.ColumnSortProperty.SortBy``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            aggregation: typing.Optional[typing.Union[typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnDashboard.ColumnTooltipItemProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__782e799a1646956f02a2971525b76e9c925fba9aceae6cf968588bd8e3c772e9)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The target column of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the column tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            line_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_aggregated_field_wells_property = quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                    bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7cb3d6d39fdba781f0f190529dc8f746b1b58a17ba7ee4360d5b96a8d1e5f22)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated category field wells of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated colors field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            line_data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_configuration_property = quicksight.CfnDashboard.ComboChartConfigurationProperty(
                    bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                        combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                            bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f36bda3941656469a40e83aebfb537492008f380eefdf05bee66715f7f3c5a9d)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category axis of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComboChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComboChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComboChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComboChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_field_wells_property = quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                    combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                        bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be2181c82ce78a39b10a5ae695ebbb80bb0eb5aae8349f15aa8fb33e162565b9)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComboChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html#cfn-quicksight-dashboard-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComboChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff98fa6b0c8fb2e67a127adde960b8c028920d511d35aad1ec6265fa0bf35cba)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The item limit configuration for the category field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The item limit configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_visual_property = quicksight.CfnDashboard.ComboChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                        bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                            combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e0dc16849294861b5d6e86d271d8bce76ce85506bb130654547837799389f11)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComboChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComboChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnDashboard.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45a3c815b98791aa8322f230091c3d047176d34646febad79bad448f25ea0e0a)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComparisonFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format of the comparison.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComparisonFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c6f707ad6ec02c67d02c131935d1d8b50023bfe4ae5487861af59774f42f7ae)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The number display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[typing.Union["CfnDashboard.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            growth_rate: typing.Optional[typing.Union[typing.Union["CfnDashboard.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maximum_minimum: typing.Optional[typing.Union[typing.Union["CfnDashboard.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            metric_comparison: typing.Optional[typing.Union[typing.Union["CfnDashboard.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            period_over_period: typing.Optional[typing.Union[typing.Union["CfnDashboard.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            period_to_date: typing.Optional[typing.Union[typing.Union["CfnDashboard.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_movers: typing.Optional[typing.Union[typing.Union["CfnDashboard.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[typing.Union["CfnDashboard.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_aggregation: typing.Optional[typing.Union[typing.Union["CfnDashboard.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            unique_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                computation_property = quicksight.CfnDashboard.ComputationProperty(
                    forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        custom_seasonality_value=123,
                        lower_boundary=123,
                        name="name",
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality="seasonality",
                        upper_boundary=123,
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_size=123,
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                        computation_id="computationId",
                        from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_time_granularity="periodTimeGranularity",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        mover_size=123,
                        name="name",
                        sort_order="sortOrder",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        result_size=123,
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                        computation_id="computationId",
                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                
                        # the properties below are optional
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc628ca1b0b5a5527e515f0164330ad2fc08ee65cc484e12f998eeda6c327db7)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ForecastComputationProperty", _IResolvable_a771d0ef]]:
            '''The forecast computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ForecastComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GrowthRateComputationProperty", _IResolvable_a771d0ef]]:
            '''The growth rate computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GrowthRateComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MaximumMinimumComputationProperty", _IResolvable_a771d0ef]]:
            '''The maximum and minimum computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MaximumMinimumComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MetricComparisonComputationProperty", _IResolvable_a771d0ef]]:
            '''The metric comparison computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MetricComparisonComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PeriodOverPeriodComputationProperty", _IResolvable_a771d0ef]]:
            '''The period over period computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PeriodOverPeriodComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PeriodToDateComputationProperty", _IResolvable_a771d0ef]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PeriodToDateComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TopBottomMoversComputationProperty", _IResolvable_a771d0ef]]:
            '''The top movers and bottom movers computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TopBottomMoversComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TopBottomRankedComputationProperty", _IResolvable_a771d0ef]]:
            '''The top ranked and bottom ranked computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TopBottomRankedComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TotalAggregationComputationProperty", _IResolvable_a771d0ef]]:
            '''The total aggregation computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TotalAggregationComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.UniqueValuesComputationProperty", _IResolvable_a771d0ef]]:
            '''The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.UniqueValuesComputationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            solid: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnDashboard.GradientColorProperty(
                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__203eb2943ec82b0c26a7fba45cef47f33ac0635d522cf58ef4a7c0ce4521191f)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingGradientColorProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingGradientColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingSolidColorProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingSolidColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[typing.Union["CfnDashboard.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80c0bdc03af4bb1bbde14503d2fb6e1d802415013c6391cdbf7421e3c951f200)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union["CfnDashboard.ConditionalFormattingCustomIconOptionsProperty", _IResolvable_a771d0ef]:
            '''Custom icon options for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union["CfnDashboard.ConditionalFormattingCustomIconOptionsProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__294b301119aba6f233c6f86ad6a8ad2beb5f50a726c3bf45442d2ed4f82c246e)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[typing.Union["CfnDashboard.GradientColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnDashboard.GradientColorProperty(
                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4036a7f599e9157c62b518b185dc1466e18cedd9e4e8f7ea431899b21a6909d0)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union["CfnDashboard.GradientColorProperty", _IResolvable_a771d0ef]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union["CfnDashboard.GradientColorProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__03f4179bcef46c0d291fbbb5e1d54dc19d0fb38b2cdebcfb7b8ee6ec9d959a70)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-dashboard-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            icon_set: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__466b512fa9803770ce0c883b94a51b01507b07a73e170fd7f3041ebd07e39b62)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingCustomIconConditionProperty", _IResolvable_a771d0ef]]:
            '''Determines the custom condition for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingCustomIconConditionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconSetProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconSetProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0ff2a07e962756bac81335cd1384fe375d579e3ac032d9b2eb1857df4b5d51af)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bbbbc6881f46b06edc10bcdedf51a79690625c8a047b4d557fa0235e23f2ab4e)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ceecae11ac13c6fe0f286e7b2805578aa405c0ca7d689d9a2c1e9a8111cdf496)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea6cddf33ff223ebf71e6a6a3244e598f8593cd3667e41a5cd7ce3b15e3ea42e)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[typing.Union["CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target_visuals_configuration: typing.Union[typing.Union["CfnDashboard.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26c4b80cb587a8fa2ca1e2abde36a92317c1f2fdfa5401ddc628ce4bf2573e53)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union["CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that chooses the fields to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union["CfnDashboard.FilterOperationTargetVisualsConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.FilterOperationTargetVisualsConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2015ff32afac777991b1c982d7dd76e0566f211be49c9fb4a0f877e0a173f798)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LocalNavigationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html#cfn-quicksight-dashboard-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LocalNavigationConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52afd365c2620982c04a8b0c19dc7cacc4b06aef3e35fabffd3bdc361fff85f8)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SetParameterValueConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html#cfn-quicksight-dashboard-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SetParameterValueConfigurationProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnDashboard.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ad65d3b8348c9a010276bc1dbeb9dba3b69ddfd44e931ab961cf81102546e20)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param color: ``CfnDashboard.CustomColorProperty.Color``.
            :param field_value: ``CfnDashboard.CustomColorProperty.FieldValue``.
            :param special_value: ``CfnDashboard.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnDashboard.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c4e10b508766abaf50cee10ecb1b3a2a209234d26095dc829eb93f8c05b3ccd)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''``CfnDashboard.CustomColorProperty.Color``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''``CfnDashboard.CustomColorProperty.FieldValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''``CfnDashboard.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnDashboard.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aae4658560321c2237342cc32ddd3586a9e9697361d5858b42738ddea71e57e2)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnDashboard.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3de8b5270a6e1feac0da7879f22737e3e6590939819dcca70b5eea7b33e4a31b)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomContentConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``CustomContentVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomContentConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d87f4f67fd255186f1dc0a6a3feca38c02d78c48da2481218e329ce80accf574)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c6acae590190d5b37bfe6f336517f7255ae2af5c457cdc915261d1495c68b80)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__466714a1e3d97920b747f1ce3bfa45c5bb06ba8a6f7369b1fe4825f125053e68)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html#cfn-quicksight-dashboard-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnDashboard.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93ef0df1e627e28a49ffa7ddd2e44b9297e40851aabcdb11966471f9ced0e46f)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[typing.Union["CfnDashboard.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: ``CfnDashboard.CustomValuesConfigurationProperty.CustomValues``.
            :param include_null_value: Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__044590f84959517e71beaed79a72965a66e66df79acf8a43a2103842188d7013)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union["CfnDashboard.CustomParameterValuesProperty", _IResolvable_a771d0ef]:
            '''``CfnDashboard.CustomValuesConfigurationProperty.CustomValues``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union["CfnDashboard.CustomParameterValuesProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class DashboardErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.EntityProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Dashboard error.

            :param message: Message.
            :param type: Type.
            :param violated_entities: Lists the violated entities that caused the dashboard error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dashboard_error_property = quicksight.CfnDashboard.DashboardErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnDashboard.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd6ca68139cd35a4db90289be255630ee376ee0f40a607ee72673b356fd8ec61)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.EntityProperty", _IResolvable_a771d0ef]]]]:
            '''Lists the violated entities that caused the dashboard error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.EntityProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardPublishOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "ad_hoc_filtering_option": "adHocFilteringOption",
            "data_point_drill_up_down_option": "dataPointDrillUpDownOption",
            "data_point_menu_label_option": "dataPointMenuLabelOption",
            "data_point_tooltip_option": "dataPointTooltipOption",
            "export_to_csv_option": "exportToCsvOption",
            "export_with_hidden_fields_option": "exportWithHiddenFieldsOption",
            "sheet_controls_option": "sheetControlsOption",
            "sheet_layout_element_maximization_option": "sheetLayoutElementMaximizationOption",
            "visual_axis_sort_option": "visualAxisSortOption",
            "visual_menu_option": "visualMenuOption",
            "visual_publish_options": "visualPublishOptions",
        },
    )
    class DashboardPublishOptionsProperty:
        def __init__(
            self,
            *,
            ad_hoc_filtering_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.AdHocFilteringOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_point_drill_up_down_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataPointDrillUpDownOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_point_menu_label_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataPointMenuLabelOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_point_tooltip_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataPointTooltipOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            export_to_csv_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.ExportToCSVOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            export_with_hidden_fields_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.ExportWithHiddenFieldsOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sheet_controls_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.SheetControlsOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sheet_layout_element_maximization_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.SheetLayoutElementMaximizationOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_axis_sort_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualAxisSortOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_menu_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualMenuOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_publish_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DashboardVisualPublishOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Dashboard publish options.

            :param ad_hoc_filtering_option: Ad hoc (one-time) filtering option.
            :param data_point_drill_up_down_option: The drill-down options of data points in a dashboard.
            :param data_point_menu_label_option: The data point menu label options of a dashboard.
            :param data_point_tooltip_option: The data point tool tip options of a dashboard.
            :param export_to_csv_option: Export to .csv option.
            :param export_with_hidden_fields_option: Determines if hidden fields are exported with a dashboard.
            :param sheet_controls_option: Sheet controls option.
            :param sheet_layout_element_maximization_option: The sheet layout maximization options of a dashbaord.
            :param visual_axis_sort_option: The axis sort options of a dashboard.
            :param visual_menu_option: The menu options of a visual in a dashboard.
            :param visual_publish_options: The visual publish options of a visual in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dashboard_publish_options_property = quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                    ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                        visibility_state="visibilityState"
                    ),
                    sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                        export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                            availability_status="availabilityStatus"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c3a6c9494c32821db96d3fdf49fb81da1fd383bf02d74a853fe0cef4d778c84)
                check_type(argname="argument ad_hoc_filtering_option", value=ad_hoc_filtering_option, expected_type=type_hints["ad_hoc_filtering_option"])
                check_type(argname="argument data_point_drill_up_down_option", value=data_point_drill_up_down_option, expected_type=type_hints["data_point_drill_up_down_option"])
                check_type(argname="argument data_point_menu_label_option", value=data_point_menu_label_option, expected_type=type_hints["data_point_menu_label_option"])
                check_type(argname="argument data_point_tooltip_option", value=data_point_tooltip_option, expected_type=type_hints["data_point_tooltip_option"])
                check_type(argname="argument export_to_csv_option", value=export_to_csv_option, expected_type=type_hints["export_to_csv_option"])
                check_type(argname="argument export_with_hidden_fields_option", value=export_with_hidden_fields_option, expected_type=type_hints["export_with_hidden_fields_option"])
                check_type(argname="argument sheet_controls_option", value=sheet_controls_option, expected_type=type_hints["sheet_controls_option"])
                check_type(argname="argument sheet_layout_element_maximization_option", value=sheet_layout_element_maximization_option, expected_type=type_hints["sheet_layout_element_maximization_option"])
                check_type(argname="argument visual_axis_sort_option", value=visual_axis_sort_option, expected_type=type_hints["visual_axis_sort_option"])
                check_type(argname="argument visual_menu_option", value=visual_menu_option, expected_type=type_hints["visual_menu_option"])
                check_type(argname="argument visual_publish_options", value=visual_publish_options, expected_type=type_hints["visual_publish_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if ad_hoc_filtering_option is not None:
                self._values["ad_hoc_filtering_option"] = ad_hoc_filtering_option
            if data_point_drill_up_down_option is not None:
                self._values["data_point_drill_up_down_option"] = data_point_drill_up_down_option
            if data_point_menu_label_option is not None:
                self._values["data_point_menu_label_option"] = data_point_menu_label_option
            if data_point_tooltip_option is not None:
                self._values["data_point_tooltip_option"] = data_point_tooltip_option
            if export_to_csv_option is not None:
                self._values["export_to_csv_option"] = export_to_csv_option
            if export_with_hidden_fields_option is not None:
                self._values["export_with_hidden_fields_option"] = export_with_hidden_fields_option
            if sheet_controls_option is not None:
                self._values["sheet_controls_option"] = sheet_controls_option
            if sheet_layout_element_maximization_option is not None:
                self._values["sheet_layout_element_maximization_option"] = sheet_layout_element_maximization_option
            if visual_axis_sort_option is not None:
                self._values["visual_axis_sort_option"] = visual_axis_sort_option
            if visual_menu_option is not None:
                self._values["visual_menu_option"] = visual_menu_option
            if visual_publish_options is not None:
                self._values["visual_publish_options"] = visual_publish_options

        @builtins.property
        def ad_hoc_filtering_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AdHocFilteringOptionProperty", _IResolvable_a771d0ef]]:
            '''Ad hoc (one-time) filtering option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-adhocfilteringoption
            '''
            result = self._values.get("ad_hoc_filtering_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AdHocFilteringOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_point_drill_up_down_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataPointDrillUpDownOptionProperty", _IResolvable_a771d0ef]]:
            '''The drill-down options of data points in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointdrillupdownoption
            '''
            result = self._values.get("data_point_drill_up_down_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataPointDrillUpDownOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_point_menu_label_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataPointMenuLabelOptionProperty", _IResolvable_a771d0ef]]:
            '''The data point menu label options of a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointmenulabeloption
            '''
            result = self._values.get("data_point_menu_label_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataPointMenuLabelOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_point_tooltip_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataPointTooltipOptionProperty", _IResolvable_a771d0ef]]:
            '''The data point tool tip options of a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointtooltipoption
            '''
            result = self._values.get("data_point_tooltip_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataPointTooltipOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def export_to_csv_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ExportToCSVOptionProperty", _IResolvable_a771d0ef]]:
            '''Export to .csv option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exporttocsvoption
            '''
            result = self._values.get("export_to_csv_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ExportToCSVOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def export_with_hidden_fields_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ExportWithHiddenFieldsOptionProperty", _IResolvable_a771d0ef]]:
            '''Determines if hidden fields are exported with a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exportwithhiddenfieldsoption
            '''
            result = self._values.get("export_with_hidden_fields_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ExportWithHiddenFieldsOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sheet_controls_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SheetControlsOptionProperty", _IResolvable_a771d0ef]]:
            '''Sheet controls option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetcontrolsoption
            '''
            result = self._values.get("sheet_controls_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SheetControlsOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sheet_layout_element_maximization_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SheetLayoutElementMaximizationOptionProperty", _IResolvable_a771d0ef]]:
            '''The sheet layout maximization options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetlayoutelementmaximizationoption
            '''
            result = self._values.get("sheet_layout_element_maximization_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SheetLayoutElementMaximizationOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_axis_sort_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualAxisSortOptionProperty", _IResolvable_a771d0ef]]:
            '''The axis sort options of a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualaxissortoption
            '''
            result = self._values.get("visual_axis_sort_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualAxisSortOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_menu_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualMenuOptionProperty", _IResolvable_a771d0ef]]:
            '''The menu options of a visual in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualmenuoption
            '''
            result = self._values.get("visual_menu_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualMenuOptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_publish_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DashboardVisualPublishOptionsProperty", _IResolvable_a771d0ef]]:
            '''The visual publish options of a visual in a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualpublishoptions
            '''
            result = self._values.get("visual_publish_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DashboardVisualPublishOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardPublishOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={"source_template": "sourceTemplate"},
    )
    class DashboardSourceEntityProperty:
        def __init__(
            self,
            *,
            source_template: typing.Optional[typing.Union[typing.Union["CfnDashboard.DashboardSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Dashboard source entity.

            :param source_template: Source template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dashboard_source_entity_property = quicksight.CfnDashboard.DashboardSourceEntityProperty(
                    source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39726a9b37c0f1dc57a7bd3725141ceb75cfadeff237d0e329d881f67f7457ae)
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DashboardSourceTemplateProperty", _IResolvable_a771d0ef]]:
            '''Source template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html#cfn-quicksight-dashboard-dashboardsourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DashboardSourceTemplateProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class DashboardSourceTemplateProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''Dashboard source template.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param data_set_references: Dataset references.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dashboard_source_template_property = quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6a1b846dad44daf0d4bec8ad0b5511357e5b2ec6138a75bb837e3867381ec68)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataSetReferenceProperty", _IResolvable_a771d0ef]]]:
            '''Dataset references.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataSetReferenceProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardVersionDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier_declarations": "dataSetIdentifierDeclarations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class DashboardVersionDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_identifier_declarations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataSetIdentifierDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            analysis_defaults: typing.Optional[typing.Union[typing.Union["CfnDashboard.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            column_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            filter_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The contents of a dashboard.

            :param data_set_identifier_declarations: An array of dataset identifier declarations. With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.
            :param analysis_defaults: ``CfnDashboard.DashboardVersionDefinitionProperty.AnalysisDefaults``.
            :param calculated_fields: An array of calculated field definitions for the dashboard.
            :param column_configurations: An array of dashboard-level column configurations. Column configurations are used to set the default formatting for a column that is used throughout a dashboard.
            :param filter_groups: The filter definitions for a dashboard. For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .
            :param parameter_declarations: The parameter declarations for a dashboard. Parameters are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                dashboard_version_definition_property = quicksight.CfnDashboard.DashboardVersionDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
                
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnDashboard.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnDashboard.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnDashboard.ColumnConfigurationProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                                color="color",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnDashboard.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnDashboard.FilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
                
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
                
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnDashboard.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                            name="name",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnDashboard.SheetDefinitionProperty(
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnDashboard.LayoutProperty(
                            configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
                
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                            configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
                
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnDashboard.VisualProperty(
                            bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                    computations=[quicksight.CfnDashboard.ComputationProperty(
                                        forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnDashboard.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                        arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
                
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                                column=quicksight.CfnDashboard.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnDashboard.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnDashboard.TableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
                
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f66c531b006e8f2c1f3d9294751f7827408a6a649a8eead3cd7e6eacc00b9aa6)
                check_type(argname="argument data_set_identifier_declarations", value=data_set_identifier_declarations, expected_type=type_hints["data_set_identifier_declarations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier_declarations": data_set_identifier_declarations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_identifier_declarations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataSetIdentifierDeclarationProperty", _IResolvable_a771d0ef]]]:
            '''An array of dataset identifier declarations.

            With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-datasetidentifierdeclarations
            '''
            result = self._values.get("data_set_identifier_declarations")
            assert result is not None, "Required property 'data_set_identifier_declarations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataSetIdentifierDeclarationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AnalysisDefaultsProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.DashboardVersionDefinitionProperty.AnalysisDefaults``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AnalysisDefaultsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.CalculatedFieldProperty", _IResolvable_a771d0ef]]]]:
            '''An array of calculated field definitions for the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.CalculatedFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''An array of dashboard-level column configurations.

            Column configurations are used to set the default formatting for a column that is used throughout a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilterGroupProperty", _IResolvable_a771d0ef]]]]:
            '''The filter definitions for a dashboard.

            For more information, see `Filtering Data in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilterGroupProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ParameterDeclarationProperty", _IResolvable_a771d0ef]]]]:
            '''The parameter declarations for a dashboard.

            Parameters are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ParameterDeclarationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetDefinitionProperty", _IResolvable_a771d0ef]]]]:
            '''An array of sheet definitions for a dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetDefinitionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVersionDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "created_time": "createdTime",
            "data_set_arns": "dataSetArns",
            "description": "description",
            "errors": "errors",
            "sheets": "sheets",
            "source_entity_arn": "sourceEntityArn",
            "status": "status",
            "theme_arn": "themeArn",
            "version_number": "versionNumber",
        },
    )
    class DashboardVersionProperty:
        def __init__(
            self,
            *,
            arn: typing.Optional[builtins.str] = None,
            created_time: typing.Optional[builtins.str] = None,
            data_set_arns: typing.Optional[typing.Sequence[builtins.str]] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DashboardErrorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SheetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            source_entity_arn: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            theme_arn: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Dashboard version.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param created_time: The time that this dashboard version was created.
            :param data_set_arns: The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
            :param description: Description.
            :param errors: Errors associated with this dashboard version.
            :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
            :param source_entity_arn: Source entity ARN.
            :param status: The HTTP status of the request.
            :param theme_arn: The ARN of the theme associated with a version of the dashboard.
            :param version_number: Version number for this version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dashboard_version_property = quicksight.CfnDashboard.DashboardVersionProperty(
                    arn="arn",
                    created_time="createdTime",
                    data_set_arns=["dataSetArns"],
                    description="description",
                    errors=[quicksight.CfnDashboard.DashboardErrorProperty(
                        message="message",
                        type="type",
                        violated_entities=[quicksight.CfnDashboard.EntityProperty(
                            path="path"
                        )]
                    )],
                    sheets=[quicksight.CfnDashboard.SheetProperty(
                        name="name",
                        sheet_id="sheetId"
                    )],
                    source_entity_arn="sourceEntityArn",
                    status="status",
                    theme_arn="themeArn",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7580ee893f6e5d4a22ac976da4dcfc6406c522ca02e7de52dc025a237b2cbeb)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument data_set_arns", value=data_set_arns, expected_type=type_hints["data_set_arns"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
                check_type(argname="argument source_entity_arn", value=source_entity_arn, expected_type=type_hints["source_entity_arn"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arn is not None:
                self._values["arn"] = arn
            if created_time is not None:
                self._values["created_time"] = created_time
            if data_set_arns is not None:
                self._values["data_set_arns"] = data_set_arns
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if sheets is not None:
                self._values["sheets"] = sheets
            if source_entity_arn is not None:
                self._values["source_entity_arn"] = source_entity_arn
            if status is not None:
                self._values["status"] = status
            if theme_arn is not None:
                self._values["theme_arn"] = theme_arn
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-arn
            '''
            result = self._values.get("arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The time that this dashboard version was created.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_set_arns(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-datasetarns
            '''
            result = self._values.get("data_set_arns")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''Description.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DashboardErrorProperty", _IResolvable_a771d0ef]]]]:
            '''Errors associated with this dashboard version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DashboardErrorProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetProperty", _IResolvable_a771d0ef]]]]:
            '''A list of the associated sheets with the unique identifier and name of each sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def source_entity_arn(self) -> typing.Optional[builtins.str]:
            '''Source entity ARN.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sourceentityarn
            '''
            result = self._values.get("source_entity_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The HTTP status of the request.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def theme_arn(self) -> typing.Optional[builtins.str]:
            '''The ARN of the theme associated with a version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-themearn
            '''
            result = self._values.get("theme_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''Version number for this version of the dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"export_hidden_fields_option": "exportHiddenFieldsOption"},
    )
    class DashboardVisualPublishOptionsProperty:
        def __init__(
            self,
            *,
            export_hidden_fields_option: typing.Optional[typing.Union[typing.Union["CfnDashboard.ExportHiddenFieldsOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The visual publish options of a visual in a dashboard.

            :param export_hidden_fields_option: Determines if hidden fields are included in an exported dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dashboard_visual_publish_options_property = quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                    export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55c64a9e491a2365c239883fb37285f7f550e5f5813b03d7959552afaf238a77)
                check_type(argname="argument export_hidden_fields_option", value=export_hidden_fields_option, expected_type=type_hints["export_hidden_fields_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if export_hidden_fields_option is not None:
                self._values["export_hidden_fields_option"] = export_hidden_fields_option

        @builtins.property
        def export_hidden_fields_option(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ExportHiddenFieldsOptionProperty", _IResolvable_a771d0ef]]:
            '''Determines if hidden fields are included in an exported dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html#cfn-quicksight-dashboard-dashboardvisualpublishoptions-exporthiddenfieldsoption
            '''
            result = self._values.get("export_hidden_fields_option")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ExportHiddenFieldsOptionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DashboardVisualPublishOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnDashboard.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__464cd8d977d96f9d8f3e4db49098939610214545f65a24f06025c931de7daa13)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnDashboard.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13b5ca3eb1fd0eb0345670fbc12e717bbf57fbb373be90568f43750445bd7b21)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1584286faefe4ac26a2f6d4d95236cf1e64ea2936e0020774dfeefd670d266aa)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param visibility: Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnDashboard.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc9545d20ae409b550d5f7246e22703fa6d2e0417e49e39ff6f156ab1a736257)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataLabelTypeProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the data label type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataLabelTypeProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Determines the font configuration of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_label_type: typing.Optional[typing.Union[typing.Union["CfnDashboard.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maximum_label_type: typing.Optional[typing.Union[typing.Union["CfnDashboard.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            minimum_label_type: typing.Optional[typing.Union[typing.Union["CfnDashboard.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_ends_label_type: typing.Optional[typing.Union[typing.Union["CfnDashboard.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnDashboard.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a97e2d2d81f7f4f2eeb4b434b0dada11b17a95d5364558ffbadc6a034ffb5a70)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataPathLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''The option that specifies individual data values for labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataPathLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FieldLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the entire field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FieldLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MaximumLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the maximum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MaximumLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MinimumLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the minimum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MinimumLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RangeEndsLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RangeEndsLabelTypeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnDashboard.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnDashboard.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe0f00f480cbd95e72189b8bd774c765c7599628c24e18704730bf6e2c33f11c)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union["CfnDashboard.DataPathValueProperty", _IResolvable_a771d0ef]:
            '''The element that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union["CfnDashboard.DataPathValueProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnDashboard.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6be538534e9017e8ac77b16ab36757837dcea7aa8a5e46b9392912e1e1b8791)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnDashboard.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a9e179ad44baf293818f66556620c9ea26ec5c96029b5eb6ef923131795efdb6)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataPathValueProperty", _IResolvable_a771d0ef]]]:
            '''The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataPathValueProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "field_value": "fieldValue"},
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            field_value: builtins.str,
        ) -> None:
            '''The data path that needs to be sorted.

            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnDashboard.DataPathValueProperty(
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f88b6be41f412a9800d8b5184cccc5a2cc69b18503db99b58fd978a0583d55c)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "field_value": field_value,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> builtins.str:
            '''The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            assert result is not None, "Required property 'field_value' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointDrillUpDownOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The drill down options for data points in a dashbaord.

            :param availability_status: The status of the drill down options of data points.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_point_drill_up_down_option_property = quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0dfa9ba0356ecb84544788e9c5f03f5cfe7634c5db2bdf23075c1f3c1b17d6a3)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the drill down options of data points.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html#cfn-quicksight-dashboard-datapointdrillupdownoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointDrillUpDownOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPointMenuLabelOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointMenuLabelOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data point menu options of a dashboard.

            :param availability_status: The status of the data point menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_point_menu_label_option_property = quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__023e8ff9b25cb8b15b81e56dc3eba2b94eca82b74b0a14cfc76393669e1c16cd)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the data point menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html#cfn-quicksight-dashboard-datapointmenulabeloption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointMenuLabelOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataPointTooltipOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class DataPointTooltipOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data point tooltip options.

            :param availability_status: The status of the data point tool tip options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_point_tooltip_option_property = quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f53a732000e256f6382e5f58403845aa0a7719ed62f6331ca8c10dc5951cf57)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the data point tool tip options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html#cfn-quicksight-dashboard-datapointtooltipoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPointTooltipOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_set_arn": "dataSetArn", "identifier": "identifier"},
    )
    class DataSetIdentifierDeclarationProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            identifier: builtins.str,
        ) -> None:
            '''A data set.

            :param data_set_arn: The Amazon Resource Name (ARN) of the data set.
            :param identifier: The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_identifier_declaration_property = quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                    data_set_arn="dataSetArn",
                    identifier="identifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ae6b64b9549272f16ba254badd0b21210ac1dcff489a3c162e45330654762d3)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "identifier": identifier,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def identifier(self) -> builtins.str:
            '''The identifier of the data set, typically the data set's name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-identifier
            '''
            result = self._values.get("identifier")
            assert result is not None, "Required property 'identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetIdentifierDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnDashboard.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2eb234144a9937a14d19def75f13d9f0a852eb199955dbe50fde7eace02ea21d)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnDashboard.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__83e96253ad4aebe41bdb92e11f0d48bab81e073d6d585835e24398600eee9290)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html#cfn-quicksight-dashboard-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnDashboard.DateDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4692a12c87c142bd49ff468c44a0cc208c8b119c92f29f8809eef693f33cb824)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``DateDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnDashboard.DateMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee0d3d361b488060844440835aa31c1944b209ba488e76595f1dedff06af830f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``DateMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rolling_date: typing.Optional[typing.Union[typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bff2fb5d78bf46a8502db54f20556ec93eb43790bb8580cd3a332913cbf6d822)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RollingDateConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RollingDateConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d7478eac1cf8912f31a3d58f6c6fe4748a397e18c53f8cff625a3049d131a79)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnDashboard.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79497bc0ea6253b57e4f671e8a2b464cbd320ab32dd7588217ca1c508ffa7cd7)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40aa516db65bb8d3e90b2a458fb21df4217f599ef6bd88e3b9818bd7d0fcbd43)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnDashboard.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimeParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DateTimeParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A date-time parameter.

            :param name: A display name for the date-time parameter.
            :param values: The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_parameter_property = quicksight.CfnDashboard.DateTimeParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bb026332bec7ec64fe0f887c6a63a5296c2cf72652b67d0c839655c2b1d83ff6)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values for the date-time parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7618a09fdc2c58a1d1fd7fcadebbf8bf5e8bcbfd8da889c6c5af35314bad7d15)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f20b97a0db742876e6d8b15a5177052a134d2b6bafa97def2d98681d485a82a2)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8b5f812bf7bc4bc9eb5f859fec9a42aaec048111d62ed4e23cacc6ad3bc125b)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnDashboard.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.DecimalParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9ca1704d4072c274375f7d9437dd82a302eb7e96e773e9cfa60029a0ef02905)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DecimalDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DecimalDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnDashboard.DecimalParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DecimalValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DecimalValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DecimalParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class DecimalParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
        ) -> None:
            '''A decimal parameter.

            :param name: A display name for the decimal parameter.
            :param values: The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_parameter_property = quicksight.CfnDashboard.DecimalParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b8e87c3a859f2bbb8c9003de951405ccef486558d2c95c60b705c3b457b6b0c)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]:
            '''The values for the decimal parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdb415a94a3ac797c79cbdc078a3d3ae0ec49fcb22e88cba01c69f835791927c)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html#cfn-quicksight-dashboard-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b94d5f109373e082e48686e8ef6ac6691828463ee8009b8760e3790ea3d79719)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e76c84c139ffdbb84448c45734af8c0a66361b4e2d838bed16b64f49489b1af)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html#cfn-quicksight-dashboard-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95d1c243322644cdaff58559f14f6c05f82e9bcc98470f0d4e792d787e99b37a)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html#cfn-quicksight-dashboard-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[typing.Union["CfnDashboard.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid: typing.Optional[typing.Union[typing.Union["CfnDashboard.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__284b72e4f40970c9b808e43512ef33f2997aeb49008a6dfb7b69d5c722d6494d)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DefaultFreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DefaultFreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DefaultGridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DefaultGridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3004525863e9a26d930df3d8bda9f68e93eeac4119623a61c6277a87e5cd2883)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DefaultInteractiveLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for interactive layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DefaultInteractiveLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DefaultPaginatedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DefaultPaginatedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[typing.Union["CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78d0bd4b8f293d49bcfac1d526b54657b4eddae2a000cb6a2b8410fb2a22cb4b)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__321c3c08e48c3bbc7485ce4fb9440a0097fd99ecb6922bb8fd2d3c85d76a45d4)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc6c411f2b79d74f7f1ae6b104874f291559f2fbc60b16664c5c3683d705023a)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomValuesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomValuesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            date_dimension_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnDashboard.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa15123818f77ef8b4d47a100507852a39bf676c45a625274c5df8f507d718d9)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CategoricalDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CategoricalDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericalDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericalDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnDashboard.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3ba4e76b341b3f96471878057c14bbf23743cfccdd25f20854ec9d077375c086)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html#cfn-quicksight-dashboard-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            donut_center_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnDashboard.DonutOptionsProperty(
                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68e99558d4574a646fea1f646125c781a3bf8da7f8e6362b96971d83591e4667)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ArcOptionsProperty", _IResolvable_a771d0ef]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ArcOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DonutCenterOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DonutCenterOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_range_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnDashboard.DrillDownFilterProperty(
                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e398680d721680a1b466c38938c36aa9cc59aa4035e3f7f75a421b974630a0e6)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CategoryDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CategoryDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericEqualityDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericEqualityDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TimeRangeDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TimeRangeDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            select_all_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea14f6ae736847ad8c9fb08710ba146e70aeb8fe0dc78eda2f7f105f40b5b89c)
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            group_name_column: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            user_name_column: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnDashboard.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa8d06534bb0820dee9864fcbba040114f61039591942a7085bc2497f5a995a1)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that contains the default value of each user or group.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column that contains the group name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnDashboard.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24c5d8ef55044b7bc4810cda64b382c269c76eaaf38149a587158566c68cc97c)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                entity_property = quicksight.CfnDashboard.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__369484222b46d1c1fd4fb62921a2ffb5bb71194c52a8075628f4cfdf193733c0)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html#cfn-quicksight-dashboard-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94145f177864a6da2ad4ad0bf3af76247e12335ec765ce9159fb235f9193436b)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnDashboard.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da502deb6cec56e03027d0bc0a5d765d925a0ccc654709300042d9fad23b5f24)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The list of columns that define the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportHiddenFieldsOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines if hidden fields are included in an exported dashboard.

            :param availability_status: The status of the export hidden fields options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                export_hidden_fields_option_property = quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__214b9407a763201e64be927eba92d09537e3a783569a761786be2496f19c23d8)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the export hidden fields options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html#cfn-quicksight-dashboard-exporthiddenfieldsoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportHiddenFieldsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ExportToCSVOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportToCSVOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Export to .csv option.

            :param availability_status: Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                export_to_cSVOption_property = quicksight.CfnDashboard.ExportToCSVOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__98e3ce4232751b841f7f54e1206c6d61bdce27dceb2ff556f50ac722ad74f738)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''Availability status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html#cfn-quicksight-dashboard-exporttocsvoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportToCSVOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class ExportWithHiddenFieldsOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines whether or not hidden fields are visible on exported dashbaords.

            :param availability_status: The status of the export with hidden fields options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                export_with_hidden_fields_option_property = quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d466da139eb10c8ccbd6e211551275bef3a142a2537713c93572d07d52a0db25)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the export with hidden fields options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html#cfn-quicksight-dashboard-exportwithhiddenfieldsoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExportWithHiddenFieldsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnDashboard.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42a97ff83c322ad22ed18be4a6b56a736b8084706b7ed08d93d166bfd3d11a6c)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TooltipItemProperty", _IResolvable_a771d0ef]]]]:
            '''The fields configuration in the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TooltipItemProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnDashboard.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a896dfb7d29f27aea47bad79ae0ddc866d150e8c1d4ae48bf62b70d680381a7)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnDashboard.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04f0620e2fce3adc894cf018a4dd6fae2564012cb6e56663025287f1a560d525)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_sort: typing.Optional[typing.Union[typing.Union["CfnDashboard.FieldSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnDashboard.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e487c84cb5581fe0ee1fd868a7d07526c63e2b57b2568d2809b80386aa38c07)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnSortProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a column that is not used in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FieldSortProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FieldSortProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnDashboard.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92f7ee6479b7b085d7cb0497112a77d4ef7c9966e96d819d50d960b65f443348)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnDashboard.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a945d83f3ae21a829eb21d0d1ed69fcf449f1088c8047b9e608f0f7c8a6ad11f)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b8c25847cbf75d8cb69e5533c6a1a29687acd673e8d3a06c7bc1afa5878072f)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[typing.Union["CfnDashboard.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42df908330aa80e775821384f0a01c16bf0cea39dc6e0157d7f9aa869264e323)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union["CfnDashboard.FilledMapShapeConditionalFormattingProperty", _IResolvable_a771d0ef]:
            '''The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html#cfn-quicksight-dashboard-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union["CfnDashboard.FilledMapShapeConditionalFormattingProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__56d00a4acf2d3088c84de39958a82fe5b1f17a23166b08bd82bdee3fcd42c091)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilledMapConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html#cfn-quicksight-dashboard-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilledMapConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_style_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            window_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_configuration_property = quicksight.CfnDashboard.FilledMapConfigurationProperty(
                    field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                        filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f4c016ecc0f4b8a4eec5285792b7a93350a3e43ea7fa8eba14792d203d608f1b)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilledMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilledMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The map style options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilledMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilledMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7df08a812066d3fbfcf249a996bd731dc4adf13b24bdd0c256f395ab91a85d58)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilledMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html#cfn-quicksight-dashboard-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilledMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[typing.Union["CfnDashboard.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0c98899b30ab082c88f84c0f257111284657e06df7ee8aeffba91faa2dd8622)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ShapeConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ShapeConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__68d929ccfe29f81f2e07de2ba2dcbeae853891c5dc51d188b680902936d93b5e)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html#cfn-quicksight-dashboard-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_visual_property = quicksight.CfnDashboard.FilledMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                        field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                            filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                            shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c031f0558a39ec4824e6d6c94e4402a5427b13372eac305657f67d556c33ae18)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilledMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilledMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilledMapConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilledMapConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            dropdown: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            list: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_date_time: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            slider: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_area: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnDashboard.FilterControlProperty(
                    date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnDashboard.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae921f66543607d38dd79849e7df9bc376fabb3a48ed2049c0f966d0644e3f85)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterDateTimePickerControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date filter that is used to specify date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterDateTimePickerControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterDropDownControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterDropDownControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterListControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterListControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterRelativeDateTimeControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date filter that is used to specify the relative date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterRelativeDateTimeControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterSliderControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterSliderControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterTextAreaControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterTextAreaControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterTextFieldControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterTextFieldControlProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27891625d7cbee4b39fb2ab4df0360a910de89d952f7f6db1c92d38b56e0277a)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnDashboard.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0910ded494fe652a4dd90bf06df06415cba52a280cf1fd08c0768982f458a65f)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            scope_configuration: typing.Union[typing.Union["CfnDashboard.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_group_property = quicksight.CfnDashboard.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnDashboard.FilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9b83febb4cc40934033261498866c40a2459dd1bae7d418f0fe1346e054be8d)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilterProperty", _IResolvable_a771d0ef]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilterProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union["CfnDashboard.FilterScopeConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.FilterScopeConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnDashboard.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad9a094c897f8c44c5dc2d38b0a4f4bfb92016c8792e5a351f59c80a72c93d5f)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnDashboard.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04aa975de765c4423d87a5139288f8a92be971f0ed1146cd2336930a2ecaa6c1)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8289ef69aa90a688cfb84a55a66af851befa54121fc3985490e3a55c0bebc89c)
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dcc3e7151dd691d54f83af31561fe3da7953ab2d79a6976d20804929e47c8cd7)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SameSheetTargetVisualConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-dashboard-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SameSheetTargetVisualConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_range_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_dates_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_equality_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_range_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_filter: typing.Optional[typing.Union[typing.Union["CfnDashboard.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_property = quicksight.CfnDashboard.FilterProperty(
                    category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection"
                        )],
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__58d4946db4d17934af163074abbd44624db96d2fee773d027f0f59e34ba3e5c9)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CategoryFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CategoryFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericEqualityFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericEqualityFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericRangeFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericRangeFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RelativeDatesFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RelativeDatesFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TimeEqualityFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TimeEqualityFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TimeRangeFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TimeRangeFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TopBottomFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TopBottomFilterProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76f7372800126f162f57efb0ba11499ee0a22c6b61b261884a9e9097046a71c7)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            selected_sheets: typing.Optional[typing.Union[typing.Union["CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_scope_configuration_property = quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                    selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8914e82cd83f372c2190c84c8b0c1bd69d449c5a9396e12fb239cbf613e54fed)
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnDashboard.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5c1bd7002191cd53fe4de3657f0785748ae988e0c9dc31047913a4276176800)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html#cfn-quicksight-dashboard-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnDashboard.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__211a0f265a0fc447e1c624c316293f49c0e2a7c6791ce3fa0c58c22c3d489080)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnDashboard.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__33cce4dc7f51913d18af84e78f5b96afe7d3aa4a5092ae98ad34bcc2ca90c87c)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnDashboard.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d9952d797b174d8f0fcfdb503727ace1605a99401d0d839e977b0a56c4dc887)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontSizeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontWeightProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnDashboard.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cf7c19afe99d3fd9ae8f1ec8ed6113d4b150955477a7a861d70b6bba46c3ee8)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontSizeProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the text display size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontSizeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontWeightProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontWeightProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnDashboard.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ace1daa73e7c850880aa6c73a3a9f0cb5d0530281f475c36f95cc61a7250e0ac)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html#cfn-quicksight-dashboard-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnDashboard.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fdcdcd920af4b771cdcd8dbd51ee33afb89148742503470da12cdfc0d9433484)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html#cfn-quicksight-dashboard-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_computation_property = quicksight.CfnDashboard.ForecastComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    custom_seasonality_value=123,
                    lower_boundary=123,
                    name="name",
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality="seasonality",
                    upper_boundary=123,
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0ab327581270923726606bc135dcae4a1fb775d8b466e2860373128207ac9a7d)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[typing.Union["CfnDashboard.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scenario: typing.Optional[typing.Union[typing.Union["CfnDashboard.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnDashboard.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e7e39e043a95201422af709df7dee5a0ee18411ff5f3a3c1887dfc5575d013e)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TimeBasedForecastPropertiesProperty", _IResolvable_a771d0ef]]:
            '''The forecast properties setup of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TimeBasedForecastPropertiesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ForecastScenarioProperty", _IResolvable_a771d0ef]]:
            '''The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ForecastScenarioProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[typing.Union["CfnDashboard.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[typing.Union["CfnDashboard.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnDashboard.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__113601ebf0cd4d87f695ef8c8f059417cf87c5f7a49925b01efacfa3f9e5e8ab)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WhatIfPointScenarioProperty", _IResolvable_a771d0ef]]:
            '''The what-if analysis forecast setup with the target date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WhatIfPointScenarioProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WhatIfRangeScenarioProperty", _IResolvable_a771d0ef]]:
            '''The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WhatIfRangeScenarioProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            string_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnDashboard.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__655434acdee81e21d53d6c5ef89f281dbcf975d4dcb9d246ac627a055196274a)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for number fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__273a7c9d5b9cc2a3450f8060a06c34e9fea7c4eef5428cc62130ac6ca4adac26)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: ``CfnDashboard.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a168ac4829034f015945d4355743aac98a6f783e87b608f73ad242bd591c068a)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e268c71d17932d16dacc61e1e1b4572127fbc50ea4da5b0d0d46f70a1dc66f43)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e66030c3cfc47717fa70cb063577196f5fe2c39438f410488e6764eb4eb9965)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            border_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            loading_animation: typing.Optional[typing.Union[typing.Union["CfnDashboard.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rendering_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            selected_border_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4664d105991a276ced4910380c196569856ab8d6d0cac9aedc5848ae8ee63338)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty", _IResolvable_a771d0ef]]:
            '''The background style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LoadingAnimationProperty", _IResolvable_a771d0ef]]:
            '''The loading animation configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LoadingAnimationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetElementRenderingRuleProperty", _IResolvable_a771d0ef]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetElementRenderingRuleProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__998388d3281adbe21ea2fd0d3b7c8f355a8bdd62f35e2a776f57a84874f4c919)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94f267c052f257ff9dd32a8b444035b736a6135a75ee1d70d50e589950b7074c)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html#cfn-quicksight-dashboard-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a7ec8f5fcc9ee585283d90a9ca204fdd93eef67d29373b692607d5f7e119802)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_configuration_property = quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        label_color="labelColor",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_data_label_style="measureDataLabelStyle",
                        measure_label_visibility="measureLabelVisibility",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                        funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7ae1bc1e8e865de2d1143b431076e54909009372a8b4f5b7271137eb4c62820)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FunnelChartDataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FunnelChartDataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FunnelChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FunnelChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FunnelChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FunnelChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f1d60e8feb7de908f5a44ef72392ce967c2fff1f51273f8ead85c1a1d0eebdd0)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2562679f303074e83bc2b69486884e6aa0d282d512014470451f9597efe38a80)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FunnelChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html#cfn-quicksight-dashboard-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FunnelChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3bad249b8eee47bc3c16ae390fc14663b62c492f20b8e53b860743db48e2dcd7)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_visual_property = quicksight.CfnDashboard.FunnelChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            label_color="labelColor",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_data_label_style="measureDataLabelStyle",
                            measure_label_visibility="measureLabelVisibility",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                            funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f55a8e0794985991874c971cb1ef0e30f3f84a03f57b2e9f09cc260ee2cf720b)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FunnelChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FunnelChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f9969c77a22bfd625bda85665a12630487f1c2e1755bc0953fe7f76aace3f08)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html#cfn-quicksight-dashboard-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b75db91915d0dff52e1b8ea5f0c3a59bd53bd59cff5016792e787247b94a405c)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartArcConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartArcConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2f08e38536c310bd2182a7eb14969c5bce6cda2946c2865d5c4d9f53bfd71df7)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.GaugeChartConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html#cfn-quicksight-dashboard-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.GaugeChartConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            gauge_chart_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_configuration_property = quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                        arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                            arc_angle=123,
                            arc_thickness="arcThickness"
                        ),
                        arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                            range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                max=123,
                                min=123
                            ),
                            reserve_range=123
                        ),
                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        )
                    ),
                    tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b77c6878b54fbd5a59716dea5c206551676700b3aaea57710a56ebd51dde8a63)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_field_wells_property = quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac94d46fb8214c53f5db9b5f39a297ea28bcdf8b9ff0fddd51b899bb0ec437c5)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[typing.Union["CfnDashboard.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            arc_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            comparison: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnDashboard.GaugeChartOptionsProperty(
                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e2d17382ec22517b13f6defe92f08dd7e3201f03ee79d28421c35fcc7732959)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ArcConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ArcConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ArcAxisConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ArcAxisConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComparisonConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComparisonConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7e490d0b9342491c4372b2fc2409e8b5322b086d8b68c786ea7838b1d010b87d)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_visual_property = quicksight.CfnDashboard.GaugeChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                            target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                            arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                arc_angle=123,
                                arc_thickness="arcThickness"
                            ),
                            arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                    max=123,
                                    min=123
                                ),
                                reserve_range=123
                            ),
                            comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        ),
                        tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                            arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f64fee1aff2d39e1324d0c6b3aaca722b1a781f086d95710495f11ffde8c0cc1)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2ef5e2cee6abd7d31901cf9fbf450fc76a069c90bd4d4980ffa86d7bc361bfe)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_aggregated_field_wells_property = quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eca225165efff16ba2176fee887433d40c473b2cc88227f0b0372e5b719ad80b)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field wells of a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_style_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            point_style_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            window_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: ``CfnDashboard.GeospatialMapConfigurationProperty.VisualPalette``.
            :param window_options: The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_configuration_property = quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                    field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                        geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                        cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                            cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                    color="color"
                                )
                            )
                        ),
                        selected_point_style="selectedPointStyle"
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6272bec17d4d2a17c3e0b8b4b6eccfedf9a1938a266a226f6b1f9c935de197cc)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The map style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialPointStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The point style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialPointStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.GeospatialMapConfigurationProperty.VisualPalette``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_field_wells_property = quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                    geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc93e3cbcf8a1b05f5f403935eadb1f26954308adf4571c964a91090b86a6742)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html#cfn-quicksight-dashboard-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__316c10e17654415076ebccfae9eb4214d247a648b5d7619c300f968443743da7)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html#cfn-quicksight-dashboard-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_visual_property = quicksight.CfnDashboard.GeospatialMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                        field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                            geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                            cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                    simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                        color="color"
                                    )
                                )
                            ),
                            selected_point_style="selectedPointStyle"
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e4ac264b095cda6d04cfde43a8814409cdeb18d49463db5eab9d4fd5ac193393)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8006474291c9e5471db8588b96c0c50c84da0e98750f548d3eaedbf2e38db620)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ClusterMarkerConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The cluster marker configuration of the geospatial point style.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ClusterMarkerConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__618a75f7371b07fa8098fecf95bb8926ce8e4e6c56425eb042fb882acdc52599)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialCoordinateBoundsProperty", _IResolvable_a771d0ef]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialCoordinateBoundsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            uniform_border: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b2a072f23fe83386faec836c361bb6d4a5c044ab34a06d1d6a1de3d09fc50b2)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableSideBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines the options for side specific border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableSideBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.GradientStopProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnDashboard.GradientColorProperty(
                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__472a762c58bb317cd53ea7447becfc6e26bbb481db3506fda7a7da8a09b3ebb6)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.GradientStopProperty", _IResolvable_a771d0ef]]]]:
            '''The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html#cfn-quicksight-dashboard-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.GradientStopProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value.
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnDashboard.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e70b76d76824a5731e135874bc91aef9dfa215b6c03b2b0ae0a28e5a9c930d6)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__efe688d577c9460cf9f7f7eb3b74ef05461ef8707eb01c7b0a1a303f0cda316c)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: ``CfnDashboard.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e92528f2e7c78b1f690ecd1f105a16ef71d62d57ac73983db9a6ab5b8dddc9a9)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.GridLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.GridLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnDashboard.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f448575cfb2433f867ce96360104e09f3c0f08e6a2e4ef361235724b7b6e8032)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2b9682d1c79667291cdbca6d7604aa1176ebc194fee087bfc292816c61ef03f3)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_size": "periodSize",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnDashboard.GrowthRateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a719fd3755736f2983d85b2caac35e327c0b9bd63683e5326b99ecd1cfcd3ce)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnDashboard.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0175a8094fd6d612a882eb905fa340ea6573b1be4061e6ceae62cdf370fe6645)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The layout configuration of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union["CfnDashboard.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionStyleProperty", _IResolvable_a771d0ef]]:
            '''The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_aggregated_field_wells_property = quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77d0446ccfc721e42706f5a73a2a292bf2803012a6aaac1c8a7944ad4675ba83)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The columns field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The rows field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_configuration_property = quicksight.CfnDashboard.HeatMapConfigurationProperty(
                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                        heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                        heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f14cbf0beace22ffd494a2df5a26d5050b882f8c0e2302099c8469a1ff1c0568)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColorScaleProperty", _IResolvable_a771d0ef]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColorScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the column that is displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HeatMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HeatMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HeatMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HeatMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_field_wells_property = quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                    heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0409983cf1f5381c1822256a9308f9d2aa43710b562e516f1082fc15d4c21a1)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HeatMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html#cfn-quicksight-dashboard-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HeatMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6930fb580b33bcaf12196109bd462af4880945ac2b98e4c65764b0f19561d4e)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_visual_property = quicksight.CfnDashboard.HeatMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                        color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                            heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                            heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12b67e77b83f973c465e11cea6df42ac19a48904b87818d2100d889946531a11)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HeatMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HeatMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7aaa7ecf1cfe0e73e580ed900bade5f2e9f5c44c5495ba06ce0aaadfcbc835b5)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html#cfn-quicksight-dashboard-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[typing.Union["CfnDashboard.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            bin_width: typing.Optional[typing.Union[typing.Union["CfnDashboard.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnDashboard.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b6849cedb2dcd6e479622c9a145e62d88ead4f6a6e63a3302e679e98c495865)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BinCountOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the bin count of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BinCountOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BinWidthOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the bin width of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BinWidthOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_configuration_property = quicksight.CfnDashboard.HistogramConfigurationProperty(
                    bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                        bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                            value=123
                        ),
                        bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                            bin_count_limit=123,
                            value=123
                        ),
                        selected_bin_type="selectedBinType",
                        start_value=123
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                        histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3dfdbf8c97ed1570a4b38ae3650e8b879632fe3b3dd48fe3969bfbcfb111cb69)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HistogramBinOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of histogram bins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HistogramBinOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HistogramFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HistogramFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnDashboard.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce826bbb34cf249b52fadfa269ddcb10b226899e3683322d7feb2b20c43940b3)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HistogramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html#cfn-quicksight-dashboard-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HistogramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_visual_property = quicksight.CfnDashboard.HistogramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                        bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                            bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                value=123
                            ),
                            bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                bin_count_limit=123,
                                value=123
                            ),
                            selected_bin_type="selectedBinType",
                            start_value=123
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                            histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        )
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3804785ef2f8b5cc7c89fe2a792661ed0ed7af661b39096b4acd770cad93d251)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HistogramConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for a ``HistogramVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HistogramConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            custom_narrative: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                insight_configuration_property = quicksight.CfnDashboard.InsightConfigurationProperty(
                    computations=[quicksight.CfnDashboard.ComputationProperty(
                        forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            custom_seasonality_value=123,
                            lower_boundary=123,
                            name="name",
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality="seasonality",
                            upper_boundary=123,
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_size=123,
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                            computation_id="computationId",
                            from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_time_granularity="periodTimeGranularity",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            mover_size=123,
                            name="name",
                            sort_order="sortOrder",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            result_size=123,
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                            computation_id="computationId",
                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                
                            # the properties below are optional
                            name="name"
                        )
                    )],
                    custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                        narrative="narrative"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c31552059474b99ea44467658cc00b95e1f6996bec23eca4a0c78bb6564e6e2)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ComputationProperty", _IResolvable_a771d0ef]]]]:
            '''The computations configurations of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ComputationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomNarrativeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomNarrativeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            insight_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                insight_visual_property = quicksight.CfnDashboard.InsightVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                        computations=[quicksight.CfnDashboard.ComputationProperty(
                            forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                custom_seasonality_value=123,
                                lower_boundary=123,
                                name="name",
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality="seasonality",
                                upper_boundary=123,
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_size=123,
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                computation_id="computationId",
                                from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_time_granularity="periodTimeGranularity",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                category=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                time=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                mover_size=123,
                                name="name",
                                sort_order="sortOrder",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                category=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                result_size=123,
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                computation_id="computationId",
                                value=quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                category=quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                
                                # the properties below are optional
                                name="name"
                            )
                        )],
                        custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                            narrative="narrative"
                        )
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5d59b667df321aaa8408409152b268f259ea5e75b1448f02be596aad6daec7a8)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.InsightConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of an insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.InsightConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99365b6a3e45ef898387d762176aba3c5ac9306fa99c37b9e5e3be8b6eb133ce)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnDashboard.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.IntegerParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9389a1c806416a68084069200423dc181d17492f4414449200f3b678bc900b55)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.IntegerDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.IntegerDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnDashboard.IntegerParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.IntegerValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.IntegerValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.IntegerParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class IntegerParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
        ) -> None:
            '''An integer parameter.

            :param name: The name of the integer parameter.
            :param values: The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_parameter_property = quicksight.CfnDashboard.IntegerParameterProperty(
                    name="name",
                    values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5916d02f946a87a88b80cb5cf11ce661663175e8657e87533d04a6e1e5f4eb81)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]:
            '''The values for the integer parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9079003123fa0d98277321803ad546fd4701ae09a7617c7cb859b92abad3e5f5)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43ef20f7dd725832b1ccb6af1067bb1f05f93ec424d3e3f2ec4464d4af0e9c79)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"primary_value": "primaryValue", "progress_bar": "progressBar"},
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            primary_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            progress_bar: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__812844b2ea4b74d16fc026f177234b326c51c4597ab0dc586923f6b895a65eb9)
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIProgressBarConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIProgressBarConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a9cfe2b8997e0d9b2458bf5aff94de13383fb7ea798f6102bf89707f5f1a88e)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.KPIConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html#cfn-quicksight-dashboard-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.KPIConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            kpi_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConfiguration_property = quicksight.CfnDashboard.KPIConfigurationProperty(
                    field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                            visibility="visibility"
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                        trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3ee290d5344f07d1c2e70b74b1726168db9e7b44113c7e0cb295634c77f9eb38)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPISortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPISortConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            trend_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIField_wells_property = quicksight.CfnDashboard.KPIFieldWellsProperty(
                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__400488f7d37c7fa5b780c31f212ffd467a46311b3a59bc6410fb28fc95ddc9c6)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The target value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The trend group field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "trend_arrows": "trendArrows",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            progress_bar: typing.Optional[typing.Union[typing.Union["CfnDashboard.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            trend_arrows: typing.Optional[typing.Union[typing.Union["CfnDashboard.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnDashboard.KPIOptionsProperty(
                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d010ed4cc652fc89265f592d8e4c61a82ba7aa2e77fd4aa16eba1d45033efe2)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComparisonConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The comparison configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComparisonConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ProgressBarOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ProgressBarOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SecondaryValueOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SecondaryValueOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the secondary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TrendArrowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TrendArrowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3077fb20abed1802274b5e003e021440fb4f90b9feeff7e4286990a08053bba)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value's icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3bc4924d18d4ca627fec69ac66628ca8bcf8f66f89b530f48e66365de4a0337f)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html#cfn-quicksight-dashboard-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnDashboard.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90d4a1142143fb394c15dbf4922173e5c9a8ab445972d97de48571b684e6c375)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html#cfn-quicksight-dashboard-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIVisual_property = quicksight.CfnDashboard.KPIVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                        field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                            target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                            comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                visibility="visibility"
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                            trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                            primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e11c189c87d06752e74f0f1a1d33773c83c531a6472251caad117d96afef8c2d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnDashboard.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02007f9c8a3871e92afa3f45d4736b3e14c085c7423b800684aaf1ef118de396)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[typing.Union["CfnDashboard.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid_layout: typing.Optional[typing.Union[typing.Union["CfnDashboard.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            section_based_layout: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnDashboard.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                            content=quicksight.CfnDashboard.BodySectionContentProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnDashboard.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnDashboard.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8dafed9ee6b32937e3e666c8b9ce8ae1e8599084660848dc5eae742195f28c84)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[typing.Union["CfnDashboard.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                layout_property = quicksight.CfnDashboard.LayoutProperty(
                    configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                content=quicksight.CfnDashboard.BodySectionContentProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnDashboard.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnDashboard.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f3162b344c55cbadbb8bf8cdeedd746e7b52ee9b5ac12d2ba20725c8cf55c00)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnDashboard.LayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html#cfn-quicksight-dashboard-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.LayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnDashboard.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__928b8daf4dc3b6c6023b3a2d95bcbba624fa46f6fd94597d9e7aea053f333bd7)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The custom title for the legend.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_aggregated_field_wells_property = quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aeac59af946eaf684d058336e30a4eb2a05aa0eafb74f37a3fa2edd9528fb70d)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            default_series_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            forecast_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            series: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_configuration_property = quicksight.CfnDashboard.LineChartConfigurationProperty(
                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                        axis_binding="axisBinding",
                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                        line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                        forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                            lower_boundary=123,
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality=123,
                            upper_boundary=123
                        ),
                        scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                            what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                date="date",
                                value=123
                            ),
                            what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                end_date="endDate",
                                start_date="startDate",
                                value=123
                            )
                        )
                    )],
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    series=[quicksight.CfnDashboard.SeriesItemProperty(
                        data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        ),
                        field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        )
                    )],
                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                        category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    type="type",
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42471dd9822b7efbb5f74e757e7063562b5afd311dfc50ae90cdd91e26cc95cf)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartDefaultSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartDefaultSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ForecastConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The forecast configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ForecastConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference lines configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SeriesItemProperty", _IResolvable_a771d0ef]]]]:
            '''The series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SeriesItemProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            marker_style_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b147f074bf4775f54e6811424b1c2f38b0c6727663879586e66ae2a69361be06)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Line styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_field_wells_property = quicksight.CfnDashboard.LineChartFieldWellsProperty(
                    line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__597b61ca3d4c76d8ec4d8cb6c5555f5b385f420f5efbe5e0b70731cf3456553a)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html#cfn-quicksight-dashboard-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dff237aa0db879fc8fa0cbdad496482eedc243b3fd13ae964be03f738ddaba52)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__07ca1a21bea8e38da220af18349691be15d1570118982ac84415d918e221181c)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            marker_style_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31d8fd577612650db1c955670b227633fb216889508e267bbd195e4fea69fe0c)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e943ce1b7ecda86d7595d504b4ccf51447b20ad8606b875026e9e2333ff8bac)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_visual_property = quicksight.CfnDashboard.LineChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                        contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                            axis_binding="axisBinding",
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                            line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                            forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                lower_boundary=123,
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality=123,
                                upper_boundary=123
                            ),
                            scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                    date="date",
                                    value=123
                                ),
                                what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                    end_date="endDate",
                                    start_date="startDate",
                                    value=123
                                )
                            )
                        )],
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                            data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        series=[quicksight.CfnDashboard.SeriesItemProperty(
                            data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            ),
                            field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            )
                        )],
                        small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                            category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        type="type",
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43ceb6d361459fb47804a3ed56df3021bf3da7c7697a73cc85e2829c5669014c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da1f16efd2ced0bc1cb18450435ac23b7c754c6ef5b6a49a5fc16027bcb12a7c)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the line series axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MissingDataConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MissingDataConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            search_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffc7adaf2859930497df79f63941fda09bdfa0d356bc9ee188a6a9ad5661853b)
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ListControlSearchOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ListControlSearchOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ea3df2085362951d5cff8570eb4833e8a517f86ab5498064eba83493e6d29c6)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html#cfn-quicksight-dashboard-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b45b545b6c3f274d771af3c7f4d06c5227e7f97abd6d868bc274c2371b7e737)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html#cfn-quicksight-dashboard-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnDashboard.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b930afb047b4044b93e8dab6457815a74a7b6440a5f230e702231e94e8d7df5d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html#cfn-quicksight-dashboard-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6175ce87546f7d162cf70c33e7f0260d6d73c7297692a17088e6cd52996093a)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html#cfn-quicksight-dashboard-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnDashboard.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce3f60d75db9ee77370abde96035b2000a715f4a0876ed3850d9c7bec773d536)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''A dataset parameter that is mapped to an analysis parameter.

            :param data_set_identifier: A unique name that identifies a dataset within the analysis or dashboard.
            :param data_set_parameter_name: The name of the dataset parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnDashboard.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fdfa4a7d687326b2dc6a02283b573f378f0e2cb07815e8651da8241efc2c1f09)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''A unique name that identifies a dataset within the analysis or dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''The name of the dataset parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnDashboard.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7372af3732d172d087e0ad56a64185adf1f8f5ff7cf1e00c2c7fe68b1af3b2e)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html#cfn-quicksight-dashboard-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "name": "name",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c5ed25edc74ea8f0e487c4e7e6fc21aeb7e3afc38996bb1131f24d618e7b0ef)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            categorical_measure_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            date_measure_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numerical_measure_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnDashboard.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7247c2ffa8ba32a7fa54226a54c5fbc9706b2973f0a96c81bd400efa4571eee1)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CalculatedMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The calculated measure field only used in pivot tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CalculatedMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CategoricalMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CategoricalMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericalMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericalMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "target_value": "targetValue",
            "time": "time",
            "name": "name",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target_value: typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                metric_comparison_computation_property = quicksight.CfnDashboard.MetricComparisonComputationProperty(
                    computation_id="computationId",
                    from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73f26ab5746e842646439b3fad2c45a293dc5be46c646b44bb4a9389829120f8)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "from_value": from_value,
                "target_value": target_value,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The field that is used in a metric comparison from value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            assert result is not None, "Required property 'from_value' is missing"
            return typing.cast(typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The field that is used in a metric comparison to value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            assert result is not None, "Required property 'target_value' is missing"
            return typing.cast(typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnDashboard.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e9a220c2448d9b6851be4a6f94a861e3f07a8fe9252c17398174f12ed1542f2)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html#cfn-quicksight-dashboard-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnDashboard.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0c6b4227849b1baf5ae270e3748102ab27bc8bf2a2500f474d1a9a4e470d0032)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html#cfn-quicksight-dashboard-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__873fa89b2b2516ed4c11b9604620c3c2e3430463da6374af7b0db31589394b2b)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html#cfn-quicksight-dashboard-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bfa3f23da0a7fa1261d31cf8efb5a75983dacd6fadca3d7c54796ba77815fe2f)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html#cfn-quicksight-dashboard-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__84d64a6c89fe377034d29c5f46b1c5b6b270fdbf62e7a8dc1ebbcda5a6ca4f48)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__86d266c00b603a86d32494b895681ab20310ab4ef65c9a1836ea445c11c9832d)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html#cfn-quicksight-dashboard-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scale: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnDashboard.NumericAxisOptionsProperty(
                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df08285efa551ddedc720f8ccfb061d9088021ddb1c329dd790de70089d77a54)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayRangeProperty", _IResolvable_a771d0ef]]:
            '''The range setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayRangeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisScaleProperty", _IResolvable_a771d0ef]]:
            '''The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisScaleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__08c5d2a02bc6a4d03fd77069cec8c69125041bd3c669e753ca85f605402372e0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnDashboard.NumericEqualityFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22a36d8ea54614feaa652e2187823346f13d132e31069bde6d5706016e0438be)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d82485e4871006424a7af399c15b8d22350769e52c1a8e0f8124d0a503219740)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CurrencyDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the currency display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CurrencyDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the number display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            range_maximum: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_minimum: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnDashboard.NumericRangeFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__990348a625c5c27e41c7214952bd968547d0b672d008265fe2c12c22ef498576)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45965f45a3415e5f023aea91341efe3e81295c90cb9f9dcb31a399b0e5fae6bc)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[typing.Union["CfnDashboard.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd3834de16bb1a3523af87ed66b2734ed82d36e0d59ce1b5ed1d970dcd7bd86d)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ThousandSeparatorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ThousandSeparatorOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[typing.Union["CfnDashboard.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a291e6cb1dc48ecccc07c6ac04e696d07880240efe27d2e2684dc67710f4b14)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PercentileAggregationProperty", _IResolvable_a771d0ef]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PercentileAggregationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4c4bd7ae907f91f51facbcebc6b6631671cadb3cf6ae29ad236789eb6b8fa6f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14662c336a174a816ebf6f1f46a8a13df7c715b7be804c20eb7bd89e0b26ee51)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnDashboard.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a655d7a7e02f15bb7fb8e2a6432c24041b8276e1f6f9a76da07ad8b71429c92)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnDashboard.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4cd6719580c552440b185c3ec3a30425ec390d28dcf41e27565c5d6962cf0d32)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PanelTitleOptionsProperty", _IResolvable_a771d0ef]]:
            '''Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PanelTitleOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: ``CfnDashboard.PanelTitleOptionsProperty.FontConfiguration``.
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnDashboard.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffa6c3710dbc99b205887c20919f9fbb1f115a967a3f16a0759b029204db3f6f)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''``CfnDashboard.PanelTitleOptionsProperty.FontConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            dropdown: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            list: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            slider: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_area: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_field: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnDashboard.ParameterControlProperty(
                    date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnDashboard.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b9a617c861fee66c2f12ab5d86dc60954b3e96d7742ec58f1f6b4d5dd31f2018)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterDateTimePickerControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date parameter that specifies date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterDateTimePickerControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterDropDownControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterDropDownControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterListControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterListControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterSliderControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterSliderControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterTextAreaControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterTextAreaControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterTextFieldControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterTextFieldControlProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1c4ff74d3f1c3059beb424c94eda0f0b1a24e88b608b85cc0df0607aff0eb71)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnDashboard.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnDashboard.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnDashboard.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0a113dcfc753dcee3562339eb40824b4980fffd9188b592abbc50c390d40b35)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DateTimeParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DateTimeParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DecimalParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DecimalParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.IntegerParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.IntegerParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.StringParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.StringParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnDashboard.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0e2d499ed1c4e455157a7ed9337cbb2c047a9378394f5063dfcdfd90204ec32)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnDashboard.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ddce4ec54b04db2ca4c161e425bd033dfc0b3003f1ad8da126436edefbcb4269)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fadb802f2e1912f59acbbecc2ce3db818bdc5630fc26e349c4695724b4c520d1)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column identifier that fetches values from the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnDashboard.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43f62462e4fe8b08e49c740ca9cf6026e8927a3a02014ffaefbf03c75ea3605b)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dafa50892a8d3ae1b4ca0ac169ae253837176077bea1b0fe34f0169807658593)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62eeefe8979b4ccad3a1592b656ce26ff20d5db0fefc0090b7c05f05389abe98)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameters": "dateTimeParameters",
            "decimal_parameters": "decimalParameters",
            "integer_parameters": "integerParameters",
            "string_parameters": "stringParameters",
        },
    )
    class ParametersProperty:
        def __init__(
            self,
            *,
            date_time_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DateTimeParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            decimal_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DecimalParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            integer_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.IntegerParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            string_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.StringParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''A list of Amazon QuickSight parameters and the list's override values.

            :param date_time_parameters: The parameters that have a data type of date-time.
            :param decimal_parameters: The parameters that have a data type of decimal.
            :param integer_parameters: The parameters that have a data type of integer.
            :param string_parameters: The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameters_property = quicksight.CfnDashboard.ParametersProperty(
                    date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__52e775d8109de32284839d05033897d7123c509fbf0ed766ca22e27cd8fc56a3)
                check_type(argname="argument date_time_parameters", value=date_time_parameters, expected_type=type_hints["date_time_parameters"])
                check_type(argname="argument decimal_parameters", value=decimal_parameters, expected_type=type_hints["decimal_parameters"])
                check_type(argname="argument integer_parameters", value=integer_parameters, expected_type=type_hints["integer_parameters"])
                check_type(argname="argument string_parameters", value=string_parameters, expected_type=type_hints["string_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameters is not None:
                self._values["date_time_parameters"] = date_time_parameters
            if decimal_parameters is not None:
                self._values["decimal_parameters"] = decimal_parameters
            if integer_parameters is not None:
                self._values["integer_parameters"] = integer_parameters
            if string_parameters is not None:
                self._values["string_parameters"] = string_parameters

        @builtins.property
        def date_time_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DateTimeParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of date-time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-datetimeparameters
            '''
            result = self._values.get("date_time_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DateTimeParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def decimal_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DecimalParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of decimal.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-decimalparameters
            '''
            result = self._values.get("decimal_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DecimalParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def integer_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.IntegerParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of integer.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-integerparameters
            '''
            result = self._values.get("integer_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.IntegerParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def string_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.StringParameterProperty", _IResolvable_a771d0ef]]]]:
            '''The parameters that have a data type of string.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-stringparameters
            '''
            result = self._values.get("string_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.StringParameterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnDashboard.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3956dead6fafc1c7f68969bc969b840dea1f36b2c3cfdcd8de39026a5bcfa77f)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2cc544278e73c2e83091b7d50ea938246d6907bbbdf38ca0ff1cdf4506cdc8a)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnDashboard.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ce6445deba68d26de2797a542dabddeb043f19f954bd9d7c26116aebb083900)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html#cfn-quicksight-dashboard-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c6d427e3d4cacf415a4d7f8879f34f47362c20db781865c3a8dc6790d9fc7e6)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnDashboard.PeriodToDateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cdf09f7f9a743f7677477d39756a8ff5981ffc3245ac11cb211530143b9c27f)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_aggregated_field_wells_property = quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a8eb20135e320550c2948156da6a9ee4aee697e879e19c6e062d514b6213763b)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category (group/color) field wells of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            donut_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_configuration_property = quicksight.CfnDashboard.PieChartConfigurationProperty(
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                        arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                            arc_thickness="arcThickness"
                        ),
                        donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                            label_visibility="labelVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                        pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80fe2576e84705ed5b5bf97a3a4ccc2f49ed8c1cb6dd5449656696bc0848001f)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DonutOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DonutOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PieChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PieChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PieChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PieChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options for the value that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_field_wells_property = quicksight.CfnDashboard.PieChartFieldWellsProperty(
                    pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e2dd3508674ab9aee1b60484025570cf54ae768543a524236d5b8f5e94abd6b0)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PieChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html#cfn-quicksight-dashboard-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PieChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8342ea26f85c14f4dcb113cbf7c26c606750f4dc668fc6613eb89eebabd188b0)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_visual_property = quicksight.CfnDashboard.PieChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                            arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                arc_thickness="arcThickness"
                            ),
                            donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                label_visibility="labelVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                            pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92f40e0ca1aef3ef70adee671248d03591b8d5ed05ed5a17474edcee68251ff5)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PieChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PieChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[typing.Union["CfnDashboard.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                        column=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnDashboard.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d2059ce187c24ecec1a3f45b0152ecd8641adfafdc1f0038f50660783d279863)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union["CfnDashboard.PivotTableSortByProperty", _IResolvable_a771d0ef]:
            '''The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union["CfnDashboard.PivotTableSortByProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_aggregated_field_wells_property = quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eca7718db8eccf93d456cbe9c95f480113c0944160ecc7fb6bd989557cd6d5e3)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_format: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b85439eb5f33ccfb4310fa3cef8675219f5f4c46f9fbb1b3de369cfe5f8d815)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableConditionalFormattingScopeProperty", _IResolvable_a771d0ef]]:
            '''The scope of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableConditionalFormattingScopeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0823a36ffa9d075a97f265c62a86e93ed14fa80ae1245ee121c674730f39d841)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableCellConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html#cfn-quicksight-dashboard-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableCellConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96d5779d7832f322dc641cc6f4efe1fba7f0ccd516ed12a2cfa53d4af392ac52)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html#cfn-quicksight-dashboard-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e6699d21aa448f479781cd663975c339d64e201af9dd2cbcad518ec2b021363)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html#cfn-quicksight-dashboard-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_report_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_configuration_property = quicksight.CfnDashboard.PivotTableConfigurationProperty(
                    field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                        data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                            data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                
                            # the properties below are optional
                            width="width"
                        )],
                        selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            visibility="visibility"
                        )]
                    ),
                    field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                        pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                        field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                            field_id="fieldId",
                            sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                column=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                    direction="direction",
                                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )]
                                ),
                                field=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )
                        )]
                    ),
                    table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_names_visibility="columnNamesVisibility",
                        metric_placement="metricPlacement",
                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        ),
                        row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        single_metric_visibility="singleMetricVisibility",
                        toggle_buttons_visibility="toggleButtonsVisibility"
                    ),
                    total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                        column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__373f98cff3775f1a4c6634eacef0fef18d147ee1df75509c901c44e393e55222)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableFieldOptionsProperty", _IResolvable_a771d0ef]]:
            '''The field options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableFieldOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]]:
            '''The paginated report options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae52fdbfa784afd98a84e03cde8df424aa16060aa5e379c9899e06784e41b2b2)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataPathValueProperty", _IResolvable_a771d0ef]]]:
            '''The list of data path values for the data path options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataPathValueProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75a75bf865fd94860ecd4ecd341a72a89e9def1da643c4a43318166ef2335f75)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            data_path_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0004eae82cfd0b10c26900e942790e914ac2e20923f876fd1b41b8c1d643b65d)
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableDataPathOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The data path options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableDataPathOptionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableFieldOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableFieldOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__28f079f6d337a4e3dfeba2410667382f40b4176f50c6b45832c702cfb83ea3d2)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html#cfn-quicksight-dashboard-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_wells_property = quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                    pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5162a07e7817035cbbf09d6ec5598e6d6acf9e8004aa5b2e79515a8b96eac261)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html#cfn-quicksight-dashboard-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_header_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_field_names_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_header_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnDashboard.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    ),
                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__152307a7f993a32a79b36cccc31a3a6d5d7d6bc5fc8e80723cb9335f15d7c2ff)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of the column header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row alternate color options (widget status, row alternate colors).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of row field names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of the row headers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ded43d2a0663600a898caf6ee9591e0ca6b99495a2db26b76d3fd4d40d4a36d)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_path: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field: typing.Optional[typing.Union[typing.Union["CfnDashboard.FieldSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnDashboard.PivotTableSortByProperty(
                    column=quicksight.CfnDashboard.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnDashboard.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnDashboard.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3444ae471bb4d45db7f476cf427657f4513a34f2304790591ce9ba7a5065a04f)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnSortProperty", _IResolvable_a771d0ef]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataPathSortProperty", _IResolvable_a771d0ef]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataPathSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FieldSortProperty", _IResolvable_a771d0ef]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FieldSortProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__69bfce39de1ccc1ad64cfed28e2af3ec9c0ec1ecdce79d0a4cbb0e518288ce87)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotFieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html#cfn-quicksight-dashboard-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotFieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_total_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_subtotal_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_total_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_total_options_property = quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                    column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fae7c10caaacfad3129d3e5b847598d0527e9d2143f9470d3cd85de0d0adb4c2)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SubtotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The column subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SubtotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The column total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SubtotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SubtotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_visual_property = quicksight.CfnDashboard.PivotTableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                        field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                            data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )],
                
                                # the properties below are optional
                                width="width"
                            )],
                            selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                visibility="visibility"
                            )]
                        ),
                        field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                            pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                            field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                field_id="fieldId",
                                sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                    column=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                        direction="direction",
                                        sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )]
                                    ),
                                    field=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )
                            )]
                        ),
                        table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                            cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_names_visibility="columnNamesVisibility",
                            metric_placement="metricPlacement",
                            row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            ),
                            row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            single_metric_visibility="singleMetricVisibility",
                            toggle_buttons_visibility="toggleButtonsVisibility"
                        ),
                        total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                            column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        )
                    ),
                    conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                    role="role"
                                ),
                                text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3c7117647ca6efee05167dc0a39a7b0f6b839f8cca72ffd2d3c843bd4815116b)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnDashboard.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__950dae094993a7c1e36361fcb586f4089e6ee69d22012ef1e2fe13aa11381fb6)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the total of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnDashboard.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f438e55bdb2db4c5b4a89462ab3991f7ecaf138c507a3437d348d41afb871f9)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The list of columns that define the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnDashboard.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1e53022020db9de733e0454f9b7cc18ffeb4fd51075617d392ad1ccd0aed65a)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html#cfn-quicksight-dashboard-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_aggregated_field_wells_property = quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    color=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b3945a32d2258b423c2984606a8faa41c3cbc13ebe9b0ae8a1dc0ee41d676b2)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated field well categories of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afe33d192148a7bc3c6ff522ed41994d2bee49fa1331af216a40442a8732673f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html#cfn-quicksight-dashboard-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_axis: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_configuration_property = quicksight.CfnDashboard.RadarChartConfigurationProperty(
                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                    alternate_band_even_color="alternateBandEvenColor",
                    alternate_band_odd_color="alternateBandOddColor",
                    base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                        area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                            visibility="visibility"
                        )
                    ),
                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                        radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    shape="shape",
                    sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    start_angle=123,
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2549cfe32010077318b6072599c75789900322117b1ad34eb540b4b5586dea4d)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The base sreies settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The color axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The color label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_field_wells_property = quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                    radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        color=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__26c893dfe60075c78b4437d8cd530a8dd7f954cab0067f55e48933db169aa628)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html#cfn-quicksight-dashboard-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d8d06de7d0459adb93d5ab41925aebcace67ccb323b3e2ce62e9c1fcb9bd9c3)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartAreaStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html#cfn-quicksight-dashboard-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartAreaStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bc7709f889d3c24581dc107f985f3e0f5ef4be5661f466ab92adf7834e52dfe)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The category items limit for a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The category sort options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The color items limit of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_visual_property = quicksight.CfnDashboard.RadarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                        alternate_band_colors_visibility="alternateBandColorsVisibility",
                        alternate_band_even_color="alternateBandEvenColor",
                        alternate_band_odd_color="alternateBandOddColor",
                        base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                            area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                visibility="visibility"
                            )
                        ),
                        category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                            radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        shape="shape",
                        sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        start_angle=123,
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae49eb9e85d732bc5959aed038b8289395f181a716c17e964b299458ffd3ad7a)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__896328ed23dccf2bb2b1c6ca31a3cfff1bdd7eff65c5830245a67a2bb6b5bae7)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html#cfn-quicksight-dashboard-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc3ffb8eef413e4c670baa75d50ad9648d3fd7289017556923e383c312d6843c)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html#cfn-quicksight-dashboard-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - PrimaryY - SecondaryY
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param static_configuration: The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53086df30d0259e4d7f96a1b56649201d816829675aff6ced451c9104cd82ed7)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - PrimaryY
            - SecondaryY

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ReferenceLineDynamicDataConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The dynamic configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ReferenceLineDynamicDataConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ReferenceLineStaticDataConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ReferenceLineStaticDataConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            measure_aggregation_function: typing.Union[typing.Union["CfnDashboard.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cedff3003733e8f3fdd5557c9ff4c4c5678dea55607ff4629d539c120b9d473b)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
                "measure_aggregation_function": measure_aggregation_function,
            }

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The calculation that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union["CfnDashboard.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the dynamic data targets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            assert result is not None, "Required property 'measure_aggregation_function' is missing"
            return typing.cast(typing.Union["CfnDashboard.AggregationFunctionProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ef1d80440ee79185f2dd599f9fdb41ebe9359ad08733560ba1cd6944eeac38a7)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ReferenceLineCustomLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The custom label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ReferenceLineCustomLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ReferenceLineValueLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The value label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ReferenceLineValueLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[typing.Union["CfnDashboard.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            label_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnDashboard.ReferenceLineProperty(
                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f58ff203d6f12d047b1db6068e93903587097aa6ecebf40704047e48b8216669)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union["CfnDashboard.ReferenceLineDataConfigurationProperty", _IResolvable_a771d0ef]:
            '''The data configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.ReferenceLineDataConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ReferenceLineLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The label configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ReferenceLineLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ReferenceLineStyleConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ReferenceLineStyleConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7cb1537e30050dff3aa6f5edde07e335024d89319fcbee7775d7f5b7c4ebe4d)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html#cfn-quicksight-dashboard-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__708a787be5b608e354cb9e82c90d925ad6a3591286d62e02fed7eb415813abc6)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75bbd70c28bfb100237d2931830fe0e8e705d9780572b6ad3d768e9e37d0b757)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the value label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3677b52f6645b670be38dac1097361fb8193c9e7d053d46494974f3d559098ca)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[typing.Union["CfnDashboard.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnDashboard.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e951d875ede35c3b89d905eda69b2d14f933c420e5ddb3f0c68981a6bf59f4d)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union["CfnDashboard.AnchorDateConfigurationProperty", _IResolvable_a771d0ef]:
            '''The date configuration of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.AnchorDateConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for the exclude period of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: ``CfnDashboard.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDashboard.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e309cc8aae3956e65ad8c02b9e5c3f4d2b0e0a396bd903871c83c3308f86c4f)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''``CfnDashboard.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnDashboard.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__08b33f83126e62dc8daf6e91b213f73ff7439a4c7703a1fd75135509b0819e56)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de3ec1e8b3f951afbbb7d94265c067b6ffb54d16735b31e44160c362a325081b)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d338e70265dc4293c3d45ff92969c3c17d622d5a23eb9eb8c4741103e19fc775)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            source: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            weight: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_aggregated_field_wells_property = quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                    destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    source=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__328265bd28f011b21a33a8abf290a63ccf33420361868726ddde7aebb12512ac)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The destination field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The source field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_chart_configuration_property = quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                        sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                            destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                        destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad2da31e4b7f1f401ba152b02f1cf3e8e908cf6d64a54d0233c5857e8762aa87)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SankeyDiagramFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SankeyDiagramFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SankeyDiagramSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SankeyDiagramSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_field_wells_property = quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                    sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                        destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        source=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__73309b74fcebd042e21631d22f14b6fa27b0b7d9f09e3c7b593d6843937391c8)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html#cfn-quicksight-dashboard-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            weight_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e8b89fc445d140ffc81194bcff5050f6ff432aa65eba9fd8713df63b5c061efc)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_visual_property = quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                            sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                            destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1a66d5616fdd1db9a5ea64776a02e2a1f36c60ed91483ed8835dc963edfcc1e0)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SankeyDiagramChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SankeyDiagramChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_categorically_aggregated_field_wells_property = quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63c0b78e43424003a24bc9ed0c070bd98c74da2ab5d71ce16e17ac95d1e20937)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_configuration_property = quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e747c35c798df5aa07e1e4f42c1b12ec5777f1043707a1678cca347f657e29a)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ScatterPlotFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ScatterPlotFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_field_wells_property = quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a6a8ab688bdc514b909a688049be101be768fc3b0b721484acae06102b0a478)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a scatter plot.

            The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The unaggregated field wells of a scatter plot.

            The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"size": "size", "x_axis": "xAxis", "y_axis": "yAxis"},
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_unaggregated_field_wells_property = quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__81c33bd62c6b12f0690e6f678fa7f902901bb8a52ac39912500638e8a8c8e600)
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_visual_property = quicksight.CfnDashboard.ScatterPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                            scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__073adbeda85fa5796988ca1e62c71c12cbb82cf10c44aa4f4a432c2b8c607f96)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ScatterPlotConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ScatterPlotConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnDashboard.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f6a739b9e6e107e34f37757ac307b8d4896d3515273b93150a9ecb1016cd721d)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisibleRangeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisibleRangeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e03c3e307cc3c6013309ff8c618f468161d60f537db8f9f5ec1435e2b3d22dca)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html#cfn-quicksight-dashboard-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7cb67a1dbad4d8903eda03761e784b361e1901e392abef30629e20d8990c3fa6)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html#cfn-quicksight-dashboard-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8e88e5e0e9e7c11880c8014e06b2f06c0c511fd0494a01dc21920d2a20a22862)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Union[typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            footer_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            header_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnDashboard.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnDashboard.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e85dde91c61578758a93856ad8f0079c6fa485c901e1a2be6e872559bb710f15)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.BodySectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of body section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.BodySectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''The options for the canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of footer section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[typing.Union["CfnDashboard.SpacingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnDashboard.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7bff00978b8c784c267d159ebd238be6484bdf9f09d8767edf6b44ed71105aab)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SpacingProperty", _IResolvable_a771d0ef]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SpacingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[typing.Union["CfnDashboard.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a6dfd7a687e23c20720e8413f4dca9b8325617775704819313512cb36f8e44f)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union["CfnDashboard.FreeFormSectionLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html#cfn-quicksight-dashboard-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union["CfnDashboard.FreeFormSectionLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[typing.Union["CfnDashboard.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e51c2617c2088a5e2f258fac141b62b8b2fa5d1aa3b940c476fabc70bcd2df4c)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SectionAfterPageBreakProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html#cfn-quicksight-dashboard-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SectionAfterPageBreakProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[typing.Union["CfnDashboard.SpacingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnDashboard.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnDashboard.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4e7e96c484d1cbd0203836ae4e0243c64cef9bbde3263ebea15a8d85b361ede)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SpacingProperty", _IResolvable_a771d0ef]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SpacingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a2117f965c7d115c31ac9fd6fb999827f581c1cff4a09665e6210fa71bec1a6c)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetVisualScopingConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-dashboard-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetVisualScopingConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_series_item: typing.Optional[typing.Union[typing.Union["CfnDashboard.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnDashboard.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8547b662e1fad8933d9001e65abfc928c97c09570033f42d5183aa5023ff21ca)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataFieldSeriesItemProperty", _IResolvable_a771d0ef]]:
            '''The data field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataFieldSeriesItemProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FieldSeriesItemProperty", _IResolvable_a771d0ef]]:
            '''The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FieldSeriesItemProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[typing.Union["CfnDashboard.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: ``CfnDashboard.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0bf26bec0af81d8c8cc1b73dd79c00452b7547f3bdf21add1f60bbf994b6b2aa)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union["CfnDashboard.DestinationParameterValueConfigurationProperty", _IResolvable_a771d0ef]:
            '''``CfnDashboard.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union["CfnDashboard.DestinationParameterValueConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4bfd5addb0b5da38cedf0efc5b8502b813ea98a04573e5461fa225eb682c9d4a)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html#cfn-quicksight-dashboard-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[typing.Union["CfnDashboard.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2431ca72e23c19e7cfc662f6be5d4f59d1bb600a1c10c097909416f029303dfc)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html#cfn-quicksight-dashboard-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[typing.Union["CfnDashboard.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnDashboard.SheetControlLayoutProperty(
                    configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__896bf953305117e4cdd98cdbb7680e9b05069be6b10d66c78ce893a1c6449d4f)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnDashboard.SheetControlLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html#cfn-quicksight-dashboard-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.SheetControlLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetControlsOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility_state": "visibilityState"},
    )
    class SheetControlsOptionProperty:
        def __init__(
            self,
            *,
            visibility_state: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Sheet controls option.

            :param visibility_state: Visibility state.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_controls_option_property = quicksight.CfnDashboard.SheetControlsOptionProperty(
                    visibility_state="visibilityState"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9cb9b42f4a076983e84b169fab3a39b5349ed6e3a3a03bc68f3a1144f8d8008a)
                check_type(argname="argument visibility_state", value=visibility_state, expected_type=type_hints["visibility_state"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility_state is not None:
                self._values["visibility_state"] = visibility_state

        @builtins.property
        def visibility_state(self) -> typing.Optional[builtins.str]:
            '''Visibility state.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html#cfn-quicksight-dashboard-sheetcontrolsoption-visibilitystate
            '''
            result = self._values.get("visibility_state")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlsOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FilterControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.LayoutProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            text_boxes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                sheet_definition_property = quicksight.CfnDashboard.SheetDefinitionProperty(
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnDashboard.LayoutProperty(
                        configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                    content=quicksight.CfnDashboard.BodySectionContentProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnDashboard.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnDashboard.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                        date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnDashboard.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                        configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
                
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnDashboard.VisualProperty(
                        bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                computations=[quicksight.CfnDashboard.ComputationProperty(
                                    forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                        category=quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                    comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnDashboard.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                    arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
                
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                            column=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnDashboard.TableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
                
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnDashboard.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__020cf2b4b69a5460645b7cc4d5324efe862b83badae9fc2693bf24ade70578dd)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilterControlProperty", _IResolvable_a771d0ef]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FilterControlProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.LayoutProperty", _IResolvable_a771d0ef]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.LayoutProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ParameterControlProperty", _IResolvable_a771d0ef]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ParameterControlProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetControlLayoutProperty", _IResolvable_a771d0ef]]]]:
            '''The control layouts of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetControlLayoutProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetTextBoxProperty", _IResolvable_a771d0ef]]]]:
            '''The text boxes that are on a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.SheetTextBoxProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualProperty", _IResolvable_a771d0ef]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__48756b5654512d03796f9c2414ee40b2b0db6a9a8b8e5b8ff7e4f0e6a5784bfb)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html#cfn-quicksight-dashboard-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[typing.Union["CfnDashboard.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57db451d902c87db172455713b235623fe5217d6d8975228a53df1037906e893)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union["CfnDashboard.SheetElementConfigurationOverridesProperty", _IResolvable_a771d0ef]:
            '''The override configuration of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union["CfnDashboard.SheetElementConfigurationOverridesProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class SheetLayoutElementMaximizationOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sheet layout maximization options of a dashbaord.

            :param availability_status: The status of the sheet layout maximization options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_layout_element_maximization_option_property = quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__719e9089e375d1d64531920e903e67864f920242422908e09cb4b223892d639e)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The status of the sheet layout maximization options of a dashbaord.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html#cfn-quicksight-dashboard-sheetlayoutelementmaximizationoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetLayoutElementMaximizationOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnDashboard.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d6d59f5fe93c16a00919ab6a0bc76f614901ae3b7d69f35f14169990c66ab7b)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnDashboard.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23aeb0481c97cedc4da6275dca763ad7d18f7d1f4d634caebeb130beb344fd2d)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f2c58ac12165b73a342d572cd83695deb81ad759dba8a8b4fc5cfb58ee16ff92)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnDashboard.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95e596e0f40b5ab6bdbbda45417ea041a9573bcd260018abd566e38963d8223a)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b38fdd017ed52e8a6a493bdc890158e2a485095a2e247f7ce360ba99b1b08581)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html#cfn-quicksight-dashboard-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"title_options": "titleOptions"},
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8db8e355270eec563b362be52f8ed49d42485e52ff1c781ac263cdd959213c98)
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dfae266922ae624a9ca6d9e2cad17241146763b037acd7febdb6bdb71f2df49f)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PanelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PanelConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnDashboard.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96b4daf4ec49b681615ad44c019a67df1ac1ed982778aff74b6f2a66dbf1f747)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnDashboard.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0d863dde28c64b9dc3f3fc513b5fc751a040238e8bda71f92051ad80e3d8b5d2)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnDashboard.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6c18759cba640870d2bd9976762093dfebecf84b71d2ec032118de17f4dfa5df)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnDashboard.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnDashboard.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnDashboard.StringParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnDashboard.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__021813ea7bfadd46e078e8c0332522d462b0b41ac86ca17f48d8c61f03b9ccff)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.StringDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.StringDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnDashboard.StringParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.StringValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.StringValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.StringParameterProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "values": "values"},
    )
    class StringParameterProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            values: typing.Sequence[builtins.str],
        ) -> None:
            '''A string parameter.

            :param name: A display name for a string parameter.
            :param values: The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_parameter_property = quicksight.CfnDashboard.StringParameterProperty(
                    name="name",
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af3a7e4414148b116d2e183f6c8f37c7cf57ee7451c6976d8d0ad0fdd0574883)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "values": values,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def values(self) -> typing.List[builtins.str]:
            '''The values of a string parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-values
            '''
            result = self._values.get("values")
            assert result is not None, "Required property 'values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85a41bc1f8f2e7dbdf1c3f74c9ca21610c881a5acaf48f08596e359ca13e4b28)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnDashboard.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__81c3651688a90b74f699473efd65f49f25957c41992b54c31c34715d526ec977)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableFieldSubtotalOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The optional configuration of subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.PivotTableFieldSubtotalOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotals of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fe979ba8d7d76724e62f44aa28cf7fc52839f8262e9379ffea0c8467b716462d)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnDashboard.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96aedadb12a6966208378fe88556425bec4817da816985750e12d3a02521c143)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a13f77aa4859fd82c7df72f06004c0f9524e2860538c9a7a7eaeeb0d7bde6564)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__300441a2cbac00103ce5b3e31357dccdcd506413008cd82284d8c635d79cea69)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html#cfn-quicksight-dashboard-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[typing.Union["CfnDashboard.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnDashboard.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0c500b7d11c6b483e5b9f05d1b8a867798bee63d6df307872ed9362b11acf75)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GlobalTableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The borders for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GlobalTableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnDashboard.GradientColorProperty(
                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ccb2cfe4b8fb0c8e2f856692cbd58cf0519caa5b95342e906aa7cd0abf4e703)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The cell conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableRowConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableRowConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnDashboard.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8feef7bc7e986824d5c97a3acebc724a41fe28f32af3fd1db48dd3413fd74db3)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html#cfn-quicksight-dashboard-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_report_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            table_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_configuration_property = quicksight.CfnDashboard.TableConfigurationProperty(
                    field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                        order=["order"],
                        selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                    )
                                ),
                                link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                            icon="icon"
                                        ),
                                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            value="value"
                                        )
                                    ),
                                    target="target"
                                )
                            ),
                            visibility="visibility",
                            width="width"
                        )]
                    ),
                    field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                        table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                            values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        ),
                        row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                        data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            negative_color="negativeColor",
                            positive_color="positiveColor"
                        )
                    )],
                    table_options=quicksight.CfnDashboard.TableOptionsProperty(
                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        orientation="orientation",
                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        )
                    ),
                    total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                        custom_label="customLabel",
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c92b93f58dfc88fd9d219f151cba291f47e6d3cdccc44e3cd34b5d9e4a0af95)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldOptionsProperty", _IResolvable_a771d0ef]]:
            '''The field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]]:
            '''The paginated report options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a ``TableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TableInlineVisualizationProperty", _IResolvable_a771d0ef]]]]:
            '''A collection of inline visualizations to display within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TableInlineVisualizationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__150ad661ef2008b2b50e7d9bbe255855e510658ef4194203f72adfc2ba7da7fd)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html#cfn-quicksight-dashboard-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[typing.Union["CfnDashboard.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9990b3e37412caa22f32fae936de93c7d82e69ad54e111a19a636fbdf8663379)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef]:
            '''The font configuration of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union["CfnDashboard.FontConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b595631d6553fc1e25569b2efc6867e9d07cdc52830dc6de0f6577c9358ac03)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellImageSizingConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html#cfn-quicksight-dashboard-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellImageSizingConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[typing.Union["CfnDashboard.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de12363331cf146e3dc6e217d9acf22d461c8fa8e95a9f0cab2749d03659b565)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union["CfnDashboard.TableFieldLinkContentConfigurationProperty", _IResolvable_a771d0ef]:
            '''The URL content (text, icon) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union["CfnDashboard.TableFieldLinkContentConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_text_content: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39cce4765754411ef3997661ee9367314704e8cb7f47d60611cd4e71de55c170)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldCustomIconContentProperty", _IResolvable_a771d0ef]]:
            '''The custom icon content for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldCustomIconContentProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldCustomTextContentProperty", _IResolvable_a771d0ef]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldCustomTextContentProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnDashboard.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d064ba63021496823fc8cab4556e6b685a4a0908b5151a863388a1b1c6b46865)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldURLConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The URL configuration for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldURLConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field options for a table visual.

            :param order: The order of field IDs of the field options for a table visual.
            :param selected_field_options: The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnDashboard.TableFieldOptionsProperty(
                    order=["order"],
                    selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a7130615f1c634c9a6baa475d6089b1d943618d96e057b0081fafb973287e174)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of field IDs of the field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TableFieldOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.TableFieldOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            link_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36c23de3a1f143cd6e8a7809b4f55b6fa215c791c1b769a7490be7a712c4a126)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldImageConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The image configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldImageConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableFieldLinkConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableFieldLinkConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_wells_property = quicksight.CfnDashboard.TableFieldWellsProperty(
                    table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                        values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9bd2087f8c31b3758cead5592c0d50d37d2bf276cf18e5ba2599b05ef81ba3e0)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnDashboard.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0977e0f57370f96c3c0077802bc54db5fcb42d821c4f667d1db7974d042e8419)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataBarsOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html#cfn-quicksight-dashboard-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataBarsOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            header_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnDashboard.TableOptionsProperty(
                    cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__66b3e13956cc195d9d20de0c2b0460edcfbb49bb7248b03eb2632c96c049eff2)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of a table header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3f00f777a4874b314485a28d7f9e99a52b0c377e8b27effdf1191a56863d946)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7caa0da8eb152e4e6e64e61a51d9af5749dbbeec791c75d7f8e79a70ca27c47)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            inner_horizontal: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            inner_vertical: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            left: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            right: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cc9296ff5d4d8e2feae335f0765bb95ba0291fda2f24160f017cc84182fa8721)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the bottom border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the inner horizontal border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the inner vertical border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the left border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the right border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnDashboard.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10fad85e8529c45258d6ac02db479a63a3a98c646741466e78920f8c530c4f3a)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PaginationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The pagination configuration (page size, page number) for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PaginationConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1baf2b9731032dd6c21168a5bade4dfae2d0f1b228b2a2e3d1d582520521f61d)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.UnaggregatedFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html#cfn-quicksight-dashboard-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.UnaggregatedFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_visual_property = quicksight.CfnDashboard.TableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                        field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                            order=["order"],
                            selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                    image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                        sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                        )
                                    ),
                                    link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                        content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                            custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                icon="icon"
                                            ),
                                            custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                
                                                # the properties below are optional
                                                value="value"
                                            )
                                        ),
                                        target="target"
                                    )
                                ),
                                visibility="visibility",
                                width="width"
                            )]
                        ),
                        field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                            table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                            pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            ),
                            row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                            data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                negative_color="negativeColor",
                                positive_color="positiveColor"
                            )
                        )],
                        table_options=quicksight.CfnDashboard.TableOptionsProperty(
                            cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            orientation="orientation",
                            row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            )
                        ),
                        total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                            custom_label="customLabel",
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility"
                        )
                    ),
                    conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            ),
                            row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a005115d8a4ba2d7151179a1241dfe5b19d7d9d46a130f7395db84fd8726f14)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a63bb4c5454f5f48ef6eeccea62873f1f7c990596f0ad3e2acff542650ef0e8d)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the placeholder options in a text area control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            icon: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnDashboard.TextConditionalFormatProperty(
                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnDashboard.GradientColorProperty(
                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__72ab17708dd4dee29aa983156e49fa72ee78451c0f7935e17deb58e96109656c)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the text background color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__41f405ea637d759b60db54ea7eda5609943d8a6c80384f83df8521ff89ac7450)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html#cfn-quicksight-dashboard-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f9f3eac431ea49b3781df1f2e40ce1978e4e4e8d86320feced47bbbfd983123)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the placeholder options in a text field control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a36e0ba3c505ab3ee0f0d7861740b5d7a816f361f0af3323170e479cffa649d)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6a15c622796a233590565499ab65a75f4c69efffadf3bfc9df99b39b22e23426)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnDashboard.TimeEqualityFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__12d66de9019ed735e5d081b8947ac743c29a70fbd46932fff3f3ed993ab28297)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4dd290a8c6ec0276bbf3e7c41585deb78351a97999b46606f038f141f2930ea4)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            range_maximum_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_minimum_value: typing.Optional[typing.Union[typing.Union["CfnDashboard.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnDashboard.TimeRangeFilterProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__02c8916a44f48330497e18ae421848c832b390cbc65a75cd05407f438a5089a0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The exclude period of the time range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[typing.Union["CfnDashboard.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7b2f5dc4bca8c6441bf8ba53afbfbbcf7c8f2760c0df37fa85b54e54a313ec01)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RollingDateConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The rolling date input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RollingDateConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_tooltip_item: typing.Optional[typing.Union[typing.Union["CfnDashboard.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnDashboard.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d5d5dd527540a63b14fcf2d27f002487579970e3ea82c8a6bf0af36b2f5ba041)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColumnTooltipItemProperty", _IResolvable_a771d0ef]]:
            '''The tooltip item for the columns that are not part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColumnTooltipItemProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FieldTooltipItemProperty", _IResolvable_a771d0ef]]:
            '''The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FieldTooltipItemProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnDashboard.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1bfb1517d4e1ccfa913cedb9145d45666fc0d9a70e57d183d35cec6dbc6f6627)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FieldBasedTooltipProperty", _IResolvable_a771d0ef]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FieldBasedTooltipProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnDashboard.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection"
                    )],
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a8d564333c80900dc8b12da7f344f243c281f188d85f0506de738bb42fc7bf96)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.AggregationSortConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.AggregationSortConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            type: builtins.str,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param mover_size: The mover size setup of the top and bottom movers computation.
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_movers_computation_property = quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    mover_size=123,
                    name="name",
                    sort_order="sortOrder",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c2074ad4c57e3231956c39923abd6a13addc6b18b5a0c4cc273ee86712697d7)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_ranked_computation_property = quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    result_size=123,
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3077b8c8184d185ecb682e9252fad228a9eb1a90105eec2bb392554e7e4e4a3)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "value": "value",
            "name": "name",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            value: typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param value: The value field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnDashboard.TotalAggregationComputationProperty(
                    computation_id="computationId",
                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44126bbbacfbcf1115ffbcaa393d1db8ba0a4050407354ebd1eb9a2e8b9214f8)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "value": value,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnDashboard.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5171e2179a4a266cc6183009076fc35c282e8de36a06bdaa4533d72bede45ee3)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''Cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sizes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_aggregated_field_wells_property = quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b134b11cca592b9e123baa45a8b9158272a73b4cde7a54c4cf9b557bb8e28a2d)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_scale: typing.Optional[typing.Union[typing.Union["CfnDashboard.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            group_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            size_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnDashboard.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_configuration_property = quicksight.CfnDashboard.TreeMapConfigurationProperty(
                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                        tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                        tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f7352915f4f203593150c38509289a3795a8ebdcac702ca2aea383d74401bc86)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ColorScaleProperty", _IResolvable_a771d0ef]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ColorScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TreeMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TreeMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TreeMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TreeMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_field_wells_property = quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                    tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f8eda1c6d8d738dc12ed9bb767a04230a94e398225a46fbe4789779e946e4920)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TreeMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html#cfn-quicksight-dashboard-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TreeMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tree_map_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__805f74245fbddda8aebf7a90f662735f840c800ce55870e429732b2d4fd69f6e)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_visual_property = quicksight.CfnDashboard.TreeMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                        color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                            tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                            tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__34fb93c3438cbfd21ae4daa667130c3e49bb5ff4aac72ca0dd76162fd3413484)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TreeMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TreeMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnDashboard.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7c0ee04f5ee87ded27a6bd61efa93fae5e69d7ddb9c3106966207f995b73bd02)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html#cfn-quicksight-dashboard-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnDashboard.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnDashboard.UnaggregatedFieldProperty(
                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__09331dab911bea1630cf2567d5ecdade692a3690a26bee03c32817da82df1788)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``UnaggregatedField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnDashboard.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnDashboard.UniqueValuesComputationProperty(
                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdf9dd380ae2350cc581664ab6036b5046cd90251796b9efc6a6622b9019fdb3)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[typing.Union["CfnDashboard.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__569c4d2c981838210bb312bf601c11974f9c36df953a07ab9345a6e07e486412)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PercentVisibleRangeProperty", _IResolvable_a771d0ef]]:
            '''The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html#cfn-quicksight-dashboard-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PercentVisibleRangeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualAxisSortOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class VisualAxisSortOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The axis sort options for a visual.

            :param availability_status: The availaiblity status of a visual's axis sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_axis_sort_option_property = quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0d0389cd0147a14c97a8f6b64aa597974ef8456753650ae5f497d59f6a18951)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The availaiblity status of a visual's axis sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html#cfn-quicksight-dashboard-visualaxissortoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualAxisSortOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            navigation_operation: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            set_parameters_operation: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            url_operation: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9515c611ac5aadf7aeb6f4ad74868aa5f3c37f075be10ba23d7b4a76b92a32b)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomActionFilterOperationProperty", _IResolvable_a771d0ef]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomActionFilterOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomActionNavigationOperationProperty", _IResolvable_a771d0ef]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomActionNavigationOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomActionSetParametersOperationProperty", _IResolvable_a771d0ef]]:
            '''The set parameter operation that sets parameters in custom action.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomActionSetParametersOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomActionURLOperationProperty", _IResolvable_a771d0ef]]:
            '''The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomActionURLOperationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnDashboard.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c94c1a76ebd0c0a784a1871e16d0cbfaf0fd402530a5264b3cbd00ac4064ff95)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionOperationProperty", _IResolvable_a771d0ef]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionOperationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualMenuOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"availability_status": "availabilityStatus"},
    )
    class VisualMenuOptionProperty:
        def __init__(
            self,
            *,
            availability_status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The menu options for a visual.

            :param availability_status: The availaiblity status of a visual's menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_menu_option_property = quicksight.CfnDashboard.VisualMenuOptionProperty(
                    availability_status="availabilityStatus"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9fc6237cd2688d1a34fcfa178eb08f6afe91c29011bc5dbe49c5ab850eecdc33)
                check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_status is not None:
                self._values["availability_status"] = availability_status

        @builtins.property
        def availability_status(self) -> typing.Optional[builtins.str]:
            '''The availaiblity status of a visual's menu options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html#cfn-quicksight-dashboard-visualmenuoption-availabilitystatus
            '''
            result = self._values.get("availability_status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualMenuOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnDashboard.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnDashboard.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a13354d788a1706289a18ef978f07b669108d63afe1c73361563163e6dd429d6)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataPathColorProperty", _IResolvable_a771d0ef]]]]:
            '''The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DataPathColorProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            box_plot_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            combo_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_content_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            empty_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filled_map_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            histogram_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            insight_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            kpi_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            line_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            pie_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            pivot_table_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            radar_chart_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.TableVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tree_map_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            waterfall_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            word_cloud_visual: typing.Optional[typing.Union[typing.Union["CfnDashboard.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                visual_property = quicksight.CfnDashboard.VisualProperty(
                    bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            orientation="orientation",
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                            box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                all_data_points_visibility="allDataPointsVisibility",
                                outlier_visibility="outlierVisibility",
                                style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                    fill_style="fillStyle"
                                )
                            ),
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                )
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                            bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                    bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                            content_type="contentType",
                            content_url="contentUrl",
                            image_scaling="imageScaling"
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )]
                    ),
                    filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                            field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                label_color="labelColor",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_data_label_style="measureDataLabelStyle",
                                measure_label_visibility="measureLabelVisibility",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                    arc_angle=123,
                                    arc_thickness="arcThickness"
                                ),
                                arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                    range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                        max=123,
                                        min=123
                                    ),
                                    reserve_range=123
                                ),
                                comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            ),
                            tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                            field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                    cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                        simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                            color="color"
                                        )
                                    )
                                ),
                                selected_point_style="selectedPointStyle"
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                            color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                            bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                    value=123
                                ),
                                bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                    bin_count_limit=123,
                                    value=123
                                ),
                                selected_bin_type="selectedBinType",
                                start_value=123
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            )
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                            computations=[quicksight.CfnDashboard.ComputationProperty(
                                forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    custom_seasonality_value=123,
                                    lower_boundary=123,
                                    name="name",
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality="seasonality",
                                    upper_boundary=123,
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_size=123,
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                    computation_id="computationId",
                                    from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_time_granularity="periodTimeGranularity",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    time=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    mover_size=123,
                                    name="name",
                                    sort_order="sortOrder",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    result_size=123,
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                    computation_id="computationId",
                                    value=quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                    category=quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                
                                    # the properties below are optional
                                    name="name"
                                )
                            )],
                            custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                narrative="narrative"
                            )
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                            field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                    visibility="visibility"
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                            contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                axis_binding="axisBinding",
                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                    lower_boundary=123,
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality=123,
                                    upper_boundary=123
                                ),
                                scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                    what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                        date="date",
                                        value=123
                                    ),
                                    what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                        end_date="endDate",
                                        start_date="startDate",
                                        value=123
                                    )
                                )
                            )],
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                            range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            series=[quicksight.CfnDashboard.SeriesItemProperty(
                                data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    field_value="fieldValue",
                                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                ),
                                field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                )
                            )],
                            small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            type="type",
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                    arc_thickness="arcThickness"
                                ),
                                donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                    label_visibility="labelVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                            field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                    data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )],
                
                                    # the properties below are optional
                                    width="width"
                                )],
                                selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    visibility="visibility"
                                )]
                            ),
                            field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                    field_id="fieldId",
                                    sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                        column=quicksight.CfnDashboard.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                            direction="direction",
                                            sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )]
                                        ),
                                        field=quicksight.CfnDashboard.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )
                                )]
                            ),
                            table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_names_visibility="columnNamesVisibility",
                                metric_placement="metricPlacement",
                                row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                ),
                                row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                single_metric_visibility="singleMetricVisibility",
                                toggle_buttons_visibility="toggleButtonsVisibility"
                            ),
                            total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            )
                        ),
                        conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                        role="role"
                                    ),
                                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                            alternate_band_colors_visibility="alternateBandColorsVisibility",
                            alternate_band_even_color="alternateBandEvenColor",
                            alternate_band_odd_color="alternateBandOddColor",
                            base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                    visibility="visibility"
                                )
                            ),
                            category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            shape="shape",
                            sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            start_angle=123,
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                    destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    table_visual=quicksight.CfnDashboard.TableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                            field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                order=["order"],
                                selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                        image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                            sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                            )
                                        ),
                                        link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                            content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                    icon="icon"
                                                ),
                                                custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                
                                                    # the properties below are optional
                                                    value="value"
                                                )
                                            ),
                                            target="target"
                                        )
                                    ),
                                    visibility="visibility",
                                    width="width"
                                )]
                            ),
                            field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                    values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                ),
                                row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    negative_color="negativeColor",
                                    positive_color="positiveColor"
                                )
                            )],
                            table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                orientation="orientation",
                                row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                )
                            ),
                            total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                custom_label="customLabel",
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility"
                            )
                        ),
                        conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnDashboard.GradientColorProperty(
                                                    stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                ),
                                row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                    background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnDashboard.GradientColorProperty(
                                                stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                            color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                            category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                    breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                        range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnDashboard.AxisScaleProperty(
                                            linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnDashboard.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                total_bar_label="totalBarLabel"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                            category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                cloud_layout="cloudLayout",
                                maximum_string_length=123,
                                word_casing="wordCasing",
                                word_orientation="wordOrientation",
                                word_padding="wordPadding",
                                word_scaling="wordScaling"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77b257a645791fc2723570ed78b8820ae80a690735dcae5e6a265cffb5803969)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BarChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BarChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.BoxPlotVisualProperty", _IResolvable_a771d0ef]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.BoxPlotVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ComboChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ComboChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.CustomContentVisualProperty", _IResolvable_a771d0ef]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.CustomContentVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.EmptyVisualProperty", _IResolvable_a771d0ef]]:
            '''An empty visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.EmptyVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FilledMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FilledMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.FunnelChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.FunnelChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GaugeChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GaugeChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.GeospatialMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.GeospatialMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HeatMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HeatMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.HistogramVisualProperty", _IResolvable_a771d0ef]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.HistogramVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.InsightVisualProperty", _IResolvable_a771d0ef]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.InsightVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.KPIVisualProperty", _IResolvable_a771d0ef]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.KPIVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LineChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LineChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PieChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PieChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.PivotTableVisualProperty", _IResolvable_a771d0ef]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.PivotTableVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.RadarChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.RadarChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.SankeyDiagramVisualProperty", _IResolvable_a771d0ef]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.SankeyDiagramVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ScatterPlotVisualProperty", _IResolvable_a771d0ef]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ScatterPlotVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TableVisualProperty", _IResolvable_a771d0ef]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TableVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.TreeMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.TreeMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WaterfallVisualProperty", _IResolvable_a771d0ef]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WaterfallVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WordCloudVisualProperty", _IResolvable_a771d0ef]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WordCloudVisualProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[typing.Union["CfnDashboard.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d324159738a94304717aa9d18ad46ff3b645f88ea8c97cc8c7583c6c1c27aad)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LongFormatTextProperty", _IResolvable_a771d0ef]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LongFormatTextProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[typing.Union["CfnDashboard.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22c5ef3884f3bc69d37991a34d5590174f5721acb49b2b430e6ef592c581e535)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ShortFormatTextProperty", _IResolvable_a771d0ef]]:
            '''The short text format of the title label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ShortFormatTextProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            categories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_aggregated_field_wells_property = quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                    breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__49da1f8c7efba1a102086854a1547844188dc619cc9465df9ecff76b3df6cba5)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The breakdown field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnDashboard.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnDashboard.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_chart_configuration_property = quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                    category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                        waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                            breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                        breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                        total_bar_label="totalBarLabel"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0fdfbe74bfcb18f664c0b448e72342667aa8486c3ac9d6f4b94a302a1152437c)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the category axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the category axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WaterfallChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WaterfallChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WaterfallChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WaterfallChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WaterfallChartOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WaterfallChartOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_field_wells_property = quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                    waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                        breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7a8a320421fd11c1f667fff2c9d675b952bc7dbf2a18c1218f78294d452907ae)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WaterfallChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html#cfn-quicksight-dashboard-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WaterfallChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8075fb40171eafc6a3b8af3cd23ccadb989723518cabed8b31fdb6a71cb223e7)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html#cfn-quicksight-dashboard-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__985cdf8e234eead907a9bfb933c3d707136b6c6cdb900103553373d9ccbb9ec5)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of bar groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_visual_property = quicksight.CfnDashboard.WaterfallVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                        category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                            waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnDashboard.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnDashboard.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                            breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnDashboard.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                            total_bar_label="totalBarLabel"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2655d5d49d56236d793ed55ae210dda69a9a61186fb2c8c633185d8e873f2162)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WaterfallChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WaterfallChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8001e7d3a93a99ec24c1340ac090b7aea45a69cb45fef5d7036abf4ea90833c8)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04cd97185b81f2bd03969cae156e186d0e632ee5c078315353ac1acad2445f74)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnDashboard.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                            column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c841f9ac1766b3816026f5f382f94ce9ca34b6c48a057b163dcdae2849e4da6)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            word_cloud_options: typing.Optional[typing.Union[typing.Union["CfnDashboard.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_chart_configuration_property = quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                        word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                        cloud_layout="cloudLayout",
                        maximum_string_length=123,
                        word_casing="wordCasing",
                        word_orientation="wordOrientation",
                        word_padding="wordPadding",
                        word_scaling="wordScaling"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20277e3c2ac23f49f297e85fd9dd01e18b5f6556465eca80a7fc222a296ce453)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WordCloudFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WordCloudFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WordCloudSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WordCloudSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WordCloudOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WordCloudOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnDashboard.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnDashboard.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d1ea487c1080559810b49efbe90c14185b0e360f95c6634fb3984f67454130d)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WordCloudAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html#cfn-quicksight-dashboard-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WordCloudAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnDashboard.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8014a12c4168127505af278ae22ab39e0306d347901f8f46aeb7ab430d723773)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnDashboard.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fd34d9fc66fd9c9ae8f0257e93c923525b8553ce125936ef1ac7d120d7b2f83d)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDashboard.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnDashboard.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDashboard.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_visual_property = quicksight.CfnDashboard.WordCloudVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                        category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                            word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                            category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                            cloud_layout="cloudLayout",
                            maximum_string_length=123,
                            word_casing="wordCasing",
                            word_orientation="wordOrientation",
                            word_padding="wordPadding",
                            word_scaling="wordScaling"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__366cc762d04d6163a5c3e4685d59f3530490b7bc0a4bf2fa6334ff99d1c3b3ec)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.WordCloudChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.WordCloudChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDashboard.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnDashboard.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnDashboardProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "dashboard_id": "dashboardId",
        "name": "name",
        "dashboard_publish_options": "dashboardPublishOptions",
        "definition": "definition",
        "parameters": "parameters",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "tags": "tags",
        "theme_arn": "themeArn",
        "version_description": "versionDescription",
    },
)
class CfnDashboardProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        dashboard_id: builtins.str,
        name: builtins.str,
        dashboard_publish_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        definition: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        parameters: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        source_entity: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        theme_arn: typing.Optional[builtins.str] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnDashboard``.

        :param aws_account_id: The ID of the AWS account where you want to create the dashboard.
        :param dashboard_id: The ID for the dashboard, also added to the IAM policy.
        :param name: The display name of the dashboard.
        :param dashboard_publish_options: Options for publishing the dashboard when you create it:. - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default. - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default. - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.
        :param definition: ``AWS::QuickSight::Dashboard.Definition``.
        :param parameters: The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
        :param permissions: A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN. To specify no permissions, omit the permissions list.
        :param source_entity: The entity that you are using as a source when you create the dashboard. In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
        :param theme_arn: The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
        :param version_description: A description for the first version of the dashboard being created.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            # data_driven: Any
            
            cfn_dashboard_props = quicksight.CfnDashboardProps(
                aws_account_id="awsAccountId",
                dashboard_id="dashboardId",
                name="name",
            
                # the properties below are optional
                dashboard_publish_options=quicksight.CfnDashboard.DashboardPublishOptionsProperty(
                    ad_hoc_filtering_option=quicksight.CfnDashboard.AdHocFilteringOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_drill_up_down_option=quicksight.CfnDashboard.DataPointDrillUpDownOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_menu_label_option=quicksight.CfnDashboard.DataPointMenuLabelOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    data_point_tooltip_option=quicksight.CfnDashboard.DataPointTooltipOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_to_csv_option=quicksight.CfnDashboard.ExportToCSVOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    export_with_hidden_fields_option=quicksight.CfnDashboard.ExportWithHiddenFieldsOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    sheet_controls_option=quicksight.CfnDashboard.SheetControlsOptionProperty(
                        visibility_state="visibilityState"
                    ),
                    sheet_layout_element_maximization_option=quicksight.CfnDashboard.SheetLayoutElementMaximizationOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_axis_sort_option=quicksight.CfnDashboard.VisualAxisSortOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_menu_option=quicksight.CfnDashboard.VisualMenuOptionProperty(
                        availability_status="availabilityStatus"
                    ),
                    visual_publish_options=quicksight.CfnDashboard.DashboardVisualPublishOptionsProperty(
                        export_hidden_fields_option=quicksight.CfnDashboard.ExportHiddenFieldsOptionProperty(
                            availability_status="availabilityStatus"
                        )
                    )
                ),
                definition=quicksight.CfnDashboard.DashboardVersionDefinitionProperty(
                    data_set_identifier_declarations=[quicksight.CfnDashboard.DataSetIdentifierDeclarationProperty(
                        data_set_arn="dataSetArn",
                        identifier="identifier"
                    )],
            
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnDashboard.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnDashboard.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnDashboard.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnDashboard.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnDashboard.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnDashboard.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnDashboard.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnDashboard.ColumnConfigurationProperty(
                        column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
            
                        # the properties below are optional
                        colors_configuration=quicksight.CfnDashboard.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnDashboard.CustomColorProperty(
                                color="color",
            
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnDashboard.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnDashboard.FilterProperty(
                            category_filter=quicksight.CfnDashboard.CategoryFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnDashboard.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnDashboard.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnDashboard.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnDashboard.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnDashboard.NumericRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnDashboard.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnDashboard.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnDashboard.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnDashboard.TimeEqualityFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnDashboard.TimeRangeFilterProperty(
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnDashboard.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnDashboard.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnDashboard.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnDashboard.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnDashboard.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnDashboard.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
            
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
            
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnDashboard.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnDashboard.DateTimeParameterDeclarationProperty(
                            name="name",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnDashboard.RollingDateConfigurationProperty(
                                    expression="expression",
            
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnDashboard.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnDashboard.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnDashboard.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnDashboard.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnDashboard.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnDashboard.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnDashboard.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnDashboard.SheetDefinitionProperty(
                        sheet_id="sheetId",
            
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnDashboard.FilterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnDashboard.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnDashboard.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnDashboard.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnDashboard.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnDashboard.LayoutProperty(
                            configuration=quicksight.CfnDashboard.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnDashboard.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
            
                                        # the properties below are optional
                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnDashboard.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnDashboard.BodySectionConfigurationProperty(
                                        content=quicksight.CfnDashboard.BodySectionContentProperty(
                                            layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
            
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnDashboard.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnDashboard.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnDashboard.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnDashboard.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnDashboard.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnDashboard.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnDashboard.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnDashboard.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnDashboard.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnDashboard.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnDashboard.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnDashboard.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnDashboard.ParameterControlProperty(
                            date_time_picker=quicksight.CfnDashboard.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnDashboard.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnDashboard.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnDashboard.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnDashboard.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnDashboard.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnDashboard.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnDashboard.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnDashboard.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnDashboard.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnDashboard.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnDashboard.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnDashboard.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnDashboard.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnDashboard.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnDashboard.SheetControlLayoutProperty(
                            configuration=quicksight.CfnDashboard.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnDashboard.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnDashboard.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnDashboard.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnDashboard.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
            
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnDashboard.VisualProperty(
                            bar_chart_visual=quicksight.CfnDashboard.BarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnDashboard.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnDashboard.BoxPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnDashboard.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnDashboard.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnDashboard.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnDashboard.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnDashboard.ComboChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnDashboard.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnDashboard.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnDashboard.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnDashboard.FilledMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnDashboard.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnDashboard.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            format=quicksight.CfnDashboard.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnDashboard.FunnelChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnDashboard.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnDashboard.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnDashboard.GaugeChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnDashboard.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnDashboard.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnDashboard.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnDashboard.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnDashboard.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnDashboard.GeospatialMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnDashboard.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnDashboard.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnDashboard.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnDashboard.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnDashboard.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnDashboard.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnDashboard.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnDashboard.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnDashboard.HeatMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnDashboard.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnDashboard.HistogramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnDashboard.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnDashboard.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnDashboard.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnDashboard.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnDashboard.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnDashboard.InsightConfigurationProperty(
                                    computations=[quicksight.CfnDashboard.ComputationProperty(
                                        forecast=quicksight.CfnDashboard.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnDashboard.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnDashboard.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnDashboard.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnDashboard.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnDashboard.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnDashboard.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnDashboard.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnDashboard.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnDashboard.UniqueValuesComputationProperty(
                                            category=quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
            
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnDashboard.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnDashboard.KPIVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnDashboard.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnDashboard.KPIOptionsProperty(
                                        comparison=quicksight.CfnDashboard.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnDashboard.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnDashboard.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnDashboard.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnDashboard.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnDashboard.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnDashboard.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnDashboard.LineChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnDashboard.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnDashboard.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnDashboard.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnDashboard.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnDashboard.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnDashboard.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnDashboard.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnDashboard.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnDashboard.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnDashboard.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnDashboard.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnDashboard.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnDashboard.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnDashboard.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnDashboard.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnDashboard.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                        linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnDashboard.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnDashboard.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnDashboard.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnDashboard.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            settings=quicksight.CfnDashboard.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnDashboard.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnDashboard.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnDashboard.PieChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnDashboard.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnDashboard.DonutOptionsProperty(
                                        arc_options=quicksight.CfnDashboard.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnDashboard.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnDashboard.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnDashboard.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnDashboard.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnDashboard.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnDashboard.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnDashboard.PivotTableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnDashboard.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
            
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnDashboard.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnDashboard.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnDashboard.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnDashboard.PivotTableSortByProperty(
                                                column=quicksight.CfnDashboard.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnDashboard.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnDashboard.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnDashboard.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnDashboard.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnDashboard.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnDashboard.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnDashboard.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnDashboard.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            scope=quicksight.CfnDashboard.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnDashboard.RadarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnDashboard.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnDashboard.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnDashboard.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnDashboard.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnDashboard.SankeyDiagramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnDashboard.ScatterPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnDashboard.TableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TableConfigurationProperty(
                                    field_options=quicksight.CfnDashboard.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnDashboard.TableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnDashboard.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnDashboard.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnDashboard.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnDashboard.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnDashboard.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnDashboard.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnDashboard.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
            
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnDashboard.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnDashboard.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnDashboard.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnDashboard.UnaggregatedFieldProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnDashboard.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnDashboard.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnDashboard.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnDashboard.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnDashboard.DataBarsOptionsProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnDashboard.TableOptionsProperty(
                                        cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnDashboard.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnDashboard.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnDashboard.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnDashboard.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnDashboard.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnDashboard.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnDashboard.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnDashboard.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnDashboard.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            text_format=quicksight.CfnDashboard.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnDashboard.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnDashboard.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnDashboard.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnDashboard.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnDashboard.GradientColorProperty(
                                                            stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnDashboard.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnDashboard.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnDashboard.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnDashboard.GradientColorProperty(
                                                        stops=[quicksight.CfnDashboard.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnDashboard.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnDashboard.TreeMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnDashboard.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnDashboard.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnDashboard.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnDashboard.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnDashboard.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnDashboard.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnDashboard.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnDashboard.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnDashboard.WaterfallVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnDashboard.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnDashboard.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnDashboard.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnDashboard.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnDashboard.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnDashboard.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnDashboard.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnDashboard.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnDashboard.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnDashboard.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnDashboard.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnDashboard.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnDashboard.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnDashboard.NumericAxisOptionsProperty(
                                                range=quicksight.CfnDashboard.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnDashboard.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnDashboard.AxisScaleProperty(
                                                    linear=quicksight.CfnDashboard.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnDashboard.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnDashboard.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnDashboard.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnDashboard.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnDashboard.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnDashboard.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnDashboard.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnDashboard.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnDashboard.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnDashboard.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnDashboard.WordCloudVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnDashboard.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnDashboard.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnDashboard.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnDashboard.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnDashboard.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnDashboard.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnDashboard.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnDashboard.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnDashboard.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnDashboard.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnDashboard.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnDashboard.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnDashboard.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnDashboard.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnDashboard.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnDashboard.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnDashboard.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnDashboard.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnDashboard.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnDashboard.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnDashboard.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnDashboard.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnDashboard.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnDashboard.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnDashboard.DateDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnDashboard.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnDashboard.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnDashboard.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnDashboard.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnDashboard.DateMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnDashboard.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnDashboard.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnDashboard.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnDashboard.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnDashboard.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnDashboard.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnDashboard.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnDashboard.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnDashboard.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnDashboard.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnDashboard.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnDashboard.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnDashboard.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnDashboard.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnDashboard.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnDashboard.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnDashboard.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnDashboard.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnDashboard.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnDashboard.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnDashboard.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnDashboard.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnDashboard.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnDashboard.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnDashboard.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnDashboard.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnDashboard.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnDashboard.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnDashboard.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnDashboard.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnDashboard.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnDashboard.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnDashboard.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnDashboard.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                ),
                parameters=quicksight.CfnDashboard.ParametersProperty(
                    date_time_parameters=[quicksight.CfnDashboard.DateTimeParameterProperty(
                        name="name",
                        values=["values"]
                    )],
                    decimal_parameters=[quicksight.CfnDashboard.DecimalParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    integer_parameters=[quicksight.CfnDashboard.IntegerParameterProperty(
                        name="name",
                        values=[123]
                    )],
                    string_parameters=[quicksight.CfnDashboard.StringParameterProperty(
                        name="name",
                        values=["values"]
                    )]
                ),
                permissions=[quicksight.CfnDashboard.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                source_entity=quicksight.CfnDashboard.DashboardSourceEntityProperty(
                    source_template=quicksight.CfnDashboard.DashboardSourceTemplateProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnDashboard.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    )
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                theme_arn="themeArn",
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b1c5f47033d3be30ea201ea35806c795f22fd1f45141bd91eca2b64943ccb53c)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument dashboard_id", value=dashboard_id, expected_type=type_hints["dashboard_id"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument dashboard_publish_options", value=dashboard_publish_options, expected_type=type_hints["dashboard_publish_options"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "dashboard_id": dashboard_id,
            "name": name,
        }
        if dashboard_publish_options is not None:
            self._values["dashboard_publish_options"] = dashboard_publish_options
        if definition is not None:
            self._values["definition"] = definition
        if parameters is not None:
            self._values["parameters"] = parameters
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if tags is not None:
            self._values["tags"] = tags
        if theme_arn is not None:
            self._values["theme_arn"] = theme_arn
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashboard_id(self) -> builtins.str:
        '''The ID for the dashboard, also added to the IAM policy.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
        '''
        result = self._values.get("dashboard_id")
        assert result is not None, "Required property 'dashboard_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The display name of the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def dashboard_publish_options(
        self,
    ) -> typing.Optional[typing.Union[CfnDashboard.DashboardPublishOptionsProperty, _IResolvable_a771d0ef]]:
        '''Options for publishing the dashboard when you create it:.

        - ``AvailabilityStatus`` for ``AdHocFilteringOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . When this is set to ``DISABLED`` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is ``ENABLED`` by default.
        - ``AvailabilityStatus`` for ``ExportToCSVOption`` - This status can be either ``ENABLED`` or ``DISABLED`` . The visual option to export data to .CSV format isn't enabled when this is set to ``DISABLED`` . This option is ``ENABLED`` by default.
        - ``VisibilityState`` for ``SheetControlsOption`` - This visibility state can be either ``COLLAPSED`` or ``EXPANDED`` . This option is ``COLLAPSED`` by default.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
        '''
        result = self._values.get("dashboard_publish_options")
        return typing.cast(typing.Optional[typing.Union[CfnDashboard.DashboardPublishOptionsProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, _IResolvable_a771d0ef]]:
        '''``AWS::QuickSight::Dashboard.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[typing.Union[CfnDashboard.ParametersProperty, _IResolvable_a771d0ef]]:
        '''The parameters for the creation of the dashboard, which you want to use to override the default settings.

        A dashboard can have any type of parameters, and some parameters might accept multiple values.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
        '''
        result = self._values.get("parameters")
        return typing.cast(typing.Optional[typing.Union[CfnDashboard.ParametersProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDashboard.ResourcePermissionProperty, _IResolvable_a771d0ef]]]]:
        '''A structure that contains the permissions of the dashboard.

        You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.

        To specify no permissions, omit the permissions list.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDashboard.ResourcePermissionProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[CfnDashboard.DashboardSourceEntityProperty, _IResolvable_a771d0ef]]:
        '''The entity that you are using as a source when you create the dashboard.

        In ``SourceEntity`` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a ``SourceTemplate`` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the ``CreateTemplate`` API operation. For ``SourceTemplate`` , specify the Amazon Resource Name (ARN) of the source template. The ``SourceTemplate`` ARN can contain any AWS account; and any QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[CfnDashboard.DashboardSourceEntityProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    @builtins.property
    def theme_arn(self) -> typing.Optional[builtins.str]:
        '''The Amazon Resource Name (ARN) of the theme that is being used for this dashboard.

        If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
        '''
        result = self._values.get("theme_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description for the first version of the dashboard being created.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDashboardProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnDataSet(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnDataSet",
):
    '''A CloudFormation ``AWS::QuickSight::DataSet``.

    Creates a dataset. This operation doesn't support datasets that include uploaded files as a source.

    :cloudformationResource: AWS::QuickSight::DataSet
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        cfn_data_set = quicksight.CfnDataSet(self, "MyCfnDataSet",
            aws_account_id="awsAccountId",
            column_groups=[quicksight.CfnDataSet.ColumnGroupProperty(
                geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                    columns=["columns"],
                    name="name",
        
                    # the properties below are optional
                    country_code="countryCode"
                )
            )],
            column_level_permission_rules=[quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                column_names=["columnNames"],
                principals=["principals"]
            )],
            data_set_id="dataSetId",
            data_set_usage_configuration=quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                disable_use_as_direct_query_source=False,
                disable_use_as_imported_source=False
            ),
            field_folders={
                "field_folders_key": quicksight.CfnDataSet.FieldFolderProperty(
                    columns=["columns"],
                    description="description"
                )
            },
            import_mode="importMode",
            ingestion_wait_policy=quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                ingestion_wait_time_in_hours=123,
                wait_for_spice_ingestion=False
            ),
            logical_table_map={
                "logical_table_map_key": quicksight.CfnDataSet.LogicalTableProperty(
                    alias="alias",
                    source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                        data_set_arn="dataSetArn",
                        join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                            left_operand="leftOperand",
                            on_clause="onClause",
                            right_operand="rightOperand",
                            type="type",
        
                            # the properties below are optional
                            left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            ),
                            right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            )
                        ),
                        physical_table_id="physicalTableId"
                    ),
        
                    # the properties below are optional
                    data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                        cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                            column_name="columnName",
                            new_column_type="newColumnType",
        
                            # the properties below are optional
                            format="format"
                        ),
                        create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                            columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                column_id="columnId",
                                column_name="columnName",
                                expression="expression"
                            )]
                        ),
                        filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                            condition_expression="conditionExpression"
                        ),
                        project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                            projected_columns=["projectedColumns"]
                        ),
                        rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                            column_name="columnName",
                            new_column_name="newColumnName"
                        ),
                        tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                            column_name="columnName",
                            tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                    text="text"
                                ),
                                column_geographic_role="columnGeographicRole"
                            )]
                        )
                    )]
                )
            },
            name="name",
            permissions=[quicksight.CfnDataSet.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            physical_table_map={
                "physical_table_map_key": quicksight.CfnDataSet.PhysicalTableProperty(
                    custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                        columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        data_source_arn="dataSourceArn",
                        name="name",
                        sql_query="sqlQuery"
                    ),
                    relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        name="name",
        
                        # the properties below are optional
                        catalog="catalog",
                        schema="schema"
                    ),
                    s3_source=quicksight.CfnDataSet.S3SourceProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
        
                        # the properties below are optional
                        upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                            contains_header=False,
                            delimiter="delimiter",
                            format="format",
                            start_from_row=123,
                            text_qualifier="textQualifier"
                        )
                    )
                )
            },
            row_level_permission_data_set=quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                arn="arn",
                permission_policy="permissionPolicy",
        
                # the properties below are optional
                format_version="formatVersion",
                namespace="namespace"
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )]
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        column_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.ColumnGroupProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.ColumnLevelPermissionRuleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        data_set_usage_configuration: typing.Optional[typing.Union[typing.Union["CfnDataSet.DataSetUsageConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        field_folders: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union["CfnDataSet.FieldFolderProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        import_mode: typing.Optional[builtins.str] = None,
        ingestion_wait_policy: typing.Optional[typing.Union[typing.Union["CfnDataSet.IngestionWaitPolicyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        logical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union["CfnDataSet.LogicalTableProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        physical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union["CfnDataSet.PhysicalTableProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        row_level_permission_data_set: typing.Optional[typing.Union[typing.Union["CfnDataSet.RowLevelPermissionDataSetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::DataSet``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The AWS account ID.
        :param column_groups: Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
        :param column_level_permission_rules: A set of one or more definitions of a ``ColumnLevelPermissionRule`` .
        :param data_set_id: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
        :param data_set_usage_configuration: The usage configuration to apply to child datasets that reference this dataset as a source.
        :param field_folders: The folder that contains fields and nested subfolders for your dataset.
        :param import_mode: Indicates whether you want to import the data into SPICE.
        :param ingestion_wait_policy: The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
        :param logical_table_map: Configures the combination and transformation of the data from the physical tables.
        :param name: The display name for the dataset.
        :param permissions: A list of resource permissions on the dataset.
        :param physical_table_map: Declares the physical tables that are available in the underlying data sources.
        :param row_level_permission_data_set: The row-level security configuration for the data that you want to create.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd11e145935e0211dba109da996b2da1ef7e71f77cc5012e8715f3bd18eb5d3d)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDataSetProps(
            aws_account_id=aws_account_id,
            column_groups=column_groups,
            column_level_permission_rules=column_level_permission_rules,
            data_set_id=data_set_id,
            data_set_usage_configuration=data_set_usage_configuration,
            field_folders=field_folders,
            import_mode=import_mode,
            ingestion_wait_policy=ingestion_wait_policy,
            logical_table_map=logical_table_map,
            name=name,
            permissions=permissions,
            physical_table_map=physical_table_map,
            row_level_permission_data_set=row_level_permission_data_set,
            tags=tags,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f834fea75017aaa47ad47a1ca0050e6997abb857cbebc532644732deb86b683f)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e4bcab09466f01e8f47c5e8afb9b9ccb4f30708f368ae23f5cfa26cc396a634f)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dataset.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrConsumedSpiceCapacityInBytes")
    def attr_consumed_spice_capacity_in_bytes(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: ConsumedSpiceCapacityInBytes
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrConsumedSpiceCapacityInBytes"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this dataset version was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time this dataset version was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrOutputColumns")
    def attr_output_columns(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: OutputColumns
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrOutputColumns"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7bfc59e353345266263342468ce002a92a314e25b41ca904324530cdc35b9251)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="columnGroups")
    def column_groups(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ColumnGroupProperty", _IResolvable_a771d0ef]]]]:
        '''Groupings of columns that work together in certain Amazon QuickSight features.

        Currently, only geospatial hierarchy is supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ColumnGroupProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "columnGroups"))

    @column_groups.setter
    def column_groups(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ColumnGroupProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a92a6ce66bf0e80a19c6892e6fd6b41269a0863dfe5ad5bad1836a737a588ef3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columnGroups", value)

    @builtins.property
    @jsii.member(jsii_name="columnLevelPermissionRules")
    def column_level_permission_rules(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ColumnLevelPermissionRuleProperty", _IResolvable_a771d0ef]]]]:
        '''A set of one or more definitions of a ``ColumnLevelPermissionRule`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ColumnLevelPermissionRuleProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "columnLevelPermissionRules"))

    @column_level_permission_rules.setter
    def column_level_permission_rules(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ColumnLevelPermissionRuleProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49163173a9f78d624847e51d6108ab4e75dbda7c492aef2dc2b5465d4d483325)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "columnLevelPermissionRules", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetId")
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the dataset that you want to create.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSetId"))

    @data_set_id.setter
    def data_set_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a9bcbcbb180cf5ddc389365ec10ac941e017fd17bfca2eb1542307c187b36eec)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetUsageConfiguration")
    def data_set_usage_configuration(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSet.DataSetUsageConfigurationProperty", _IResolvable_a771d0ef]]:
        '''The usage configuration to apply to child datasets that reference this dataset as a source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSet.DataSetUsageConfigurationProperty", _IResolvable_a771d0ef]], jsii.get(self, "dataSetUsageConfiguration"))

    @data_set_usage_configuration.setter
    def data_set_usage_configuration(
        self,
        value: typing.Optional[typing.Union["CfnDataSet.DataSetUsageConfigurationProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c3b4f53517b4449ce367428883aebb1985c966f53d0c273fca981a1aa2b03a9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetUsageConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="fieldFolders")
    def field_folders(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.FieldFolderProperty", _IResolvable_a771d0ef]]]]:
        '''The folder that contains fields and nested subfolders for your dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.FieldFolderProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "fieldFolders"))

    @field_folders.setter
    def field_folders(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.FieldFolderProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__45de91a5495ae4ed8be8aa5a5240c2db72ca295aeba28e2dbd44739b47739e62)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "fieldFolders", value)

    @builtins.property
    @jsii.member(jsii_name="importMode")
    def import_mode(self) -> typing.Optional[builtins.str]:
        '''Indicates whether you want to import the data into SPICE.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "importMode"))

    @import_mode.setter
    def import_mode(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f496b1d8d947319a8220da6be1829eb5e0ba9a59e524381e265ea6f9f414ed65)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "importMode", value)

    @builtins.property
    @jsii.member(jsii_name="ingestionWaitPolicy")
    def ingestion_wait_policy(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSet.IngestionWaitPolicyProperty", _IResolvable_a771d0ef]]:
        '''The wait policy to use when creating or updating a Dataset.

        The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSet.IngestionWaitPolicyProperty", _IResolvable_a771d0ef]], jsii.get(self, "ingestionWaitPolicy"))

    @ingestion_wait_policy.setter
    def ingestion_wait_policy(
        self,
        value: typing.Optional[typing.Union["CfnDataSet.IngestionWaitPolicyProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__49d08894bb1c5bac6a95f7f1f7128f75385f43b6503dae147a24cc8a93d42a00)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "ingestionWaitPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="logicalTableMap")
    def logical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.LogicalTableProperty", _IResolvable_a771d0ef]]]]:
        '''Configures the combination and transformation of the data from the physical tables.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.LogicalTableProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "logicalTableMap"))

    @logical_table_map.setter
    def logical_table_map(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.LogicalTableProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__db02ffa36fe42cfaea221c52e29dade9c36d32de68e6bf35349900076d57795b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "logicalTableMap", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ccbc9e7093c77506258bbfd6ab73fa9cd08c88716b1000921612f11ef765f050)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ResourcePermissionProperty", _IResolvable_a771d0ef]]]]:
        '''A list of resource permissions on the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ResourcePermissionProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.ResourcePermissionProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a5ca93b474b9b3702d7384799311679de696eaef73b4172c3c6bc7ba56bba00e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="physicalTableMap")
    def physical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.PhysicalTableProperty", _IResolvable_a771d0ef]]]]:
        '''Declares the physical tables that are available in the underlying data sources.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.PhysicalTableProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "physicalTableMap"))

    @physical_table_map.setter
    def physical_table_map(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union["CfnDataSet.PhysicalTableProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0b52277d883cfee428b386ea5894d95d0d4a6d282d61a8e83e291a747c5a8f2b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "physicalTableMap", value)

    @builtins.property
    @jsii.member(jsii_name="rowLevelPermissionDataSet")
    def row_level_permission_data_set(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSet.RowLevelPermissionDataSetProperty", _IResolvable_a771d0ef]]:
        '''The row-level security configuration for the data that you want to create.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSet.RowLevelPermissionDataSetProperty", _IResolvable_a771d0ef]], jsii.get(self, "rowLevelPermissionDataSet"))

    @row_level_permission_data_set.setter
    def row_level_permission_data_set(
        self,
        value: typing.Optional[typing.Union["CfnDataSet.RowLevelPermissionDataSetProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ff933d5f2d76d5c5c30bb738e162a7791efe35a8852e59ff70be07204211a340)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "rowLevelPermissionDataSet", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.CalculatedColumnProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_id": "columnId",
            "column_name": "columnName",
            "expression": "expression",
        },
    )
    class CalculatedColumnProperty:
        def __init__(
            self,
            *,
            column_id: builtins.str,
            column_name: builtins.str,
            expression: builtins.str,
        ) -> None:
            '''A calculated column for a dataset.

            :param column_id: A unique ID to identify a calculated column. During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.
            :param column_name: Column name.
            :param expression: An expression that defines the calculated column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_column_property = quicksight.CfnDataSet.CalculatedColumnProperty(
                    column_id="columnId",
                    column_name="columnName",
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__273d9c1517ec57c54104d8e12f3337e6fc766a017a53abf21e9dc9e333d88f1a)
                check_type(argname="argument column_id", value=column_id, expected_type=type_hints["column_id"])
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_id": column_id,
                "column_name": column_name,
                "expression": expression,
            }

        @builtins.property
        def column_id(self) -> builtins.str:
            '''A unique ID to identify a calculated column.

            During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnid
            '''
            result = self._values.get("column_id")
            assert result is not None, "Required property 'column_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def column_name(self) -> builtins.str:
            '''Column name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''An expression that defines the calculated column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.CastColumnTypeOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "new_column_type": "newColumnType",
            "format": "format",
        },
    )
    class CastColumnTypeOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            new_column_type: builtins.str,
            format: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A transform operation that casts a column to a different type.

            :param column_name: Column name.
            :param new_column_type: New column data type.
            :param format: When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cast_column_type_operation_property = quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                    column_name="columnName",
                    new_column_type="newColumnType",
                
                    # the properties below are optional
                    format="format"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0c37aa63040b20ffe67347ac979961687ead12949f409c27407ded70b1c82ab)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument new_column_type", value=new_column_type, expected_type=type_hints["new_column_type"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "new_column_type": new_column_type,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def column_name(self) -> builtins.str:
            '''Column name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_column_type(self) -> builtins.str:
            '''New column data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-newcolumntype
            '''
            result = self._values.get("new_column_type")
            assert result is not None, "Required property 'new_column_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(self) -> typing.Optional[builtins.str]:
            '''When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CastColumnTypeOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.ColumnDescriptionProperty",
        jsii_struct_bases=[],
        name_mapping={"text": "text"},
    )
    class ColumnDescriptionProperty:
        def __init__(self, *, text: typing.Optional[builtins.str] = None) -> None:
            '''Metadata that contains a description for a column.

            :param text: The text of a description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_description_property = quicksight.CfnDataSet.ColumnDescriptionProperty(
                    text="text"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bf78338548d16a11097287f452fa1a933c1407e5e3289b5e3d308c4628afebf4)
                check_type(argname="argument text", value=text, expected_type=type_hints["text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if text is not None:
                self._values["text"] = text

        @builtins.property
        def text(self) -> typing.Optional[builtins.str]:
            '''The text of a description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html#cfn-quicksight-dataset-columndescription-text
            '''
            result = self._values.get("text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnDescriptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.ColumnGroupProperty",
        jsii_struct_bases=[],
        name_mapping={"geo_spatial_column_group": "geoSpatialColumnGroup"},
    )
    class ColumnGroupProperty:
        def __init__(
            self,
            *,
            geo_spatial_column_group: typing.Optional[typing.Union[typing.Union["CfnDataSet.GeoSpatialColumnGroupProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Groupings of columns that work together in certain Amazon QuickSight features.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param geo_spatial_column_group: Geospatial column group that denotes a hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_group_property = quicksight.CfnDataSet.ColumnGroupProperty(
                    geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                        columns=["columns"],
                        name="name",
                
                        # the properties below are optional
                        country_code="countryCode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f44659e7be31e0ef281eb3ffa819f6d714017dbcb82f533c0ab50f2e03c70a5e)
                check_type(argname="argument geo_spatial_column_group", value=geo_spatial_column_group, expected_type=type_hints["geo_spatial_column_group"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geo_spatial_column_group is not None:
                self._values["geo_spatial_column_group"] = geo_spatial_column_group

        @builtins.property
        def geo_spatial_column_group(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.GeoSpatialColumnGroupProperty", _IResolvable_a771d0ef]]:
            '''Geospatial column group that denotes a hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html#cfn-quicksight-dataset-columngroup-geospatialcolumngroup
            '''
            result = self._values.get("geo_spatial_column_group")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.GeoSpatialColumnGroupProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty",
        jsii_struct_bases=[],
        name_mapping={"column_names": "columnNames", "principals": "principals"},
    )
    class ColumnLevelPermissionRuleProperty:
        def __init__(
            self,
            *,
            column_names: typing.Optional[typing.Sequence[builtins.str]] = None,
            principals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A rule defined to grant access on one or more restricted columns.

            Each dataset can have multiple rules. To create a restricted column, you add it to one or more rules. Each rule must contain at least one column and at least one user or group. To be able to see a restricted column, a user or group needs to be added to a rule for that column.

            :param column_names: An array of column names.
            :param principals: An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_level_permission_rule_property = quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                    column_names=["columnNames"],
                    principals=["principals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3894be355eacdc3448c425eec38910d2a554920ab53215cf383bf2cd4b16839)
                check_type(argname="argument column_names", value=column_names, expected_type=type_hints["column_names"])
                check_type(argname="argument principals", value=principals, expected_type=type_hints["principals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_names is not None:
                self._values["column_names"] = column_names
            if principals is not None:
                self._values["principals"] = principals

        @builtins.property
        def column_names(self) -> typing.Optional[typing.List[builtins.str]]:
            '''An array of column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-columnnames
            '''
            result = self._values.get("column_names")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def principals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-principals
            '''
            result = self._values.get("principals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnLevelPermissionRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.ColumnTagProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_description": "columnDescription",
            "column_geographic_role": "columnGeographicRole",
        },
    )
    class ColumnTagProperty:
        def __init__(
            self,
            *,
            column_description: typing.Optional[typing.Union[typing.Union["CfnDataSet.ColumnDescriptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_geographic_role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A tag for a column in a ``[TagColumnOperation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagColumnOperation.html)`` structure. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param column_description: A description for a column.
            :param column_geographic_role: A geospatial role for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_tag_property = quicksight.CfnDataSet.ColumnTagProperty(
                    column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                        text="text"
                    ),
                    column_geographic_role="columnGeographicRole"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bffcbd16fd78bf2462fb30c2a38020c604d66a5bbdfaa3cc7671acae68249bc6)
                check_type(argname="argument column_description", value=column_description, expected_type=type_hints["column_description"])
                check_type(argname="argument column_geographic_role", value=column_geographic_role, expected_type=type_hints["column_geographic_role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_description is not None:
                self._values["column_description"] = column_description
            if column_geographic_role is not None:
                self._values["column_geographic_role"] = column_geographic_role

        @builtins.property
        def column_description(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.ColumnDescriptionProperty", _IResolvable_a771d0ef]]:
            '''A description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columndescription
            '''
            result = self._values.get("column_description")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.ColumnDescriptionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_geographic_role(self) -> typing.Optional[builtins.str]:
            '''A geospatial role for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columngeographicrole
            '''
            result = self._values.get("column_geographic_role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTagProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.CreateColumnsOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns"},
    )
    class CreateColumnsOperationProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.CalculatedColumnProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''A transform operation that creates calculated columns.

            Columns created in one such operation form a lexical closure.

            :param columns: Calculated columns to create.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                create_columns_operation_property = quicksight.CfnDataSet.CreateColumnsOperationProperty(
                    columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                        column_id="columnId",
                        column_name="columnName",
                        expression="expression"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6662289fef1c1e529ada7353abde8c207b58451878bf1047c24d0bbe48989dbd)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
            }

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.CalculatedColumnProperty", _IResolvable_a771d0ef]]]:
            '''Calculated columns to create.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html#cfn-quicksight-dataset-createcolumnsoperation-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.CalculatedColumnProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CreateColumnsOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.CustomSqlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "data_source_arn": "dataSourceArn",
            "name": "name",
            "sql_query": "sqlQuery",
        },
    )
    class CustomSqlProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            data_source_arn: builtins.str,
            name: builtins.str,
            sql_query: builtins.str,
        ) -> None:
            '''A physical table type built from the results of the custom SQL query.

            :param columns: The column schema from the SQL query result set.
            :param data_source_arn: The Amazon Resource Name (ARN) of the data source.
            :param name: A display name for the SQL query result.
            :param sql_query: The SQL query.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_sql_property = quicksight.CfnDataSet.CustomSqlProperty(
                    columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type"
                    )],
                    data_source_arn="dataSourceArn",
                    name="name",
                    sql_query="sqlQuery"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__03337b785de389917354b8e9ffcbd236038adf31364d6aaef63d43021d67e5f6)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sql_query", value=sql_query, expected_type=type_hints["sql_query"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "data_source_arn": data_source_arn,
                "name": name,
                "sql_query": sql_query,
            }

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.InputColumnProperty", _IResolvable_a771d0ef]]]:
            '''The column schema from the SQL query result set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.InputColumnProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the SQL query result.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sql_query(self) -> builtins.str:
            '''The SQL query.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-sqlquery
            '''
            result = self._values.get("sql_query")
            assert result is not None, "Required property 'sql_query' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomSqlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.DataSetUsageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "disable_use_as_direct_query_source": "disableUseAsDirectQuerySource",
            "disable_use_as_imported_source": "disableUseAsImportedSource",
        },
    )
    class DataSetUsageConfigurationProperty:
        def __init__(
            self,
            *,
            disable_use_as_direct_query_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            disable_use_as_imported_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The usage configuration to apply to child datasets that reference this dataset as a source.

            :param disable_use_as_direct_query_source: An option that controls whether a child dataset of a direct query can use this dataset as a source.
            :param disable_use_as_imported_source: An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_usage_configuration_property = quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                    disable_use_as_direct_query_source=False,
                    disable_use_as_imported_source=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9a61679b0b9a90f5a1cadb5cdf5101897357c43f96d2199521083310fb1cf1e1)
                check_type(argname="argument disable_use_as_direct_query_source", value=disable_use_as_direct_query_source, expected_type=type_hints["disable_use_as_direct_query_source"])
                check_type(argname="argument disable_use_as_imported_source", value=disable_use_as_imported_source, expected_type=type_hints["disable_use_as_imported_source"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if disable_use_as_direct_query_source is not None:
                self._values["disable_use_as_direct_query_source"] = disable_use_as_direct_query_source
            if disable_use_as_imported_source is not None:
                self._values["disable_use_as_imported_source"] = disable_use_as_imported_source

        @builtins.property
        def disable_use_as_direct_query_source(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''An option that controls whether a child dataset of a direct query can use this dataset as a source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasdirectquerysource
            '''
            result = self._values.get("disable_use_as_direct_query_source")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def disable_use_as_imported_source(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasimportedsource
            '''
            result = self._values.get("disable_use_as_imported_source")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetUsageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.FieldFolderProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "description": "description"},
    )
    class FieldFolderProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Sequence[builtins.str]] = None,
            description: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A FieldFolder element is a folder that contains fields and nested subfolders.

            :param columns: A folder has a list of columns. A column can only be in one folder.
            :param description: The description for a field folder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_folder_property = quicksight.CfnDataSet.FieldFolderProperty(
                    columns=["columns"],
                    description="description"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e972acba05605e616fda082940f19ffca023db514fc472b1ab6ce9729b30fa5)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if description is not None:
                self._values["description"] = description

        @builtins.property
        def columns(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A folder has a list of columns.

            A column can only be in one folder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description for a field folder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldFolderProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.FilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"condition_expression": "conditionExpression"},
    )
    class FilterOperationProperty:
        def __init__(self, *, condition_expression: builtins.str) -> None:
            '''A transform operation that filters rows based on a condition.

            :param condition_expression: An expression that must evaluate to a Boolean value. Rows for which the expression evaluates to true are kept in the dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_property = quicksight.CfnDataSet.FilterOperationProperty(
                    condition_expression="conditionExpression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43f07171648b89ffa1f88e36967ec2cb710581eb1b210401a3992b4f0a7852a1)
                check_type(argname="argument condition_expression", value=condition_expression, expected_type=type_hints["condition_expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "condition_expression": condition_expression,
            }

        @builtins.property
        def condition_expression(self) -> builtins.str:
            '''An expression that must evaluate to a Boolean value.

            Rows for which the expression evaluates to true are kept in the dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html#cfn-quicksight-dataset-filteroperation-conditionexpression
            '''
            result = self._values.get("condition_expression")
            assert result is not None, "Required property 'condition_expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.GeoSpatialColumnGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "name": "name",
            "country_code": "countryCode",
        },
    )
    class GeoSpatialColumnGroupProperty:
        def __init__(
            self,
            *,
            columns: typing.Sequence[builtins.str],
            name: builtins.str,
            country_code: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Geospatial column group that denotes a hierarchy.

            :param columns: Columns in this hierarchy.
            :param name: A display name for the hierarchy.
            :param country_code: Country code.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geo_spatial_column_group_property = quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                    columns=["columns"],
                    name="name",
                
                    # the properties below are optional
                    country_code="countryCode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5c8c2d28e8087e6d90159f21e796dcb3a4483be61c93189e2dec80c5f3b6098)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument country_code", value=country_code, expected_type=type_hints["country_code"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "name": name,
            }
            if country_code is not None:
                self._values["country_code"] = country_code

        @builtins.property
        def columns(self) -> typing.List[builtins.str]:
            '''Columns in this hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def name(self) -> builtins.str:
            '''A display name for the hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def country_code(self) -> typing.Optional[builtins.str]:
            '''Country code.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-countrycode
            '''
            result = self._values.get("country_code")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeoSpatialColumnGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.IngestionWaitPolicyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "ingestion_wait_time_in_hours": "ingestionWaitTimeInHours",
            "wait_for_spice_ingestion": "waitForSpiceIngestion",
        },
    )
    class IngestionWaitPolicyProperty:
        def __init__(
            self,
            *,
            ingestion_wait_time_in_hours: typing.Optional[jsii.Number] = None,
            wait_for_spice_ingestion: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The wait policy to use when creating or updating a Dataset.

            The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

            :param ingestion_wait_time_in_hours: The maximum time (in hours) to wait for Ingestion to complete. Default timeout is 36 hours. Applicable only when ``DataSetImportMode`` mode is set to SPICE and ``WaitForSpiceIngestion`` is set to true.
            :param wait_for_spice_ingestion: Wait for SPICE ingestion to finish to mark dataset creation or update as successful. Default (true). Applicable only when ``DataSetImportMode`` mode is set to SPICE.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                ingestion_wait_policy_property = quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                    ingestion_wait_time_in_hours=123,
                    wait_for_spice_ingestion=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4602efa8eaf5b2a029c3b3760ed4afeaa5fe5238fecea6e8092cb21f136f20ef)
                check_type(argname="argument ingestion_wait_time_in_hours", value=ingestion_wait_time_in_hours, expected_type=type_hints["ingestion_wait_time_in_hours"])
                check_type(argname="argument wait_for_spice_ingestion", value=wait_for_spice_ingestion, expected_type=type_hints["wait_for_spice_ingestion"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if ingestion_wait_time_in_hours is not None:
                self._values["ingestion_wait_time_in_hours"] = ingestion_wait_time_in_hours
            if wait_for_spice_ingestion is not None:
                self._values["wait_for_spice_ingestion"] = wait_for_spice_ingestion

        @builtins.property
        def ingestion_wait_time_in_hours(self) -> typing.Optional[jsii.Number]:
            '''The maximum time (in hours) to wait for Ingestion to complete.

            Default timeout is 36 hours. Applicable only when ``DataSetImportMode`` mode is set to SPICE and ``WaitForSpiceIngestion`` is set to true.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-ingestionwaittimeinhours
            '''
            result = self._values.get("ingestion_wait_time_in_hours")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def wait_for_spice_ingestion(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Wait for SPICE ingestion to finish to mark dataset creation or update as successful.

            Default (true). Applicable only when ``DataSetImportMode`` mode is set to SPICE.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-waitforspiceingestion
            '''
            result = self._values.get("wait_for_spice_ingestion")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IngestionWaitPolicyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.InputColumnProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "type": "type"},
    )
    class InputColumnProperty:
        def __init__(self, *, name: builtins.str, type: builtins.str) -> None:
            '''Metadata for a column that is used as the input of a transform operation.

            :param name: The name of this column in the underlying data source.
            :param type: The data type of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                input_column_property = quicksight.CfnDataSet.InputColumnProperty(
                    name="name",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0598042b5c66c6b948f015dc719bca7669607d6cfea8745643d2ca91465970f7)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "type": type,
            }

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of this column in the underlying data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The data type of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InputColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.JoinInstructionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "left_operand": "leftOperand",
            "on_clause": "onClause",
            "right_operand": "rightOperand",
            "type": "type",
            "left_join_key_properties": "leftJoinKeyProperties",
            "right_join_key_properties": "rightJoinKeyProperties",
        },
    )
    class JoinInstructionProperty:
        def __init__(
            self,
            *,
            left_operand: builtins.str,
            on_clause: builtins.str,
            right_operand: builtins.str,
            type: builtins.str,
            left_join_key_properties: typing.Optional[typing.Union[typing.Union["CfnDataSet.JoinKeyPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            right_join_key_properties: typing.Optional[typing.Union[typing.Union["CfnDataSet.JoinKeyPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The instructions associated with a join.

            :param left_operand: The operand on the left side of a join.
            :param on_clause: The join instructions provided in the ``ON`` clause of a join.
            :param right_operand: The operand on the right side of a join.
            :param type: The type of join that it is.
            :param left_join_key_properties: Join key properties of the left operand.
            :param right_join_key_properties: Join key properties of the right operand.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                join_instruction_property = quicksight.CfnDataSet.JoinInstructionProperty(
                    left_operand="leftOperand",
                    on_clause="onClause",
                    right_operand="rightOperand",
                    type="type",
                
                    # the properties below are optional
                    left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                        unique_key=False
                    ),
                    right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                        unique_key=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1fe516329c08faf5f63956a5acdb1cd9e20cf21cb63275c725f51b0d4a702293)
                check_type(argname="argument left_operand", value=left_operand, expected_type=type_hints["left_operand"])
                check_type(argname="argument on_clause", value=on_clause, expected_type=type_hints["on_clause"])
                check_type(argname="argument right_operand", value=right_operand, expected_type=type_hints["right_operand"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument left_join_key_properties", value=left_join_key_properties, expected_type=type_hints["left_join_key_properties"])
                check_type(argname="argument right_join_key_properties", value=right_join_key_properties, expected_type=type_hints["right_join_key_properties"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "left_operand": left_operand,
                "on_clause": on_clause,
                "right_operand": right_operand,
                "type": type,
            }
            if left_join_key_properties is not None:
                self._values["left_join_key_properties"] = left_join_key_properties
            if right_join_key_properties is not None:
                self._values["right_join_key_properties"] = right_join_key_properties

        @builtins.property
        def left_operand(self) -> builtins.str:
            '''The operand on the left side of a join.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftoperand
            '''
            result = self._values.get("left_operand")
            assert result is not None, "Required property 'left_operand' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def on_clause(self) -> builtins.str:
            '''The join instructions provided in the ``ON`` clause of a join.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-onclause
            '''
            result = self._values.get("on_clause")
            assert result is not None, "Required property 'on_clause' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def right_operand(self) -> builtins.str:
            '''The operand on the right side of a join.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightoperand
            '''
            result = self._values.get("right_operand")
            assert result is not None, "Required property 'right_operand' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of join that it is.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def left_join_key_properties(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.JoinKeyPropertiesProperty", _IResolvable_a771d0ef]]:
            '''Join key properties of the left operand.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftjoinkeyproperties
            '''
            result = self._values.get("left_join_key_properties")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.JoinKeyPropertiesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def right_join_key_properties(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.JoinKeyPropertiesProperty", _IResolvable_a771d0ef]]:
            '''Join key properties of the right operand.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightjoinkeyproperties
            '''
            result = self._values.get("right_join_key_properties")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.JoinKeyPropertiesProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "JoinInstructionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.JoinKeyPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"unique_key": "uniqueKey"},
    )
    class JoinKeyPropertiesProperty:
        def __init__(
            self,
            *,
            unique_key: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Properties associated with the columns participating in a join.

            :param unique_key: A value that indicates that a row in a table is uniquely identified by the columns in a join key. This is used by Amazon QuickSight to optimize query performance.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                join_key_properties_property = quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                    unique_key=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2156edf8f3ae29c2acab57117244c4387798c5b6b998c9f0fd4ee218ddeb94b)
                check_type(argname="argument unique_key", value=unique_key, expected_type=type_hints["unique_key"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if unique_key is not None:
                self._values["unique_key"] = unique_key

        @builtins.property
        def unique_key(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''A value that indicates that a row in a table is uniquely identified by the columns in a join key.

            This is used by Amazon QuickSight to optimize query performance.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html#cfn-quicksight-dataset-joinkeyproperties-uniquekey
            '''
            result = self._values.get("unique_key")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "JoinKeyPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.LogicalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alias": "alias",
            "source": "source",
            "data_transforms": "dataTransforms",
        },
    )
    class LogicalTableProperty:
        def __init__(
            self,
            *,
            alias: builtins.str,
            source: typing.Union[typing.Union["CfnDataSet.LogicalTableSourceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            data_transforms: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.TransformOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''A *logical table* is a unit that joins and that data transformations operate on.

            A logical table has a source, which can be either a physical table or result of a join. When a logical table points to a physical table, the logical table acts as a mutable copy of that physical table through transform operations.

            :param alias: A display name for the logical table.
            :param source: Source of this logical table.
            :param data_transforms: Transform operations that act on this logical table. For this structure to be valid, only one of the attributes can be non-null.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                logical_table_property = quicksight.CfnDataSet.LogicalTableProperty(
                    alias="alias",
                    source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                        data_set_arn="dataSetArn",
                        join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                            left_operand="leftOperand",
                            on_clause="onClause",
                            right_operand="rightOperand",
                            type="type",
                
                            # the properties below are optional
                            left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            ),
                            right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                unique_key=False
                            )
                        ),
                        physical_table_id="physicalTableId"
                    ),
                
                    # the properties below are optional
                    data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                        cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                            column_name="columnName",
                            new_column_type="newColumnType",
                
                            # the properties below are optional
                            format="format"
                        ),
                        create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                            columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                column_id="columnId",
                                column_name="columnName",
                                expression="expression"
                            )]
                        ),
                        filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                            condition_expression="conditionExpression"
                        ),
                        project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                            projected_columns=["projectedColumns"]
                        ),
                        rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                            column_name="columnName",
                            new_column_name="newColumnName"
                        ),
                        tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                            column_name="columnName",
                            tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                    text="text"
                                ),
                                column_geographic_role="columnGeographicRole"
                            )]
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94306fc7c9d318604ae92c12e40802746bbf86d136b1fa13b6ea56c2245635c4)
                check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument data_transforms", value=data_transforms, expected_type=type_hints["data_transforms"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "alias": alias,
                "source": source,
            }
            if data_transforms is not None:
                self._values["data_transforms"] = data_transforms

        @builtins.property
        def alias(self) -> builtins.str:
            '''A display name for the logical table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-alias
            '''
            result = self._values.get("alias")
            assert result is not None, "Required property 'alias' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source(
            self,
        ) -> typing.Union["CfnDataSet.LogicalTableSourceProperty", _IResolvable_a771d0ef]:
            '''Source of this logical table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-source
            '''
            result = self._values.get("source")
            assert result is not None, "Required property 'source' is missing"
            return typing.cast(typing.Union["CfnDataSet.LogicalTableSourceProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def data_transforms(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.TransformOperationProperty", _IResolvable_a771d0ef]]]]:
            '''Transform operations that act on this logical table.

            For this structure to be valid, only one of the attributes can be non-null.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-datatransforms
            '''
            result = self._values.get("data_transforms")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.TransformOperationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LogicalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.LogicalTableSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "join_instruction": "joinInstruction",
            "physical_table_id": "physicalTableId",
        },
    )
    class LogicalTableSourceProperty:
        def __init__(
            self,
            *,
            data_set_arn: typing.Optional[builtins.str] = None,
            join_instruction: typing.Optional[typing.Union[typing.Union["CfnDataSet.JoinInstructionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            physical_table_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about the source of a logical table.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param data_set_arn: The Amazon Resource Number (ARN) of the parent dataset.
            :param join_instruction: Specifies the result of a join of two logical tables.
            :param physical_table_id: Physical table ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                logical_table_source_property = quicksight.CfnDataSet.LogicalTableSourceProperty(
                    data_set_arn="dataSetArn",
                    join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                        left_operand="leftOperand",
                        on_clause="onClause",
                        right_operand="rightOperand",
                        type="type",
                
                        # the properties below are optional
                        left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                            unique_key=False
                        ),
                        right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                            unique_key=False
                        )
                    ),
                    physical_table_id="physicalTableId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8b25a41e07acf10c2de1e0afbfa76e2a8a16b7094e4851ecb64e7fc8fc8e5e2d)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument join_instruction", value=join_instruction, expected_type=type_hints["join_instruction"])
                check_type(argname="argument physical_table_id", value=physical_table_id, expected_type=type_hints["physical_table_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_set_arn is not None:
                self._values["data_set_arn"] = data_set_arn
            if join_instruction is not None:
                self._values["join_instruction"] = join_instruction
            if physical_table_id is not None:
                self._values["physical_table_id"] = physical_table_id

        @builtins.property
        def data_set_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Number (ARN) of the parent dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-datasetarn
            '''
            result = self._values.get("data_set_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def join_instruction(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.JoinInstructionProperty", _IResolvable_a771d0ef]]:
            '''Specifies the result of a join of two logical tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-joininstruction
            '''
            result = self._values.get("join_instruction")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.JoinInstructionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def physical_table_id(self) -> typing.Optional[builtins.str]:
            '''Physical table ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-physicaltableid
            '''
            result = self._values.get("physical_table_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LogicalTableSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.OutputColumnProperty",
        jsii_struct_bases=[],
        name_mapping={"description": "description", "name": "name", "type": "type"},
    )
    class OutputColumnProperty:
        def __init__(
            self,
            *,
            description: typing.Optional[builtins.str] = None,
            name: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Output column.

            :param description: A description for a column.
            :param name: A display name for the dataset.
            :param type: The type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                output_column_property = quicksight.CfnDataSet.OutputColumnProperty(
                    description="description",
                    name="name",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd32814175c01598390d3b875a9d6b05215f17b4a4666f60a3ccadfc5f6ce5ee)
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if description is not None:
                self._values["description"] = description
            if name is not None:
                self._values["name"] = name
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description for a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''A display name for the dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OutputColumnProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.PhysicalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_sql": "customSql",
            "relational_table": "relationalTable",
            "s3_source": "s3Source",
        },
    )
    class PhysicalTableProperty:
        def __init__(
            self,
            *,
            custom_sql: typing.Optional[typing.Union[typing.Union["CfnDataSet.CustomSqlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relational_table: typing.Optional[typing.Union[typing.Union["CfnDataSet.RelationalTableProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            s3_source: typing.Optional[typing.Union[typing.Union["CfnDataSet.S3SourceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A view of a data source that contains information about the shape of the data in the underlying source.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param custom_sql: A physical table type built from the results of the custom SQL query.
            :param relational_table: A physical table type for relational data sources.
            :param s3_source: A physical table type for as S3 data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                physical_table_property = quicksight.CfnDataSet.PhysicalTableProperty(
                    custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                        columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        data_source_arn="dataSourceArn",
                        name="name",
                        sql_query="sqlQuery"
                    ),
                    relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                        name="name",
                
                        # the properties below are optional
                        catalog="catalog",
                        schema="schema"
                    ),
                    s3_source=quicksight.CfnDataSet.S3SourceProperty(
                        data_source_arn="dataSourceArn",
                        input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                            name="name",
                            type="type"
                        )],
                
                        # the properties below are optional
                        upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                            contains_header=False,
                            delimiter="delimiter",
                            format="format",
                            start_from_row=123,
                            text_qualifier="textQualifier"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a16da72220d436aa413517ea6d04e9c3d388f5212e733ba67b64d15ff5774e3)
                check_type(argname="argument custom_sql", value=custom_sql, expected_type=type_hints["custom_sql"])
                check_type(argname="argument relational_table", value=relational_table, expected_type=type_hints["relational_table"])
                check_type(argname="argument s3_source", value=s3_source, expected_type=type_hints["s3_source"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_sql is not None:
                self._values["custom_sql"] = custom_sql
            if relational_table is not None:
                self._values["relational_table"] = relational_table
            if s3_source is not None:
                self._values["s3_source"] = s3_source

        @builtins.property
        def custom_sql(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.CustomSqlProperty", _IResolvable_a771d0ef]]:
            '''A physical table type built from the results of the custom SQL query.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-customsql
            '''
            result = self._values.get("custom_sql")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.CustomSqlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relational_table(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.RelationalTableProperty", _IResolvable_a771d0ef]]:
            '''A physical table type for relational data sources.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-relationaltable
            '''
            result = self._values.get("relational_table")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.RelationalTableProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def s3_source(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.S3SourceProperty", _IResolvable_a771d0ef]]:
            '''A physical table type for as S3 data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-s3source
            '''
            result = self._values.get("s3_source")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.S3SourceProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PhysicalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.ProjectOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"projected_columns": "projectedColumns"},
    )
    class ProjectOperationProperty:
        def __init__(self, *, projected_columns: typing.Sequence[builtins.str]) -> None:
            '''A transform operation that projects columns.

            Operations that come after a projection can only refer to projected columns.

            :param projected_columns: Projected columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                project_operation_property = quicksight.CfnDataSet.ProjectOperationProperty(
                    projected_columns=["projectedColumns"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ee639269184eca513d6b65b98ccaecb34a42d3b8daf0be4e76d81dcf3e881bec)
                check_type(argname="argument projected_columns", value=projected_columns, expected_type=type_hints["projected_columns"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "projected_columns": projected_columns,
            }

        @builtins.property
        def projected_columns(self) -> typing.List[builtins.str]:
            '''Projected columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html#cfn-quicksight-dataset-projectoperation-projectedcolumns
            '''
            result = self._values.get("projected_columns")
            assert result is not None, "Required property 'projected_columns' is missing"
            return typing.cast(typing.List[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProjectOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.RelationalTableProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_source_arn": "dataSourceArn",
            "input_columns": "inputColumns",
            "name": "name",
            "catalog": "catalog",
            "schema": "schema",
        },
    )
    class RelationalTableProperty:
        def __init__(
            self,
            *,
            data_source_arn: builtins.str,
            input_columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            name: builtins.str,
            catalog: typing.Optional[builtins.str] = None,
            schema: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A physical table type for relational data sources.

            :param data_source_arn: The Amazon Resource Name (ARN) for the data source.
            :param input_columns: The column schema of the table.
            :param name: The name of the relational table.
            :param catalog: ``CfnDataSet.RelationalTableProperty.Catalog``.
            :param schema: The schema name. This name applies to certain relational database engines.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relational_table_property = quicksight.CfnDataSet.RelationalTableProperty(
                    data_source_arn="dataSourceArn",
                    input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type"
                    )],
                    name="name",
                
                    # the properties below are optional
                    catalog="catalog",
                    schema="schema"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0179718a192849bb93683be25c659d6642cb937317d8078a21adbdb61477d00d)
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument input_columns", value=input_columns, expected_type=type_hints["input_columns"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument schema", value=schema, expected_type=type_hints["schema"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_source_arn": data_source_arn,
                "input_columns": input_columns,
                "name": name,
            }
            if catalog is not None:
                self._values["catalog"] = catalog
            if schema is not None:
                self._values["schema"] = schema

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def input_columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.InputColumnProperty", _IResolvable_a771d0ef]]]:
            '''The column schema of the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-inputcolumns
            '''
            result = self._values.get("input_columns")
            assert result is not None, "Required property 'input_columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.InputColumnProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the relational table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def catalog(self) -> typing.Optional[builtins.str]:
            '''``CfnDataSet.RelationalTableProperty.Catalog``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-catalog
            '''
            result = self._values.get("catalog")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def schema(self) -> typing.Optional[builtins.str]:
            '''The schema name.

            This name applies to certain relational database engines.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-schema
            '''
            result = self._values.get("schema")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelationalTableProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.RenameColumnOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"column_name": "columnName", "new_column_name": "newColumnName"},
    )
    class RenameColumnOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            new_column_name: builtins.str,
        ) -> None:
            '''A transform operation that renames a column.

            :param column_name: The name of the column to be renamed.
            :param new_column_name: The new name for the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                rename_column_operation_property = quicksight.CfnDataSet.RenameColumnOperationProperty(
                    column_name="columnName",
                    new_column_name="newColumnName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__698ec42086cd55af0f1b6e1bc26312487d56a137e000617859ed49422d3c3957)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument new_column_name", value=new_column_name, expected_type=type_hints["new_column_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "new_column_name": new_column_name,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column to be renamed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def new_column_name(self) -> builtins.str:
            '''The new name for the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-newcolumnname
            '''
            result = self._values.get("new_column_name")
            assert result is not None, "Required property 'new_column_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RenameColumnOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permisions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDataSet.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b924a98dee9d4b67e66def0da89ea10a6d932fd65a6209e5b2019948917d039a)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permisions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.RowLevelPermissionDataSetProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "permission_policy": "permissionPolicy",
            "format_version": "formatVersion",
            "namespace": "namespace",
        },
    )
    class RowLevelPermissionDataSetProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            permission_policy: builtins.str,
            format_version: typing.Optional[builtins.str] = None,
            namespace: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about a dataset that contains permissions for row-level security (RLS).

            The permissions dataset maps fields to users or groups. For more information, see `Using Row-Level Security (RLS) to Restrict Access to a Dataset <https://docs.aws.amazon.com/quicksight/latest/user/restrict-access-to-a-data-set-using-row-level-security.html>`_ in the *Amazon QuickSight User Guide* .

            The option to deny permissions by setting ``PermissionPolicy`` to ``DENY_ACCESS`` is not supported for new RLS datasets.

            :param arn: The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.
            :param permission_policy: The type of permissions to use when interpreting the permissions for RLS. ``DENY_ACCESS`` is included for backward compatibility only.
            :param format_version: The user or group rules associated with the dataset that contains permissions for RLS. By default, ``FormatVersion`` is ``VERSION_1`` . When ``FormatVersion`` is ``VERSION_1`` , ``UserName`` and ``GroupName`` are required. When ``FormatVersion`` is ``VERSION_2`` , ``UserARN`` and ``GroupARN`` are required, and ``Namespace`` must not exist.
            :param namespace: The namespace associated with the dataset that contains permissions for RLS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                row_level_permission_data_set_property = quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                    arn="arn",
                    permission_policy="permissionPolicy",
                
                    # the properties below are optional
                    format_version="formatVersion",
                    namespace="namespace"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__046ce17827977938f1ceec9a2f17911e6d411cf5f37f6746381cbed51153fbd5)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument permission_policy", value=permission_policy, expected_type=type_hints["permission_policy"])
                check_type(argname="argument format_version", value=format_version, expected_type=type_hints["format_version"])
                check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "permission_policy": permission_policy,
            }
            if format_version is not None:
                self._values["format_version"] = format_version
            if namespace is not None:
                self._values["namespace"] = namespace

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def permission_policy(self) -> builtins.str:
            '''The type of permissions to use when interpreting the permissions for RLS.

            ``DENY_ACCESS`` is included for backward compatibility only.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-permissionpolicy
            '''
            result = self._values.get("permission_policy")
            assert result is not None, "Required property 'permission_policy' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_version(self) -> typing.Optional[builtins.str]:
            '''The user or group rules associated with the dataset that contains permissions for RLS.

            By default, ``FormatVersion`` is ``VERSION_1`` . When ``FormatVersion`` is ``VERSION_1`` , ``UserName`` and ``GroupName`` are required. When ``FormatVersion`` is ``VERSION_2`` , ``UserARN`` and ``GroupARN`` are required, and ``Namespace`` must not exist.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-formatversion
            '''
            result = self._values.get("format_version")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def namespace(self) -> typing.Optional[builtins.str]:
            '''The namespace associated with the dataset that contains permissions for RLS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-namespace
            '''
            result = self._values.get("namespace")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowLevelPermissionDataSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.S3SourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_source_arn": "dataSourceArn",
            "input_columns": "inputColumns",
            "upload_settings": "uploadSettings",
        },
    )
    class S3SourceProperty:
        def __init__(
            self,
            *,
            data_source_arn: builtins.str,
            input_columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSet.InputColumnProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            upload_settings: typing.Optional[typing.Union[typing.Union["CfnDataSet.UploadSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A physical table type for an S3 data source.

            :param data_source_arn: The Amazon Resource Name (ARN) for the data source.
            :param input_columns: A physical table type for an S3 data source. .. epigraph:: For files that aren't JSON, only ``STRING`` data types are supported in input columns.
            :param upload_settings: Information about the format for the S3 source file or files.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                s3_source_property = quicksight.CfnDataSet.S3SourceProperty(
                    data_source_arn="dataSourceArn",
                    input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                        name="name",
                        type="type"
                    )],
                
                    # the properties below are optional
                    upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                        contains_header=False,
                        delimiter="delimiter",
                        format="format",
                        start_from_row=123,
                        text_qualifier="textQualifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1025cb40fbbb056e3530fbe86d11aed2d2b6be309d34b206817850a67efa7b78)
                check_type(argname="argument data_source_arn", value=data_source_arn, expected_type=type_hints["data_source_arn"])
                check_type(argname="argument input_columns", value=input_columns, expected_type=type_hints["input_columns"])
                check_type(argname="argument upload_settings", value=upload_settings, expected_type=type_hints["upload_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_source_arn": data_source_arn,
                "input_columns": input_columns,
            }
            if upload_settings is not None:
                self._values["upload_settings"] = upload_settings

        @builtins.property
        def data_source_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-datasourcearn
            '''
            result = self._values.get("data_source_arn")
            assert result is not None, "Required property 'data_source_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def input_columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.InputColumnProperty", _IResolvable_a771d0ef]]]:
            '''A physical table type for an S3 data source.

            .. epigraph::

               For files that aren't JSON, only ``STRING`` data types are supported in input columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-inputcolumns
            '''
            result = self._values.get("input_columns")
            assert result is not None, "Required property 'input_columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSet.InputColumnProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def upload_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.UploadSettingsProperty", _IResolvable_a771d0ef]]:
            '''Information about the format for the S3 source file or files.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-uploadsettings
            '''
            result = self._values.get("upload_settings")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.UploadSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "S3SourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.TagColumnOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"column_name": "columnName", "tags": "tags"},
    )
    class TagColumnOperationProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            tags: typing.Sequence[typing.Union["CfnDataSet.ColumnTagProperty", typing.Dict[builtins.str, typing.Any]]],
        ) -> None:
            '''A transform operation that tags a column with additional information.

            :param column_name: The column that this operation acts on.
            :param tags: The dataset column tag, currently only used for geospatial type tagging. .. epigraph:: This is not tags for the AWS tagging feature.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tag_column_operation_property = quicksight.CfnDataSet.TagColumnOperationProperty(
                    column_name="columnName",
                    tags=[quicksight.CfnDataSet.ColumnTagProperty(
                        column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                            text="text"
                        ),
                        column_geographic_role="columnGeographicRole"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9b36407e47dd52ddd00c96c86a6a745dd8101af3ffb395d6cec041547051d5a)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "tags": tags,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The column that this operation acts on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def tags(self) -> typing.List["CfnDataSet.ColumnTagProperty"]:
            '''The dataset column tag, currently only used for geospatial type tagging.

            .. epigraph::

               This is not tags for the AWS tagging feature.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-tags
            '''
            result = self._values.get("tags")
            assert result is not None, "Required property 'tags' is missing"
            return typing.cast(typing.List["CfnDataSet.ColumnTagProperty"], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TagColumnOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.TransformOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cast_column_type_operation": "castColumnTypeOperation",
            "create_columns_operation": "createColumnsOperation",
            "filter_operation": "filterOperation",
            "project_operation": "projectOperation",
            "rename_column_operation": "renameColumnOperation",
            "tag_column_operation": "tagColumnOperation",
        },
    )
    class TransformOperationProperty:
        def __init__(
            self,
            *,
            cast_column_type_operation: typing.Optional[typing.Union[typing.Union["CfnDataSet.CastColumnTypeOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            create_columns_operation: typing.Optional[typing.Union[typing.Union["CfnDataSet.CreateColumnsOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filter_operation: typing.Optional[typing.Union[typing.Union["CfnDataSet.FilterOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            project_operation: typing.Optional[typing.Union[typing.Union["CfnDataSet.ProjectOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rename_column_operation: typing.Optional[typing.Union[typing.Union["CfnDataSet.RenameColumnOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tag_column_operation: typing.Optional[typing.Union[typing.Union["CfnDataSet.TagColumnOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A data transformation on a logical table.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param cast_column_type_operation: A transform operation that casts a column to a different type.
            :param create_columns_operation: An operation that creates calculated columns. Columns created in one such operation form a lexical closure.
            :param filter_operation: An operation that filters rows based on some condition.
            :param project_operation: An operation that projects columns. Operations that come after a projection can only refer to projected columns.
            :param rename_column_operation: An operation that renames a column.
            :param tag_column_operation: An operation that tags a column with additional information.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                transform_operation_property = quicksight.CfnDataSet.TransformOperationProperty(
                    cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                        column_name="columnName",
                        new_column_type="newColumnType",
                
                        # the properties below are optional
                        format="format"
                    ),
                    create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                        columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                            column_id="columnId",
                            column_name="columnName",
                            expression="expression"
                        )]
                    ),
                    filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                        condition_expression="conditionExpression"
                    ),
                    project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                        projected_columns=["projectedColumns"]
                    ),
                    rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                        column_name="columnName",
                        new_column_name="newColumnName"
                    ),
                    tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                        column_name="columnName",
                        tags=[quicksight.CfnDataSet.ColumnTagProperty(
                            column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                text="text"
                            ),
                            column_geographic_role="columnGeographicRole"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39eeed8ab5362d331fad437a1db05a40f9462e67d2c60e079c57ba6c4a48674d)
                check_type(argname="argument cast_column_type_operation", value=cast_column_type_operation, expected_type=type_hints["cast_column_type_operation"])
                check_type(argname="argument create_columns_operation", value=create_columns_operation, expected_type=type_hints["create_columns_operation"])
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument project_operation", value=project_operation, expected_type=type_hints["project_operation"])
                check_type(argname="argument rename_column_operation", value=rename_column_operation, expected_type=type_hints["rename_column_operation"])
                check_type(argname="argument tag_column_operation", value=tag_column_operation, expected_type=type_hints["tag_column_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cast_column_type_operation is not None:
                self._values["cast_column_type_operation"] = cast_column_type_operation
            if create_columns_operation is not None:
                self._values["create_columns_operation"] = create_columns_operation
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if project_operation is not None:
                self._values["project_operation"] = project_operation
            if rename_column_operation is not None:
                self._values["rename_column_operation"] = rename_column_operation
            if tag_column_operation is not None:
                self._values["tag_column_operation"] = tag_column_operation

        @builtins.property
        def cast_column_type_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.CastColumnTypeOperationProperty", _IResolvable_a771d0ef]]:
            '''A transform operation that casts a column to a different type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-castcolumntypeoperation
            '''
            result = self._values.get("cast_column_type_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.CastColumnTypeOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def create_columns_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.CreateColumnsOperationProperty", _IResolvable_a771d0ef]]:
            '''An operation that creates calculated columns.

            Columns created in one such operation form a lexical closure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-createcolumnsoperation
            '''
            result = self._values.get("create_columns_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.CreateColumnsOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.FilterOperationProperty", _IResolvable_a771d0ef]]:
            '''An operation that filters rows based on some condition.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.FilterOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def project_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.ProjectOperationProperty", _IResolvable_a771d0ef]]:
            '''An operation that projects columns.

            Operations that come after a projection can only refer to projected columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-projectoperation
            '''
            result = self._values.get("project_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.ProjectOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rename_column_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.RenameColumnOperationProperty", _IResolvable_a771d0ef]]:
            '''An operation that renames a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-renamecolumnoperation
            '''
            result = self._values.get("rename_column_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.RenameColumnOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tag_column_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSet.TagColumnOperationProperty", _IResolvable_a771d0ef]]:
            '''An operation that tags a column with additional information.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-tagcolumnoperation
            '''
            result = self._values.get("tag_column_operation")
            return typing.cast(typing.Optional[typing.Union["CfnDataSet.TagColumnOperationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TransformOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSet.UploadSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contains_header": "containsHeader",
            "delimiter": "delimiter",
            "format": "format",
            "start_from_row": "startFromRow",
            "text_qualifier": "textQualifier",
        },
    )
    class UploadSettingsProperty:
        def __init__(
            self,
            *,
            contains_header: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            delimiter: typing.Optional[builtins.str] = None,
            format: typing.Optional[builtins.str] = None,
            start_from_row: typing.Optional[jsii.Number] = None,
            text_qualifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Information about the format for a source file or files.

            :param contains_header: Whether the file has a header row, or the files each have a header row.
            :param delimiter: The delimiter between values in the file.
            :param format: File format.
            :param start_from_row: A row number to start reading data from.
            :param text_qualifier: Text qualifier.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                upload_settings_property = quicksight.CfnDataSet.UploadSettingsProperty(
                    contains_header=False,
                    delimiter="delimiter",
                    format="format",
                    start_from_row=123,
                    text_qualifier="textQualifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ff525119003c83ef161e831fad888a599a4f68ce862e396c9dcaa2b7a0124c5)
                check_type(argname="argument contains_header", value=contains_header, expected_type=type_hints["contains_header"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
                check_type(argname="argument start_from_row", value=start_from_row, expected_type=type_hints["start_from_row"])
                check_type(argname="argument text_qualifier", value=text_qualifier, expected_type=type_hints["text_qualifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contains_header is not None:
                self._values["contains_header"] = contains_header
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if format is not None:
                self._values["format"] = format
            if start_from_row is not None:
                self._values["start_from_row"] = start_from_row
            if text_qualifier is not None:
                self._values["text_qualifier"] = text_qualifier

        @builtins.property
        def contains_header(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Whether the file has a header row, or the files each have a header row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-containsheader
            '''
            result = self._values.get("contains_header")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter between values in the file.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format(self) -> typing.Optional[builtins.str]:
            '''File format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_from_row(self) -> typing.Optional[jsii.Number]:
            '''A row number to start reading data from.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-startfromrow
            '''
            result = self._values.get("start_from_row")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def text_qualifier(self) -> typing.Optional[builtins.str]:
            '''Text qualifier.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-textqualifier
            '''
            result = self._values.get("text_qualifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UploadSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnDataSetProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "column_groups": "columnGroups",
        "column_level_permission_rules": "columnLevelPermissionRules",
        "data_set_id": "dataSetId",
        "data_set_usage_configuration": "dataSetUsageConfiguration",
        "field_folders": "fieldFolders",
        "import_mode": "importMode",
        "ingestion_wait_policy": "ingestionWaitPolicy",
        "logical_table_map": "logicalTableMap",
        "name": "name",
        "permissions": "permissions",
        "physical_table_map": "physicalTableMap",
        "row_level_permission_data_set": "rowLevelPermissionDataSet",
        "tags": "tags",
    },
)
class CfnDataSetProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        column_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        data_set_usage_configuration: typing.Optional[typing.Union[typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        field_folders: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        import_mode: typing.Optional[builtins.str] = None,
        ingestion_wait_policy: typing.Optional[typing.Union[typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        logical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        physical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        row_level_permission_data_set: typing.Optional[typing.Union[typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    ) -> None:
        '''Properties for defining a ``CfnDataSet``.

        :param aws_account_id: The AWS account ID.
        :param column_groups: Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
        :param column_level_permission_rules: A set of one or more definitions of a ``ColumnLevelPermissionRule`` .
        :param data_set_id: An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
        :param data_set_usage_configuration: The usage configuration to apply to child datasets that reference this dataset as a source.
        :param field_folders: The folder that contains fields and nested subfolders for your dataset.
        :param import_mode: Indicates whether you want to import the data into SPICE.
        :param ingestion_wait_policy: The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
        :param logical_table_map: Configures the combination and transformation of the data from the physical tables.
        :param name: The display name for the dataset.
        :param permissions: A list of resource permissions on the dataset.
        :param physical_table_map: Declares the physical tables that are available in the underlying data sources.
        :param row_level_permission_data_set: The row-level security configuration for the data that you want to create.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            cfn_data_set_props = quicksight.CfnDataSetProps(
                aws_account_id="awsAccountId",
                column_groups=[quicksight.CfnDataSet.ColumnGroupProperty(
                    geo_spatial_column_group=quicksight.CfnDataSet.GeoSpatialColumnGroupProperty(
                        columns=["columns"],
                        name="name",
            
                        # the properties below are optional
                        country_code="countryCode"
                    )
                )],
                column_level_permission_rules=[quicksight.CfnDataSet.ColumnLevelPermissionRuleProperty(
                    column_names=["columnNames"],
                    principals=["principals"]
                )],
                data_set_id="dataSetId",
                data_set_usage_configuration=quicksight.CfnDataSet.DataSetUsageConfigurationProperty(
                    disable_use_as_direct_query_source=False,
                    disable_use_as_imported_source=False
                ),
                field_folders={
                    "field_folders_key": quicksight.CfnDataSet.FieldFolderProperty(
                        columns=["columns"],
                        description="description"
                    )
                },
                import_mode="importMode",
                ingestion_wait_policy=quicksight.CfnDataSet.IngestionWaitPolicyProperty(
                    ingestion_wait_time_in_hours=123,
                    wait_for_spice_ingestion=False
                ),
                logical_table_map={
                    "logical_table_map_key": quicksight.CfnDataSet.LogicalTableProperty(
                        alias="alias",
                        source=quicksight.CfnDataSet.LogicalTableSourceProperty(
                            data_set_arn="dataSetArn",
                            join_instruction=quicksight.CfnDataSet.JoinInstructionProperty(
                                left_operand="leftOperand",
                                on_clause="onClause",
                                right_operand="rightOperand",
                                type="type",
            
                                # the properties below are optional
                                left_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                    unique_key=False
                                ),
                                right_join_key_properties=quicksight.CfnDataSet.JoinKeyPropertiesProperty(
                                    unique_key=False
                                )
                            ),
                            physical_table_id="physicalTableId"
                        ),
            
                        # the properties below are optional
                        data_transforms=[quicksight.CfnDataSet.TransformOperationProperty(
                            cast_column_type_operation=quicksight.CfnDataSet.CastColumnTypeOperationProperty(
                                column_name="columnName",
                                new_column_type="newColumnType",
            
                                # the properties below are optional
                                format="format"
                            ),
                            create_columns_operation=quicksight.CfnDataSet.CreateColumnsOperationProperty(
                                columns=[quicksight.CfnDataSet.CalculatedColumnProperty(
                                    column_id="columnId",
                                    column_name="columnName",
                                    expression="expression"
                                )]
                            ),
                            filter_operation=quicksight.CfnDataSet.FilterOperationProperty(
                                condition_expression="conditionExpression"
                            ),
                            project_operation=quicksight.CfnDataSet.ProjectOperationProperty(
                                projected_columns=["projectedColumns"]
                            ),
                            rename_column_operation=quicksight.CfnDataSet.RenameColumnOperationProperty(
                                column_name="columnName",
                                new_column_name="newColumnName"
                            ),
                            tag_column_operation=quicksight.CfnDataSet.TagColumnOperationProperty(
                                column_name="columnName",
                                tags=[quicksight.CfnDataSet.ColumnTagProperty(
                                    column_description=quicksight.CfnDataSet.ColumnDescriptionProperty(
                                        text="text"
                                    ),
                                    column_geographic_role="columnGeographicRole"
                                )]
                            )
                        )]
                    )
                },
                name="name",
                permissions=[quicksight.CfnDataSet.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                physical_table_map={
                    "physical_table_map_key": quicksight.CfnDataSet.PhysicalTableProperty(
                        custom_sql=quicksight.CfnDataSet.CustomSqlProperty(
                            columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type"
                            )],
                            data_source_arn="dataSourceArn",
                            name="name",
                            sql_query="sqlQuery"
                        ),
                        relational_table=quicksight.CfnDataSet.RelationalTableProperty(
                            data_source_arn="dataSourceArn",
                            input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type"
                            )],
                            name="name",
            
                            # the properties below are optional
                            catalog="catalog",
                            schema="schema"
                        ),
                        s3_source=quicksight.CfnDataSet.S3SourceProperty(
                            data_source_arn="dataSourceArn",
                            input_columns=[quicksight.CfnDataSet.InputColumnProperty(
                                name="name",
                                type="type"
                            )],
            
                            # the properties below are optional
                            upload_settings=quicksight.CfnDataSet.UploadSettingsProperty(
                                contains_header=False,
                                delimiter="delimiter",
                                format="format",
                                start_from_row=123,
                                text_qualifier="textQualifier"
                            )
                        )
                    )
                },
                row_level_permission_data_set=quicksight.CfnDataSet.RowLevelPermissionDataSetProperty(
                    arn="arn",
                    permission_policy="permissionPolicy",
            
                    # the properties below are optional
                    format_version="formatVersion",
                    namespace="namespace"
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )]
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__64ec39b807cc879ea1450bd3114d0c18167529bce23e812bd109bbcdacbc3e7d)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument column_groups", value=column_groups, expected_type=type_hints["column_groups"])
            check_type(argname="argument column_level_permission_rules", value=column_level_permission_rules, expected_type=type_hints["column_level_permission_rules"])
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument data_set_usage_configuration", value=data_set_usage_configuration, expected_type=type_hints["data_set_usage_configuration"])
            check_type(argname="argument field_folders", value=field_folders, expected_type=type_hints["field_folders"])
            check_type(argname="argument import_mode", value=import_mode, expected_type=type_hints["import_mode"])
            check_type(argname="argument ingestion_wait_policy", value=ingestion_wait_policy, expected_type=type_hints["ingestion_wait_policy"])
            check_type(argname="argument logical_table_map", value=logical_table_map, expected_type=type_hints["logical_table_map"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument physical_table_map", value=physical_table_map, expected_type=type_hints["physical_table_map"])
            check_type(argname="argument row_level_permission_data_set", value=row_level_permission_data_set, expected_type=type_hints["row_level_permission_data_set"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if column_groups is not None:
            self._values["column_groups"] = column_groups
        if column_level_permission_rules is not None:
            self._values["column_level_permission_rules"] = column_level_permission_rules
        if data_set_id is not None:
            self._values["data_set_id"] = data_set_id
        if data_set_usage_configuration is not None:
            self._values["data_set_usage_configuration"] = data_set_usage_configuration
        if field_folders is not None:
            self._values["field_folders"] = field_folders
        if import_mode is not None:
            self._values["import_mode"] = import_mode
        if ingestion_wait_policy is not None:
            self._values["ingestion_wait_policy"] = ingestion_wait_policy
        if logical_table_map is not None:
            self._values["logical_table_map"] = logical_table_map
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if physical_table_map is not None:
            self._values["physical_table_map"] = physical_table_map
        if row_level_permission_data_set is not None:
            self._values["row_level_permission_data_set"] = row_level_permission_data_set
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def column_groups(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ColumnGroupProperty, _IResolvable_a771d0ef]]]]:
        '''Groupings of columns that work together in certain Amazon QuickSight features.

        Currently, only geospatial hierarchy is supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
        '''
        result = self._values.get("column_groups")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ColumnGroupProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def column_level_permission_rules(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, _IResolvable_a771d0ef]]]]:
        '''A set of one or more definitions of a ``ColumnLevelPermissionRule`` .

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
        '''
        result = self._values.get("column_level_permission_rules")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the dataset that you want to create.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
        '''
        result = self._values.get("data_set_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_set_usage_configuration(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, _IResolvable_a771d0ef]]:
        '''The usage configuration to apply to child datasets that reference this dataset as a source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
        '''
        result = self._values.get("data_set_usage_configuration")
        return typing.cast(typing.Optional[typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def field_folders(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.FieldFolderProperty, _IResolvable_a771d0ef]]]]:
        '''The folder that contains fields and nested subfolders for your dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
        '''
        result = self._values.get("field_folders")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.FieldFolderProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def import_mode(self) -> typing.Optional[builtins.str]:
        '''Indicates whether you want to import the data into SPICE.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
        '''
        result = self._values.get("import_mode")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def ingestion_wait_policy(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSet.IngestionWaitPolicyProperty, _IResolvable_a771d0ef]]:
        '''The wait policy to use when creating or updating a Dataset.

        The default is to wait for SPICE ingestion to finish with timeout of 36 hours.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
        '''
        result = self._values.get("ingestion_wait_policy")
        return typing.cast(typing.Optional[typing.Union[CfnDataSet.IngestionWaitPolicyProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def logical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.LogicalTableProperty, _IResolvable_a771d0ef]]]]:
        '''Configures the combination and transformation of the data from the physical tables.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
        '''
        result = self._values.get("logical_table_map")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.LogicalTableProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ResourcePermissionProperty, _IResolvable_a771d0ef]]]]:
        '''A list of resource permissions on the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ResourcePermissionProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def physical_table_map(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.PhysicalTableProperty, _IResolvable_a771d0ef]]]]:
        '''Declares the physical tables that are available in the underlying data sources.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
        '''
        result = self._values.get("physical_table_map")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.PhysicalTableProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def row_level_permission_data_set(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, _IResolvable_a771d0ef]]:
        '''The row-level security configuration for the data that you want to create.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
        '''
        result = self._values.get("row_level_permission_data_set")
        return typing.cast(typing.Optional[typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDataSetProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnDataSource(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnDataSource",
):
    '''A CloudFormation ``AWS::QuickSight::DataSource``.

    Creates a data source.

    :cloudformationResource: AWS::QuickSight::DataSource
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        cfn_data_source = quicksight.CfnDataSource(self, "MyCfnDataSource",
            alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                ),
                amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                ),
                athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                    work_group="workGroup"
                ),
                aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                ),
                maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                ),
                rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                ),
                redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
        
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                ),
                s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    )
                ),
                snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                ),
                spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                ),
                sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            )],
            aws_account_id="awsAccountId",
            credentials=quicksight.CfnDataSource.DataSourceCredentialsProperty(
                copy_source_arn="copySourceArn",
                credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                    password="password",
                    username="username",
        
                    # the properties below are optional
                    alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                        amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                            domain="domain"
                        ),
                        amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                            domain="domain"
                        ),
                        athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                            work_group="workGroup"
                        ),
                        aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                            host="host",
                            port=123,
                            sql_endpoint_path="sqlEndpointPath"
                        ),
                        maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        ),
                        rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                            database="database",
                            instance_id="instanceId"
                        ),
                        redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                            database="database",
        
                            # the properties below are optional
                            cluster_id="clusterId",
                            host="host",
                            port=123
                        ),
                        s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                            manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                bucket="bucket",
                                key="key"
                            )
                        ),
                        snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                            database="database",
                            host="host",
                            warehouse="warehouse"
                        ),
                        spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                            host="host",
                            port=123
                        ),
                        sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        )
                    )]
                ),
                secret_arn="secretArn"
            ),
            data_source_id="dataSourceId",
            data_source_parameters=quicksight.CfnDataSource.DataSourceParametersProperty(
                amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                ),
                amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                ),
                athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                    work_group="workGroup"
                ),
                aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                ),
                maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                ),
                rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                ),
                redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
        
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                ),
                s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    )
                ),
                snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                ),
                spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                ),
                sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                ),
                teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            ),
            error_info=quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                message="message",
                type="type"
            ),
            name="name",
            permissions=[quicksight.CfnDataSource.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            ssl_properties=quicksight.CfnDataSource.SslPropertiesProperty(
                disable_ssl=False
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            type="type",
            vpc_connection_properties=quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                vpc_connection_arn="vpcConnectionArn"
            )
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        credentials: typing.Optional[typing.Union[typing.Union["CfnDataSource.DataSourceCredentialsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        data_source_id: typing.Optional[builtins.str] = None,
        data_source_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        error_info: typing.Optional[typing.Union[typing.Union["CfnDataSource.DataSourceErrorInfoProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSource.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ssl_properties: typing.Optional[typing.Union[typing.Union["CfnDataSource.SslPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        type: typing.Optional[builtins.str] = None,
        vpc_connection_properties: typing.Optional[typing.Union[typing.Union["CfnDataSource.VpcConnectionPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::DataSource``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.
        :param aws_account_id: The AWS account ID.
        :param credentials: The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
        :param data_source_id: An ID for the data source. This ID is unique per AWS Region for each AWS account.
        :param data_source_parameters: The parameters that Amazon QuickSight uses to connect to your underlying source.
        :param error_info: Error information from the last update or the creation of the data source.
        :param name: A display name for the data source.
        :param permissions: A list of resource permissions on the data source.
        :param ssl_properties: Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
        :param type: The type of the data source. To return a list of all data sources, use ``ListDataSources`` . Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.
        :param vpc_connection_properties: Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a7c53922691ab39dd1b021a3e30bf67046272ed2c896c058e9c51c75f7b24ac7)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnDataSourceProps(
            alternate_data_source_parameters=alternate_data_source_parameters,
            aws_account_id=aws_account_id,
            credentials=credentials,
            data_source_id=data_source_id,
            data_source_parameters=data_source_parameters,
            error_info=error_info,
            name=name,
            permissions=permissions,
            ssl_properties=ssl_properties,
            tags=tags,
            type=type,
            vpc_connection_properties=vpc_connection_properties,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5ee1fb159cc6b8cc0bc67cd55e6d6d66359157eacd2e3a2d9f123e087cf80c7d)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7179296e6dc01e4678af405d91a94fcf856b7bf6300b244bceab58490660f8a1)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the dataset.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time that this data source was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The last time that this data source was updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrStatus")
    def attr_status(self) -> builtins.str:
        '''The HTTP status of the request.

        :cloudformationAttribute: Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrStatus"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="alternateDataSourceParameters")
    def alternate_data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]]]]:
        '''A set of alternate data source parameters that you want to share for the credentials stored with this data source.

        The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "alternateDataSourceParameters"))

    @alternate_data_source_parameters.setter
    def alternate_data_source_parameters(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1b0816db7c39cd9db3c8b3078bf61f117bf251d82b252a64f0ed5d432dd596dd)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alternateDataSourceParameters", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__86b21f206c80d8e14f5273917a89fb864cecfaa6d00bcc5d80b652fea34c3002)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="credentials")
    def credentials(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSource.DataSourceCredentialsProperty", _IResolvable_a771d0ef]]:
        '''The credentials Amazon QuickSight that uses to connect to your underlying source.

        Currently, only credentials based on user name and password are supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSource.DataSourceCredentialsProperty", _IResolvable_a771d0ef]], jsii.get(self, "credentials"))

    @credentials.setter
    def credentials(
        self,
        value: typing.Optional[typing.Union["CfnDataSource.DataSourceCredentialsProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2a9a0595c38b1ddf4f7b48c7b632a5c528d44fb306facad9a1e1c58a5bd08f7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "credentials", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceId")
    def data_source_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the data source.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSourceId"))

    @data_source_id.setter
    def data_source_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aabbb5f63bf58c14637689d3cd5d6e33804c1a6c7eeaefc6785c22a0a62de436)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSourceId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceParameters")
    def data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]]:
        '''The parameters that Amazon QuickSight uses to connect to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]], jsii.get(self, "dataSourceParameters"))

    @data_source_parameters.setter
    def data_source_parameters(
        self,
        value: typing.Optional[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f6f6439b5e9a8a21df2d26a45ca721ffb274503a57ab546077e68c0eacfd3774)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSourceParameters", value)

    @builtins.property
    @jsii.member(jsii_name="errorInfo")
    def error_info(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSource.DataSourceErrorInfoProperty", _IResolvable_a771d0ef]]:
        '''Error information from the last update or the creation of the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSource.DataSourceErrorInfoProperty", _IResolvable_a771d0ef]], jsii.get(self, "errorInfo"))

    @error_info.setter
    def error_info(
        self,
        value: typing.Optional[typing.Union["CfnDataSource.DataSourceErrorInfoProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5e99a6c9c6baf50107afb1c0e73ed267fbc0af2d005365feef2f15f5ba1a5380)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "errorInfo", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__25c63184b9e48cf6560b413d7ffc6e0646a490d01ead4de626bebcae288e5cae)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.ResourcePermissionProperty", _IResolvable_a771d0ef]]]]:
        '''A list of resource permissions on the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.ResourcePermissionProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.ResourcePermissionProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d938c60ffa7f9c40aa8974443884b021b831dc4a72dbd5fb03126d3c4b6d98f7)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sslProperties")
    def ssl_properties(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSource.SslPropertiesProperty", _IResolvable_a771d0ef]]:
        '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSource.SslPropertiesProperty", _IResolvable_a771d0ef]], jsii.get(self, "sslProperties"))

    @ssl_properties.setter
    def ssl_properties(
        self,
        value: typing.Optional[typing.Union["CfnDataSource.SslPropertiesProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ca7a9aadfc4174e97adcc5ee078b87d8e91bea513e8997dbc5eaf8da4147b74a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sslProperties", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[builtins.str]:
        '''The type of the data source. To return a list of all data sources, use ``ListDataSources`` .

        Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "type"))

    @type.setter
    def type(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c53248f590f6132fb3072daa03741d6e291f03e09dcf57c49507521ebf9d83eb)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConnectionProperties")
    def vpc_connection_properties(
        self,
    ) -> typing.Optional[typing.Union["CfnDataSource.VpcConnectionPropertiesProperty", _IResolvable_a771d0ef]]:
        '''Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
        '''
        return typing.cast(typing.Optional[typing.Union["CfnDataSource.VpcConnectionPropertiesProperty", _IResolvable_a771d0ef]], jsii.get(self, "vpcConnectionProperties"))

    @vpc_connection_properties.setter
    def vpc_connection_properties(
        self,
        value: typing.Optional[typing.Union["CfnDataSource.VpcConnectionPropertiesProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7db4a56893b5c3e49e9997efe8bb08d5efe6508f29ab0c4c961a8fcc8d2cbd6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vpcConnectionProperties", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.AmazonElasticsearchParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"domain": "domain"},
    )
    class AmazonElasticsearchParametersProperty:
        def __init__(self, *, domain: builtins.str) -> None:
            '''The parameters for OpenSearch.

            :param domain: The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                amazon_elasticsearch_parameters_property = quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                    domain="domain"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0713c768f4967c02a66768f543d77cf272acf7c12ed68bdf2d2d350f78b5c3e1)
                check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "domain": domain,
            }

        @builtins.property
        def domain(self) -> builtins.str:
            '''The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html#cfn-quicksight-datasource-amazonelasticsearchparameters-domain
            '''
            result = self._values.get("domain")
            assert result is not None, "Required property 'domain' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AmazonElasticsearchParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.AmazonOpenSearchParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"domain": "domain"},
    )
    class AmazonOpenSearchParametersProperty:
        def __init__(self, *, domain: builtins.str) -> None:
            '''The parameters for OpenSearch.

            :param domain: The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                amazon_open_search_parameters_property = quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                    domain="domain"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ffcb56d73bc925a49945582aeca6efe82ebb2e9bb85734685d28fba0d7129f7)
                check_type(argname="argument domain", value=domain, expected_type=type_hints["domain"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "domain": domain,
            }

        @builtins.property
        def domain(self) -> builtins.str:
            '''The OpenSearch domain.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html#cfn-quicksight-datasource-amazonopensearchparameters-domain
            '''
            result = self._values.get("domain")
            assert result is not None, "Required property 'domain' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AmazonOpenSearchParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.AthenaParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"work_group": "workGroup"},
    )
    class AthenaParametersProperty:
        def __init__(self, *, work_group: typing.Optional[builtins.str] = None) -> None:
            '''Parameters for Amazon Athena.

            :param work_group: The workgroup that Amazon Athena uses.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                athena_parameters_property = quicksight.CfnDataSource.AthenaParametersProperty(
                    work_group="workGroup"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55871c8c64b72ed559f3c4682ecaafb157503cae3b32ea010aaf723bffb1e6fb)
                check_type(argname="argument work_group", value=work_group, expected_type=type_hints["work_group"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if work_group is not None:
                self._values["work_group"] = work_group

        @builtins.property
        def work_group(self) -> typing.Optional[builtins.str]:
            '''The workgroup that Amazon Athena uses.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-workgroup
            '''
            result = self._values.get("work_group")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AthenaParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.AuroraParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class AuroraParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Parameters for Amazon Aurora.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aurora_parameters_property = quicksight.CfnDataSource.AuroraParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f602d9aa381bf2cecc2fdb2a111f3618af1612d2245f01c1036efd28ae8878be)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AuroraParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class AuroraPostgreSqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Parameters for Amazon Aurora PostgreSQL-Compatible Edition.

            :param database: The Amazon Aurora PostgreSQL database to connect to.
            :param host: The Amazon Aurora PostgreSQL-Compatible host to connect to.
            :param port: The port that Amazon Aurora PostgreSQL is listening on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aurora_postgre_sql_parameters_property = quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b1091b4ef26fde3a2fd9403fec9511387f871c562e5d9d4a64af30d118da432f)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''The Amazon Aurora PostgreSQL database to connect to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''The Amazon Aurora PostgreSQL-Compatible host to connect to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port that Amazon Aurora PostgreSQL is listening on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AuroraPostgreSqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.CredentialPairProperty",
        jsii_struct_bases=[],
        name_mapping={
            "password": "password",
            "username": "username",
            "alternate_data_source_parameters": "alternateDataSourceParameters",
        },
    )
    class CredentialPairProperty:
        def __init__(
            self,
            *,
            password: builtins.str,
            username: builtins.str,
            alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnDataSource.DataSourceParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The combination of user name and password that are used as credentials.

            :param password: Password.
            :param username: User name.
            :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for these credentials. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the ``AlternateDataSourceParameters`` list is null, the ``DataSourceParameters`` originally used with these ``Credentials`` is automatically allowed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                credential_pair_property = quicksight.CfnDataSource.CredentialPairProperty(
                    password="password",
                    username="username",
                
                    # the properties below are optional
                    alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                        amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                            domain="domain"
                        ),
                        amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                            domain="domain"
                        ),
                        athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                            work_group="workGroup"
                        ),
                        aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                            host="host",
                            port=123,
                            sql_endpoint_path="sqlEndpointPath"
                        ),
                        maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                            catalog="catalog",
                            host="host",
                            port=123
                        ),
                        rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                            database="database",
                            instance_id="instanceId"
                        ),
                        redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                            database="database",
                
                            # the properties below are optional
                            cluster_id="clusterId",
                            host="host",
                            port=123
                        ),
                        s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                            manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                bucket="bucket",
                                key="key"
                            )
                        ),
                        snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                            database="database",
                            host="host",
                            warehouse="warehouse"
                        ),
                        spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                            host="host",
                            port=123
                        ),
                        sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        ),
                        teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                            database="database",
                            host="host",
                            port=123
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0b7b580fc1e20721676afeb23765acb8eb8a2fe2ab8078b4ce2f7057e4002e2)
                check_type(argname="argument password", value=password, expected_type=type_hints["password"])
                check_type(argname="argument username", value=username, expected_type=type_hints["username"])
                check_type(argname="argument alternate_data_source_parameters", value=alternate_data_source_parameters, expected_type=type_hints["alternate_data_source_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "password": password,
                "username": username,
            }
            if alternate_data_source_parameters is not None:
                self._values["alternate_data_source_parameters"] = alternate_data_source_parameters

        @builtins.property
        def password(self) -> builtins.str:
            '''Password.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-password
            '''
            result = self._values.get("password")
            assert result is not None, "Required property 'password' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def username(self) -> builtins.str:
            '''User name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-username
            '''
            result = self._values.get("username")
            assert result is not None, "Required property 'username' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def alternate_data_source_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]]]]:
            '''A set of alternate data source parameters that you want to share for these credentials.

            The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the ``AlternateDataSourceParameters`` list is null, the ``DataSourceParameters`` originally used with these ``Credentials`` is automatically allowed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-alternatedatasourceparameters
            '''
            result = self._values.get("alternate_data_source_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnDataSource.DataSourceParametersProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CredentialPairProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.DataSourceCredentialsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "copy_source_arn": "copySourceArn",
            "credential_pair": "credentialPair",
            "secret_arn": "secretArn",
        },
    )
    class DataSourceCredentialsProperty:
        def __init__(
            self,
            *,
            copy_source_arn: typing.Optional[builtins.str] = None,
            credential_pair: typing.Optional[typing.Union[typing.Union["CfnDataSource.CredentialPairProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secret_arn: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Data source credentials.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param copy_source_arn: The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When ``CopySourceArn`` is not null, the credential pair from the data source in the ARN is used as the credentials for the ``DataSourceCredentials`` structure.
            :param credential_pair: Credential pair. For more information, see ``[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)`` .
            :param secret_arn: The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_source_credentials_property = quicksight.CfnDataSource.DataSourceCredentialsProperty(
                    copy_source_arn="copySourceArn",
                    credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                        password="password",
                        username="username",
                
                        # the properties below are optional
                        alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                            amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                                domain="domain"
                            ),
                            amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                                domain="domain"
                            ),
                            athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                                work_group="workGroup"
                            ),
                            aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                                host="host",
                                port=123,
                                sql_endpoint_path="sqlEndpointPath"
                            ),
                            maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            ),
                            rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                                database="database",
                                instance_id="instanceId"
                            ),
                            redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                                database="database",
                
                                # the properties below are optional
                                cluster_id="clusterId",
                                host="host",
                                port=123
                            ),
                            s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                                manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                    bucket="bucket",
                                    key="key"
                                )
                            ),
                            snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                                database="database",
                                host="host",
                                warehouse="warehouse"
                            ),
                            spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                                host="host",
                                port=123
                            ),
                            sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            )
                        )]
                    ),
                    secret_arn="secretArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5dbea4a00d0551805bb3fea09ca0480db769ea71896d37ca0c86109cda08efe0)
                check_type(argname="argument copy_source_arn", value=copy_source_arn, expected_type=type_hints["copy_source_arn"])
                check_type(argname="argument credential_pair", value=credential_pair, expected_type=type_hints["credential_pair"])
                check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if copy_source_arn is not None:
                self._values["copy_source_arn"] = copy_source_arn
            if credential_pair is not None:
                self._values["credential_pair"] = credential_pair
            if secret_arn is not None:
                self._values["secret_arn"] = secret_arn

        @builtins.property
        def copy_source_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use.

            When ``CopySourceArn`` is not null, the credential pair from the data source in the ARN is used as the credentials for the ``DataSourceCredentials`` structure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-copysourcearn
            '''
            result = self._values.get("copy_source_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def credential_pair(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.CredentialPairProperty", _IResolvable_a771d0ef]]:
            '''Credential pair.

            For more information, see ``[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-credentialpair
            '''
            result = self._values.get("credential_pair")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.CredentialPairProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secret_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the secret associated with the data source in AWS Secrets Manager .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-secretarn
            '''
            result = self._values.get("secret_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceCredentialsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.DataSourceErrorInfoProperty",
        jsii_struct_bases=[],
        name_mapping={"message": "message", "type": "type"},
    )
    class DataSourceErrorInfoProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Error information for the data source creation or update.

            :param message: Error message.
            :param type: Error type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_source_error_info_property = quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                    message="message",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a85ba8b5593d942655cf1a6c754ee156401119e0beb21fedb7a4e7556a702fb)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Error message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Error type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceErrorInfoProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.DataSourceParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amazon_elasticsearch_parameters": "amazonElasticsearchParameters",
            "amazon_open_search_parameters": "amazonOpenSearchParameters",
            "athena_parameters": "athenaParameters",
            "aurora_parameters": "auroraParameters",
            "aurora_postgre_sql_parameters": "auroraPostgreSqlParameters",
            "databricks_parameters": "databricksParameters",
            "maria_db_parameters": "mariaDbParameters",
            "my_sql_parameters": "mySqlParameters",
            "oracle_parameters": "oracleParameters",
            "postgre_sql_parameters": "postgreSqlParameters",
            "presto_parameters": "prestoParameters",
            "rds_parameters": "rdsParameters",
            "redshift_parameters": "redshiftParameters",
            "s3_parameters": "s3Parameters",
            "snowflake_parameters": "snowflakeParameters",
            "spark_parameters": "sparkParameters",
            "sql_server_parameters": "sqlServerParameters",
            "teradata_parameters": "teradataParameters",
        },
    )
    class DataSourceParametersProperty:
        def __init__(
            self,
            *,
            amazon_elasticsearch_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.AmazonElasticsearchParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            amazon_open_search_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.AmazonOpenSearchParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            athena_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.AthenaParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            aurora_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.AuroraParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            aurora_postgre_sql_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.AuroraPostgreSqlParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            databricks_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.DatabricksParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maria_db_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.MariaDbParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            my_sql_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.MySqlParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            oracle_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.OracleParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            postgre_sql_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.PostgreSqlParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            presto_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.PrestoParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rds_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.RdsParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            redshift_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.RedshiftParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            s3_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.S3ParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            snowflake_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.SnowflakeParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            spark_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.SparkParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sql_server_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.SqlServerParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            teradata_parameters: typing.Optional[typing.Union[typing.Union["CfnDataSource.TeradataParametersProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The parameters that Amazon QuickSight uses to connect to your underlying data source.

            This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.

            :param amazon_elasticsearch_parameters: The parameters for OpenSearch.
            :param amazon_open_search_parameters: The parameters for OpenSearch.
            :param athena_parameters: The parameters for Amazon Athena.
            :param aurora_parameters: The parameters for Amazon Aurora MySQL.
            :param aurora_postgre_sql_parameters: The parameters for Amazon Aurora.
            :param databricks_parameters: The required parameters that are needed to connect to a Databricks data source.
            :param maria_db_parameters: The parameters for MariaDB.
            :param my_sql_parameters: The parameters for MySQL.
            :param oracle_parameters: Oracle parameters.
            :param postgre_sql_parameters: The parameters for PostgreSQL.
            :param presto_parameters: The parameters for Presto.
            :param rds_parameters: The parameters for Amazon RDS.
            :param redshift_parameters: The parameters for Amazon Redshift.
            :param s3_parameters: The parameters for S3.
            :param snowflake_parameters: The parameters for Snowflake.
            :param spark_parameters: The parameters for Spark.
            :param sql_server_parameters: The parameters for SQL Server.
            :param teradata_parameters: The parameters for Teradata.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_source_parameters_property = quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
                
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        )
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90db356a882e890618e0a242f815c83fce513ed33cffd59bb2ac7bfe39ed9dfd)
                check_type(argname="argument amazon_elasticsearch_parameters", value=amazon_elasticsearch_parameters, expected_type=type_hints["amazon_elasticsearch_parameters"])
                check_type(argname="argument amazon_open_search_parameters", value=amazon_open_search_parameters, expected_type=type_hints["amazon_open_search_parameters"])
                check_type(argname="argument athena_parameters", value=athena_parameters, expected_type=type_hints["athena_parameters"])
                check_type(argname="argument aurora_parameters", value=aurora_parameters, expected_type=type_hints["aurora_parameters"])
                check_type(argname="argument aurora_postgre_sql_parameters", value=aurora_postgre_sql_parameters, expected_type=type_hints["aurora_postgre_sql_parameters"])
                check_type(argname="argument databricks_parameters", value=databricks_parameters, expected_type=type_hints["databricks_parameters"])
                check_type(argname="argument maria_db_parameters", value=maria_db_parameters, expected_type=type_hints["maria_db_parameters"])
                check_type(argname="argument my_sql_parameters", value=my_sql_parameters, expected_type=type_hints["my_sql_parameters"])
                check_type(argname="argument oracle_parameters", value=oracle_parameters, expected_type=type_hints["oracle_parameters"])
                check_type(argname="argument postgre_sql_parameters", value=postgre_sql_parameters, expected_type=type_hints["postgre_sql_parameters"])
                check_type(argname="argument presto_parameters", value=presto_parameters, expected_type=type_hints["presto_parameters"])
                check_type(argname="argument rds_parameters", value=rds_parameters, expected_type=type_hints["rds_parameters"])
                check_type(argname="argument redshift_parameters", value=redshift_parameters, expected_type=type_hints["redshift_parameters"])
                check_type(argname="argument s3_parameters", value=s3_parameters, expected_type=type_hints["s3_parameters"])
                check_type(argname="argument snowflake_parameters", value=snowflake_parameters, expected_type=type_hints["snowflake_parameters"])
                check_type(argname="argument spark_parameters", value=spark_parameters, expected_type=type_hints["spark_parameters"])
                check_type(argname="argument sql_server_parameters", value=sql_server_parameters, expected_type=type_hints["sql_server_parameters"])
                check_type(argname="argument teradata_parameters", value=teradata_parameters, expected_type=type_hints["teradata_parameters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if amazon_elasticsearch_parameters is not None:
                self._values["amazon_elasticsearch_parameters"] = amazon_elasticsearch_parameters
            if amazon_open_search_parameters is not None:
                self._values["amazon_open_search_parameters"] = amazon_open_search_parameters
            if athena_parameters is not None:
                self._values["athena_parameters"] = athena_parameters
            if aurora_parameters is not None:
                self._values["aurora_parameters"] = aurora_parameters
            if aurora_postgre_sql_parameters is not None:
                self._values["aurora_postgre_sql_parameters"] = aurora_postgre_sql_parameters
            if databricks_parameters is not None:
                self._values["databricks_parameters"] = databricks_parameters
            if maria_db_parameters is not None:
                self._values["maria_db_parameters"] = maria_db_parameters
            if my_sql_parameters is not None:
                self._values["my_sql_parameters"] = my_sql_parameters
            if oracle_parameters is not None:
                self._values["oracle_parameters"] = oracle_parameters
            if postgre_sql_parameters is not None:
                self._values["postgre_sql_parameters"] = postgre_sql_parameters
            if presto_parameters is not None:
                self._values["presto_parameters"] = presto_parameters
            if rds_parameters is not None:
                self._values["rds_parameters"] = rds_parameters
            if redshift_parameters is not None:
                self._values["redshift_parameters"] = redshift_parameters
            if s3_parameters is not None:
                self._values["s3_parameters"] = s3_parameters
            if snowflake_parameters is not None:
                self._values["snowflake_parameters"] = snowflake_parameters
            if spark_parameters is not None:
                self._values["spark_parameters"] = spark_parameters
            if sql_server_parameters is not None:
                self._values["sql_server_parameters"] = sql_server_parameters
            if teradata_parameters is not None:
                self._values["teradata_parameters"] = teradata_parameters

        @builtins.property
        def amazon_elasticsearch_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.AmazonElasticsearchParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for OpenSearch.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonelasticsearchparameters
            '''
            result = self._values.get("amazon_elasticsearch_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.AmazonElasticsearchParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def amazon_open_search_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.AmazonOpenSearchParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for OpenSearch.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonopensearchparameters
            '''
            result = self._values.get("amazon_open_search_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.AmazonOpenSearchParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def athena_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.AthenaParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Amazon Athena.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-athenaparameters
            '''
            result = self._values.get("athena_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.AthenaParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def aurora_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.AuroraParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Amazon Aurora MySQL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-auroraparameters
            '''
            result = self._values.get("aurora_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.AuroraParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def aurora_postgre_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.AuroraPostgreSqlParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Amazon Aurora.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-aurorapostgresqlparameters
            '''
            result = self._values.get("aurora_postgre_sql_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.AuroraPostgreSqlParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def databricks_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.DatabricksParametersProperty", _IResolvable_a771d0ef]]:
            '''The required parameters that are needed to connect to a Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-databricksparameters
            '''
            result = self._values.get("databricks_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.DatabricksParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maria_db_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.MariaDbParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for MariaDB.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mariadbparameters
            '''
            result = self._values.get("maria_db_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.MariaDbParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def my_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.MySqlParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for MySQL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mysqlparameters
            '''
            result = self._values.get("my_sql_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.MySqlParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def oracle_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.OracleParametersProperty", _IResolvable_a771d0ef]]:
            '''Oracle parameters.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-oracleparameters
            '''
            result = self._values.get("oracle_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.OracleParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def postgre_sql_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.PostgreSqlParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for PostgreSQL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-postgresqlparameters
            '''
            result = self._values.get("postgre_sql_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.PostgreSqlParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def presto_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.PrestoParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Presto.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-prestoparameters
            '''
            result = self._values.get("presto_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.PrestoParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rds_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.RdsParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Amazon RDS.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-rdsparameters
            '''
            result = self._values.get("rds_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.RdsParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def redshift_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.RedshiftParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Amazon Redshift.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-redshiftparameters
            '''
            result = self._values.get("redshift_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.RedshiftParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def s3_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.S3ParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for S3.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-s3parameters
            '''
            result = self._values.get("s3_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.S3ParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def snowflake_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.SnowflakeParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Snowflake.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-snowflakeparameters
            '''
            result = self._values.get("snowflake_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.SnowflakeParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def spark_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.SparkParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Spark.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sparkparameters
            '''
            result = self._values.get("spark_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.SparkParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sql_server_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.SqlServerParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for SQL Server.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sqlserverparameters
            '''
            result = self._values.get("sql_server_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.SqlServerParametersProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def teradata_parameters(
            self,
        ) -> typing.Optional[typing.Union["CfnDataSource.TeradataParametersProperty", _IResolvable_a771d0ef]]:
            '''The parameters for Teradata.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-teradataparameters
            '''
            result = self._values.get("teradata_parameters")
            return typing.cast(typing.Optional[typing.Union["CfnDataSource.TeradataParametersProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSourceParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.DatabricksParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "host": "host",
            "port": "port",
            "sql_endpoint_path": "sqlEndpointPath",
        },
    )
    class DatabricksParametersProperty:
        def __init__(
            self,
            *,
            host: builtins.str,
            port: jsii.Number,
            sql_endpoint_path: builtins.str,
        ) -> None:
            '''The required parameters that are needed to connect to a Databricks data source.

            :param host: The host name of the Databricks data source.
            :param port: The port for the Databricks data source.
            :param sql_endpoint_path: The HTTP path of the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                databricks_parameters_property = quicksight.CfnDataSource.DatabricksParametersProperty(
                    host="host",
                    port=123,
                    sql_endpoint_path="sqlEndpointPath"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b94e11c88398b55ace7936b2d79553efd6867932364ced9f504fa9f5970440b)
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
                check_type(argname="argument sql_endpoint_path", value=sql_endpoint_path, expected_type=type_hints["sql_endpoint_path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "host": host,
                "port": port,
                "sql_endpoint_path": sql_endpoint_path,
            }

        @builtins.property
        def host(self) -> builtins.str:
            '''The host name of the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''The port for the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def sql_endpoint_path(self) -> builtins.str:
            '''The HTTP path of the Databricks data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-sqlendpointpath
            '''
            result = self._values.get("sql_endpoint_path")
            assert result is not None, "Required property 'sql_endpoint_path' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DatabricksParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.ManifestFileLocationProperty",
        jsii_struct_bases=[],
        name_mapping={"bucket": "bucket", "key": "key"},
    )
    class ManifestFileLocationProperty:
        def __init__(self, *, bucket: builtins.str, key: builtins.str) -> None:
            '''Amazon S3 manifest file location.

            :param bucket: Amazon S3 bucket.
            :param key: Amazon S3 key that identifies an object.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                manifest_file_location_property = quicksight.CfnDataSource.ManifestFileLocationProperty(
                    bucket="bucket",
                    key="key"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da51ed98eb626db1b2fb46039a1a507b288e80a0769ab12c5327f6375a5977d9)
                check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
                check_type(argname="argument key", value=key, expected_type=type_hints["key"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "bucket": bucket,
                "key": key,
            }

        @builtins.property
        def bucket(self) -> builtins.str:
            '''Amazon S3 bucket.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-bucket
            '''
            result = self._values.get("bucket")
            assert result is not None, "Required property 'bucket' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def key(self) -> builtins.str:
            '''Amazon S3 key that identifies an object.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-key
            '''
            result = self._values.get("key")
            assert result is not None, "Required property 'key' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ManifestFileLocationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.MariaDbParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class MariaDbParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for MariaDB.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maria_db_parameters_property = quicksight.CfnDataSource.MariaDbParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__be3b31ea0873feba21927daa4f9822cc75eeff4e97f1bdf4c1a2973537eb6373)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MariaDbParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.MySqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class MySqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for MySQL.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                my_sql_parameters_property = quicksight.CfnDataSource.MySqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__949a9d305a46722ed2684a273a58c9fc4673894e14d306bf9fb6fa66528a06d0)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MySqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.OracleParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class OracleParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''Oracle parameters.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                oracle_parameters_property = quicksight.CfnDataSource.OracleParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__122af4d0adcdda159b17c0e6de101f1077f9ecccbe4d2d9e01c502203d9709bb)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "OracleParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.PostgreSqlParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class PostgreSqlParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for PostgreSQL.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                postgre_sql_parameters_property = quicksight.CfnDataSource.PostgreSqlParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9289c9c8d412ef412498f69f97cdb57d46a9aac6c4849032cb71410ef593bf4e)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PostgreSqlParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.PrestoParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"catalog": "catalog", "host": "host", "port": "port"},
    )
    class PrestoParametersProperty:
        def __init__(
            self,
            *,
            catalog: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for Presto.

            :param catalog: Catalog.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                presto_parameters_property = quicksight.CfnDataSource.PrestoParametersProperty(
                    catalog="catalog",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9d296fcfbcb689fd276cccacc82918f7f20d166eaf1dd94ae523d668d7a92b5)
                check_type(argname="argument catalog", value=catalog, expected_type=type_hints["catalog"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "catalog": catalog,
                "host": host,
                "port": port,
            }

        @builtins.property
        def catalog(self) -> builtins.str:
            '''Catalog.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-catalog
            '''
            result = self._values.get("catalog")
            assert result is not None, "Required property 'catalog' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PrestoParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.RdsParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "instance_id": "instanceId"},
    )
    class RdsParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            instance_id: builtins.str,
        ) -> None:
            '''The parameters for Amazon RDS.

            :param database: Database.
            :param instance_id: Instance ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                rds_parameters_property = quicksight.CfnDataSource.RdsParametersProperty(
                    database="database",
                    instance_id="instanceId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f62c76a31e25da9e67e8ab77a08b73b8fdcb2ebfb750d7ba7f18e15abf1b846a)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "instance_id": instance_id,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def instance_id(self) -> builtins.str:
            '''Instance ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-instanceid
            '''
            result = self._values.get("instance_id")
            assert result is not None, "Required property 'instance_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RdsParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.RedshiftParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "database": "database",
            "cluster_id": "clusterId",
            "host": "host",
            "port": "port",
        },
    )
    class RedshiftParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            cluster_id: typing.Optional[builtins.str] = None,
            host: typing.Optional[builtins.str] = None,
            port: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The parameters for Amazon Redshift.

            The ``ClusterId`` field can be blank if ``Host`` and ``Port`` are both set. The ``Host`` and ``Port`` fields can be blank if the ``ClusterId`` field is set.

            :param database: Database.
            :param cluster_id: Cluster ID. This field can be blank if the ``Host`` and ``Port`` are provided.
            :param host: Host. This field can be blank if ``ClusterId`` is provided.
            :param port: Port. This field can be blank if the ``ClusterId`` is provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                redshift_parameters_property = quicksight.CfnDataSource.RedshiftParametersProperty(
                    database="database",
                
                    # the properties below are optional
                    cluster_id="clusterId",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d681dc5c2b5906e42f74a3d74d81d8fdc22b644d9d898effe4191cae18d0968a)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
            }
            if cluster_id is not None:
                self._values["cluster_id"] = cluster_id
            if host is not None:
                self._values["host"] = host
            if port is not None:
                self._values["port"] = port

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cluster_id(self) -> typing.Optional[builtins.str]:
            '''Cluster ID.

            This field can be blank if the ``Host`` and ``Port`` are provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-clusterid
            '''
            result = self._values.get("cluster_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def host(self) -> typing.Optional[builtins.str]:
            '''Host.

            This field can be blank if ``ClusterId`` is provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-host
            '''
            result = self._values.get("host")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def port(self) -> typing.Optional[jsii.Number]:
            '''Port.

            This field can be blank if the ``ClusterId`` is provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-port
            '''
            result = self._values.get("port")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RedshiftParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnDataSource.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d8ba2637641ae79129ccc101dedb746820207e3e6771202fcb6053bf798fc1c)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.S3ParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"manifest_file_location": "manifestFileLocation"},
    )
    class S3ParametersProperty:
        def __init__(
            self,
            *,
            manifest_file_location: typing.Union[typing.Union["CfnDataSource.ManifestFileLocationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The parameters for S3.

            :param manifest_file_location: Location of the Amazon S3 manifest file. This is NULL if the manifest file was uploaded into Amazon QuickSight.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                s3_parameters_property = quicksight.CfnDataSource.S3ParametersProperty(
                    manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                        bucket="bucket",
                        key="key"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2220bc18a3b550bd8bbe9884783e7dcc70a6d97fa288c61ef81e81c7e218abd6)
                check_type(argname="argument manifest_file_location", value=manifest_file_location, expected_type=type_hints["manifest_file_location"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "manifest_file_location": manifest_file_location,
            }

        @builtins.property
        def manifest_file_location(
            self,
        ) -> typing.Union["CfnDataSource.ManifestFileLocationProperty", _IResolvable_a771d0ef]:
            '''Location of the Amazon S3 manifest file.

            This is NULL if the manifest file was uploaded into Amazon QuickSight.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-manifestfilelocation
            '''
            result = self._values.get("manifest_file_location")
            assert result is not None, "Required property 'manifest_file_location' is missing"
            return typing.cast(typing.Union["CfnDataSource.ManifestFileLocationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "S3ParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.SnowflakeParametersProperty",
        jsii_struct_bases=[],
        name_mapping={
            "database": "database",
            "host": "host",
            "warehouse": "warehouse",
        },
    )
    class SnowflakeParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            warehouse: builtins.str,
        ) -> None:
            '''The parameters for Snowflake.

            :param database: Database.
            :param host: Host.
            :param warehouse: Warehouse.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                snowflake_parameters_property = quicksight.CfnDataSource.SnowflakeParametersProperty(
                    database="database",
                    host="host",
                    warehouse="warehouse"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0cd90d69c367729964c97dbdd087458e1cf75795a6ee637c2f247e1f75a4c75e)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument warehouse", value=warehouse, expected_type=type_hints["warehouse"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "warehouse": warehouse,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def warehouse(self) -> builtins.str:
            '''Warehouse.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-warehouse
            '''
            result = self._values.get("warehouse")
            assert result is not None, "Required property 'warehouse' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SnowflakeParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.SparkParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"host": "host", "port": "port"},
    )
    class SparkParametersProperty:
        def __init__(self, *, host: builtins.str, port: jsii.Number) -> None:
            '''The parameters for Spark.

            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                spark_parameters_property = quicksight.CfnDataSource.SparkParametersProperty(
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f0fb62f442d8b8e6f75b1f480fd2e88b6cac336309c3524b6f59fc03dfd15dd8)
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "host": host,
                "port": port,
            }

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SparkParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.SqlServerParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class SqlServerParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for SQL Server.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sql_server_parameters_property = quicksight.CfnDataSource.SqlServerParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac01cba832bc02b452cf6a71bb3db3d8378dd4fbba57dd250e691fd23739fdaf)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SqlServerParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.SslPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"disable_ssl": "disableSsl"},
    )
    class SslPropertiesProperty:
        def __init__(
            self,
            *,
            disable_ssl: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying data source.

            :param disable_ssl: A Boolean option to control whether SSL should be disabled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                ssl_properties_property = quicksight.CfnDataSource.SslPropertiesProperty(
                    disable_ssl=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8b4cdd1a954c0db9fa5845dd75420a9ef237bd66cf3f657e106c4ad8ae12557)
                check_type(argname="argument disable_ssl", value=disable_ssl, expected_type=type_hints["disable_ssl"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if disable_ssl is not None:
                self._values["disable_ssl"] = disable_ssl

        @builtins.property
        def disable_ssl(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''A Boolean option to control whether SSL should be disabled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html#cfn-quicksight-datasource-sslproperties-disablessl
            '''
            result = self._values.get("disable_ssl")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SslPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.TeradataParametersProperty",
        jsii_struct_bases=[],
        name_mapping={"database": "database", "host": "host", "port": "port"},
    )
    class TeradataParametersProperty:
        def __init__(
            self,
            *,
            database: builtins.str,
            host: builtins.str,
            port: jsii.Number,
        ) -> None:
            '''The parameters for Teradata.

            :param database: Database.
            :param host: Host.
            :param port: Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                teradata_parameters_property = quicksight.CfnDataSource.TeradataParametersProperty(
                    database="database",
                    host="host",
                    port=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__08bcc91fd1330bd9ae822b9d535599fcb0daabd309c89eb18b2dcf886d8c5c7c)
                check_type(argname="argument database", value=database, expected_type=type_hints["database"])
                check_type(argname="argument host", value=host, expected_type=type_hints["host"])
                check_type(argname="argument port", value=port, expected_type=type_hints["port"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "database": database,
                "host": host,
                "port": port,
            }

        @builtins.property
        def database(self) -> builtins.str:
            '''Database.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-database
            '''
            result = self._values.get("database")
            assert result is not None, "Required property 'database' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def host(self) -> builtins.str:
            '''Host.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-host
            '''
            result = self._values.get("host")
            assert result is not None, "Required property 'host' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def port(self) -> jsii.Number:
            '''Port.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-port
            '''
            result = self._values.get("port")
            assert result is not None, "Required property 'port' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TeradataParametersProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnDataSource.VpcConnectionPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={"vpc_connection_arn": "vpcConnectionArn"},
    )
    class VpcConnectionPropertiesProperty:
        def __init__(self, *, vpc_connection_arn: builtins.str) -> None:
            '''VPC connection properties.

            :param vpc_connection_arn: The Amazon Resource Name (ARN) for the VPC connection.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                vpc_connection_properties_property = quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                    vpc_connection_arn="vpcConnectionArn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf4d4dcdc5ae539af50f23da19ba530dc5ec59840155436251424130b5bcd2e0)
                check_type(argname="argument vpc_connection_arn", value=vpc_connection_arn, expected_type=type_hints["vpc_connection_arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "vpc_connection_arn": vpc_connection_arn,
            }

        @builtins.property
        def vpc_connection_arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) for the VPC connection.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html#cfn-quicksight-datasource-vpcconnectionproperties-vpcconnectionarn
            '''
            result = self._values.get("vpc_connection_arn")
            assert result is not None, "Required property 'vpc_connection_arn' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VpcConnectionPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnDataSourceProps",
    jsii_struct_bases=[],
    name_mapping={
        "alternate_data_source_parameters": "alternateDataSourceParameters",
        "aws_account_id": "awsAccountId",
        "credentials": "credentials",
        "data_source_id": "dataSourceId",
        "data_source_parameters": "dataSourceParameters",
        "error_info": "errorInfo",
        "name": "name",
        "permissions": "permissions",
        "ssl_properties": "sslProperties",
        "tags": "tags",
        "type": "type",
        "vpc_connection_properties": "vpcConnectionProperties",
    },
)
class CfnDataSourceProps:
    def __init__(
        self,
        *,
        alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        credentials: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        data_source_id: typing.Optional[builtins.str] = None,
        data_source_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        error_info: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ssl_properties: typing.Optional[typing.Union[typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        type: typing.Optional[builtins.str] = None,
        vpc_connection_properties: typing.Optional[typing.Union[typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    ) -> None:
        '''Properties for defining a ``CfnDataSource``.

        :param alternate_data_source_parameters: A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.
        :param aws_account_id: The AWS account ID.
        :param credentials: The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
        :param data_source_id: An ID for the data source. This ID is unique per AWS Region for each AWS account.
        :param data_source_parameters: The parameters that Amazon QuickSight uses to connect to your underlying source.
        :param error_info: Error information from the last update or the creation of the data source.
        :param name: A display name for the data source.
        :param permissions: A list of resource permissions on the data source.
        :param ssl_properties: Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
        :param type: The type of the data source. To return a list of all data sources, use ``ListDataSources`` . Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.
        :param vpc_connection_properties: Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            cfn_data_source_props = quicksight.CfnDataSourceProps(
                alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
            
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        )
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    )
                )],
                aws_account_id="awsAccountId",
                credentials=quicksight.CfnDataSource.DataSourceCredentialsProperty(
                    copy_source_arn="copySourceArn",
                    credential_pair=quicksight.CfnDataSource.CredentialPairProperty(
                        password="password",
                        username="username",
            
                        # the properties below are optional
                        alternate_data_source_parameters=[quicksight.CfnDataSource.DataSourceParametersProperty(
                            amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                                domain="domain"
                            ),
                            amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                                domain="domain"
                            ),
                            athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                                work_group="workGroup"
                            ),
                            aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                                host="host",
                                port=123,
                                sql_endpoint_path="sqlEndpointPath"
                            ),
                            maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                                catalog="catalog",
                                host="host",
                                port=123
                            ),
                            rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                                database="database",
                                instance_id="instanceId"
                            ),
                            redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                                database="database",
            
                                # the properties below are optional
                                cluster_id="clusterId",
                                host="host",
                                port=123
                            ),
                            s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                                manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                                    bucket="bucket",
                                    key="key"
                                )
                            ),
                            snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                                database="database",
                                host="host",
                                warehouse="warehouse"
                            ),
                            spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                                host="host",
                                port=123
                            ),
                            sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            ),
                            teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                                database="database",
                                host="host",
                                port=123
                            )
                        )]
                    ),
                    secret_arn="secretArn"
                ),
                data_source_id="dataSourceId",
                data_source_parameters=quicksight.CfnDataSource.DataSourceParametersProperty(
                    amazon_elasticsearch_parameters=quicksight.CfnDataSource.AmazonElasticsearchParametersProperty(
                        domain="domain"
                    ),
                    amazon_open_search_parameters=quicksight.CfnDataSource.AmazonOpenSearchParametersProperty(
                        domain="domain"
                    ),
                    athena_parameters=quicksight.CfnDataSource.AthenaParametersProperty(
                        work_group="workGroup"
                    ),
                    aurora_parameters=quicksight.CfnDataSource.AuroraParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    aurora_postgre_sql_parameters=quicksight.CfnDataSource.AuroraPostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    databricks_parameters=quicksight.CfnDataSource.DatabricksParametersProperty(
                        host="host",
                        port=123,
                        sql_endpoint_path="sqlEndpointPath"
                    ),
                    maria_db_parameters=quicksight.CfnDataSource.MariaDbParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    my_sql_parameters=quicksight.CfnDataSource.MySqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    oracle_parameters=quicksight.CfnDataSource.OracleParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    postgre_sql_parameters=quicksight.CfnDataSource.PostgreSqlParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    presto_parameters=quicksight.CfnDataSource.PrestoParametersProperty(
                        catalog="catalog",
                        host="host",
                        port=123
                    ),
                    rds_parameters=quicksight.CfnDataSource.RdsParametersProperty(
                        database="database",
                        instance_id="instanceId"
                    ),
                    redshift_parameters=quicksight.CfnDataSource.RedshiftParametersProperty(
                        database="database",
            
                        # the properties below are optional
                        cluster_id="clusterId",
                        host="host",
                        port=123
                    ),
                    s3_parameters=quicksight.CfnDataSource.S3ParametersProperty(
                        manifest_file_location=quicksight.CfnDataSource.ManifestFileLocationProperty(
                            bucket="bucket",
                            key="key"
                        )
                    ),
                    snowflake_parameters=quicksight.CfnDataSource.SnowflakeParametersProperty(
                        database="database",
                        host="host",
                        warehouse="warehouse"
                    ),
                    spark_parameters=quicksight.CfnDataSource.SparkParametersProperty(
                        host="host",
                        port=123
                    ),
                    sql_server_parameters=quicksight.CfnDataSource.SqlServerParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    ),
                    teradata_parameters=quicksight.CfnDataSource.TeradataParametersProperty(
                        database="database",
                        host="host",
                        port=123
                    )
                ),
                error_info=quicksight.CfnDataSource.DataSourceErrorInfoProperty(
                    message="message",
                    type="type"
                ),
                name="name",
                permissions=[quicksight.CfnDataSource.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                ssl_properties=quicksight.CfnDataSource.SslPropertiesProperty(
                    disable_ssl=False
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                type="type",
                vpc_connection_properties=quicksight.CfnDataSource.VpcConnectionPropertiesProperty(
                    vpc_connection_arn="vpcConnectionArn"
                )
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fc0aa356c3689030299b81aad1fcec24aec9ccd94c8ed08f7a5d309a2402678a)
            check_type(argname="argument alternate_data_source_parameters", value=alternate_data_source_parameters, expected_type=type_hints["alternate_data_source_parameters"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument credentials", value=credentials, expected_type=type_hints["credentials"])
            check_type(argname="argument data_source_id", value=data_source_id, expected_type=type_hints["data_source_id"])
            check_type(argname="argument data_source_parameters", value=data_source_parameters, expected_type=type_hints["data_source_parameters"])
            check_type(argname="argument error_info", value=error_info, expected_type=type_hints["error_info"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument ssl_properties", value=ssl_properties, expected_type=type_hints["ssl_properties"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            check_type(argname="argument vpc_connection_properties", value=vpc_connection_properties, expected_type=type_hints["vpc_connection_properties"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if alternate_data_source_parameters is not None:
            self._values["alternate_data_source_parameters"] = alternate_data_source_parameters
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if credentials is not None:
            self._values["credentials"] = credentials
        if data_source_id is not None:
            self._values["data_source_id"] = data_source_id
        if data_source_parameters is not None:
            self._values["data_source_parameters"] = data_source_parameters
        if error_info is not None:
            self._values["error_info"] = error_info
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if ssl_properties is not None:
            self._values["ssl_properties"] = ssl_properties
        if tags is not None:
            self._values["tags"] = tags
        if type is not None:
            self._values["type"] = type
        if vpc_connection_properties is not None:
            self._values["vpc_connection_properties"] = vpc_connection_properties

    @builtins.property
    def alternate_data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSource.DataSourceParametersProperty, _IResolvable_a771d0ef]]]]:
        '''A set of alternate data source parameters that you want to share for the credentials stored with this data source.

        The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the ``DataSourceParameters`` structure that's in the request with the structures in the ``AlternateDataSourceParameters`` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the ``AlternateDataSourceParameters`` list is null, the ``Credentials`` originally used with this ``DataSourceParameters`` are automatically allowed.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
        '''
        result = self._values.get("alternate_data_source_parameters")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSource.DataSourceParametersProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def credentials(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSource.DataSourceCredentialsProperty, _IResolvable_a771d0ef]]:
        '''The credentials Amazon QuickSight that uses to connect to your underlying source.

        Currently, only credentials based on user name and password are supported.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
        '''
        result = self._values.get("credentials")
        return typing.cast(typing.Optional[typing.Union[CfnDataSource.DataSourceCredentialsProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def data_source_id(self) -> typing.Optional[builtins.str]:
        '''An ID for the data source.

        This ID is unique per AWS Region for each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
        '''
        result = self._values.get("data_source_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_source_parameters(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSource.DataSourceParametersProperty, _IResolvable_a771d0ef]]:
        '''The parameters that Amazon QuickSight uses to connect to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
        '''
        result = self._values.get("data_source_parameters")
        return typing.cast(typing.Optional[typing.Union[CfnDataSource.DataSourceParametersProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def error_info(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSource.DataSourceErrorInfoProperty, _IResolvable_a771d0ef]]:
        '''Error information from the last update or the creation of the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
        '''
        result = self._values.get("error_info")
        return typing.cast(typing.Optional[typing.Union[CfnDataSource.DataSourceErrorInfoProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSource.ResourcePermissionProperty, _IResolvable_a771d0ef]]]]:
        '''A list of resource permissions on the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSource.ResourcePermissionProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def ssl_properties(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSource.SslPropertiesProperty, _IResolvable_a771d0ef]]:
        '''Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
        '''
        result = self._values.get("ssl_properties")
        return typing.cast(typing.Optional[typing.Union[CfnDataSource.SslPropertiesProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    @builtins.property
    def type(self) -> typing.Optional[builtins.str]:
        '''The type of the data source. To return a list of all data sources, use ``ListDataSources`` .

        Use ``AMAZON_ELASTICSEARCH`` for Amazon OpenSearch Service.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
        '''
        result = self._values.get("type")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def vpc_connection_properties(
        self,
    ) -> typing.Optional[typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, _IResolvable_a771d0ef]]:
        '''Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
        '''
        result = self._values.get("vpc_connection_properties")
        return typing.cast(typing.Optional[typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, _IResolvable_a771d0ef]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnDataSourceProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnRefreshSchedule(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnRefreshSchedule",
):
    '''A CloudFormation ``AWS::QuickSight::RefreshSchedule``.

    Creates a refresh schedule for a dataset in Amazon QuickSight .

    :cloudformationResource: AWS::QuickSight::RefreshSchedule
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        cfn_refresh_schedule = quicksight.CfnRefreshSchedule(self, "MyCfnRefreshSchedule",
            aws_account_id="awsAccountId",
            data_set_id="dataSetId",
            schedule=quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                refresh_type="refreshType",
                schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                    interval="interval",
                    refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                        day_of_month="dayOfMonth",
                        day_of_week="dayOfWeek"
                    ),
                    time_of_the_day="timeOfTheDay",
                    time_zone="timeZone"
                ),
                schedule_id="scheduleId",
                start_after_date_time="startAfterDateTime"
            )
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        schedule: typing.Optional[typing.Union[typing.Union["CfnRefreshSchedule.RefreshScheduleMapProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::RefreshSchedule``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The AWS account ID of the account that you are creating a schedule in.
        :param data_set_id: The ID of the dataset that you are creating a refresh schedule for.
        :param schedule: The refresh schedule of a dataset.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2cb98577ae0aa5fa792462e9b70cd9e6244aef13c152842e033a79d126e5ed49)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnRefreshScheduleProps(
            aws_account_id=aws_account_id, data_set_id=data_set_id, schedule=schedule
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__cedca9f24cc89ee50e4bcb185db3fa7e33511058aae57df76fd6979709a3130f)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a613aedd91cf4c27b92b858b2778574c61520dfbb1055d1f9646fbe195f333b9)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) for the refresh schedule.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account that you are creating a schedule in.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6dcda8ff88ed183aa8a9f876be4110750dce0d9207db65e4758537f4cb0c7bde)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSetId")
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the dataset that you are creating a refresh schedule for.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-datasetid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dataSetId"))

    @data_set_id.setter
    def data_set_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0f2432e0f85abc089d7642bf01eae839cd8befc96b6ac1cedc64c1294ccdca5f)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dataSetId", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(
        self,
    ) -> typing.Optional[typing.Union["CfnRefreshSchedule.RefreshScheduleMapProperty", _IResolvable_a771d0ef]]:
        '''The refresh schedule of a dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-schedule
        '''
        return typing.cast(typing.Optional[typing.Union["CfnRefreshSchedule.RefreshScheduleMapProperty", _IResolvable_a771d0ef]], jsii.get(self, "schedule"))

    @schedule.setter
    def schedule(
        self,
        value: typing.Optional[typing.Union["CfnRefreshSchedule.RefreshScheduleMapProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__126e6a64cbde64eebc0cd5b7e30bcbae9ebaee18670b88c858d354c5fdea6288)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "schedule", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnRefreshSchedule.RefreshOnDayProperty",
        jsii_struct_bases=[],
        name_mapping={"day_of_month": "dayOfMonth", "day_of_week": "dayOfWeek"},
    )
    class RefreshOnDayProperty:
        def __init__(
            self,
            *,
            day_of_month: typing.Optional[builtins.str] = None,
            day_of_week: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The day that you want yout dataset to refresh.

            :param day_of_month: The day of the month that you want your dataset to refresh. This value is required for monthly refresh intervals.
            :param day_of_week: The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                refresh_on_day_property = quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                    day_of_month="dayOfMonth",
                    day_of_week="dayOfWeek"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__afba7e37a976d3acd9ed3ae5b0019ddc7ae613723af911fee427edf967f4a0a6)
                check_type(argname="argument day_of_month", value=day_of_month, expected_type=type_hints["day_of_month"])
                check_type(argname="argument day_of_week", value=day_of_week, expected_type=type_hints["day_of_week"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if day_of_month is not None:
                self._values["day_of_month"] = day_of_month
            if day_of_week is not None:
                self._values["day_of_week"] = day_of_week

        @builtins.property
        def day_of_month(self) -> typing.Optional[builtins.str]:
            '''The day of the month that you want your dataset to refresh.

            This value is required for monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofmonth
            '''
            result = self._values.get("day_of_month")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def day_of_week(self) -> typing.Optional[builtins.str]:
            '''The day of the week that you want to schedule the refresh on.

            This value is required for weekly and monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshonday.html#cfn-quicksight-refreshschedule-refreshonday-dayofweek
            '''
            result = self._values.get("day_of_week")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshOnDayProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty",
        jsii_struct_bases=[],
        name_mapping={
            "refresh_type": "refreshType",
            "schedule_frequency": "scheduleFrequency",
            "schedule_id": "scheduleId",
            "start_after_date_time": "startAfterDateTime",
        },
    )
    class RefreshScheduleMapProperty:
        def __init__(
            self,
            *,
            refresh_type: typing.Optional[builtins.str] = None,
            schedule_frequency: typing.Optional[typing.Union[typing.Union["CfnRefreshSchedule.ScheduleFrequencyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            schedule_id: typing.Optional[builtins.str] = None,
            start_after_date_time: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A summary of a configured refresh schedule for a dataset.

            :param refresh_type: The type of refresh that a dataset undergoes. Valid values are as follows:. - ``FULL_REFRESH`` : A complete refresh of a dataset. - ``INCREMENTAL_REFRESH`` : A partial refresh of some rows of a dataset, based on the time window specified. For more information on full and incremental refreshes, see `Refreshing SPICE data <https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html>`_ in the *Amazon QuickSight User Guide* .
            :param schedule_frequency: The frequency for the refresh schedule.
            :param schedule_id: An identifier for the refresh schedule.
            :param start_after_date_time: Time after which the refresh schedule can be started, expressed in ``YYYY-MM-DDTHH:MM:SS`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                refresh_schedule_map_property = quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                    refresh_type="refreshType",
                    schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                        interval="interval",
                        refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                            day_of_month="dayOfMonth",
                            day_of_week="dayOfWeek"
                        ),
                        time_of_the_day="timeOfTheDay",
                        time_zone="timeZone"
                    ),
                    schedule_id="scheduleId",
                    start_after_date_time="startAfterDateTime"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bdbba0c66aa208f475da2eccc8b33c90f217300dc3acd2a62838794ae59cbb08)
                check_type(argname="argument refresh_type", value=refresh_type, expected_type=type_hints["refresh_type"])
                check_type(argname="argument schedule_frequency", value=schedule_frequency, expected_type=type_hints["schedule_frequency"])
                check_type(argname="argument schedule_id", value=schedule_id, expected_type=type_hints["schedule_id"])
                check_type(argname="argument start_after_date_time", value=start_after_date_time, expected_type=type_hints["start_after_date_time"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if refresh_type is not None:
                self._values["refresh_type"] = refresh_type
            if schedule_frequency is not None:
                self._values["schedule_frequency"] = schedule_frequency
            if schedule_id is not None:
                self._values["schedule_id"] = schedule_id
            if start_after_date_time is not None:
                self._values["start_after_date_time"] = start_after_date_time

        @builtins.property
        def refresh_type(self) -> typing.Optional[builtins.str]:
            '''The type of refresh that a dataset undergoes. Valid values are as follows:.

            - ``FULL_REFRESH`` : A complete refresh of a dataset.
            - ``INCREMENTAL_REFRESH`` : A partial refresh of some rows of a dataset, based on the time window specified.

            For more information on full and incremental refreshes, see `Refreshing SPICE data <https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-refreshtype
            '''
            result = self._values.get("refresh_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def schedule_frequency(
            self,
        ) -> typing.Optional[typing.Union["CfnRefreshSchedule.ScheduleFrequencyProperty", _IResolvable_a771d0ef]]:
            '''The frequency for the refresh schedule.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-schedulefrequency
            '''
            result = self._values.get("schedule_frequency")
            return typing.cast(typing.Optional[typing.Union["CfnRefreshSchedule.ScheduleFrequencyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def schedule_id(self) -> typing.Optional[builtins.str]:
            '''An identifier for the refresh schedule.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-scheduleid
            '''
            result = self._values.get("schedule_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_after_date_time(self) -> typing.Optional[builtins.str]:
            '''Time after which the refresh schedule can be started, expressed in ``YYYY-MM-DDTHH:MM:SS`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-refreshschedulemap.html#cfn-quicksight-refreshschedule-refreshschedulemap-startafterdatetime
            '''
            result = self._values.get("start_after_date_time")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RefreshScheduleMapProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interval": "interval",
            "refresh_on_day": "refreshOnDay",
            "time_of_the_day": "timeOfTheDay",
            "time_zone": "timeZone",
        },
    )
    class ScheduleFrequencyProperty:
        def __init__(
            self,
            *,
            interval: typing.Optional[builtins.str] = None,
            refresh_on_day: typing.Optional[typing.Union[typing.Union["CfnRefreshSchedule.RefreshOnDayProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_of_the_day: typing.Optional[builtins.str] = None,
            time_zone: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The frequency for the refresh schedule.

            :param interval: The interval between scheduled refreshes. Valid values are as follows:. - ``MINUTE15`` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset. - ``MINUTE30`` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset. - ``HOURLY`` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset. - ``DAILY`` : The dataset refreshes every day. - ``WEEKLY`` : The dataset refreshes every week. - ``MONTHLY`` : The dataset refreshes every month.
            :param refresh_on_day: The day of the week that you want to schedule the refresh on. This value is required for weekly and monthly refresh intervals.
            :param time_of_the_day: The time of day that you want the dataset to refresh. This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.
            :param time_zone: The timezone that you want the refresh schedule to use. The timezone ID must match a corresponding ID found on ``java.util.time.getAvailableIDs()`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                schedule_frequency_property = quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                    interval="interval",
                    refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                        day_of_month="dayOfMonth",
                        day_of_week="dayOfWeek"
                    ),
                    time_of_the_day="timeOfTheDay",
                    time_zone="timeZone"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04f6ba7ad2f0fff1eaa90fd7b374909c222d4545d0fdf370bcc096978077ea00)
                check_type(argname="argument interval", value=interval, expected_type=type_hints["interval"])
                check_type(argname="argument refresh_on_day", value=refresh_on_day, expected_type=type_hints["refresh_on_day"])
                check_type(argname="argument time_of_the_day", value=time_of_the_day, expected_type=type_hints["time_of_the_day"])
                check_type(argname="argument time_zone", value=time_zone, expected_type=type_hints["time_zone"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interval is not None:
                self._values["interval"] = interval
            if refresh_on_day is not None:
                self._values["refresh_on_day"] = refresh_on_day
            if time_of_the_day is not None:
                self._values["time_of_the_day"] = time_of_the_day
            if time_zone is not None:
                self._values["time_zone"] = time_zone

        @builtins.property
        def interval(self) -> typing.Optional[builtins.str]:
            '''The interval between scheduled refreshes. Valid values are as follows:.

            - ``MINUTE15`` : The dataset refreshes every 15 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
            - ``MINUTE30`` : The dataset refreshes every 30 minutes. This value is only supported for incremental refreshes. This interval can only be used for one schedule per dataset.
            - ``HOURLY`` : The dataset refreshes every hour. This interval can only be used for one schedule per dataset.
            - ``DAILY`` : The dataset refreshes every day.
            - ``WEEKLY`` : The dataset refreshes every week.
            - ``MONTHLY`` : The dataset refreshes every month.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-interval
            '''
            result = self._values.get("interval")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def refresh_on_day(
            self,
        ) -> typing.Optional[typing.Union["CfnRefreshSchedule.RefreshOnDayProperty", _IResolvable_a771d0ef]]:
            '''The day of the week that you want to schedule the refresh on.

            This value is required for weekly and monthly refresh intervals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-refreshonday
            '''
            result = self._values.get("refresh_on_day")
            return typing.cast(typing.Optional[typing.Union["CfnRefreshSchedule.RefreshOnDayProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_of_the_day(self) -> typing.Optional[builtins.str]:
            '''The time of day that you want the dataset to refresh.

            This value is expressed in HH:MM format. This field is not required for schedules that refresh hourly.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timeoftheday
            '''
            result = self._values.get("time_of_the_day")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_zone(self) -> typing.Optional[builtins.str]:
            '''The timezone that you want the refresh schedule to use.

            The timezone ID must match a corresponding ID found on ``java.util.time.getAvailableIDs()`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-refreshschedule-schedulefrequency.html#cfn-quicksight-refreshschedule-schedulefrequency-timezone
            '''
            result = self._values.get("time_zone")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScheduleFrequencyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnRefreshScheduleProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "data_set_id": "dataSetId",
        "schedule": "schedule",
    },
)
class CfnRefreshScheduleProps:
    def __init__(
        self,
        *,
        aws_account_id: typing.Optional[builtins.str] = None,
        data_set_id: typing.Optional[builtins.str] = None,
        schedule: typing.Optional[typing.Union[typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    ) -> None:
        '''Properties for defining a ``CfnRefreshSchedule``.

        :param aws_account_id: The AWS account ID of the account that you are creating a schedule in.
        :param data_set_id: The ID of the dataset that you are creating a refresh schedule for.
        :param schedule: The refresh schedule of a dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            cfn_refresh_schedule_props = quicksight.CfnRefreshScheduleProps(
                aws_account_id="awsAccountId",
                data_set_id="dataSetId",
                schedule=quicksight.CfnRefreshSchedule.RefreshScheduleMapProperty(
                    refresh_type="refreshType",
                    schedule_frequency=quicksight.CfnRefreshSchedule.ScheduleFrequencyProperty(
                        interval="interval",
                        refresh_on_day=quicksight.CfnRefreshSchedule.RefreshOnDayProperty(
                            day_of_month="dayOfMonth",
                            day_of_week="dayOfWeek"
                        ),
                        time_of_the_day="timeOfTheDay",
                        time_zone="timeZone"
                    ),
                    schedule_id="scheduleId",
                    start_after_date_time="startAfterDateTime"
                )
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ea32cc2d0bb94e945c49fd8ec5363a4703069033ad264025a5a966ac11f7d302)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument data_set_id", value=data_set_id, expected_type=type_hints["data_set_id"])
            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if data_set_id is not None:
            self._values["data_set_id"] = data_set_id
        if schedule is not None:
            self._values["schedule"] = schedule

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account that you are creating a schedule in.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def data_set_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the dataset that you are creating a refresh schedule for.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-datasetid
        '''
        result = self._values.get("data_set_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def schedule(
        self,
    ) -> typing.Optional[typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, _IResolvable_a771d0ef]]:
        '''The refresh schedule of a dataset.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-refreshschedule.html#cfn-quicksight-refreshschedule-schedule
        '''
        result = self._values.get("schedule")
        return typing.cast(typing.Optional[typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, _IResolvable_a771d0ef]], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnRefreshScheduleProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnTemplate(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnTemplate",
):
    '''A CloudFormation ``AWS::QuickSight::Template``.

    Creates a template from an existing Amazon QuickSight analysis or template. You can use the resulting template to create a dashboard.

    A *template* is an entity in Amazon QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.

    :cloudformationResource: AWS::QuickSight::Template
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        # data_driven: Any
        
        cfn_template = quicksight.CfnTemplate(self, "MyCfnTemplate",
            aws_account_id="awsAccountId",
            template_id="templateId",
        
            # the properties below are optional
            definition=quicksight.CfnTemplate.TemplateVersionDefinitionProperty(
                data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                    column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                        column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                            name="name"
                        )],
                        name="name"
                    )],
                    data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                        column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                            data_type="dataType",
                            geographic_role="geographicRole",
                            name="name"
                        )]
                    ),
                    placeholder="placeholder"
                )],
        
                # the properties below are optional
                analysis_defaults=quicksight.CfnTemplate.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                ),
                calculated_fields=[quicksight.CfnTemplate.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )],
                column_configurations=[quicksight.CfnTemplate.ColumnConfigurationProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
        
                    # the properties below are optional
                    colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                            color="color",
        
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )],
                filter_groups=[quicksight.CfnTemplate.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnTemplate.FilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
        
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
        
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
        
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
        
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
        
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
        
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
        
                    # the properties below are optional
                    status="status"
                )],
                parameter_declarations=[quicksight.CfnTemplate.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                        name="name",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
        
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
        
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
        
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )],
                sheets=[quicksight.CfnTemplate.SheetDefinitionProperty(
                    sheet_id="sheetId",
        
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnTemplate.LayoutProperty(
                        configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
        
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
        
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
        
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
        
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
        
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                        configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
        
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
        
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
        
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
        
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnTemplate.VisualProperty(
                        bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                computations=[quicksight.CfnTemplate.ComputationProperty(
                                    forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
        
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
        
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
        
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
        
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
        
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
        
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnTemplate.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
        
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnTemplate.TableVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
        
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
        
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
        
                                        # the properties below are optional
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
        
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
        
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
        
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
        
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
        
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
        
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
        
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
        
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                            visual_id="visualId",
        
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
        
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
        
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
        
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
        
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
        
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )]
            ),
            name="name",
            permissions=[quicksight.CfnTemplate.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal",
        
                # the properties below are optional
                resource="resource"
            )],
            source_entity=quicksight.CfnTemplate.TemplateSourceEntityProperty(
                source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                ),
                source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                    arn="arn"
                )
            ),
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        template_id: builtins.str,
        definition: typing.Optional[typing.Union[typing.Union["CfnTemplate.TemplateVersionDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        source_entity: typing.Optional[typing.Union[typing.Union["CfnTemplate.TemplateSourceEntityProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Template``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
        :param template_id: An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
        :param definition: ``AWS::QuickSight::Template.Definition``.
        :param name: A display name for the template.
        :param permissions: A list of resource permissions to be set on the template.
        :param source_entity: The entity that you are using as a source when you create the template. In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
        :param version_description: A description of the current template version being created. This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__c4084f68e91f3572eab4f41fd7ae4ba2d978302797741b347ca022b7c4f2b268)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnTemplateProps(
            aws_account_id=aws_account_id,
            template_id=template_id,
            definition=definition,
            name=name,
            permissions=permissions,
            source_entity=source_entity,
            tags=tags,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__f434abfce74fa9db644d0cdb158fc4d477f3195b7547ebbd0c6a6beac8bfa468)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__69f3549d4979025b08bcafac59dd4f61e8c1b5202351c2754e35a19d1999eecc)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the template.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time this template was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time this template was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDataSetConfigurations")
    def attr_version_data_set_configurations(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.DataSetConfigurations
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionDataSetConfigurations"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSheets")
    def attr_version_sheets(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.Sheets
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionSheets"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionSourceEntityArn")
    def attr_version_source_entity_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.SourceEntityArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionSourceEntityArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionThemeArn")
    def attr_version_theme_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.ThemeArn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionThemeArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID for the AWS account that the group is in.

        You use the ID for the AWS account that contains your Amazon QuickSight account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3e87cf21a3226da5edc284966da8cc60b0955f3d8985f51a9e116c4393ada70c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="templateId")
    def template_id(self) -> builtins.str:
        '''An ID for the template that you want to create.

        This template is unique per AWS Region ; in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
        '''
        return typing.cast(builtins.str, jsii.get(self, "templateId"))

    @template_id.setter
    def template_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dd72d25d1868a71c8a014f6df04e9732ff666709d3657be269b917f6684156fa)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "templateId", value)

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(
        self,
    ) -> typing.Optional[typing.Union["CfnTemplate.TemplateVersionDefinitionProperty", _IResolvable_a771d0ef]]:
        '''``AWS::QuickSight::Template.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
        '''
        return typing.cast(typing.Optional[typing.Union["CfnTemplate.TemplateVersionDefinitionProperty", _IResolvable_a771d0ef]], jsii.get(self, "definition"))

    @definition.setter
    def definition(
        self,
        value: typing.Optional[typing.Union["CfnTemplate.TemplateVersionDefinitionProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__52b656d928c8196c5277586852abb25e7ef493b0791b877ce4f5b949f35f547c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2c6be0670201afea3006abaab464bf3165bd4ecb2d4c115ca74a16a410ad8aa3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ResourcePermissionProperty", _IResolvable_a771d0ef]]]]:
        '''A list of resource permissions to be set on the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ResourcePermissionProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ResourcePermissionProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__398a1395b884bedc1e304f6a693e4015f76baf9cb79f766789eedd537b279992)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEntity")
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union["CfnTemplate.TemplateSourceEntityProperty", _IResolvable_a771d0ef]]:
        '''The entity that you are using as a source when you create the template.

        In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
        '''
        return typing.cast(typing.Optional[typing.Union["CfnTemplate.TemplateSourceEntityProperty", _IResolvable_a771d0ef]], jsii.get(self, "sourceEntity"))

    @source_entity.setter
    def source_entity(
        self,
        value: typing.Optional[typing.Union["CfnTemplate.TemplateSourceEntityProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3442f652ffc3117b277a39aa52f6750ace3d44bd0baed921ce633c78ff1bf2d9)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "sourceEntity", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the current template version being created.

        This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__636062ca9a7cb9788d19bb62fa92dcace11ecde08bb509f69b30c2f41ec8cca3)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_aggregation_function": "categoricalAggregationFunction",
            "date_aggregation_function": "dateAggregationFunction",
            "numerical_aggregation_function": "numericalAggregationFunction",
        },
    )
    class AggregationFunctionProperty:
        def __init__(
            self,
            *,
            categorical_aggregation_function: typing.Optional[builtins.str] = None,
            date_aggregation_function: typing.Optional[builtins.str] = None,
            numerical_aggregation_function: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''An aggregation function aggregates values from a dimension or measure.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param categorical_aggregation_function: Aggregation for categorical values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            :param date_aggregation_function: Aggregation for date values. - ``COUNT`` : Aggregate by the total number of values, including duplicates. - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values. - ``MIN`` : Select the smallest date value. - ``MAX`` : Select the largest date value.
            :param numerical_aggregation_function: Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aggregation_function_property = quicksight.CfnTemplate.AggregationFunctionProperty(
                    categorical_aggregation_function="categoricalAggregationFunction",
                    date_aggregation_function="dateAggregationFunction",
                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1bdccf1f0dcd5bd9bcf4f53f1908aecf55fb8632ac968542ad9ee6e3a6c5665)
                check_type(argname="argument categorical_aggregation_function", value=categorical_aggregation_function, expected_type=type_hints["categorical_aggregation_function"])
                check_type(argname="argument date_aggregation_function", value=date_aggregation_function, expected_type=type_hints["date_aggregation_function"])
                check_type(argname="argument numerical_aggregation_function", value=numerical_aggregation_function, expected_type=type_hints["numerical_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_aggregation_function is not None:
                self._values["categorical_aggregation_function"] = categorical_aggregation_function
            if date_aggregation_function is not None:
                self._values["date_aggregation_function"] = date_aggregation_function
            if numerical_aggregation_function is not None:
                self._values["numerical_aggregation_function"] = numerical_aggregation_function

        @builtins.property
        def categorical_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for categorical values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-categoricalaggregationfunction
            '''
            result = self._values.get("categorical_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def date_aggregation_function(self) -> typing.Optional[builtins.str]:
            '''Aggregation for date values.

            - ``COUNT`` : Aggregate by the total number of values, including duplicates.
            - ``DISTINCT_COUNT`` : Aggregate by the total number of distinct values.
            - ``MIN`` : Select the smallest date value.
            - ``MAX`` : Select the largest date value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-dateaggregationfunction
            '''
            result = self._values.get("date_aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def numerical_aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''Aggregation for numerical values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-numericalaggregationfunction
            '''
            result = self._values.get("numerical_aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AggregationSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_function": "aggregationFunction",
            "column": "column",
            "sort_direction": "sortDirection",
        },
    )
    class AggregationSortConfigurationProperty:
        def __init__(
            self,
            *,
            aggregation_function: typing.Union[typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            sort_direction: builtins.str,
        ) -> None:
            '''The configuration options to sort aggregated values.

            :param aggregation_function: The function that aggregates the values in ``Column`` .
            :param column: The column that determines the sort order of aggregated values.
            :param sort_direction: The sort direction of values. - ``ASC`` : Sort in ascending order. - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                aggregation_sort_configuration_property = quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    sort_direction="sortDirection"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__18a0d31e2b2f0002dacf73bdd15e71d4247ea285a4611f98680e8f5996b94c88)
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument sort_direction", value=sort_direction, expected_type=type_hints["sort_direction"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_function": aggregation_function,
                "column": column,
                "sort_direction": sort_direction,
            }

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The function that aggregates the values in ``Column`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            assert result is not None, "Required property 'aggregation_function' is missing"
            return typing.cast(typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that determines the sort order of aggregated values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def sort_direction(self) -> builtins.str:
            '''The sort direction of values.

            - ``ASC`` : Sort in ascending order.
            - ``DESC`` : Sort in descending order.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-sortdirection
            '''
            result = self._values.get("sort_direction")
            assert result is not None, "Required property 'sort_direction' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AggregationSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AnalysisDefaultsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_new_sheet_configuration": "defaultNewSheetConfiguration",
        },
    )
    class AnalysisDefaultsProperty:
        def __init__(
            self,
            *,
            default_new_sheet_configuration: typing.Union[typing.Union["CfnTemplate.DefaultNewSheetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The configuration for default analysis settings.

            :param default_new_sheet_configuration: The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                analysis_defaults_property = quicksight.CfnTemplate.AnalysisDefaultsProperty(
                    default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                        interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                            free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        ),
                        paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                            section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                )
                            )
                        ),
                        sheet_content_type="sheetContentType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f10853e1006ca2badbc4299fb0b8f0e7a4506d94142a85cbeceb83d99ceb5669)
                check_type(argname="argument default_new_sheet_configuration", value=default_new_sheet_configuration, expected_type=type_hints["default_new_sheet_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_new_sheet_configuration": default_new_sheet_configuration,
            }

        @builtins.property
        def default_new_sheet_configuration(
            self,
        ) -> typing.Union["CfnTemplate.DefaultNewSheetConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration for default new sheet settings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html#cfn-quicksight-template-analysisdefaults-defaultnewsheetconfiguration
            '''
            result = self._values.get("default_new_sheet_configuration")
            assert result is not None, "Required property 'default_new_sheet_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.DefaultNewSheetConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnalysisDefaultsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AnchorDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_option": "anchorOption",
            "parameter_name": "parameterName",
        },
    )
    class AnchorDateConfigurationProperty:
        def __init__(
            self,
            *,
            anchor_option: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The date configuration of the filter.

            :param anchor_option: The options for the date configuration. Choose one of the options below:. - ``NOW``
            :param parameter_name: The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                anchor_date_configuration_property = quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                    anchor_option="anchorOption",
                    parameter_name="parameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20be54004759a6aa92d19fa29de2fc07af124cc330cf2532f1150d4d012618aa)
                check_type(argname="argument anchor_option", value=anchor_option, expected_type=type_hints["anchor_option"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if anchor_option is not None:
                self._values["anchor_option"] = anchor_option
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name

        @builtins.property
        def anchor_option(self) -> typing.Optional[builtins.str]:
            '''The options for the date configuration. Choose one of the options below:.

            - ``NOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-anchoroption
            '''
            result = self._values.get("anchor_option")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The name of the parameter that is used for the anchor date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AnchorDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ArcAxisConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "reserve_range": "reserveRange"},
    )
    class ArcAxisConfigurationProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[typing.Union["CfnTemplate.ArcAxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reserve_range: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :param range: The arc axis range of a ``GaugeChartVisual`` .
            :param reserve_range: The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_axis_configuration_property = quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                    range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                        max=123,
                        min=123
                    ),
                    reserve_range=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__18b10f73dc38e4053a4531bb5a8482499cade0f259cd01430c3dbc1470e640b2)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument reserve_range", value=reserve_range, expected_type=type_hints["reserve_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if reserve_range is not None:
                self._values["reserve_range"] = reserve_range

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ArcAxisDisplayRangeProperty", _IResolvable_a771d0ef]]:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ArcAxisDisplayRangeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reserve_range(self) -> typing.Optional[jsii.Number]:
            '''The reserved range of the arc axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-reserverange
            '''
            result = self._values.get("reserve_range")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ArcAxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"max": "max", "min": "min"},
    )
    class ArcAxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            max: typing.Optional[jsii.Number] = None,
            min: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The arc axis range of a ``GaugeChartVisual`` .

            :param max: The maximum value of the arc axis range.
            :param min: The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_axis_display_range_property = quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                    max=123,
                    min=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__62f6e1a9d8aac070cc5e158f9317886e34b0f0d497327952dc68136e971e2c45)
                check_type(argname="argument max", value=max, expected_type=type_hints["max"])
                check_type(argname="argument min", value=min, expected_type=type_hints["min"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max is not None:
                self._values["max"] = max
            if min is not None:
                self._values["min"] = min

        @builtins.property
        def max(self) -> typing.Optional[jsii.Number]:
            '''The maximum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-max
            '''
            result = self._values.get("max")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def min(self) -> typing.Optional[jsii.Number]:
            '''The minimum value of the arc axis range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-min
            '''
            result = self._values.get("min")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcAxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ArcConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_angle": "arcAngle", "arc_thickness": "arcThickness"},
    )
    class ArcConfigurationProperty:
        def __init__(
            self,
            *,
            arc_angle: typing.Optional[jsii.Number] = None,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :param arc_angle: The option that determines the arc angle of a ``GaugeChartVisual`` .
            :param arc_thickness: The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_configuration_property = quicksight.CfnTemplate.ArcConfigurationProperty(
                    arc_angle=123,
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77de119c90dc6ba2a062c588003bca92c3b71e773a42569448a90b654691b8ba)
                check_type(argname="argument arc_angle", value=arc_angle, expected_type=type_hints["arc_angle"])
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_angle is not None:
                self._values["arc_angle"] = arc_angle
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_angle(self) -> typing.Optional[jsii.Number]:
            '''The option that determines the arc angle of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcangle
            '''
            result = self._values.get("arc_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ArcOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"arc_thickness": "arcThickness"},
    )
    class ArcOptionsProperty:
        def __init__(
            self,
            *,
            arc_thickness: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the arc thickness of a ``GaugeChartVisual`` .

            :param arc_thickness: The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                arc_options_property = quicksight.CfnTemplate.ArcOptionsProperty(
                    arc_thickness="arcThickness"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc0811c9cfb7816023854b1ea9bb883826372ca532b95874475751ddce5ecc9c)
                check_type(argname="argument arc_thickness", value=arc_thickness, expected_type=type_hints["arc_thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_thickness is not None:
                self._values["arc_thickness"] = arc_thickness

        @builtins.property
        def arc_thickness(self) -> typing.Optional[builtins.str]:
            '''The arc thickness of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html#cfn-quicksight-template-arcoptions-arcthickness
            '''
            result = self._values.get("arc_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ArcOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisDataOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_axis_options": "dateAxisOptions",
            "numeric_axis_options": "numericAxisOptions",
        },
    )
    class AxisDataOptionsProperty:
        def __init__(
            self,
            *,
            date_axis_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_axis_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericAxisOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data options for an axis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_axis_options: The options for an axis with a date field.
            :param numeric_axis_options: The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_data_options_property = quicksight.CfnTemplate.AxisDataOptionsProperty(
                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                        missing_date_visibility="missingDateVisibility"
                    ),
                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                            data_driven=data_driven,
                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                maximum=123,
                                minimum=123
                            )
                        ),
                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                step_count=123,
                                step_size=123
                            ),
                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                base=123
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dfb1c97b40be91160807bf4b49d709ec27830a05f1b10512e5bd6c09fb947947)
                check_type(argname="argument date_axis_options", value=date_axis_options, expected_type=type_hints["date_axis_options"])
                check_type(argname="argument numeric_axis_options", value=numeric_axis_options, expected_type=type_hints["numeric_axis_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_axis_options is not None:
                self._values["date_axis_options"] = date_axis_options
            if numeric_axis_options is not None:
                self._values["numeric_axis_options"] = numeric_axis_options

        @builtins.property
        def date_axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateAxisOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for an axis with a date field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-dateaxisoptions
            '''
            result = self._values.get("date_axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateAxisOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericAxisOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for an axis with a numeric field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-numericaxisoptions
            '''
            result = self._values.get("numeric_axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericAxisOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDataOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"maximum": "maximum", "minimum": "minimum"},
    )
    class AxisDisplayMinMaxRangeProperty:
        def __init__(
            self,
            *,
            maximum: typing.Optional[jsii.Number] = None,
            minimum: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The minimum and maximum setup for an axis display range.

            :param maximum: The maximum setup for an axis display range.
            :param minimum: The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_display_min_max_range_property = quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                    maximum=123,
                    minimum=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f3f6d84656f78abc74fc514401551e83d638c829bfaff00c48e6f9aa2ff3f69e)
                check_type(argname="argument maximum", value=maximum, expected_type=type_hints["maximum"])
                check_type(argname="argument minimum", value=minimum, expected_type=type_hints["minimum"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if maximum is not None:
                self._values["maximum"] = maximum
            if minimum is not None:
                self._values["minimum"] = minimum

        @builtins.property
        def maximum(self) -> typing.Optional[jsii.Number]:
            '''The maximum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-maximum
            '''
            result = self._values.get("maximum")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def minimum(self) -> typing.Optional[jsii.Number]:
            '''The minimum setup for an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-minimum
            '''
            result = self._values.get("minimum")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayMinMaxRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_line_visibility": "axisLineVisibility",
            "axis_offset": "axisOffset",
            "data_options": "dataOptions",
            "grid_line_visibility": "gridLineVisibility",
            "scrollbar_options": "scrollbarOptions",
            "tick_label_options": "tickLabelOptions",
        },
    )
    class AxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_line_visibility: typing.Optional[builtins.str] = None,
            axis_offset: typing.Optional[builtins.str] = None,
            data_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDataOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid_line_visibility: typing.Optional[builtins.str] = None,
            scrollbar_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ScrollBarOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tick_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisTickLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for the axis label.

            :param axis_line_visibility: Determines whether or not the axis line is visible.
            :param axis_offset: The offset value that determines the starting placement of the axis within a visual's bounds.
            :param data_options: The data options for an axis.
            :param grid_line_visibility: Determines whether or not the grid line is visible.
            :param scrollbar_options: The scroll bar options for an axis.
            :param tick_label_options: The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_options_property = quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                    axis_line_visibility="axisLineVisibility",
                    axis_offset="axisOffset",
                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                            missing_date_visibility="missingDateVisibility"
                        ),
                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                data_driven=data_driven,
                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                    maximum=123,
                                    minimum=123
                                )
                            ),
                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                    step_count=123,
                                    step_size=123
                                ),
                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                    base=123
                                )
                            )
                        )
                    ),
                    grid_line_visibility="gridLineVisibility",
                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                        visibility="visibility",
                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                from=123,
                                to=123
                            )
                        )
                    ),
                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        rotation_angle=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6fe1eaca5b226525925c17234fe4b739ccf632902ebe9b9bf1b58c313e55587c)
                check_type(argname="argument axis_line_visibility", value=axis_line_visibility, expected_type=type_hints["axis_line_visibility"])
                check_type(argname="argument axis_offset", value=axis_offset, expected_type=type_hints["axis_offset"])
                check_type(argname="argument data_options", value=data_options, expected_type=type_hints["data_options"])
                check_type(argname="argument grid_line_visibility", value=grid_line_visibility, expected_type=type_hints["grid_line_visibility"])
                check_type(argname="argument scrollbar_options", value=scrollbar_options, expected_type=type_hints["scrollbar_options"])
                check_type(argname="argument tick_label_options", value=tick_label_options, expected_type=type_hints["tick_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_line_visibility is not None:
                self._values["axis_line_visibility"] = axis_line_visibility
            if axis_offset is not None:
                self._values["axis_offset"] = axis_offset
            if data_options is not None:
                self._values["data_options"] = data_options
            if grid_line_visibility is not None:
                self._values["grid_line_visibility"] = grid_line_visibility
            if scrollbar_options is not None:
                self._values["scrollbar_options"] = scrollbar_options
            if tick_label_options is not None:
                self._values["tick_label_options"] = tick_label_options

        @builtins.property
        def axis_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the axis line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axislinevisibility
            '''
            result = self._values.get("axis_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def axis_offset(self) -> typing.Optional[builtins.str]:
            '''The offset value that determines the starting placement of the axis within a visual's bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axisoffset
            '''
            result = self._values.get("axis_offset")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDataOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-dataoptions
            '''
            result = self._values.get("data_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDataOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid_line_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the grid line is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-gridlinevisibility
            '''
            result = self._values.get("grid_line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scrollbar_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ScrollBarOptionsProperty", _IResolvable_a771d0ef]]:
            '''The scroll bar options for an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-scrollbaroptions
            '''
            result = self._values.get("scrollbar_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ScrollBarOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tick_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisTickLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tick label options of an axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-ticklabeloptions
            '''
            result = self._values.get("tick_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisTickLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisDisplayRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"data_driven": "dataDriven", "min_max": "minMax"},
    )
    class AxisDisplayRangeProperty:
        def __init__(
            self,
            *,
            data_driven: typing.Any = None,
            min_max: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayMinMaxRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The range setup of a numeric axis display range.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_driven: The data-driven setup of an axis display range.
            :param min_max: The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                axis_display_range_property = quicksight.CfnTemplate.AxisDisplayRangeProperty(
                    data_driven=data_driven,
                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                        maximum=123,
                        minimum=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24e901885d9106af77d2d29866a49259ae74fb93b0396d99ed1ca314e380410d)
                check_type(argname="argument data_driven", value=data_driven, expected_type=type_hints["data_driven"])
                check_type(argname="argument min_max", value=min_max, expected_type=type_hints["min_max"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_driven is not None:
                self._values["data_driven"] = data_driven
            if min_max is not None:
                self._values["min_max"] = min_max

        @builtins.property
        def data_driven(self) -> typing.Any:
            '''The data-driven setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-datadriven
            '''
            result = self._values.get("data_driven")
            return typing.cast(typing.Any, result)

        @builtins.property
        def min_max(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayMinMaxRangeProperty", _IResolvable_a771d0ef]]:
            '''The minimum and maximum setup of an axis display range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-minmax
            '''
            result = self._values.get("min_max")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayMinMaxRangeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisDisplayRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "apply_to": "applyTo",
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
        },
    )
    class AxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            apply_to: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisLabelReferenceOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The label options for a chart axis.

            You must specify the field that the label is targeted to.

            :param apply_to: The options that indicate which field the label belongs to.
            :param custom_label: The text for the axis label.
            :param font_configuration: The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_label_options_property = quicksight.CfnTemplate.AxisLabelOptionsProperty(
                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId"
                    ),
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6cbd43f2b9505f14714c944ba6992a8032c5df3dfab606e6512123f1b0bec122)
                check_type(argname="argument apply_to", value=apply_to, expected_type=type_hints["apply_to"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if apply_to is not None:
                self._values["apply_to"] = apply_to
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration

        @builtins.property
        def apply_to(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisLabelReferenceOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that indicate which field the label belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-applyto
            '''
            result = self._values.get("apply_to")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisLabelReferenceOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "field_id": "fieldId"},
    )
    class AxisLabelReferenceOptionsProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
        ) -> None:
            '''The reference that specifies where the axis label is applied to.

            :param column: The column that the axis label is targeted to.
            :param field_id: The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_label_reference_options_property = quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22276746e68baf66ceb6c3c35a812be33a6863226f9ddf8c60251007476ecae0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field that the axis label is targeted to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLabelReferenceOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisLinearScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"step_count": "stepCount", "step_size": "stepSize"},
    )
    class AxisLinearScaleProperty:
        def __init__(
            self,
            *,
            step_count: typing.Optional[jsii.Number] = None,
            step_size: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The liner axis scale setup.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param step_count: The step count setup of a linear axis.
            :param step_size: The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_linear_scale_property = quicksight.CfnTemplate.AxisLinearScaleProperty(
                    step_count=123,
                    step_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd52f6ca8ba88f59ef9aacaf9219e39df02db598199a578ec9483fb611b7a6a9)
                check_type(argname="argument step_count", value=step_count, expected_type=type_hints["step_count"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if step_count is not None:
                self._values["step_count"] = step_count
            if step_size is not None:
                self._values["step_size"] = step_size

        @builtins.property
        def step_count(self) -> typing.Optional[jsii.Number]:
            '''The step count setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepcount
            '''
            result = self._values.get("step_count")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def step_size(self) -> typing.Optional[jsii.Number]:
            '''The step size setup of a linear axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepsize
            '''
            result = self._values.get("step_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLinearScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisLogarithmicScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"base": "base"},
    )
    class AxisLogarithmicScaleProperty:
        def __init__(self, *, base: typing.Optional[jsii.Number] = None) -> None:
            '''The logarithmic axis scale setup.

            :param base: The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_logarithmic_scale_property = quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                    base=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__07851c3a73e1ee39155acb28217c43ede081fe5692f81bb7276ff636c805b7af)
                check_type(argname="argument base", value=base, expected_type=type_hints["base"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base is not None:
                self._values["base"] = base

        @builtins.property
        def base(self) -> typing.Optional[jsii.Number]:
            '''The base setup of a logarithmic axis scale.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html#cfn-quicksight-template-axislogarithmicscale-base
            '''
            result = self._values.get("base")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisLogarithmicScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisScaleProperty",
        jsii_struct_bases=[],
        name_mapping={"linear": "linear", "logarithmic": "logarithmic"},
    )
    class AxisScaleProperty:
        def __init__(
            self,
            *,
            linear: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisLinearScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            logarithmic: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisLogarithmicScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The scale setup options for a numeric axis display.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param linear: The linear axis scale setup.
            :param logarithmic: The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_scale_property = quicksight.CfnTemplate.AxisScaleProperty(
                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                        step_count=123,
                        step_size=123
                    ),
                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                        base=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__00219b67351dfde76642e0aee1ee541183be99929ece3d64ed1b84c763f4fc5b)
                check_type(argname="argument linear", value=linear, expected_type=type_hints["linear"])
                check_type(argname="argument logarithmic", value=logarithmic, expected_type=type_hints["logarithmic"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if linear is not None:
                self._values["linear"] = linear
            if logarithmic is not None:
                self._values["logarithmic"] = logarithmic

        @builtins.property
        def linear(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisLinearScaleProperty", _IResolvable_a771d0ef]]:
            '''The linear axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-linear
            '''
            result = self._values.get("linear")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisLinearScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def logarithmic(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisLogarithmicScaleProperty", _IResolvable_a771d0ef]]:
            '''The logarithmic axis scale setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-logarithmic
            '''
            result = self._values.get("logarithmic")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisLogarithmicScaleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.AxisTickLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "label_options": "labelOptions",
            "rotation_angle": "rotationAngle",
        },
    )
    class AxisTickLabelOptionsProperty:
        def __init__(
            self,
            *,
            label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rotation_angle: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The tick label options of an axis.

            :param label_options: Determines whether or not the axis ticks are visible.
            :param rotation_angle: The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                axis_tick_label_options_property = quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    rotation_angle=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__82f154a04ad11f8e09877e6d05a3a223513b0d9ac1411da770aa6bf9866addcb)
                check_type(argname="argument label_options", value=label_options, expected_type=type_hints["label_options"])
                check_type(argname="argument rotation_angle", value=rotation_angle, expected_type=type_hints["rotation_angle"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_options is not None:
                self._values["label_options"] = label_options
            if rotation_angle is not None:
                self._values["rotation_angle"] = rotation_angle

        @builtins.property
        def label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines whether or not the axis ticks are visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-labeloptions
            '''
            result = self._values.get("label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rotation_angle(self) -> typing.Optional[jsii.Number]:
            '''The rotation angle of the axis tick labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-rotationangle
            '''
            result = self._values.get("rotation_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "AxisTickLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class BarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a bar chart.

            :param category: The category (y-axis) field well of a bar chart.
            :param colors: The color (group/color) field well of a bar chart.
            :param small_multiples: The small multiples field well of a bar chart.
            :param values: The value field wells of a bar chart. Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_aggregated_field_wells_property = quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5b82dff70bd87c3d3385a4298ffee85c687bcf9e2508e907cadd74d72d6ba235)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category (y-axis) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color (group/color) field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a bar chart.

            Values are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "orientation": "orientation",
            "reference_lines": "referenceLines",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_axis": "valueAxis",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class BarChartConfigurationProperty:
        def __init__(
            self,
            *,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.BarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            orientation: typing.Optional[builtins.str] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.BarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``BarChartVisual`` .

            :param bars_arrangement: Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) for bar chart category.
            :param category_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart.
            :param color_label_options: The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param orientation: The orientation of the bars in a bar chart visual. There are two valid values in this structure:. - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts. - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
            :param reference_lines: The reference line setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a ``BarChartVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param value_axis: The label display options (grid line, range, scale, axis step) for a bar chart value.
            :param value_label_options: The label options (label text, label visibility and sort icon visibility) for a bar chart value.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_configuration_property = quicksight.CfnTemplate.BarChartConfigurationProperty(
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                        bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    orientation="orientation",
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__169a7c867586c038eef0332b0659ed70146d9ed9fe662e75dd2487823108c69e)
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_axis", value=value_axis, expected_type=type_hints["value_axis"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if orientation is not None:
                self._values["orientation"] = orientation
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_axis is not None:
                self._values["value_axis"] = value_axis
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the arrangement of the bars.

            The orientation and arrangement of bars determine the type of bar that is used in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) for bar chart category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BarChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BarChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation of the bars in a bar chart visual. There are two valid values in this structure:.

            - ``HORIZONTAL`` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
            - ``VERTICAL`` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BarChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``BarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BarChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valueaxis
            '''
            result = self._values.get("value_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) for a bar chart value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_aggregated_field_wells": "barChartAggregatedFieldWells",
        },
    )
    class BarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.BarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``BarChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_aggregated_field_wells: The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_field_wells_property = quicksight.CfnTemplate.BarChartFieldWellsProperty(
                    bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__756fa076bd6e83208a6f665863c9b33d066c89d803544653816cc47443201666)
                check_type(argname="argument bar_chart_aggregated_field_wells", value=bar_chart_aggregated_field_wells, expected_type=type_hints["bar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_aggregated_field_wells is not None:
                self._values["bar_chart_aggregated_field_wells"] = bar_chart_aggregated_field_wells

        @builtins.property
        def bar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html#cfn-quicksight-template-barchartfieldwells-barchartaggregatedfieldwells
            '''
            result = self._values.get("bar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class BarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''sort-configuration-description.

            :param category_items_limit: The limit on the number of categories displayed in a bar chart.
            :param category_sort: The sort configuration of category fields.
            :param color_items_limit: The limit on the number of values displayed in a bar chart.
            :param color_sort: The sort configuration of color fields in a bar chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bar_chart_sort_configuration_property = quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71cb0d75d58325803e6870b0f6631c3b13d205cc9aa9c1f5666ba17ee6b604d8)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of values displayed in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of color fields in a bar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.BarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A bar chart.

            The ``BarChartVisual`` structure describes a visual that is a member of the bar chart family. The following charts can be described using this structure:

            - Horizontal bar chart
            - Vertical bar chart
            - Horizontal stacked bar chart
            - Vertical stacked bar chart
            - Horizontal stacked 100% bar chart
            - Vertical stacked 100% bar chart

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                bar_chart_visual_property = quicksight.CfnTemplate.BarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                            bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        orientation="orientation",
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32c54f780a85fa4229aec418a20f60ddb7b5b674bbb5a302c5b72dac6de275cf)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BarChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BarChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BinCountOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class BinCountOptionsProperty:
        def __init__(self, *, value: typing.Optional[jsii.Number] = None) -> None:
            '''The options that determine the bin count of a histogram.

            :param value: The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bin_count_options_property = quicksight.CfnTemplate.BinCountOptionsProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90048ed633a0e6a782fc21039b508d81512c87d9d9b87fb3fb8751464b29ddfe)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html#cfn-quicksight-template-bincountoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinCountOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BinWidthOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bin_count_limit": "binCountLimit", "value": "value"},
    )
    class BinWidthOptionsProperty:
        def __init__(
            self,
            *,
            bin_count_limit: typing.Optional[jsii.Number] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the bin width of a histogram.

            :param bin_count_limit: The options that determine the bin count limit.
            :param value: The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                bin_width_options_property = quicksight.CfnTemplate.BinWidthOptionsProperty(
                    bin_count_limit=123,
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4617f3dacdfb99eb1ef5442fb799bbeb72b687299c31e5ae5fbcf9bc5c465e5c)
                check_type(argname="argument bin_count_limit", value=bin_count_limit, expected_type=type_hints["bin_count_limit"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count_limit is not None:
                self._values["bin_count_limit"] = bin_count_limit
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def bin_count_limit(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin count limit.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-bincountlimit
            '''
            result = self._values.get("bin_count_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin width value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BinWidthOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BodySectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content": "content",
            "section_id": "sectionId",
            "page_break_configuration": "pageBreakConfiguration",
            "style": "style",
        },
    )
    class BodySectionConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[typing.Union["CfnTemplate.BodySectionContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            section_id: builtins.str,
            page_break_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionPageBreakConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            style: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a body section.

            :param content: The configuration of content in a body section.
            :param section_id: The unique identifier of a body section.
            :param page_break_configuration: The configuration of a page break for a section.
            :param style: The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                body_section_configuration_property = quicksight.CfnTemplate.BodySectionConfigurationProperty(
                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                            status="status"
                        )
                    ),
                    style=quicksight.CfnTemplate.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__978cba332a167e332ea6ca3bc3e43f00c5a3cb0679e1ae81ef7cacfaedb5da50)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument page_break_configuration", value=page_break_configuration, expected_type=type_hints["page_break_configuration"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "section_id": section_id,
            }
            if page_break_configuration is not None:
                self._values["page_break_configuration"] = page_break_configuration
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def content(
            self,
        ) -> typing.Union["CfnTemplate.BodySectionContentProperty", _IResolvable_a771d0ef]:
            '''The configuration of content in a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union["CfnTemplate.BodySectionContentProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def page_break_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionPageBreakConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a page break for a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-pagebreakconfiguration
            '''
            result = self._values.get("page_break_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionPageBreakConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionStyleProperty", _IResolvable_a771d0ef]]:
            '''The style options of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BodySectionContentProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout"},
    )
    class BodySectionContentProperty:
        def __init__(
            self,
            *,
            layout: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of content in a body section.

            :param layout: The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                body_section_content_property = quicksight.CfnTemplate.BodySectionContentProperty(
                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ebe06d9b1a380c53f29828799ecde6f950060ba022ffe3802fc06bef1df342eb)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if layout is not None:
                self._values["layout"] = layout

        @builtins.property
        def layout(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The layout configuration of a body section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html#cfn-quicksight-template-bodysectioncontent-layout
            '''
            result = self._values.get("layout")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BodySectionContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class BoxPlotAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for a box plot.

            :param group_by: The group by field well of a box plot chart. Values are grouped based on group by fields.
            :param values: The value field well of a box plot chart. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_aggregated_field_wells_property = quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__623ee8b2624567b44113291afc9ed116dd3b14ea92a8485e4f5831ac37e9fa39)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a box plot chart.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field well of a box plot chart.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_options": "boxPlotOptions",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class BoxPlotChartConfigurationProperty:
        def __init__(
            self,
            *,
            box_plot_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``BoxPlotVisual`` .

            :param box_plot_options: The box plot chart options for a box plot visual.
            :param category_axis: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param category_label_options: The label options (label text, label visibility and sort Icon visibility) of a box plot category.
            :param field_wells: The field wells of the visual.
            :param legend: ``CfnTemplate.BoxPlotChartConfigurationProperty.Legend``.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a box plot category.
            :param primary_y_axis_label_options: The label options (label text, label visibility and sort icon visibility) of a box plot value.
            :param reference_lines: The reference line setup of the visual.
            :param sort_configuration: The sort configuration of a ``BoxPlotVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_chart_configuration_property = quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                    box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                        all_data_points_visibility="allDataPointsVisibility",
                        outlier_visibility="outlierVisibility",
                        style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                            fill_style="fillStyle"
                        )
                    ),
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                        box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        )
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3a971963c7b8a89f1df9de38c2af8f42dc4908164b782451efc2bd444759b4d)
                check_type(argname="argument box_plot_options", value=box_plot_options, expected_type=type_hints["box_plot_options"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_options is not None:
                self._values["box_plot_options"] = box_plot_options
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def box_plot_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotOptionsProperty", _IResolvable_a771d0ef]]:
            '''The box plot chart options for a box plot visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-boxplotoptions
            '''
            result = self._values.get("box_plot_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort Icon visibility) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.BoxPlotChartConfigurationProperty.Legend``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a box plot category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility and sort icon visibility) of a box plot value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "box_plot_aggregated_field_wells": "boxPlotAggregatedFieldWells",
        },
    )
    class BoxPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            box_plot_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``BoxPlotVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param box_plot_aggregated_field_wells: The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_field_wells_property = quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2efdc8f9cf941d1fb67cb15dc0c00dcac5fc6b80b4172156ad8cb98a78fc6061)
                check_type(argname="argument box_plot_aggregated_field_wells", value=box_plot_aggregated_field_wells, expected_type=type_hints["box_plot_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if box_plot_aggregated_field_wells is not None:
                self._values["box_plot_aggregated_field_wells"] = box_plot_aggregated_field_wells

        @builtins.property
        def box_plot_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html#cfn-quicksight-template-boxplotfieldwells-boxplotaggregatedfieldwells
            '''
            result = self._values.get("box_plot_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "all_data_points_visibility": "allDataPointsVisibility",
            "outlier_visibility": "outlierVisibility",
            "style_options": "styleOptions",
        },
    )
    class BoxPlotOptionsProperty:
        def __init__(
            self,
            *,
            all_data_points_visibility: typing.Optional[builtins.str] = None,
            outlier_visibility: typing.Optional[builtins.str] = None,
            style_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options of a box plot visual.

            :param all_data_points_visibility: Determines the visibility of all data points of the box plot.
            :param outlier_visibility: Determines the visibility of the outlier in a box plot.
            :param style_options: The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_options_property = quicksight.CfnTemplate.BoxPlotOptionsProperty(
                    all_data_points_visibility="allDataPointsVisibility",
                    outlier_visibility="outlierVisibility",
                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                        fill_style="fillStyle"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f0574041ce16a651e9aba0d583026c831c1a3f83c906405b87ea8e4342e5433)
                check_type(argname="argument all_data_points_visibility", value=all_data_points_visibility, expected_type=type_hints["all_data_points_visibility"])
                check_type(argname="argument outlier_visibility", value=outlier_visibility, expected_type=type_hints["outlier_visibility"])
                check_type(argname="argument style_options", value=style_options, expected_type=type_hints["style_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if all_data_points_visibility is not None:
                self._values["all_data_points_visibility"] = all_data_points_visibility
            if outlier_visibility is not None:
                self._values["outlier_visibility"] = outlier_visibility
            if style_options is not None:
                self._values["style_options"] = style_options

        @builtins.property
        def all_data_points_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of all data points of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-alldatapointsvisibility
            '''
            result = self._values.get("all_data_points_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def outlier_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the outlier in a box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-outliervisibility
            '''
            result = self._values.get("outlier_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The style options of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-styleoptions
            '''
            result = self._values.get("style_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_sort": "categorySort",
            "pagination_configuration": "paginationConfiguration",
        },
    )
    class BoxPlotSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            pagination_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort configuration of a ``BoxPlotVisual`` .

            :param category_sort: The sort configuration of a group by fields.
            :param pagination_configuration: The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_sort_configuration_property = quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af0047edd4030a082d44f1812b08435bdd2793f707bfada697c2252cf19dc62f)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of a group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PaginationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The pagination configuration of a table visual or box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PaginationConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"fill_style": "fillStyle"},
    )
    class BoxPlotStyleOptionsProperty:
        def __init__(self, *, fill_style: typing.Optional[builtins.str] = None) -> None:
            '''The style options of the box plot.

            :param fill_style: The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                box_plot_style_options_property = quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                    fill_style="fillStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__31517b77ca1d87776729ad911f29d8b4ff5259018ed78d6f5ed6621b37338b29)
                check_type(argname="argument fill_style", value=fill_style, expected_type=type_hints["fill_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if fill_style is not None:
                self._values["fill_style"] = fill_style

        @builtins.property
        def fill_style(self) -> typing.Optional[builtins.str]:
            '''The fill styles (solid, transparent) of the box plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html#cfn-quicksight-template-boxplotstyleoptions-fillstyle
            '''
            result = self._values.get("fill_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.BoxPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class BoxPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                box_plot_visual_property = quicksight.CfnTemplate.BoxPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                        box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                            all_data_points_visibility="allDataPointsVisibility",
                            outlier_visibility="outlierVisibility",
                            style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                fill_style="fillStyle"
                            )
                        ),
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                            box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            )
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ada8c50e0520ecc1facf0825a19ead96fbe8f075266112220b9f2a081b4f219c)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BoxPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CalculatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "expression": "expression",
            "name": "name",
        },
    )
    class CalculatedFieldProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            expression: builtins.str,
            name: builtins.str,
        ) -> None:
            '''The calculated field of an analysis.

            :param data_set_identifier: The data set that is used in this calculated field.
            :param expression: The expression of the calculated field.
            :param name: The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_field_property = quicksight.CfnTemplate.CalculatedFieldProperty(
                    data_set_identifier="dataSetIdentifier",
                    expression="expression",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d80e60b47dff9fc916edfd94ff6acade3daa915f355d88e14f1c23dc5742dd6)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "expression": expression,
                "name": name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in this calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the calculated field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CalculatedMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "field_id": "fieldId"},
    )
    class CalculatedMeasureFieldProperty:
        def __init__(self, *, expression: builtins.str, field_id: builtins.str) -> None:
            '''The table calculation measure field for pivot tables.

            :param expression: The expression in the table calculation.
            :param field_id: The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                calculated_measure_field_property = quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                    expression="expression",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c8b4d5dbf8933105264735a82d3d99dbbed01e475102d9e879aca428dd46d1e)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "field_id": field_id,
            }

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression in the table calculation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CalculatedMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CascadingControlConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"source_controls": "sourceControls"},
    )
    class CascadingControlConfigurationProperty:
        def __init__(
            self,
            *,
            source_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.CascadingControlSourceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :param source_controls: A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cascading_control_configuration_property = quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        source_sheet_control_id="sourceSheetControlId"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8a3fdf89cc814adfed4942092c61c9300af359d64533b17e12c6cbc0e4147889)
                check_type(argname="argument source_controls", value=source_controls, expected_type=type_hints["source_controls"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_controls is not None:
                self._values["source_controls"] = source_controls

        @builtins.property
        def source_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.CascadingControlSourceProperty", _IResolvable_a771d0ef]]]]:
            '''A list of source controls that determine the values that are used in the current control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html#cfn-quicksight-template-cascadingcontrolconfiguration-sourcecontrols
            '''
            result = self._values.get("source_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.CascadingControlSourceProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CascadingControlSourceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_to_match": "columnToMatch",
            "source_sheet_control_id": "sourceSheetControlId",
        },
    )
    class CascadingControlSourceProperty:
        def __init__(
            self,
            *,
            column_to_match: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_sheet_control_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The source controls that are used in a ``CascadingControlConfiguration`` .

            :param column_to_match: The column identifier that determines which column to look up for the source sheet control.
            :param source_sheet_control_id: The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cascading_control_source_property = quicksight.CfnTemplate.CascadingControlSourceProperty(
                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    source_sheet_control_id="sourceSheetControlId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9f374555628e115730297f1b43598d4eff98c741834513c6574b9dd9c276811d)
                check_type(argname="argument column_to_match", value=column_to_match, expected_type=type_hints["column_to_match"])
                check_type(argname="argument source_sheet_control_id", value=source_sheet_control_id, expected_type=type_hints["source_sheet_control_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_to_match is not None:
                self._values["column_to_match"] = column_to_match
            if source_sheet_control_id is not None:
                self._values["source_sheet_control_id"] = source_sheet_control_id

        @builtins.property
        def column_to_match(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column identifier that determines which column to look up for the source sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-columntomatch
            '''
            result = self._values.get("column_to_match")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_sheet_control_id(self) -> typing.Optional[builtins.str]:
            '''The source sheet control ID of a ``CascadingControlSource`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-sourcesheetcontrolid
            '''
            result = self._values.get("source_sheet_control_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CascadingControlSourceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CategoricalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class CategoricalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with categorical type columns..

            :param column: The column that is used in the ``CategoricalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                categorical_dimension_field_property = quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5f85d04e830cfc56c2bd1c055734954195c245511f7e862893798eb9ac3e0b9c)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``CategoricalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CategoricalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class CategoricalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with categorical type columns.

            :param column: The column that is used in the ``CategoricalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                categorical_measure_field_property = quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff19b999a517a69a5ad081871747de13768e9cf092ab6ade1f2eb5591a2b4fbd)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``CategoricalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoricalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CategoryDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"category_values": "categoryValues", "column": "column"},
    )
    class CategoryDrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_values: typing.Sequence[builtins.str],
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The numeric equality type drill down filter.

            :param category_values: A list of the string inputs that are the values of the category drill down filter.
            :param column: The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_drill_down_filter_property = quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                    category_values=["categoryValues"],
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2fbc8244ddf3971b442d55ee4205b3ea263402bf9e2d26f74f9e9e8d48010f53)
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category_values": category_values,
                "column": column,
            }

        @builtins.property
        def category_values(self) -> typing.List[builtins.str]:
            '''A list of the string inputs that are the values of the category drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-categoryvalues
            '''
            result = self._values.get("category_values")
            assert result is not None, "Required property 'category_values' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CategoryFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_filter_configuration": "customFilterConfiguration",
            "custom_filter_list_configuration": "customFilterListConfiguration",
            "filter_list_configuration": "filterListConfiguration",
        },
    )
    class CategoryFilterConfigurationProperty:
        def __init__(
            self,
            *,
            custom_filter_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_filter_list_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomFilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filter_list_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterListConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``CategoryFilter`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_filter_configuration: A custom filter that filters based on a single value. This filter can be partially matched.
            :param custom_filter_list_configuration: A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
            :param filter_list_configuration: A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_filter_configuration_property = quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_value="categoryValue",
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions"
                    ),
                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    ),
                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                        match_operator="matchOperator",
                
                        # the properties below are optional
                        category_values=["categoryValues"],
                        select_all_options="selectAllOptions"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ab5d93814532835c22d56dab1f142039e031cf0a1f0be1c68681ae99e142456)
                check_type(argname="argument custom_filter_configuration", value=custom_filter_configuration, expected_type=type_hints["custom_filter_configuration"])
                check_type(argname="argument custom_filter_list_configuration", value=custom_filter_list_configuration, expected_type=type_hints["custom_filter_list_configuration"])
                check_type(argname="argument filter_list_configuration", value=filter_list_configuration, expected_type=type_hints["filter_list_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_filter_configuration is not None:
                self._values["custom_filter_configuration"] = custom_filter_configuration
            if custom_filter_list_configuration is not None:
                self._values["custom_filter_list_configuration"] = custom_filter_list_configuration
            if filter_list_configuration is not None:
                self._values["filter_list_configuration"] = filter_list_configuration

        @builtins.property
        def custom_filter_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomFilterConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterconfiguration
            '''
            result = self._values.get("custom_filter_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomFilterConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomFilterListConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A list of custom filter values.

            In the Amazon QuickSight console, this filter type is called a custom filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterlistconfiguration
            '''
            result = self._values.get("custom_filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomFilterListConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filter_list_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterListConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A list of filter configurations.

            In the Amazon QuickSight console, this filter type is called a filter list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-filterlistconfiguration
            '''
            result = self._values.get("filter_list_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterListConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CategoryFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "configuration": "configuration",
            "filter_id": "filterId",
        },
    )
    class CategoryFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            configuration: typing.Union[typing.Union["CfnTemplate.CategoryFilterConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
        ) -> None:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :param column: The column that the filter is applied to.
            :param configuration: The configuration for a ``CategoryFilter`` .
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                category_filter_property = quicksight.CfnTemplate.CategoryFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                        custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_value="categoryValue",
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions"
                        ),
                        custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        ),
                        filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                            match_operator="matchOperator",
                
                            # the properties below are optional
                            category_values=["categoryValues"],
                            select_all_options="selectAllOptions"
                        )
                    ),
                    filter_id="filterId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__57ba3e3132bed5edb713c5f99ffe0d4603cf2d46cabe2b0792684eccc6bb11c1)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "configuration": configuration,
                "filter_id": filter_id,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnTemplate.CategoryFilterConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration for a ``CategoryFilter`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.CategoryFilterConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CategoryFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ChartAxisLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_label_options": "axisLabelOptions",
            "sort_icon_visibility": "sortIconVisibility",
            "visibility": "visibility",
        },
    )
    class ChartAxisLabelOptionsProperty:
        def __init__(
            self,
            *,
            axis_label_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.AxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sort_icon_visibility: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options for an axis on a chart.

            :param axis_label_options: The label options for a chart axis.
            :param sort_icon_visibility: The visibility configuration of the sort icon on a chart's axis label.
            :param visibility: The visibility of an axis label on a chart. Choose one of the following options:. - ``VISIBLE`` : Shows the axis. - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                chart_axis_label_options_property = quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId"
                        ),
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        )
                    )],
                    sort_icon_visibility="sortIconVisibility",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1a714a6a5ccbc8ebc5f5f0b0096505434c14bd0207fbd40c9b7fb19d317ae69)
                check_type(argname="argument axis_label_options", value=axis_label_options, expected_type=type_hints["axis_label_options"])
                check_type(argname="argument sort_icon_visibility", value=sort_icon_visibility, expected_type=type_hints["sort_icon_visibility"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_label_options is not None:
                self._values["axis_label_options"] = axis_label_options
            if sort_icon_visibility is not None:
                self._values["sort_icon_visibility"] = sort_icon_visibility
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def axis_label_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.AxisLabelOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The label options for a chart axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-axislabeloptions
            '''
            result = self._values.get("axis_label_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.AxisLabelOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sort_icon_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the sort icon on a chart's axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-sorticonvisibility
            '''
            result = self._values.get("sort_icon_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an axis label on a chart. Choose one of the following options:.

            - ``VISIBLE`` : Shows the axis.
            - ``HIDDEN`` : Hides the axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ChartAxisLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ClusterMarkerConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"cluster_marker": "clusterMarker"},
    )
    class ClusterMarkerConfigurationProperty:
        def __init__(
            self,
            *,
            cluster_marker: typing.Optional[typing.Union[typing.Union["CfnTemplate.ClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cluster marker configuration of the geospatial map selected point style.

            :param cluster_marker: The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cluster_marker_configuration_property = quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                    cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                        simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e98eab85cccee16e53081a3818f15dd21b809a945a95dcbef74a93c6164eca50)
                check_type(argname="argument cluster_marker", value=cluster_marker, expected_type=type_hints["cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker is not None:
                self._values["cluster_marker"] = cluster_marker

        @builtins.property
        def cluster_marker(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ClusterMarkerProperty", _IResolvable_a771d0ef]]:
            '''The cluster marker that is a part of the cluster marker configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html#cfn-quicksight-template-clustermarkerconfiguration-clustermarker
            '''
            result = self._values.get("cluster_marker")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ClusterMarkerProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"simple_cluster_marker": "simpleClusterMarker"},
    )
    class ClusterMarkerProperty:
        def __init__(
            self,
            *,
            simple_cluster_marker: typing.Optional[typing.Union[typing.Union["CfnTemplate.SimpleClusterMarkerProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cluster marker that is a part of the cluster marker configuration.

            :param simple_cluster_marker: The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                cluster_marker_property = quicksight.CfnTemplate.ClusterMarkerProperty(
                    simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__256c9d54654730809d0f1dfb61f99dc567baabea7c3262581aaa3749c3e613a1)
                check_type(argname="argument simple_cluster_marker", value=simple_cluster_marker, expected_type=type_hints["simple_cluster_marker"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if simple_cluster_marker is not None:
                self._values["simple_cluster_marker"] = simple_cluster_marker

        @builtins.property
        def simple_cluster_marker(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SimpleClusterMarkerProperty", _IResolvable_a771d0ef]]:
            '''The simple cluster marker of the cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html#cfn-quicksight-template-clustermarker-simpleclustermarker
            '''
            result = self._values.get("simple_cluster_marker")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SimpleClusterMarkerProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColorScaleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_fill_type": "colorFillType",
            "colors": "colors",
            "null_value_color": "nullValueColor",
        },
    )
    class ColorScaleProperty:
        def __init__(
            self,
            *,
            color_fill_type: builtins.str,
            colors: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            null_value_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the color scale that is applied to the visual.

            :param color_fill_type: Determines the color fill type.
            :param colors: Determines the list of colors that are applied to the visual.
            :param null_value_color: Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                color_scale_property = quicksight.CfnTemplate.ColorScaleProperty(
                    color_fill_type="colorFillType",
                    colors=[quicksight.CfnTemplate.DataColorProperty(
                        color="color",
                        data_value=123
                    )],
                
                    # the properties below are optional
                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                        color="color",
                        data_value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0264786e888f069bee84d1f3191f798abbbb0aa5e22f9504e75d4472c798545e)
                check_type(argname="argument color_fill_type", value=color_fill_type, expected_type=type_hints["color_fill_type"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument null_value_color", value=null_value_color, expected_type=type_hints["null_value_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color_fill_type": color_fill_type,
                "colors": colors,
            }
            if null_value_color is not None:
                self._values["null_value_color"] = null_value_color

        @builtins.property
        def color_fill_type(self) -> builtins.str:
            '''Determines the color fill type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colorfilltype
            '''
            result = self._values.get("color_fill_type")
            assert result is not None, "Required property 'color_fill_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataColorProperty", _IResolvable_a771d0ef]]]:
            '''Determines the list of colors that are applied to the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colors
            '''
            result = self._values.get("colors")
            assert result is not None, "Required property 'colors' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataColorProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def null_value_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataColorProperty", _IResolvable_a771d0ef]]:
            '''Determines the color that is applied to null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-nullvaluecolor
            '''
            result = self._values.get("null_value_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorScaleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColorsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_colors": "customColors"},
    )
    class ColorsConfigurationProperty:
        def __init__(
            self,
            *,
            custom_colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.CustomColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''
            :param custom_colors: ``CfnTemplate.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                colors_configuration_property = quicksight.CfnTemplate.ColorsConfigurationProperty(
                    custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                        color="color",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        special_value="specialValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f161fa9fdef505501305e6433b4515eeb17d8dc4aff78b67987a6a979feb3d45)
                check_type(argname="argument custom_colors", value=custom_colors, expected_type=type_hints["custom_colors"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_colors is not None:
                self._values["custom_colors"] = custom_colors

        @builtins.property
        def custom_colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.CustomColorProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnTemplate.ColorsConfigurationProperty.CustomColors``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html#cfn-quicksight-template-colorsconfiguration-customcolors
            '''
            result = self._values.get("custom_colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.CustomColorProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColorsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "colors_configuration": "colorsConfiguration",
            "format_configuration": "formatConfiguration",
            "role": "role",
        },
    )
    class ColumnConfigurationProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            colors_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColorsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            role: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The general configuration of a column.

            :param column: The column.
            :param colors_configuration: ``CfnTemplate.ColumnConfigurationProperty.ColorsConfiguration``.
            :param format_configuration: The format configuration of a column.
            :param role: The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_configuration_property = quicksight.CfnTemplate.ColumnConfigurationProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                        custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                            color="color",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            special_value="specialValue"
                        )]
                    ),
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d82280f69aea32af27cc84aa7902f26b59bb940a69f35e601b53ac9876150f0b)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument colors_configuration", value=colors_configuration, expected_type=type_hints["colors_configuration"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if colors_configuration is not None:
                self._values["colors_configuration"] = colors_configuration
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def colors_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColorsConfigurationProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.ColumnConfigurationProperty.ColorsConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-colorsconfiguration
            '''
            result = self._values.get("colors_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColorsConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of a column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class ColumnGroupColumnSchemaProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''A structure describing the name, data type, and geographic role of the columns.

            :param name: The name of the column group's column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_group_column_schema_property = quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__506d905c100729d69bdae500232bc0bd89c7016746913c23e50347f24a6c97d4)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column group's column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html#cfn-quicksight-template-columngroupcolumnschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupColumnSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnGroupSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_group_column_schema_list": "columnGroupColumnSchemaList",
            "name": "name",
        },
    )
    class ColumnGroupSchemaProperty:
        def __init__(
            self,
            *,
            column_group_column_schema_list: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnGroupColumnSchemaProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The column group schema.

            :param column_group_column_schema_list: A structure containing the list of schemas for column group columns.
            :param name: The name of the column group schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_group_schema_property = quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                    column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                        name="name"
                    )],
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac23fa70b74f2047de958b13a0f894548d2c9a3e67c93e1d539e5e87e030df38)
                check_type(argname="argument column_group_column_schema_list", value=column_group_column_schema_list, expected_type=type_hints["column_group_column_schema_list"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_group_column_schema_list is not None:
                self._values["column_group_column_schema_list"] = column_group_column_schema_list
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def column_group_column_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnGroupColumnSchemaProperty", _IResolvable_a771d0ef]]]]:
            '''A structure containing the list of schemas for column group columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-columngroupcolumnschemalist
            '''
            result = self._values.get("column_group_column_schema_list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnGroupColumnSchemaProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column group schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnGroupSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_hierarchy": "dateTimeHierarchy",
            "explicit_hierarchy": "explicitHierarchy",
            "predefined_hierarchy": "predefinedHierarchy",
        },
    )
    class ColumnHierarchyProperty:
        def __init__(
            self,
            *,
            date_time_hierarchy: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            explicit_hierarchy: typing.Optional[typing.Union[typing.Union["CfnTemplate.ExplicitHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            predefined_hierarchy: typing.Optional[typing.Union[typing.Union["CfnTemplate.PredefinedHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields for a visual element.

            :param date_time_hierarchy: The option that determines the hierarchy of any ``DateTime`` fields.
            :param explicit_hierarchy: The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
            :param predefined_hierarchy: The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_hierarchy_property = quicksight.CfnTemplate.ColumnHierarchyProperty(
                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    ),
                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        hierarchy_id="hierarchyId",
                
                        # the properties below are optional
                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                category_values=["categoryValues"],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                value=123
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                range_maximum="rangeMaximum",
                                range_minimum="rangeMinimum",
                                time_granularity="timeGranularity"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d246238c318494ab7a26a7340e8e3320bcee2d3ca2c0604b03d8046f0cdadd9)
                check_type(argname="argument date_time_hierarchy", value=date_time_hierarchy, expected_type=type_hints["date_time_hierarchy"])
                check_type(argname="argument explicit_hierarchy", value=explicit_hierarchy, expected_type=type_hints["explicit_hierarchy"])
                check_type(argname="argument predefined_hierarchy", value=predefined_hierarchy, expected_type=type_hints["predefined_hierarchy"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_hierarchy is not None:
                self._values["date_time_hierarchy"] = date_time_hierarchy
            if explicit_hierarchy is not None:
                self._values["explicit_hierarchy"] = explicit_hierarchy
            if predefined_hierarchy is not None:
                self._values["predefined_hierarchy"] = predefined_hierarchy

        @builtins.property
        def date_time_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-datetimehierarchy
            '''
            result = self._values.get("date_time_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeHierarchyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def explicit_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ExplicitHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-explicithierarchy
            '''
            result = self._values.get("explicit_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ExplicitHierarchyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def predefined_hierarchy(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PredefinedHierarchyProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-predefinedhierarchy
            '''
            result = self._values.get("predefined_hierarchy")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PredefinedHierarchyProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnIdentifierProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_name": "columnName",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class ColumnIdentifierProperty:
        def __init__(
            self,
            *,
            column_name: builtins.str,
            data_set_identifier: builtins.str,
        ) -> None:
            '''A column of a data set.

            :param column_name: The name of the column.
            :param data_set_identifier: The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_identifier_property = quicksight.CfnTemplate.ColumnIdentifierProperty(
                    column_name="columnName",
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a8f236457ce439d56bdbd0a89c81d38c7c0dd468446bbfde02a51e4ed0626dff)
                check_type(argname="argument column_name", value=column_name, expected_type=type_hints["column_name"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_name": column_name,
                "data_set_identifier": data_set_identifier,
            }

        @builtins.property
        def column_name(self) -> builtins.str:
            '''The name of the column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-columnname
            '''
            result = self._values.get("column_name")
            assert result is not None, "Required property 'column_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that the column belongs to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnIdentifierProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_type": "dataType",
            "geographic_role": "geographicRole",
            "name": "name",
        },
    )
    class ColumnSchemaProperty:
        def __init__(
            self,
            *,
            data_type: typing.Optional[builtins.str] = None,
            geographic_role: typing.Optional[builtins.str] = None,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The column schema.

            :param data_type: The data type of the column schema.
            :param geographic_role: The geographic role of the column schema.
            :param name: The name of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_schema_property = quicksight.CfnTemplate.ColumnSchemaProperty(
                    data_type="dataType",
                    geographic_role="geographicRole",
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c8cf0ece2a5a56135ab6eb46bd57677089eedc347b11dbe731753b58685f9682)
                check_type(argname="argument data_type", value=data_type, expected_type=type_hints["data_type"])
                check_type(argname="argument geographic_role", value=geographic_role, expected_type=type_hints["geographic_role"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_type is not None:
                self._values["data_type"] = data_type
            if geographic_role is not None:
                self._values["geographic_role"] = geographic_role
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def data_type(self) -> typing.Optional[builtins.str]:
            '''The data type of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-datatype
            '''
            result = self._values.get("data_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def geographic_role(self) -> typing.Optional[builtins.str]:
            '''The geographic role of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-geographicrole
            '''
            result = self._values.get("geographic_role")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the column schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnSortProperty",
        jsii_struct_bases=[],
        name_mapping={
            "direction": "direction",
            "sort_by": "sortBy",
            "aggregation_function": "aggregationFunction",
        },
    )
    class ColumnSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_by: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort configuration for a column that is not used in a field well.

            :param direction: The sort direction.
            :param sort_by: ``CfnTemplate.ColumnSortProperty.SortBy``.
            :param aggregation_function: The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_sort_property = quicksight.CfnTemplate.ColumnSortProperty(
                    direction="direction",
                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c57f121512b4c7afd669afb5b99aee4cf2f76a9949c8d4bf0583511b05bb75aa)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_by": sort_by,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''``CfnTemplate.ColumnSortProperty.SortBy``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function that is defined in the column sort.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ColumnTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "aggregation": "aggregation",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class ColumnTooltipItemProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            aggregation: typing.Optional[typing.Union[typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the columns that are not part of a field well.

            :param column: The target column of the tooltip item.
            :param aggregation: The aggregation function of the column tooltip item.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                column_tooltip_item_property = quicksight.CfnTemplate.ColumnTooltipItemProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b41ed4d55ff8c0ed5880b82efa1096ba5a9c710bc606968e8a6bba18d5937d9e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument aggregation", value=aggregation, expected_type=type_hints["aggregation"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
            }
            if aggregation is not None:
                self._values["aggregation"] = aggregation
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The target column of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the column tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-aggregation
            '''
            result = self._values.get("aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ColumnTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_values": "barValues",
            "category": "category",
            "colors": "colors",
            "line_values": "lineValues",
        },
    )
    class ComboChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            bar_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            line_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a combo chart.

            :param bar_values: The aggregated ``BarValues`` field well of a combo chart.
            :param category: The aggregated category field wells of a combo chart.
            :param colors: The aggregated colors field well of a combo chart.
            :param line_values: The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_aggregated_field_wells_property = quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                    bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9d647ddb42b44df7f2589fd90dfd84b6daf5f5c8e16cef7a15ffa1b1f3656bc)
                check_type(argname="argument bar_values", value=bar_values, expected_type=type_hints["bar_values"])
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument line_values", value=line_values, expected_type=type_hints["line_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_values is not None:
                self._values["bar_values"] = bar_values
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if line_values is not None:
                self._values["line_values"] = line_values

        @builtins.property
        def bar_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated ``BarValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-barvalues
            '''
            result = self._values.get("bar_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated category field wells of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated colors field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def line_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated ``LineValues`` field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-linevalues
            '''
            result = self._values.get("line_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComboChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_data_labels": "barDataLabels",
            "bars_arrangement": "barsArrangement",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "line_data_labels": "lineDataLabels",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
        },
    )
    class ComboChartConfigurationProperty:
        def __init__(
            self,
            *,
            bar_data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            bars_arrangement: typing.Optional[builtins.str] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComboChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            line_data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComboChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``ComboChartVisual`` .

            :param bar_data_labels: The options that determine if visual data labels are displayed. The data label options for a bar in a combo chart.
            :param bars_arrangement: Determines the bar arrangement in a combo chart. The following are valid values in this structure:. - ``CLUSTERED`` : For clustered bar combo charts. - ``STACKED`` : For stacked bar combo charts. - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.
            :param category_axis: The category axis of a combo chart.
            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
            :param color_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param line_data_labels: The options that determine if visual data labels are displayed. The data label options for a line in a combo chart.
            :param primary_y_axis_display_options: The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
            :param primary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
            :param reference_lines: The reference line setup of the visual.
            :param secondary_y_axis_display_options: The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
            :param secondary_y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
            :param sort_configuration: The sort configuration of a ``ComboChartVisual`` .
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_configuration_property = quicksight.CfnTemplate.ComboChartConfigurationProperty(
                    bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    bars_arrangement="barsArrangement",
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                        combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                            bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63cf08e84abd6e9afe0bd22fa596aad5415f2edb124ad713ba383cf0044159e0)
                check_type(argname="argument bar_data_labels", value=bar_data_labels, expected_type=type_hints["bar_data_labels"])
                check_type(argname="argument bars_arrangement", value=bars_arrangement, expected_type=type_hints["bars_arrangement"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument line_data_labels", value=line_data_labels, expected_type=type_hints["line_data_labels"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_data_labels is not None:
                self._values["bar_data_labels"] = bar_data_labels
            if bars_arrangement is not None:
                self._values["bars_arrangement"] = bars_arrangement
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if line_data_labels is not None:
                self._values["line_data_labels"] = line_data_labels
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def bar_data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a bar in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-bardatalabels
            '''
            result = self._values.get("bar_data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def bars_arrangement(self) -> typing.Optional[builtins.str]:
            '''Determines the bar arrangement in a combo chart. The following are valid values in this structure:.

            - ``CLUSTERED`` : For clustered bar combo charts.
            - ``STACKED`` : For stacked bar combo charts.
            - ``STACKED_PERCENT`` : Do not use. If you use this value, the operation returns a validation error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-barsarrangement
            '''
            result = self._values.get("bars_arrangement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category axis of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComboChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComboChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def line_data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            The data label options for a line in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-linedatalabels
            '''
            result = self._values.get("line_data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference line setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComboChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``ComboChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComboChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComboChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "combo_chart_aggregated_field_wells": "comboChartAggregatedFieldWells",
        },
    )
    class ComboChartFieldWellsProperty:
        def __init__(
            self,
            *,
            combo_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComboChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of the visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param combo_chart_aggregated_field_wells: The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_field_wells_property = quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                    combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                        bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__845f3fd8dfc3e680d27e3ef393f3702ae13ede1f98517802cb2aebc3d488288c)
                check_type(argname="argument combo_chart_aggregated_field_wells", value=combo_chart_aggregated_field_wells, expected_type=type_hints["combo_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if combo_chart_aggregated_field_wells is not None:
                self._values["combo_chart_aggregated_field_wells"] = combo_chart_aggregated_field_wells

        @builtins.property
        def combo_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComboChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a combo chart.

            Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html#cfn-quicksight-template-combochartfieldwells-combochartaggregatedfieldwells
            '''
            result = self._values.get("combo_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComboChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComboChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class ComboChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``ComboChartVisual`` .

            :param category_items_limit: The item limit configuration for the category field well of a combo chart.
            :param category_sort: The sort configuration of the category field well in a combo chart.
            :param color_items_limit: The item limit configuration of the color field well in a combo chart.
            :param color_sort: The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                combo_chart_sort_configuration_property = quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4041bcd7db2d510690e6ce8507b997be79cd49152f0243d3e13b7ac5380f564e)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The item limit configuration for the category field well of a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The item limit configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the color field well in a combo chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComboChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ComboChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComboChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A combo chart.

            The ``ComboChartVisual`` includes stacked bar combo charts and clustered bar combo charts

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                combo_chart_visual_property = quicksight.CfnTemplate.ComboChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                        bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        bars_arrangement="barsArrangement",
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                            combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__340a51b9c529cf83d209d4a6d3c73810fa12b4b8acdda6834f2fa7c09a83a9e8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComboChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComboChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComboChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComparisonConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison_format": "comparisonFormat",
            "comparison_method": "comparisonMethod",
        },
    )
    class ComparisonConfigurationProperty:
        def __init__(
            self,
            *,
            comparison_format: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComparisonFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            comparison_method: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The comparison display configuration of a KPI or gauge chart.

            :param comparison_format: The format of the comparison.
            :param comparison_method: The method of the comparison. Choose from the following options:. - ``DIFFERENCE`` - ``PERCENT_DIFFERENCE`` - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                comparison_configuration_property = quicksight.CfnTemplate.ComparisonConfigurationProperty(
                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    comparison_method="comparisonMethod"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d676d92e6b025637a3e679b6679df5fff865843308be939813c58012a525f37d)
                check_type(argname="argument comparison_format", value=comparison_format, expected_type=type_hints["comparison_format"])
                check_type(argname="argument comparison_method", value=comparison_method, expected_type=type_hints["comparison_method"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison_format is not None:
                self._values["comparison_format"] = comparison_format
            if comparison_method is not None:
                self._values["comparison_method"] = comparison_method

        @builtins.property
        def comparison_format(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComparisonFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format of the comparison.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonformat
            '''
            result = self._values.get("comparison_format")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComparisonFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def comparison_method(self) -> typing.Optional[builtins.str]:
            '''The method of the comparison. Choose from the following options:.

            - ``DIFFERENCE``
            - ``PERCENT_DIFFERENCE``
            - ``PERCENT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonmethod
            '''
            result = self._values.get("comparison_method")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComparisonFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class ComparisonFormatConfigurationProperty:
        def __init__(
            self,
            *,
            number_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The format of the comparison.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param number_display_format_configuration: The number display format.
            :param percentage_display_format_configuration: The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                comparison_format_configuration_property = quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b67a9d63f186589bc5fb65a14057c3fe7b50181eb5824ee35ab1bc5ef2ed5d63)
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The number display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The percentage display format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComparisonFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast": "forecast",
            "growth_rate": "growthRate",
            "maximum_minimum": "maximumMinimum",
            "metric_comparison": "metricComparison",
            "period_over_period": "periodOverPeriod",
            "period_to_date": "periodToDate",
            "top_bottom_movers": "topBottomMovers",
            "top_bottom_ranked": "topBottomRanked",
            "total_aggregation": "totalAggregation",
            "unique_values": "uniqueValues",
        },
    )
    class ComputationProperty:
        def __init__(
            self,
            *,
            forecast: typing.Optional[typing.Union[typing.Union["CfnTemplate.ForecastComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            growth_rate: typing.Optional[typing.Union[typing.Union["CfnTemplate.GrowthRateComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maximum_minimum: typing.Optional[typing.Union[typing.Union["CfnTemplate.MaximumMinimumComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            metric_comparison: typing.Optional[typing.Union[typing.Union["CfnTemplate.MetricComparisonComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            period_over_period: typing.Optional[typing.Union[typing.Union["CfnTemplate.PeriodOverPeriodComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            period_to_date: typing.Optional[typing.Union[typing.Union["CfnTemplate.PeriodToDateComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_movers: typing.Optional[typing.Union[typing.Union["CfnTemplate.TopBottomMoversComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_ranked: typing.Optional[typing.Union[typing.Union["CfnTemplate.TopBottomRankedComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_aggregation: typing.Optional[typing.Union[typing.Union["CfnTemplate.TotalAggregationComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            unique_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.UniqueValuesComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The computation union that is used in an insight visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param forecast: The forecast computation configuration.
            :param growth_rate: The growth rate computation configuration.
            :param maximum_minimum: The maximum and minimum computation configuration.
            :param metric_comparison: The metric comparison computation configuration.
            :param period_over_period: The period over period computation configuration.
            :param period_to_date: The period to ``DataSetIdentifier`` computation configuration.
            :param top_bottom_movers: The top movers and bottom movers computation configuration.
            :param top_bottom_ranked: The top ranked and bottom ranked computation configuration.
            :param total_aggregation: The total aggregation computation configuration.
            :param unique_values: The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                computation_property = quicksight.CfnTemplate.ComputationProperty(
                    forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        custom_seasonality_value=123,
                        lower_boundary=123,
                        name="name",
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality="seasonality",
                        upper_boundary=123,
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_size=123,
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                        computation_id="computationId",
                        from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                
                        # the properties below are optional
                        name="name",
                        period_time_granularity="periodTimeGranularity",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        type="type",
                
                        # the properties below are optional
                        mover_size=123,
                        name="name",
                        sort_order="sortOrder",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                        type="type",
                
                        # the properties below are optional
                        name="name",
                        result_size=123,
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )
                    ),
                    total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                        computation_id="computationId",
                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        ),
                
                        # the properties below are optional
                        name="name"
                    ),
                    unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        ),
                        computation_id="computationId",
                
                        # the properties below are optional
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e33ba0a3d73109d9db95fd1759ab20d4b280b0e0858b87908c3616efdb18ce1)
                check_type(argname="argument forecast", value=forecast, expected_type=type_hints["forecast"])
                check_type(argname="argument growth_rate", value=growth_rate, expected_type=type_hints["growth_rate"])
                check_type(argname="argument maximum_minimum", value=maximum_minimum, expected_type=type_hints["maximum_minimum"])
                check_type(argname="argument metric_comparison", value=metric_comparison, expected_type=type_hints["metric_comparison"])
                check_type(argname="argument period_over_period", value=period_over_period, expected_type=type_hints["period_over_period"])
                check_type(argname="argument period_to_date", value=period_to_date, expected_type=type_hints["period_to_date"])
                check_type(argname="argument top_bottom_movers", value=top_bottom_movers, expected_type=type_hints["top_bottom_movers"])
                check_type(argname="argument top_bottom_ranked", value=top_bottom_ranked, expected_type=type_hints["top_bottom_ranked"])
                check_type(argname="argument total_aggregation", value=total_aggregation, expected_type=type_hints["total_aggregation"])
                check_type(argname="argument unique_values", value=unique_values, expected_type=type_hints["unique_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast is not None:
                self._values["forecast"] = forecast
            if growth_rate is not None:
                self._values["growth_rate"] = growth_rate
            if maximum_minimum is not None:
                self._values["maximum_minimum"] = maximum_minimum
            if metric_comparison is not None:
                self._values["metric_comparison"] = metric_comparison
            if period_over_period is not None:
                self._values["period_over_period"] = period_over_period
            if period_to_date is not None:
                self._values["period_to_date"] = period_to_date
            if top_bottom_movers is not None:
                self._values["top_bottom_movers"] = top_bottom_movers
            if top_bottom_ranked is not None:
                self._values["top_bottom_ranked"] = top_bottom_ranked
            if total_aggregation is not None:
                self._values["total_aggregation"] = total_aggregation
            if unique_values is not None:
                self._values["unique_values"] = unique_values

        @builtins.property
        def forecast(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ForecastComputationProperty", _IResolvable_a771d0ef]]:
            '''The forecast computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-forecast
            '''
            result = self._values.get("forecast")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ForecastComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def growth_rate(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GrowthRateComputationProperty", _IResolvable_a771d0ef]]:
            '''The growth rate computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-growthrate
            '''
            result = self._values.get("growth_rate")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GrowthRateComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maximum_minimum(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MaximumMinimumComputationProperty", _IResolvable_a771d0ef]]:
            '''The maximum and minimum computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-maximumminimum
            '''
            result = self._values.get("maximum_minimum")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MaximumMinimumComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def metric_comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MetricComparisonComputationProperty", _IResolvable_a771d0ef]]:
            '''The metric comparison computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-metriccomparison
            '''
            result = self._values.get("metric_comparison")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MetricComparisonComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def period_over_period(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PeriodOverPeriodComputationProperty", _IResolvable_a771d0ef]]:
            '''The period over period computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodoverperiod
            '''
            result = self._values.get("period_over_period")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PeriodOverPeriodComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def period_to_date(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PeriodToDateComputationProperty", _IResolvable_a771d0ef]]:
            '''The period to ``DataSetIdentifier`` computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodtodate
            '''
            result = self._values.get("period_to_date")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PeriodToDateComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_movers(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TopBottomMoversComputationProperty", _IResolvable_a771d0ef]]:
            '''The top movers and bottom movers computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottommovers
            '''
            result = self._values.get("top_bottom_movers")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TopBottomMoversComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_ranked(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TopBottomRankedComputationProperty", _IResolvable_a771d0ef]]:
            '''The top ranked and bottom ranked computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottomranked
            '''
            result = self._values.get("top_bottom_ranked")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TopBottomRankedComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TotalAggregationComputationProperty", _IResolvable_a771d0ef]]:
            '''The total aggregation computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-totalaggregation
            '''
            result = self._values.get("total_aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TotalAggregationComputationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def unique_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.UniqueValuesComputationProperty", _IResolvable_a771d0ef]]:
            '''The unique values computation configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-uniquevalues
            '''
            result = self._values.get("unique_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.UniqueValuesComputationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingColorProperty",
        jsii_struct_bases=[],
        name_mapping={"gradient": "gradient", "solid": "solid"},
    )
    class ConditionalFormattingColorProperty:
        def __init__(
            self,
            *,
            gradient: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingGradientColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            solid: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingSolidColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for the color.

            :param gradient: Formatting configuration for gradient color.
            :param solid: Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_color_property = quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                        color=quicksight.CfnTemplate.GradientColorProperty(
                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                gradient_offset=123,
                
                                # the properties below are optional
                                color="color",
                                data_value=123
                            )]
                        ),
                        expression="expression"
                    ),
                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                        expression="expression",
                
                        # the properties below are optional
                        color="color"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6efa7f716a5738db35c84dcfd4de6d74b2ffaa0f6ee4b018235bfa4d3de02bd3)
                check_type(argname="argument gradient", value=gradient, expected_type=type_hints["gradient"])
                check_type(argname="argument solid", value=solid, expected_type=type_hints["solid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gradient is not None:
                self._values["gradient"] = gradient
            if solid is not None:
                self._values["solid"] = solid

        @builtins.property
        def gradient(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingGradientColorProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-gradient
            '''
            result = self._values.get("gradient")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingGradientColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def solid(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingSolidColorProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-solid
            '''
            result = self._values.get("solid")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingSolidColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "icon_options": "iconOptions",
            "color": "color",
            "display_configuration": "displayConfiguration",
        },
    )
    class ConditionalFormattingCustomIconConditionProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_options: typing.Union[typing.Union["CfnTemplate.ConditionalFormattingCustomIconOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            color: typing.Optional[builtins.str] = None,
            display_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the custom condition for an icon set.

            :param expression: The expression that determines the condition of the icon set.
            :param icon_options: Custom icon options for an icon set.
            :param color: Determines the color of the icon.
            :param display_configuration: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_condition_property = quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                    expression="expression",
                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                        icon="icon",
                        unicode_icon="unicodeIcon"
                    ),
                
                    # the properties below are optional
                    color="color",
                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                        icon_display_option="iconDisplayOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__93e5a9717c2f4c5c6594b365b4c3ed2d796a9dd177ea5da9a4c1d8db8bd550dc)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_options", value=icon_options, expected_type=type_hints["icon_options"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument display_configuration", value=display_configuration, expected_type=type_hints["display_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
                "icon_options": icon_options,
            }
            if color is not None:
                self._values["color"] = color
            if display_configuration is not None:
                self._values["display_configuration"] = display_configuration

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the condition of the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_options(
            self,
        ) -> typing.Union["CfnTemplate.ConditionalFormattingCustomIconOptionsProperty", _IResolvable_a771d0ef]:
            '''Custom icon options for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-iconoptions
            '''
            result = self._values.get("icon_options")
            assert result is not None, "Required property 'icon_options' is missing"
            return typing.cast(typing.Union["CfnTemplate.ConditionalFormattingCustomIconOptionsProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-displayconfiguration
            '''
            result = self._values.get("display_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconConditionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "unicode_icon": "unicodeIcon"},
    )
    class ConditionalFormattingCustomIconOptionsProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[builtins.str] = None,
            unicode_icon: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Custom icon options for an icon set.

            :param icon: Determines the type of icon.
            :param unicode_icon: Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_custom_icon_options_property = quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                    icon="icon",
                    unicode_icon="unicodeIcon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__edad2c40db5a0cace45c0a9df530f2cdf80f4eb84a235a1a93c406b0d208fdb7)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument unicode_icon", value=unicode_icon, expected_type=type_hints["unicode_icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if unicode_icon is not None:
                self._values["unicode_icon"] = unicode_icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''Determines the type of icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def unicode_icon(self) -> typing.Optional[builtins.str]:
            '''Determines the Unicode icon type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-unicodeicon
            '''
            result = self._values.get("unicode_icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingCustomIconOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "expression": "expression"},
    )
    class ConditionalFormattingGradientColorProperty:
        def __init__(
            self,
            *,
            color: typing.Union[typing.Union["CfnTemplate.GradientColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            expression: builtins.str,
        ) -> None:
            '''Formatting configuration for gradient color.

            :param color: Determines the color.
            :param expression: The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_gradient_color_property = quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                    color=quicksight.CfnTemplate.GradientColorProperty(
                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                            gradient_offset=123,
                
                            # the properties below are optional
                            color="color",
                            data_value=123
                        )]
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff6e6910a8cbe09d1b3e059793315f22c282618fa095e32555dadc9e9d4d1ee0)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "expression": expression,
            }

        @builtins.property
        def color(
            self,
        ) -> typing.Union["CfnTemplate.GradientColorProperty", _IResolvable_a771d0ef]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(typing.Union["CfnTemplate.GradientColorProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for gradient color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingGradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"icon_display_option": "iconDisplayOption"},
    )
    class ConditionalFormattingIconDisplayConfigurationProperty:
        def __init__(
            self,
            *,
            icon_display_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the icon display configuration.

            :param icon_display_option: Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_display_configuration_property = quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                    icon_display_option="iconDisplayOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c321b2cda2a82240d3a9d8ca1058657d3ff4804ede4c9e8b87809dc59d6bdc33)
                check_type(argname="argument icon_display_option", value=icon_display_option, expected_type=type_hints["icon_display_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon_display_option is not None:
                self._values["icon_display_option"] = icon_display_option

        @builtins.property
        def icon_display_option(self) -> typing.Optional[builtins.str]:
            '''Determines the icon display configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-template-conditionalformattingicondisplayconfiguration-icondisplayoption
            '''
            result = self._values.get("icon_display_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconDisplayConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingIconProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_condition": "customCondition", "icon_set": "iconSet"},
    )
    class ConditionalFormattingIconProperty:
        def __init__(
            self,
            *,
            custom_condition: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingCustomIconConditionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            icon_set: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingIconSetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for the icon.

            :param custom_condition: Determines the custom condition for an icon set.
            :param icon_set: Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_property = quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                        expression="expression",
                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                            icon="icon",
                            unicode_icon="unicodeIcon"
                        ),
                
                        # the properties below are optional
                        color="color",
                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                            icon_display_option="iconDisplayOption"
                        )
                    ),
                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                        expression="expression",
                
                        # the properties below are optional
                        icon_set_type="iconSetType"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__96cc9f5a292a048d175fdbaba70b3aab075324f9bde49346f2d7f598f4c7e82a)
                check_type(argname="argument custom_condition", value=custom_condition, expected_type=type_hints["custom_condition"])
                check_type(argname="argument icon_set", value=icon_set, expected_type=type_hints["icon_set"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_condition is not None:
                self._values["custom_condition"] = custom_condition
            if icon_set is not None:
                self._values["icon_set"] = icon_set

        @builtins.property
        def custom_condition(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingCustomIconConditionProperty", _IResolvable_a771d0ef]]:
            '''Determines the custom condition for an icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-customcondition
            '''
            result = self._values.get("custom_condition")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingCustomIconConditionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def icon_set(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconSetProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-iconset
            '''
            result = self._values.get("icon_set")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconSetProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingIconSetProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "icon_set_type": "iconSetType"},
    )
    class ConditionalFormattingIconSetProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            icon_set_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for icon set.

            :param expression: The expression that determines the formatting configuration for the icon set.
            :param icon_set_type: Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_icon_set_property = quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                    expression="expression",
                
                    # the properties below are optional
                    icon_set_type="iconSetType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__71c6a063e0355e7b953e9cc5a6f7e4f05c885de1a30011fb7f50b0aec934acef)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument icon_set_type", value=icon_set_type, expected_type=type_hints["icon_set_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if icon_set_type is not None:
                self._values["icon_set_type"] = icon_set_type

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for the icon set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def icon_set_type(self) -> typing.Optional[builtins.str]:
            '''Determines the icon set type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-iconsettype
            '''
            result = self._values.get("icon_set_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingIconSetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty",
        jsii_struct_bases=[],
        name_mapping={"expression": "expression", "color": "color"},
    )
    class ConditionalFormattingSolidColorProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Formatting configuration for solid color.

            :param expression: The expression that determines the formatting configuration for solid color.
            :param color: Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                conditional_formatting_solid_color_property = quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                    expression="expression",
                
                    # the properties below are optional
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a121c9abd82cee9b0530695102ba22533fe26d2cf39544e35fae46ef5405c662)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression that determines the formatting configuration for solid color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ConditionalFormattingSolidColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ContributionAnalysisDefaultProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contributor_dimensions": "contributorDimensions",
            "measure_field_id": "measureFieldId",
        },
    )
    class ContributionAnalysisDefaultProperty:
        def __init__(
            self,
            *,
            contributor_dimensions: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            measure_field_id: builtins.str,
        ) -> None:
            '''The contribution analysis visual display for a line, pie, or bar chart.

            :param contributor_dimensions: The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .
            :param measure_field_id: The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                contribution_analysis_default_property = quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    measure_field_id="measureFieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b9998cd42f4e0f58e97f9627cdf0c7caf8e76895d69abcffdf2489406c33878c)
                check_type(argname="argument contributor_dimensions", value=contributor_dimensions, expected_type=type_hints["contributor_dimensions"])
                check_type(argname="argument measure_field_id", value=measure_field_id, expected_type=type_hints["measure_field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "contributor_dimensions": contributor_dimensions,
                "measure_field_id": measure_field_id,
            }

        @builtins.property
        def contributor_dimensions(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The dimensions columns that are used in the contribution analysis, usually a list of ``ColumnIdentifiers`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-contributordimensions
            '''
            result = self._values.get("contributor_dimensions")
            assert result is not None, "Required property 'contributor_dimensions' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def measure_field_id(self) -> builtins.str:
            '''The measure field that is used in the contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-measurefieldid
            '''
            result = self._values.get("measure_field_id")
            assert result is not None, "Required property 'measure_field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ContributionAnalysisDefaultProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
            "symbol": "symbol",
        },
    )
    class CurrencyDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
            symbol: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the currency display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value for the currency format.
            :param prefix: Determines the prefix value of the currency format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the currency format.
            :param symbol: Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                currency_display_format_configuration_property = quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix",
                    symbol="symbol"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3e86c22a94b30c396ce686c483b1fe162ecc0ab38f9c375d8241c0881be5142b)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix
            if symbol is not None:
                self._values["symbol"] = symbol

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the symbol for the currency format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CurrencyDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomActionFilterOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_fields_configuration": "selectedFieldsConfiguration",
            "target_visuals_configuration": "targetVisualsConfiguration",
        },
    )
    class CustomActionFilterOperationProperty:
        def __init__(
            self,
            *,
            selected_fields_configuration: typing.Union[typing.Union["CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target_visuals_configuration: typing.Union[typing.Union["CfnTemplate.FilterOperationTargetVisualsConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :param selected_fields_configuration: The configuration that chooses the fields to be filtered.
            :param target_visuals_configuration: The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_filter_operation_property = quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                        selected_field_options="selectedFieldOptions",
                        selected_fields=["selectedFields"]
                    ),
                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                            target_visual_options="targetVisualOptions",
                            target_visuals=["targetVisuals"]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cace275b7c7d44a022bb514197953afc61c423c388b5e7afc6d392d96877284a)
                check_type(argname="argument selected_fields_configuration", value=selected_fields_configuration, expected_type=type_hints["selected_fields_configuration"])
                check_type(argname="argument target_visuals_configuration", value=target_visuals_configuration, expected_type=type_hints["target_visuals_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "selected_fields_configuration": selected_fields_configuration,
                "target_visuals_configuration": target_visuals_configuration,
            }

        @builtins.property
        def selected_fields_configuration(
            self,
        ) -> typing.Union["CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that chooses the fields to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-selectedfieldsconfiguration
            '''
            result = self._values.get("selected_fields_configuration")
            assert result is not None, "Required property 'selected_fields_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target_visuals_configuration(
            self,
        ) -> typing.Union["CfnTemplate.FilterOperationTargetVisualsConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that chooses the target visuals to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-targetvisualsconfiguration
            '''
            result = self._values.get("target_visuals_configuration")
            assert result is not None, "Required property 'target_visuals_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.FilterOperationTargetVisualsConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionFilterOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomActionNavigationOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "local_navigation_configuration": "localNavigationConfiguration",
        },
    )
    class CustomActionNavigationOperationProperty:
        def __init__(
            self,
            *,
            local_navigation_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.LocalNavigationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The navigation operation that navigates between different sheets in the same analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param local_navigation_configuration: The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_navigation_operation_property = quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                        target_sheet_id="targetSheetId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27cdd2e733696e06935d84fb6cb13b9c7898e22ee0ab59fa00b5ee3f7ee81a43)
                check_type(argname="argument local_navigation_configuration", value=local_navigation_configuration, expected_type=type_hints["local_navigation_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if local_navigation_configuration is not None:
                self._values["local_navigation_configuration"] = local_navigation_configuration

        @builtins.property
        def local_navigation_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LocalNavigationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that chooses the navigation target.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html#cfn-quicksight-template-customactionnavigationoperation-localnavigationconfiguration
            '''
            result = self._values.get("local_navigation_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LocalNavigationConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionNavigationOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomActionSetParametersOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_value_configurations": "parameterValueConfigurations",
        },
    )
    class CustomActionSetParametersOperationProperty:
        def __init__(
            self,
            *,
            parameter_value_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SetParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The set parameter operation that sets parameters in custom action.

            :param parameter_value_configurations: The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_set_parameters_operation_property = quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                        destination_parameter_name="destinationParameterName",
                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                    date_time_values=["dateTimeValues"],
                                    decimal_values=[123],
                                    integer_values=[123],
                                    string_values=["stringValues"]
                                ),
                
                                # the properties below are optional
                                include_null_value=False
                            ),
                            select_all_value_options="selectAllValueOptions",
                            source_field="sourceField",
                            source_parameter_name="sourceParameterName"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ac54c582e1334b5129d225f4bfa0448ed94c50379ee02611475ce29f72a06e0)
                check_type(argname="argument parameter_value_configurations", value=parameter_value_configurations, expected_type=type_hints["parameter_value_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_value_configurations": parameter_value_configurations,
            }

        @builtins.property
        def parameter_value_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SetParameterValueConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''The parameter that determines the value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html#cfn-quicksight-template-customactionsetparametersoperation-parametervalueconfigurations
            '''
            result = self._values.get("parameter_value_configurations")
            assert result is not None, "Required property 'parameter_value_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SetParameterValueConfigurationProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionSetParametersOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomActionURLOperationProperty",
        jsii_struct_bases=[],
        name_mapping={"url_target": "urlTarget", "url_template": "urlTemplate"},
    )
    class CustomActionURLOperationProperty:
        def __init__(
            self,
            *,
            url_target: builtins.str,
            url_template: builtins.str,
        ) -> None:
            '''The URL operation that opens a link to another webpage.

            :param url_target: The target of the ``CustomActionURLOperation`` . Valid values are defined as follows: - ``NEW_TAB`` : Opens the target URL in a new browser tab. - ``NEW_WINDOW`` : Opens the target URL in a new browser window. - ``SAME_TAB`` : Opens the target URL in the same browser tab.
            :param url_template: THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_action_uRLOperation_property = quicksight.CfnTemplate.CustomActionURLOperationProperty(
                    url_target="urlTarget",
                    url_template="urlTemplate"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1c71dc93060b26ed857331e9657aaeeffc215596a19c577dcb854405b4552f98)
                check_type(argname="argument url_target", value=url_target, expected_type=type_hints["url_target"])
                check_type(argname="argument url_template", value=url_template, expected_type=type_hints["url_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "url_target": url_target,
                "url_template": url_template,
            }

        @builtins.property
        def url_target(self) -> builtins.str:
            '''The target of the ``CustomActionURLOperation`` .

            Valid values are defined as follows:

            - ``NEW_TAB`` : Opens the target URL in a new browser tab.
            - ``NEW_WINDOW`` : Opens the target URL in a new browser window.
            - ``SAME_TAB`` : Opens the target URL in the same browser tab.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltarget
            '''
            result = self._values.get("url_target")
            assert result is not None, "Required property 'url_target' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def url_template(self) -> builtins.str:
            '''THe URL link of the ``CustomActionURLOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltemplate
            '''
            result = self._values.get("url_template")
            assert result is not None, "Required property 'url_template' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomActionURLOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "field_value": "fieldValue",
            "special_value": "specialValue",
        },
    )
    class CustomColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            special_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param color: ``CfnTemplate.CustomColorProperty.Color``.
            :param field_value: ``CfnTemplate.CustomColorProperty.FieldValue``.
            :param special_value: ``CfnTemplate.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_color_property = quicksight.CfnTemplate.CustomColorProperty(
                    color="color",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    special_value="specialValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a0a6acdf73ffeb1e8e4a3af9d3563f0252e0a215b6a32b9d75898da5bbb06e20)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument special_value", value=special_value, expected_type=type_hints["special_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if special_value is not None:
                self._values["special_value"] = special_value

        @builtins.property
        def color(self) -> builtins.str:
            '''``CfnTemplate.CustomColorProperty.Color``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''``CfnTemplate.CustomColorProperty.FieldValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def special_value(self) -> typing.Optional[builtins.str]:
            '''``CfnTemplate.CustomColorProperty.SpecialValue``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-specialvalue
            '''
            result = self._values.get("special_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "content_type": "contentType",
            "content_url": "contentUrl",
            "image_scaling": "imageScaling",
        },
    )
    class CustomContentConfigurationProperty:
        def __init__(
            self,
            *,
            content_type: typing.Optional[builtins.str] = None,
            content_url: typing.Optional[builtins.str] = None,
            image_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of a ``CustomContentVisual`` .

            :param content_type: The content type of the custom content visual. You can use this to have the visual render as an image.
            :param content_url: The input URL that links to the custom content that you want in the custom visual.
            :param image_scaling: The sizing options for the size of the custom content visual. This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_content_configuration_property = quicksight.CfnTemplate.CustomContentConfigurationProperty(
                    content_type="contentType",
                    content_url="contentUrl",
                    image_scaling="imageScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3afe7425cdf869aa20d275d5a14ad190e9affc2d505bcad72aa4d3ba920b8654)
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument content_url", value=content_url, expected_type=type_hints["content_url"])
                check_type(argname="argument image_scaling", value=image_scaling, expected_type=type_hints["image_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if content_type is not None:
                self._values["content_type"] = content_type
            if content_url is not None:
                self._values["content_url"] = content_url
            if image_scaling is not None:
                self._values["image_scaling"] = image_scaling

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The content type of the custom content visual.

            You can use this to have the visual render as an image.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def content_url(self) -> typing.Optional[builtins.str]:
            '''The input URL that links to the custom content that you want in the custom visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenturl
            '''
            result = self._values.get("content_url")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def image_scaling(self) -> typing.Optional[builtins.str]:
            '''The sizing options for the size of the custom content visual.

            This structure is required when the ``ContentType`` of the visual is ``'IMAGE'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-imagescaling
            '''
            result = self._values.get("image_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomContentVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class CustomContentVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``CustomContentVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_content_visual_property = quicksight.CfnTemplate.CustomContentVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                        content_type="contentType",
                        content_url="contentUrl",
                        image_scaling="imageScaling"
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f615e7edd8c5109452d4f4f1ad56747e54ab09d2da739c962f166469a7308df)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used to create the custom content visual.

            You can't create a visual without a dataset.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomContentConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``CustomContentVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomContentConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomContentVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomFilterConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_value": "categoryValue",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_value: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom filter that filters based on a single value.

            This filter can be partially matched.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_value: The category value for the filter. This field is mutually exclusive to ``ParameterName`` .
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``CategoryValue`` .
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_filter_configuration_property = quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_value="categoryValue",
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__92bbd515c230d4b2b9a8cb7499081b25a3c07186a6f3aad185f13d902e3aa935)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_value", value=category_value, expected_type=type_hints["category_value"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_value is not None:
                self._values["category_value"] = category_value
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_value(self) -> typing.Optional[builtins.str]:
            '''The category value for the filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-categoryvalue
            '''
            result = self._values.get("category_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``CategoryValue`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomFilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class CustomFilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            null_option: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of custom filter values.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_filter_list_configuration_property = quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__431403adcf325cabd39d04c21f24949e163aaf3e6e5e54293d2475c788127a54)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomFilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomNarrativeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"narrative": "narrative"},
    )
    class CustomNarrativeOptionsProperty:
        def __init__(self, *, narrative: builtins.str) -> None:
            '''The custom narrative options.

            :param narrative: The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_narrative_options_property = quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                    narrative="narrative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dfe7a6364bdaaed3fa6b8d896134d30802613f9b256f9697be85d814a826bf9d)
                check_type(argname="argument narrative", value=narrative, expected_type=type_hints["narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "narrative": narrative,
            }

        @builtins.property
        def narrative(self) -> builtins.str:
            '''The string input of custom narrative.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html#cfn-quicksight-template-customnarrativeoptions-narrative
            '''
            result = self._values.get("narrative")
            assert result is not None, "Required property 'narrative' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomNarrativeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomParameterValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_values": "dateTimeValues",
            "decimal_values": "decimalValues",
            "integer_values": "integerValues",
            "string_values": "stringValues",
        },
    )
    class CustomParameterValuesProperty:
        def __init__(
            self,
            *,
            date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            decimal_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
            integer_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
            string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The customized parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_values: A list of datetime-type parameter values.
            :param decimal_values: A list of decimal-type parameter values.
            :param integer_values: A list of integer-type parameter values.
            :param string_values: A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_parameter_values_property = quicksight.CfnTemplate.CustomParameterValuesProperty(
                    date_time_values=["dateTimeValues"],
                    decimal_values=[123],
                    integer_values=[123],
                    string_values=["stringValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__36986c27bc4546a328c54c5b12879b4f7da33ba2ed7689252d97d5036697b8fb)
                check_type(argname="argument date_time_values", value=date_time_values, expected_type=type_hints["date_time_values"])
                check_type(argname="argument decimal_values", value=decimal_values, expected_type=type_hints["decimal_values"])
                check_type(argname="argument integer_values", value=integer_values, expected_type=type_hints["integer_values"])
                check_type(argname="argument string_values", value=string_values, expected_type=type_hints["string_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_values is not None:
                self._values["date_time_values"] = date_time_values
            if decimal_values is not None:
                self._values["decimal_values"] = decimal_values
            if integer_values is not None:
                self._values["integer_values"] = integer_values
            if string_values is not None:
                self._values["string_values"] = string_values

        @builtins.property
        def date_time_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of datetime-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-datetimevalues
            '''
            result = self._values.get("date_time_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def decimal_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''A list of decimal-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-decimalvalues
            '''
            result = self._values.get("decimal_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        @builtins.property
        def integer_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''A list of integer-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-integervalues
            '''
            result = self._values.get("integer_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        @builtins.property
        def string_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of string-type parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-stringvalues
            '''
            result = self._values.get("string_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomParameterValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.CustomValuesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values": "customValues",
            "include_null_value": "includeNullValue",
        },
    )
    class CustomValuesConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values: typing.Union[typing.Union["CfnTemplate.CustomParameterValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of custom values for the destination parameter in ``DestinationParameterValueConfiguration`` .

            :param custom_values: ``CfnTemplate.CustomValuesConfigurationProperty.CustomValues``.
            :param include_null_value: Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                custom_values_configuration_property = quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                        date_time_values=["dateTimeValues"],
                        decimal_values=[123],
                        integer_values=[123],
                        string_values=["stringValues"]
                    ),
                
                    # the properties below are optional
                    include_null_value=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eabd0aca81507c133d6486d84578cc85a26fc6f01c7816843f61c042b8258195)
                check_type(argname="argument custom_values", value=custom_values, expected_type=type_hints["custom_values"])
                check_type(argname="argument include_null_value", value=include_null_value, expected_type=type_hints["include_null_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_values": custom_values,
            }
            if include_null_value is not None:
                self._values["include_null_value"] = include_null_value

        @builtins.property
        def custom_values(
            self,
        ) -> typing.Union["CfnTemplate.CustomParameterValuesProperty", _IResolvable_a771d0ef]:
            '''``CfnTemplate.CustomValuesConfigurationProperty.CustomValues``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-customvalues
            '''
            result = self._values.get("custom_values")
            assert result is not None, "Required property 'custom_values' is missing"
            return typing.cast(typing.Union["CfnTemplate.CustomParameterValuesProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def include_null_value(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Includes the null value in custom action parameter values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-includenullvalue
            '''
            result = self._values.get("include_null_value")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "CustomValuesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataBarsOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "negative_color": "negativeColor",
            "positive_color": "positiveColor",
        },
    )
    class DataBarsOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            negative_color: typing.Optional[builtins.str] = None,
            positive_color: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for data bars.

            :param field_id: The field ID for the data bars options.
            :param negative_color: The color of the negative data bar.
            :param positive_color: The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_bars_options_property = quicksight.CfnTemplate.DataBarsOptionsProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    negative_color="negativeColor",
                    positive_color="positiveColor"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c23a9173cc7177e64bb59473d0e58e4f622116d4f2826d8226c0b0a7e2eee2ce)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument negative_color", value=negative_color, expected_type=type_hints["negative_color"])
                check_type(argname="argument positive_color", value=positive_color, expected_type=type_hints["positive_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if negative_color is not None:
                self._values["negative_color"] = negative_color
            if positive_color is not None:
                self._values["positive_color"] = positive_color

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the data bars options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def negative_color(self) -> typing.Optional[builtins.str]:
            '''The color of the negative data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-negativecolor
            '''
            result = self._values.get("negative_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def positive_color(self) -> typing.Optional[builtins.str]:
            '''The color of the positive data bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-positivecolor
            '''
            result = self._values.get("positive_color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataBarsOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataColorProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "data_value": "dataValue"},
    )
    class DataColorProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the color that is applied to a particular data value.

            :param color: The color that is applied to the data value.
            :param data_value: The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_color_property = quicksight.CfnTemplate.DataColorProperty(
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__986eea6f6c76b2441c634de131d267bb31ba7e216b8581691ce1bd19692ca6ee)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color that is applied to the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''The data value that the color is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataFieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "settings": "settings",
        },
    )
    class DataFieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            field_value: typing.Optional[builtins.str] = None,
            settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field that you are setting the axis binding to.
            :param field_value: The field value of the field that you are setting the axis binding to.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_field_series_item_property = quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    field_value="fieldValue",
                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70c94c837cbe0ae029c805075a977f29055d8d4fff62307419a5f32c511f9378)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if field_value is not None:
                self._values["field_value"] = field_value
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The field value of the field that you are setting the axis binding to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataFieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "data_label_types": "dataLabelTypes",
            "label_color": "labelColor",
            "label_content": "labelContent",
            "label_font_configuration": "labelFontConfiguration",
            "measure_label_visibility": "measureLabelVisibility",
            "overlap": "overlap",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class DataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            data_label_types: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_content: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            overlap: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: Determines the visibility of the category field labels.
            :param data_label_types: The option that determines the data label type.
            :param label_color: Determines the color of the data labels.
            :param label_content: Determines the content of the data labels.
            :param label_font_configuration: Determines the font configuration of the data labels.
            :param measure_label_visibility: Determines the visibility of the measure field labels.
            :param overlap: Determines whether overlap is enabled or disabled for the data labels.
            :param position: Determines the position of the data labels.
            :param visibility: Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_label_options_property = quicksight.CfnTemplate.DataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                            field_id="fieldId",
                            field_value="fieldValue",
                            visibility="visibility"
                        ),
                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                            field_id="fieldId",
                            visibility="visibility"
                        ),
                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                            visibility="visibility"
                        ),
                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                            visibility="visibility"
                        )
                    )],
                    label_color="labelColor",
                    label_content="labelContent",
                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_label_visibility="measureLabelVisibility",
                    overlap="overlap",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cbd9343b78cb83ee2a284bfee56760b84e318c328dca65c16588944be15f69ff)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument data_label_types", value=data_label_types, expected_type=type_hints["data_label_types"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_content", value=label_content, expected_type=type_hints["label_content"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument overlap", value=overlap, expected_type=type_hints["overlap"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if data_label_types is not None:
                self._values["data_label_types"] = data_label_types
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_content is not None:
                self._values["label_content"] = label_content
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if overlap is not None:
                self._values["overlap"] = overlap
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the category field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_label_types(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataLabelTypeProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the data label type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-datalabeltypes
            '''
            result = self._values.get("data_label_types")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataLabelTypeProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_content(self) -> typing.Optional[builtins.str]:
            '''Determines the content of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcontent
            '''
            result = self._values.get("label_content")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Determines the font configuration of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the measure field labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def overlap(self) -> typing.Optional[builtins.str]:
            '''Determines whether overlap is enabled or disabled for the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-overlap
            '''
            result = self._values.get("overlap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the position of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_label_type": "dataPathLabelType",
            "field_label_type": "fieldLabelType",
            "maximum_label_type": "maximumLabelType",
            "minimum_label_type": "minimumLabelType",
            "range_ends_label_type": "rangeEndsLabelType",
        },
    )
    class DataLabelTypeProperty:
        def __init__(
            self,
            *,
            data_path_label_type: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataPathLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_label_type: typing.Optional[typing.Union[typing.Union["CfnTemplate.FieldLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            maximum_label_type: typing.Optional[typing.Union[typing.Union["CfnTemplate.MaximumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            minimum_label_type: typing.Optional[typing.Union[typing.Union["CfnTemplate.MinimumLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_ends_label_type: typing.Optional[typing.Union[typing.Union["CfnTemplate.RangeEndsLabelTypeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The option that determines the data label type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_path_label_type: The option that specifies individual data values for labels.
            :param field_label_type: Determines the label configuration for the entire field.
            :param maximum_label_type: Determines the label configuration for the maximum value in a visual.
            :param minimum_label_type: Determines the label configuration for the minimum value in a visual.
            :param range_ends_label_type: Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_label_type_property = quicksight.CfnTemplate.DataLabelTypeProperty(
                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                        field_id="fieldId",
                        field_value="fieldValue",
                        visibility="visibility"
                    ),
                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                        field_id="fieldId",
                        visibility="visibility"
                    ),
                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                        visibility="visibility"
                    ),
                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__febe3c79ae1b0c6a205c53ae5c35e4e494a9db28db27a4f7bd1af9673f24786b)
                check_type(argname="argument data_path_label_type", value=data_path_label_type, expected_type=type_hints["data_path_label_type"])
                check_type(argname="argument field_label_type", value=field_label_type, expected_type=type_hints["field_label_type"])
                check_type(argname="argument maximum_label_type", value=maximum_label_type, expected_type=type_hints["maximum_label_type"])
                check_type(argname="argument minimum_label_type", value=minimum_label_type, expected_type=type_hints["minimum_label_type"])
                check_type(argname="argument range_ends_label_type", value=range_ends_label_type, expected_type=type_hints["range_ends_label_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_label_type is not None:
                self._values["data_path_label_type"] = data_path_label_type
            if field_label_type is not None:
                self._values["field_label_type"] = field_label_type
            if maximum_label_type is not None:
                self._values["maximum_label_type"] = maximum_label_type
            if minimum_label_type is not None:
                self._values["minimum_label_type"] = minimum_label_type
            if range_ends_label_type is not None:
                self._values["range_ends_label_type"] = range_ends_label_type

        @builtins.property
        def data_path_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataPathLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''The option that specifies individual data values for labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-datapathlabeltype
            '''
            result = self._values.get("data_path_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataPathLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FieldLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the entire field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-fieldlabeltype
            '''
            result = self._values.get("field_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FieldLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def maximum_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MaximumLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the maximum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-maximumlabeltype
            '''
            result = self._values.get("maximum_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MaximumLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def minimum_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MinimumLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for the minimum value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-minimumlabeltype
            '''
            result = self._values.get("minimum_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MinimumLabelTypeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_ends_label_type(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RangeEndsLabelTypeProperty", _IResolvable_a771d0ef]]:
            '''Determines the label configuration for range end value in a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-rangeendslabeltype
            '''
            result = self._values.get("range_ends_label_type")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RangeEndsLabelTypeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataPathColorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color": "color",
            "element": "element",
            "time_granularity": "timeGranularity",
        },
    )
    class DataPathColorProperty:
        def __init__(
            self,
            *,
            color: builtins.str,
            element: typing.Union[typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The color map that determines the color options for a particular element.

            :param color: The color that needs to be applied to the element.
            :param element: The element that the color needs to be applied to.
            :param time_granularity: The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_color_property = quicksight.CfnTemplate.DataPathColorProperty(
                    color="color",
                    element=quicksight.CfnTemplate.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    ),
                
                    # the properties below are optional
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e842b713fb756bfbe6337496050eac4eb09ca12cdaea7e2f3c9934571401093f)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument element", value=element, expected_type=type_hints["element"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "color": color,
                "element": element,
            }
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def color(self) -> builtins.str:
            '''The color that needs to be applied to the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-color
            '''
            result = self._values.get("color")
            assert result is not None, "Required property 'color' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element(
            self,
        ) -> typing.Union["CfnTemplate.DataPathValueProperty", _IResolvable_a771d0ef]:
            '''The element that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-element
            '''
            result = self._values.get("element")
            assert result is not None, "Required property 'element' is missing"
            return typing.cast(typing.Union["CfnTemplate.DataPathValueProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity of the field that the color needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataPathLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "field_value": "fieldValue",
            "visibility": "visibility",
        },
    )
    class DataPathLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            field_value: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The option that specifies individual data values for labels.

            :param field_id: The field ID of the field that the data label needs to be applied to.
            :param field_value: The actual value of the field that is labeled.
            :param visibility: The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_label_type_property = quicksight.CfnTemplate.DataPathLabelTypeProperty(
                    field_id="fieldId",
                    field_value="fieldValue",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d226641d81b40091940e06f14b381489aba89bd4c47494daba4ab092d38a7fb4)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if field_value is not None:
                self._values["field_value"] = field_value
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the field that the data label needs to be applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_value(self) -> typing.Optional[builtins.str]:
            '''The actual value of the field that is labeled.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldvalue
            '''
            result = self._values.get("field_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataPathSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "sort_paths": "sortPaths"},
    )
    class DataPathSortProperty:
        def __init__(
            self,
            *,
            direction: builtins.str,
            sort_paths: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''Allows data paths to be sorted by a specific data value.

            :param direction: Determines the sort direction.
            :param sort_paths: The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_sort_property = quicksight.CfnTemplate.DataPathSortProperty(
                    direction="direction",
                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__10cdcef6faad4a75e47c795d59dd1857c32028b147b3986ecee0d5285f097562)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument sort_paths", value=sort_paths, expected_type=type_hints["sort_paths"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "sort_paths": sort_paths,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''Determines the sort direction.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_paths(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataPathValueProperty", _IResolvable_a771d0ef]]]:
            '''The list of data paths that need to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-sortpaths
            '''
            result = self._values.get("sort_paths")
            assert result is not None, "Required property 'sort_paths' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataPathValueProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataPathValueProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "field_value": "fieldValue"},
    )
    class DataPathValueProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            field_value: builtins.str,
        ) -> None:
            '''The data path that needs to be sorted.

            :param field_id: The field ID of the field that needs to be sorted.
            :param field_value: The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_path_value_property = quicksight.CfnTemplate.DataPathValueProperty(
                    field_id="fieldId",
                    field_value="fieldValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd6d9c393096edd469072d3bc2ae3b2624beff74a3ee250971977866f7629bb9)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument field_value", value=field_value, expected_type=type_hints["field_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "field_value": field_value,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_value(self) -> builtins.str:
            '''The actual value of the field that needs to be sorted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldvalue
            '''
            result = self._values.get("field_value")
            assert result is not None, "Required property 'field_value' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataPathValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataSetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_group_schema_list": "columnGroupSchemaList",
            "data_set_schema": "dataSetSchema",
            "placeholder": "placeholder",
        },
    )
    class DataSetConfigurationProperty:
        def __init__(
            self,
            *,
            column_group_schema_list: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnGroupSchemaProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_set_schema: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataSetSchemaProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            placeholder: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Dataset configuration.

            :param column_group_schema_list: A structure containing the list of column group schemas.
            :param data_set_schema: Dataset schema.
            :param placeholder: Placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_configuration_property = quicksight.CfnTemplate.DataSetConfigurationProperty(
                    column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                        column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                            name="name"
                        )],
                        name="name"
                    )],
                    data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                        column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                            data_type="dataType",
                            geographic_role="geographicRole",
                            name="name"
                        )]
                    ),
                    placeholder="placeholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7867b3344600a6488acaa336311720a3b05e4259e8c1593e8cd749c38a78d22)
                check_type(argname="argument column_group_schema_list", value=column_group_schema_list, expected_type=type_hints["column_group_schema_list"])
                check_type(argname="argument data_set_schema", value=data_set_schema, expected_type=type_hints["data_set_schema"])
                check_type(argname="argument placeholder", value=placeholder, expected_type=type_hints["placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_group_schema_list is not None:
                self._values["column_group_schema_list"] = column_group_schema_list
            if data_set_schema is not None:
                self._values["data_set_schema"] = data_set_schema
            if placeholder is not None:
                self._values["placeholder"] = placeholder

        @builtins.property
        def column_group_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnGroupSchemaProperty", _IResolvable_a771d0ef]]]]:
            '''A structure containing the list of column group schemas.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-columngroupschemalist
            '''
            result = self._values.get("column_group_schema_list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnGroupSchemaProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_set_schema(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataSetSchemaProperty", _IResolvable_a771d0ef]]:
            '''Dataset schema.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-datasetschema
            '''
            result = self._values.get("data_set_schema")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataSetSchemaProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def placeholder(self) -> typing.Optional[builtins.str]:
            '''Placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-placeholder
            '''
            result = self._values.get("placeholder")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataSetReferenceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_arn": "dataSetArn",
            "data_set_placeholder": "dataSetPlaceholder",
        },
    )
    class DataSetReferenceProperty:
        def __init__(
            self,
            *,
            data_set_arn: builtins.str,
            data_set_placeholder: builtins.str,
        ) -> None:
            '''Dataset reference.

            :param data_set_arn: Dataset Amazon Resource Name (ARN).
            :param data_set_placeholder: Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_reference_property = quicksight.CfnTemplate.DataSetReferenceProperty(
                    data_set_arn="dataSetArn",
                    data_set_placeholder="dataSetPlaceholder"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__517acdef00db34d17d00e274f0affbb1b12358f698ffd023fa8bce130d0346ed)
                check_type(argname="argument data_set_arn", value=data_set_arn, expected_type=type_hints["data_set_arn"])
                check_type(argname="argument data_set_placeholder", value=data_set_placeholder, expected_type=type_hints["data_set_placeholder"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_arn": data_set_arn,
                "data_set_placeholder": data_set_placeholder,
            }

        @builtins.property
        def data_set_arn(self) -> builtins.str:
            '''Dataset Amazon Resource Name (ARN).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetarn
            '''
            result = self._values.get("data_set_arn")
            assert result is not None, "Required property 'data_set_arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_placeholder(self) -> builtins.str:
            '''Dataset placeholder.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetplaceholder
            '''
            result = self._values.get("data_set_placeholder")
            assert result is not None, "Required property 'data_set_placeholder' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetReferenceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DataSetSchemaProperty",
        jsii_struct_bases=[],
        name_mapping={"column_schema_list": "columnSchemaList"},
    )
    class DataSetSchemaProperty:
        def __init__(
            self,
            *,
            column_schema_list: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnSchemaProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Dataset schema.

            :param column_schema_list: A structure containing the list of column schemas.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_set_schema_property = quicksight.CfnTemplate.DataSetSchemaProperty(
                    column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                        data_type="dataType",
                        geographic_role="geographicRole",
                        name="name"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4c92bec9d7d4a5d5cf43399514bd4dd19809d1a0c0dc7003405fbe8f4efd3a3b)
                check_type(argname="argument column_schema_list", value=column_schema_list, expected_type=type_hints["column_schema_list"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_schema_list is not None:
                self._values["column_schema_list"] = column_schema_list

        @builtins.property
        def column_schema_list(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnSchemaProperty", _IResolvable_a771d0ef]]]]:
            '''A structure containing the list of column schemas.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html#cfn-quicksight-template-datasetschema-columnschemalist
            '''
            result = self._values.get("column_schema_list")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnSchemaProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataSetSchemaProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"missing_date_visibility": "missingDateVisibility"},
    )
    class DateAxisOptionsProperty:
        def __init__(
            self,
            *,
            missing_date_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine how a date axis is displayed.

            :param missing_date_visibility: Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_axis_options_property = quicksight.CfnTemplate.DateAxisOptionsProperty(
                    missing_date_visibility="missingDateVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6646c080b7a746259ebfd2512c72d65573c0e27626d2819f0d0f09505799dad1)
                check_type(argname="argument missing_date_visibility", value=missing_date_visibility, expected_type=type_hints["missing_date_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if missing_date_visibility is not None:
                self._values["missing_date_visibility"] = missing_date_visibility

        @builtins.property
        def missing_date_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not missing dates are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html#cfn-quicksight-template-dateaxisoptions-missingdatevisibility
            '''
            result = self._values.get("missing_date_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "date_granularity": "dateGranularity",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class DateDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            date_granularity: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with date type columns.

            :param column: The column that is used in the ``DateDimensionField`` .
            :param field_id: The custom field ID.
            :param date_granularity: The date granularity of the ``DateDimensionField`` . Choose one of the following options:. - ``YEAR`` - ``QUARTER`` - ``MONTH`` - ``WEEK`` - ``DAY`` - ``HOUR`` - ``MINUTE`` - ``SECOND`` - ``MILLISECOND``
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_dimension_field_property = quicksight.CfnTemplate.DateDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    date_granularity="dateGranularity",
                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6fde5ff8bff3c09eb3cc22fb9915e51148329caafeedbed0e7c4613eb46c2bc8)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument date_granularity", value=date_granularity, expected_type=type_hints["date_granularity"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if date_granularity is not None:
                self._values["date_granularity"] = date_granularity
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``DateDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def date_granularity(self) -> typing.Optional[builtins.str]:
            '''The date granularity of the ``DateDimensionField`` . Choose one of the following options:.

            - ``YEAR``
            - ``QUARTER``
            - ``MONTH``
            - ``WEEK``
            - ``DAY``
            - ``HOUR``
            - ``MINUTE``
            - ``SECOND``
            - ``MILLISECOND``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-dategranularity
            '''
            result = self._values.get("date_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class DateMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[builtins.str] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with date type columns.

            :param column: The column that is used in the ``DateMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_measure_field_property = quicksight.CfnTemplate.DateMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function="aggregationFunction",
                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4445a2ee955472c0fbc679f3cb85c13dcf7316e8d96ca69cd010b04457940e1)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``DateMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(self) -> typing.Optional[builtins.str]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateTimeDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "rolling_date": "rollingDate",
            "static_values": "staticValues",
        },
    )
    class DateTimeDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rolling_date: typing.Optional[typing.Union[typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``DateTimeParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DataTimeDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param rolling_date: The rolling date of the ``DataTimeDefaultValues`` . The date is determined from the dataset based on input expression.
            :param static_values: The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_default_values_property = quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7d5c6f15bd5b678baa42ec568addd68bab04fff9be7986c01f044690ec60a504)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``DataTimeDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RollingDateConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The rolling date of the ``DataTimeDefaultValues`` .

            The date is determined from the dataset based on input expression.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RollingDateConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DataTimeDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateTimeFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class DateTimeFormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for ``DateTime`` fields.

            :param date_time_format: Determines the ``DateTime`` format.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_format_configuration_property = quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                    date_time_format="dateTimeFormat",
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2574cc1c98bed3f4a6f3d310622d54f5a0ca6fbfc7483e773cb1cc71c06081d9)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Determines the ``DateTime`` format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The formatting configuration for numeric ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateTimeHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class DateTimeHierarchyProperty:
        def __init__(
            self,
            *,
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of any ``DateTime`` fields.

            :param hierarchy_id: The hierarchy ID of the ``DateTime`` hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_hierarchy_property = quicksight.CfnTemplate.DateTimeHierarchyProperty(
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b64e331b652b216d9e17685aebf0e893960ca460662e015be59fbbf04c1df37d)
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the ``DateTime`` hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateTimeParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "time_granularity": "timeGranularity",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DateTimeParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``DateTime`` data type.

            :param name: The name of the parameter that is being declared.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value_when_unset: The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_parameter_declaration_property = quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                    name="name",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    time_granularity="timeGranularity",
                    value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__85c2334cfd0267e41bbf4939f0ff02249edc9ea90e9819a961e7e3aebda37ac5)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnTemplate.DateTimeParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class DateTimePickerControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_picker_control_display_options_property = quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6e4b6b9cc3eae35f1b0420f446d9792823aeb10bceac0d6c45f3b7f3ffd5e955)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimePickerControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DateTimeValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``DateTime`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                date_time_value_when_unset_configuration_property = quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__687ffdf3d337150dacaca7b508aa52f36cb245ec5328c9a4039369abca507dcb)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DateTimeValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DecimalDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class DecimalDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``DecimalParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``DecimalDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_default_values_property = quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a63d1a98df9b8bb3a5c4e6e10768c93161729c62da0b600c1d1b4f82c72fe8d)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``DecimalDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DecimalParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class DecimalParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.DecimalDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnTemplate.DecimalValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``Decimal`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.DecimalParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_parameter_declaration_property = quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3495cb1258be244fe9de2ff4d45814a512b6ed48d89de7307b7bf8472a00962)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DecimalDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DecimalDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnTemplate.DecimalParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DecimalValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DecimalValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DecimalPlacesConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"decimal_places": "decimalPlaces"},
    )
    class DecimalPlacesConfigurationProperty:
        def __init__(self, *, decimal_places: jsii.Number) -> None:
            '''The option that determines the decimal places configuration.

            :param decimal_places: The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_places_configuration_property = quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                    decimal_places=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9421c25ef79e8b07b8e60532343e0c3b01568bd4a03a2e672cd423e9c48228fb)
                check_type(argname="argument decimal_places", value=decimal_places, expected_type=type_hints["decimal_places"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "decimal_places": decimal_places,
            }

        @builtins.property
        def decimal_places(self) -> jsii.Number:
            '''The values of the decimal places.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html#cfn-quicksight-template-decimalplacesconfiguration-decimalplaces
            '''
            result = self._values.get("decimal_places")
            assert result is not None, "Required property 'decimal_places' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalPlacesConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class DecimalValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``Decimal`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                decimal_value_when_unset_configuration_property = quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1af1b98f4866a5688c72943bf30ac6c06a0cce452e2a430e638e5b84745fb585)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DecimalValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultFreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings of a free-form layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_free_form_layout_configuration_property = quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4a4c18f003a7916d475aa6e2dde0a9c67afbdbe5da45e2c3239f487d6b170b37)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html#cfn-quicksight-template-defaultfreeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultFreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultGridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings for a grid layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_grid_layout_configuration_property = quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c41d313b83eaf358d8111f70033c77d13f5e35df5d6785fc7d2d9f901e308ec)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html#cfn-quicksight-template-defaultgridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultGridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form": "freeForm", "grid": "grid"},
    )
    class DefaultInteractiveLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form: typing.Optional[typing.Union[typing.Union["CfnTemplate.DefaultFreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid: typing.Optional[typing.Union[typing.Union["CfnTemplate.DefaultGridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default settings for interactive layout configuration.

            :param free_form: The options that determine the default settings of a free-form layout configuration.
            :param grid: The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_interactive_layout_configuration_property = quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                    free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ece5753659e12015dc0b5f01760988487a7e8fd36dbd93a244847cc980f3b05a)
                check_type(argname="argument free_form", value=free_form, expected_type=type_hints["free_form"])
                check_type(argname="argument grid", value=grid, expected_type=type_hints["grid"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form is not None:
                self._values["free_form"] = free_form
            if grid is not None:
                self._values["grid"] = grid

        @builtins.property
        def free_form(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DefaultFreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings of a free-form layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-freeform
            '''
            result = self._values.get("free_form")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DefaultFreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DefaultGridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a grid layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-grid
            '''
            result = self._values.get("grid")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DefaultGridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultInteractiveLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "interactive_layout_configuration": "interactiveLayoutConfiguration",
            "paginated_layout_configuration": "paginatedLayoutConfiguration",
            "sheet_content_type": "sheetContentType",
        },
    )
    class DefaultNewSheetConfigurationProperty:
        def __init__(
            self,
            *,
            interactive_layout_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DefaultInteractiveLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_layout_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DefaultPaginatedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sheet_content_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration for default new sheet settings.

            :param interactive_layout_configuration: The options that determine the default settings for interactive layout configuration.
            :param paginated_layout_configuration: The options that determine the default settings for a paginated layout configuration.
            :param sheet_content_type: The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_new_sheet_configuration_property = quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                    interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                        free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    ),
                    paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                        section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                            canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            )
                        )
                    ),
                    sheet_content_type="sheetContentType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4113d983c50491bcd143f148aa44a22cb1ab0c48cdc2444f12da537d903cce08)
                check_type(argname="argument interactive_layout_configuration", value=interactive_layout_configuration, expected_type=type_hints["interactive_layout_configuration"])
                check_type(argname="argument paginated_layout_configuration", value=paginated_layout_configuration, expected_type=type_hints["paginated_layout_configuration"])
                check_type(argname="argument sheet_content_type", value=sheet_content_type, expected_type=type_hints["sheet_content_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if interactive_layout_configuration is not None:
                self._values["interactive_layout_configuration"] = interactive_layout_configuration
            if paginated_layout_configuration is not None:
                self._values["paginated_layout_configuration"] = paginated_layout_configuration
            if sheet_content_type is not None:
                self._values["sheet_content_type"] = sheet_content_type

        @builtins.property
        def interactive_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DefaultInteractiveLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for interactive layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-interactivelayoutconfiguration
            '''
            result = self._values.get("interactive_layout_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DefaultInteractiveLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_layout_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DefaultPaginatedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a paginated layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-paginatedlayoutconfiguration
            '''
            result = self._values.get("paginated_layout_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DefaultPaginatedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sheet_content_type(self) -> typing.Optional[builtins.str]:
            '''The option that determines the sheet content type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-sheetcontenttype
            '''
            result = self._values.get("sheet_content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultNewSheetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"section_based": "sectionBased"},
    )
    class DefaultPaginatedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            section_based: typing.Optional[typing.Union[typing.Union["CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default settings for a paginated layout configuration.

            :param section_based: The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_paginated_layout_configuration_property = quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                    section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                        canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__399e9696b83e0c3677fff2fe5778c16e6963255ca18b8843415114ef9603ffaf)
                check_type(argname="argument section_based", value=section_based, expected_type=type_hints["section_based"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if section_based is not None:
                self._values["section_based"] = section_based

        @builtins.property
        def section_based(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default settings for a section-based layout configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-template-defaultpaginatedlayoutconfiguration-sectionbased
            '''
            result = self._values.get("section_based")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultPaginatedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"canvas_size_options": "canvasSizeOptions"},
    )
    class DefaultSectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            canvas_size_options: typing.Union[typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The options that determine the default settings for a section-based layout configuration.

            :param canvas_size_options: Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                default_section_based_layout_configuration_property = quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7aeee674423bd0120cd29e2e13dc5241d9dbd2d7eebf7dcf39eb89d4335e61d5)
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "canvas_size_options": canvas_size_options,
            }

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''Determines the screen canvas size options for a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-template-defaultsectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DefaultSectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_values_configuration": "customValuesConfiguration",
            "select_all_value_options": "selectAllValueOptions",
            "source_field": "sourceField",
            "source_parameter_name": "sourceParameterName",
        },
    )
    class DestinationParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            custom_values_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomValuesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_value_options: typing.Optional[builtins.str] = None,
            source_field: typing.Optional[builtins.str] = None,
            source_parameter_name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of destination parameter values.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_values_configuration: The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .
            :param select_all_value_options: The configuration that selects all options.
            :param source_field: The source field ID of the destination parameter.
            :param source_parameter_name: The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                destination_parameter_value_configuration_property = quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                            date_time_values=["dateTimeValues"],
                            decimal_values=[123],
                            integer_values=[123],
                            string_values=["stringValues"]
                        ),
                
                        # the properties below are optional
                        include_null_value=False
                    ),
                    select_all_value_options="selectAllValueOptions",
                    source_field="sourceField",
                    source_parameter_name="sourceParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ff618ac2310368210449f7e6dbcef555152246d58c93a92b9a8aa20499acc315)
                check_type(argname="argument custom_values_configuration", value=custom_values_configuration, expected_type=type_hints["custom_values_configuration"])
                check_type(argname="argument select_all_value_options", value=select_all_value_options, expected_type=type_hints["select_all_value_options"])
                check_type(argname="argument source_field", value=source_field, expected_type=type_hints["source_field"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_values_configuration is not None:
                self._values["custom_values_configuration"] = custom_values_configuration
            if select_all_value_options is not None:
                self._values["select_all_value_options"] = select_all_value_options
            if source_field is not None:
                self._values["source_field"] = source_field
            if source_parameter_name is not None:
                self._values["source_parameter_name"] = source_parameter_name

        @builtins.property
        def custom_values_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomValuesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of custom values for destination parameter in ``DestinationParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-customvaluesconfiguration
            '''
            result = self._values.get("custom_values_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomValuesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_value_options(self) -> typing.Optional[builtins.str]:
            '''The configuration that selects all options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-selectallvalueoptions
            '''
            result = self._values.get("select_all_value_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_field(self) -> typing.Optional[builtins.str]:
            '''The source field ID of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcefield
            '''
            result = self._values.get("source_field")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def source_parameter_name(self) -> typing.Optional[builtins.str]:
            '''The source parameter name of the destination parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DestinationParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "categorical_dimension_field": "categoricalDimensionField",
            "date_dimension_field": "dateDimensionField",
            "numerical_dimension_field": "numericalDimensionField",
        },
    )
    class DimensionFieldProperty:
        def __init__(
            self,
            *,
            categorical_dimension_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.CategoricalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            date_dimension_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numerical_dimension_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericalDimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The dimension type field.

            :param categorical_dimension_field: The dimension type field with categorical type columns.
            :param date_dimension_field: The dimension type field with date type columns.
            :param numerical_dimension_field: The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dimension_field_property = quicksight.CfnTemplate.DimensionFieldProperty(
                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        date_granularity="dateGranularity",
                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    ),
                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        hierarchy_id="hierarchyId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b968e9abb6cdb63dc546b14a28e092b37d4d91b14a7609bcea9efeb901dc629)
                check_type(argname="argument categorical_dimension_field", value=categorical_dimension_field, expected_type=type_hints["categorical_dimension_field"])
                check_type(argname="argument date_dimension_field", value=date_dimension_field, expected_type=type_hints["date_dimension_field"])
                check_type(argname="argument numerical_dimension_field", value=numerical_dimension_field, expected_type=type_hints["numerical_dimension_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if categorical_dimension_field is not None:
                self._values["categorical_dimension_field"] = categorical_dimension_field
            if date_dimension_field is not None:
                self._values["date_dimension_field"] = date_dimension_field
            if numerical_dimension_field is not None:
                self._values["numerical_dimension_field"] = numerical_dimension_field

        @builtins.property
        def categorical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CategoricalDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-categoricaldimensionfield
            '''
            result = self._values.get("categorical_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CategoricalDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def date_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-datedimensionfield
            '''
            result = self._values.get("date_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numerical_dimension_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericalDimensionFieldProperty", _IResolvable_a771d0ef]]:
            '''The dimension type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-numericaldimensionfield
            '''
            result = self._values.get("numerical_dimension_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericalDimensionFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DonutCenterOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"label_visibility": "labelVisibility"},
    )
    class DonutCenterOptionsProperty:
        def __init__(
            self,
            *,
            label_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :param label_visibility: Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                donut_center_options_property = quicksight.CfnTemplate.DonutCenterOptionsProperty(
                    label_visibility="labelVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__16d07d8eb8f08198c8e73efb46aa7e61f5980c8762629d2fa2e1089f0d698b81)
                check_type(argname="argument label_visibility", value=label_visibility, expected_type=type_hints["label_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if label_visibility is not None:
                self._values["label_visibility"] = label_visibility

        @builtins.property
        def label_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the label in a donut chart.

            In the Amazon QuickSight console, this option is called ``'Show total'`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html#cfn-quicksight-template-donutcenteroptions-labelvisibility
            '''
            result = self._values.get("label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutCenterOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DonutOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc_options": "arcOptions",
            "donut_center_options": "donutCenterOptions",
        },
    )
    class DonutOptionsProperty:
        def __init__(
            self,
            *,
            arc_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ArcOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            donut_center_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DonutCenterOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for configuring a donut chart or pie chart.

            :param arc_options: The option for define the arc of the chart shape. Valid values are as follows:. - ``WHOLE`` - A pie chart - ``SMALL`` - A small-sized donut chart - ``MEDIUM`` - A medium-sized donut chart - ``LARGE`` - A large-sized donut chart
            :param donut_center_options: The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                donut_options_property = quicksight.CfnTemplate.DonutOptionsProperty(
                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                        arc_thickness="arcThickness"
                    ),
                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                        label_visibility="labelVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f162daf32a440d32c14d0ab1b4382ae53271fd98bfe720fa8286474172854cbc)
                check_type(argname="argument arc_options", value=arc_options, expected_type=type_hints["arc_options"])
                check_type(argname="argument donut_center_options", value=donut_center_options, expected_type=type_hints["donut_center_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc_options is not None:
                self._values["arc_options"] = arc_options
            if donut_center_options is not None:
                self._values["donut_center_options"] = donut_center_options

        @builtins.property
        def arc_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ArcOptionsProperty", _IResolvable_a771d0ef]]:
            '''The option for define the arc of the chart shape. Valid values are as follows:.

            - ``WHOLE`` - A pie chart
            - ``SMALL`` - A small-sized donut chart
            - ``MEDIUM`` - A medium-sized donut chart
            - ``LARGE`` - A large-sized donut chart

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-arcoptions
            '''
            result = self._values.get("arc_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ArcOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def donut_center_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DonutCenterOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the label that is displayed in the center of a donut chart.

            This option isn't available for pie charts.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-donutcenteroptions
            '''
            result = self._values.get("donut_center_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DonutCenterOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DonutOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "time_range_filter": "timeRangeFilter",
        },
    )
    class DrillDownFilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.CategoryDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericEqualityDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_range_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.TimeRangeDrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The drill down filter for the column hierarchies.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: The category type drill down filter. This filter is used for string type columns.
            :param numeric_equality_filter: The numeric equality type drill down filter. This filter is used for number type columns.
            :param time_range_filter: The time range drill down filter. This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                drill_down_filter_property = quicksight.CfnTemplate.DrillDownFilterProperty(
                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                        category_values=["categoryValues"],
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        value=123
                    ),
                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        range_maximum="rangeMaximum",
                        range_minimum="rangeMinimum",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3f19f7f523b71b0aed17616e55be4efee20f4f81ca5a7ca85cee04537296046e)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CategoryDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The category type drill down filter.

            This filter is used for string type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CategoryDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericEqualityDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The numeric equality type drill down filter.

            This filter is used for number type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericEqualityDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TimeRangeDrillDownFilterProperty", _IResolvable_a771d0ef]]:
            '''The time range drill down filter.

            This filter is used for date time columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TimeRangeDrillDownFilterProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class DropDownControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            select_all_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param select_all_options: The configuration of the ``Select all`` options in a dropdown control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                drop_down_control_display_options_property = quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3958cee17b6ba78e3f08ed694e20fe2959d6bed5118ccb03850b8cdc87dc098)
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the ``Select all`` options in a dropdown control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DropDownControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.DynamicDefaultValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "default_value_column": "defaultValueColumn",
            "group_name_column": "groupNameColumn",
            "user_name_column": "userNameColumn",
        },
    )
    class DynamicDefaultValueProperty:
        def __init__(
            self,
            *,
            default_value_column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            group_name_column: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            user_name_column: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Defines different defaults to the users or groups based on mapping.

            :param default_value_column: The column that contains the default value of each user or group.
            :param group_name_column: The column that contains the group name.
            :param user_name_column: The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                dynamic_default_value_property = quicksight.CfnTemplate.DynamicDefaultValueProperty(
                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                
                    # the properties below are optional
                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b531afbf9e163e0b94cb3d523eacd67630ca0acb0ee5989a6023bf6d282caafa)
                check_type(argname="argument default_value_column", value=default_value_column, expected_type=type_hints["default_value_column"])
                check_type(argname="argument group_name_column", value=group_name_column, expected_type=type_hints["group_name_column"])
                check_type(argname="argument user_name_column", value=user_name_column, expected_type=type_hints["user_name_column"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "default_value_column": default_value_column,
            }
            if group_name_column is not None:
                self._values["group_name_column"] = group_name_column
            if user_name_column is not None:
                self._values["user_name_column"] = user_name_column

        @builtins.property
        def default_value_column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that contains the default value of each user or group.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-defaultvaluecolumn
            '''
            result = self._values.get("default_value_column")
            assert result is not None, "Required property 'default_value_column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def group_name_column(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column that contains the group name.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-groupnamecolumn
            '''
            result = self._values.get("group_name_column")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def user_name_column(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column that contains the username.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-usernamecolumn
            '''
            result = self._values.get("user_name_column")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DynamicDefaultValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.EmptyVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
        },
    )
    class EmptyVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''An empty visual.

            Empty visuals are used in layouts but have not been configured to show any data. A new visual created in the Amazon QuickSight console is considered an ``EmptyVisual`` until a visual type is selected.

            :param data_set_identifier: The data set that is used in the empty visual. Every visual requires a dataset to render.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                empty_visual_property = quicksight.CfnTemplate.EmptyVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3439b3b58b64299ffbe03514dbb2c0c1111229aea0d250c4e2ca8c94b951412)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The data set that is used in the empty visual.

            Every visual requires a dataset to render.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EmptyVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.EntityProperty",
        jsii_struct_bases=[],
        name_mapping={"path": "path"},
    )
    class EntityProperty:
        def __init__(self, *, path: typing.Optional[builtins.str] = None) -> None:
            '''An object, structure, or sub-structure of an analysis, template, or dashboard.

            :param path: The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                entity_property = quicksight.CfnTemplate.EntityProperty(
                    path="path"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35bbd61bd39c8fbf0c7d1701694f75a43d49ec5b06186de709eb3b8068ed5bcd)
                check_type(argname="argument path", value=path, expected_type=type_hints["path"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if path is not None:
                self._values["path"] = path

        @builtins.property
        def path(self) -> typing.Optional[builtins.str]:
            '''The hierarchical path of the entity within the analysis, template, or dashboard definition tree.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html#cfn-quicksight-template-entity-path
            '''
            result = self._values.get("path")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "EntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ExcludePeriodConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "amount": "amount",
            "granularity": "granularity",
            "status": "status",
        },
    )
    class ExcludePeriodConfigurationProperty:
        def __init__(
            self,
            *,
            amount: jsii.Number,
            granularity: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The exclude period of ``TimeRangeFilter`` or ``RelativeDatesFilter`` .

            :param amount: The amount or number of the exclude period.
            :param granularity: The granularity or unit (day, month, year) of the exclude period.
            :param status: The status of the exclude period. Choose from the following options:. - ``ENABLED`` - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                exclude_period_configuration_property = quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                    amount=123,
                    granularity="granularity",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f90c41e10426b2b2163f788a29630672fec9efef3beadab5458d00dda3db8c66)
                check_type(argname="argument amount", value=amount, expected_type=type_hints["amount"])
                check_type(argname="argument granularity", value=granularity, expected_type=type_hints["granularity"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "amount": amount,
                "granularity": granularity,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def amount(self) -> jsii.Number:
            '''The amount or number of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-amount
            '''
            result = self._values.get("amount")
            assert result is not None, "Required property 'amount' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def granularity(self) -> builtins.str:
            '''The granularity or unit (day, month, year) of the exclude period.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-granularity
            '''
            result = self._values.get("granularity")
            assert result is not None, "Required property 'granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the exclude period. Choose from the following options:.

            - ``ENABLED``
            - ``DISABLED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExcludePeriodConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ExplicitHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class ExplicitHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are built within a visual's field wells.

            These fields can't be duplicated to other visuals.

            :param columns: The list of columns that define the explicit hierarchy.
            :param hierarchy_id: The hierarchy ID of the explicit hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                explicit_hierarchy_property = quicksight.CfnTemplate.ExplicitHierarchyProperty(
                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b8afe23c4b3549b89f81e20f8c65924ce77a844879cc02b15c5cbb43f67bcd1a)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The list of columns that define the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the explicit hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ExplicitHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FieldBasedTooltipProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_visibility": "aggregationVisibility",
            "tooltip_fields": "tooltipFields",
            "tooltip_title_type": "tooltipTitleType",
        },
    )
    class FieldBasedTooltipProperty:
        def __init__(
            self,
            *,
            aggregation_visibility: typing.Optional[builtins.str] = None,
            tooltip_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.TooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            tooltip_title_type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The setup for the detailed tooltip.

            :param aggregation_visibility: The visibility of ``Show aggregations`` .
            :param tooltip_fields: The fields configuration in the tooltip.
            :param tooltip_title_type: The type for the >tooltip title. Choose one of the following options:. - ``NONE`` : Doesn't use the primary value as the title. - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_based_tooltip_property = quicksight.CfnTemplate.FieldBasedTooltipProperty(
                    aggregation_visibility="aggregationVisibility",
                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            label="label",
                            visibility="visibility"
                        ),
                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            label="label",
                            visibility="visibility"
                        )
                    )],
                    tooltip_title_type="tooltipTitleType"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3cb71b0237d587e0960bd535e81d80a5d62e841e7049842b21d98acf062312d7)
                check_type(argname="argument aggregation_visibility", value=aggregation_visibility, expected_type=type_hints["aggregation_visibility"])
                check_type(argname="argument tooltip_fields", value=tooltip_fields, expected_type=type_hints["tooltip_fields"])
                check_type(argname="argument tooltip_title_type", value=tooltip_title_type, expected_type=type_hints["tooltip_title_type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if aggregation_visibility is not None:
                self._values["aggregation_visibility"] = aggregation_visibility
            if tooltip_fields is not None:
                self._values["tooltip_fields"] = tooltip_fields
            if tooltip_title_type is not None:
                self._values["tooltip_title_type"] = tooltip_title_type

        @builtins.property
        def aggregation_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of ``Show aggregations`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-aggregationvisibility
            '''
            result = self._values.get("aggregation_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TooltipItemProperty", _IResolvable_a771d0ef]]]]:
            '''The fields configuration in the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltipfields
            '''
            result = self._values.get("tooltip_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TooltipItemProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def tooltip_title_type(self) -> typing.Optional[builtins.str]:
            '''The type for the >tooltip title. Choose one of the following options:.

            - ``NONE`` : Doesn't use the primary value as the title.
            - ``PRIMARY_VALUE`` : Uses primary value as the title.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltiptitletype
            '''
            result = self._values.get("tooltip_title_type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldBasedTooltipProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FieldLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "visibility": "visibility"},
    )
    class FieldLabelTypeProperty:
        def __init__(
            self,
            *,
            field_id: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The field label type.

            :param field_id: Indicates the field that is targeted by the field label.
            :param visibility: The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_label_type_property = quicksight.CfnTemplate.FieldLabelTypeProperty(
                    field_id="fieldId",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a78dda34e070c463968746ffa0b6db48b21ff4bc1b29d563613bd1746fbb24b)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''Indicates the field that is targeted by the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the field label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FieldSeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "field_id": "fieldId",
            "settings": "settings",
        },
    )
    class FieldSeriesItemProperty:
        def __init__(
            self,
            *,
            axis_binding: builtins.str,
            field_id: builtins.str,
            settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field series item configuration of a line chart.

            :param axis_binding: The axis that you are binding the field to.
            :param field_id: The field ID of the field for which you are setting the axis binding.
            :param settings: The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_series_item_property = quicksight.CfnTemplate.FieldSeriesItemProperty(
                    axis_binding="axisBinding",
                    field_id="fieldId",
                
                    # the properties below are optional
                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__655400cc9a8d3ddafffdbff970e7fe07f487e727f7695864857c2f11f07ab613)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument settings", value=settings, expected_type=type_hints["settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "axis_binding": axis_binding,
                "field_id": field_id,
            }
            if settings is not None:
                self._values["settings"] = settings

        @builtins.property
        def axis_binding(self) -> builtins.str:
            '''The axis that you are binding the field to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-axisbinding
            '''
            result = self._values.get("axis_binding")
            assert result is not None, "Required property 'axis_binding' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the field for which you are setting the axis binding.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of line series associated to the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-settings
            '''
            result = self._values.get("settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"column_sort": "columnSort", "field_sort": "fieldSort"},
    )
    class FieldSortOptionsProperty:
        def __init__(
            self,
            *,
            column_sort: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_sort: typing.Optional[typing.Union[typing.Union["CfnTemplate.FieldSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field sort options in a chart configuration.

            :param column_sort: The sort configuration for a column that is not used in a field well.
            :param field_sort: The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_sort_options_property = quicksight.CfnTemplate.FieldSortOptionsProperty(
                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__91fa599a6a19a78991e1577ed44c063b414dd383736a03bdfa48143d247fd150)
                check_type(argname="argument column_sort", value=column_sort, expected_type=type_hints["column_sort"])
                check_type(argname="argument field_sort", value=field_sort, expected_type=type_hints["field_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_sort is not None:
                self._values["column_sort"] = column_sort
            if field_sort is not None:
                self._values["field_sort"] = field_sort

        @builtins.property
        def column_sort(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnSortProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a column that is not used in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-columnsort
            '''
            result = self._values.get("column_sort")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_sort(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FieldSortProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a field in a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-fieldsort
            '''
            result = self._values.get("field_sort")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FieldSortProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FieldSortProperty",
        jsii_struct_bases=[],
        name_mapping={"direction": "direction", "field_id": "fieldId"},
    )
    class FieldSortProperty:
        def __init__(self, *, direction: builtins.str, field_id: builtins.str) -> None:
            '''The sort configuration for a field in a field well.

            :param direction: The sort direction. Choose one of the following options:. - ``ASC`` : Ascending - ``DESC`` : Descending
            :param field_id: The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_sort_property = quicksight.CfnTemplate.FieldSortProperty(
                    direction="direction",
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df95c7ae16d080166819aeb029fbedcc31e68e5e08714f0ebf149d792ec45a21)
                check_type(argname="argument direction", value=direction, expected_type=type_hints["direction"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "direction": direction,
                "field_id": field_id,
            }

        @builtins.property
        def direction(self) -> builtins.str:
            '''The sort direction. Choose one of the following options:.

            - ``ASC`` : Ascending
            - ``DESC`` : Descending

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-direction
            '''
            result = self._values.get("direction")
            assert result is not None, "Required property 'direction' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The sort configuration target field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldSortProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FieldTooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "label": "label",
            "visibility": "visibility",
        },
    )
    class FieldTooltipItemProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The tooltip item for the fields.

            :param field_id: The unique ID of the field that is targeted by the tooltip.
            :param label: The label of the tooltip item.
            :param visibility: The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                field_tooltip_item_property = quicksight.CfnTemplate.FieldTooltipItemProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    label="label",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11357835ce4d1e05bc029e9e2f155819ef12044b432b32bdf0ef8f102ce5a05f)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument label", value=label, expected_type=type_hints["label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if label is not None:
                self._values["label"] = label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The unique ID of the field that is targeted by the tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def label(self) -> typing.Optional[builtins.str]:
            '''The label of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-label
            '''
            result = self._values.get("label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the tooltip item.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FieldTooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"geospatial": "geospatial", "values": "values"},
    )
    class FilledMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well of the filled map.

            :param geospatial: The aggregated location field well of the filled map. Values are grouped by location fields.
            :param values: The aggregated color field well of a filled map. Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_aggregated_field_wells_property = quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bed6f4e08fc9987bdad3c6138a0d78f0a83736775d4c5fe033686ed031f04e5f)
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated location field well of the filled map.

            Values are grouped by location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated color field well of a filled map.

            Values are aggregated based on location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"shape": "shape"},
    )
    class FilledMapConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            shape: typing.Union[typing.Union["CfnTemplate.FilledMapShapeConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :param shape: The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_option_property = quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4e7f890cf306784b86a0ae39e2fc11f52b416fcca8ea84a522a8d51417f846e9)
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "shape": shape,
            }

        @builtins.property
        def shape(
            self,
        ) -> typing.Union["CfnTemplate.FilledMapShapeConditionalFormattingProperty", _IResolvable_a771d0ef]:
            '''The conditional formatting that determines the shape of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html#cfn-quicksight-template-filledmapconditionalformattingoption-shape
            '''
            result = self._values.get("shape")
            assert result is not None, "Required property 'shape' is missing"
            return typing.cast(typing.Union["CfnTemplate.FilledMapShapeConditionalFormattingProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class FilledMapConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FilledMapConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_conditional_formatting_property = quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6412f0ce73e461ce7531504c120b2e6000c5a1aac2e0af5dee82ea16e9299b88)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "conditional_formatting_options": conditional_formatting_options,
            }

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilledMapConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]:
            '''Conditional formatting options of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html#cfn-quicksight-template-filledmapconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            assert result is not None, "Required property 'conditional_formatting_options' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilledMapConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "window_options": "windowOptions",
        },
    )
    class FilledMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilledMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_style_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilledMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            window_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``FilledMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the filled map visual.
            :param sort_configuration: The sort configuration of a ``FilledMapVisual`` .
            :param tooltip: The tooltip display setup of the visual.
            :param window_options: The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_configuration_property = quicksight.CfnTemplate.FilledMapConfigurationProperty(
                    field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                        filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bd2e26a82ccc8b908754ea11b287c2d96ccb965f17209efa0867745e159030d7)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilledMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilledMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The map style options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilledMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilledMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The window options of the filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filled_map_aggregated_field_wells": "filledMapAggregatedFieldWells",
        },
    )
    class FilledMapFieldWellsProperty:
        def __init__(
            self,
            *,
            filled_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilledMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``FilledMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filled_map_aggregated_field_wells: The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_field_wells_property = quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc3c00c9229e2a92bd2792b41c201b812241182543c4ab65353fc9f0d6269034)
                check_type(argname="argument filled_map_aggregated_field_wells", value=filled_map_aggregated_field_wells, expected_type=type_hints["filled_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filled_map_aggregated_field_wells is not None:
                self._values["filled_map_aggregated_field_wells"] = filled_map_aggregated_field_wells

        @builtins.property
        def filled_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilledMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well of the filled map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html#cfn-quicksight-template-filledmapfieldwells-filledmapaggregatedfieldwells
            '''
            result = self._values.get("filled_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilledMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "format": "format"},
    )
    class FilledMapShapeConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            format: typing.Optional[typing.Union[typing.Union["CfnTemplate.ShapeConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting that determines the shape of the filled map.

            :param field_id: The field ID of the filled map shape.
            :param format: The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_shape_conditional_formatting_property = quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5e3fd0aec1db2cd6b609dc7ef753c1351491e4518fb862857619536341e5e529)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format", value=format, expected_type=type_hints["format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if format is not None:
                self._values["format"] = format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the filled map shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ShapeConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting that determines the background color of a filled map's shape.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-format
            '''
            result = self._values.get("format")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ShapeConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapShapeConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"category_sort": "categorySort"},
    )
    class FilledMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FilledMapVisual`` .

            :param category_sort: The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_sort_configuration_property = quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1213c455eb989f68b5559fedae3ccad00e65da67b87c336abe46a79270af9ff)
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the location fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html#cfn-quicksight-template-filledmapsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilledMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FilledMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilledMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilledMapConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a ``FilledMapVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filled_map_visual_property = quicksight.CfnTemplate.FilledMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                        field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                            filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                            shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d50769b122efc97da1fd28c8ade51b0d77c814c7176b35fa4fd7cb70ecba6a53)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilledMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilledMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilledMapConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a ``FilledMapVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilledMapConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilledMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "relative_date_time": "relativeDateTime",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class FilterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            dropdown: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            list: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterListControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_date_time: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterRelativeDateTimeControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            slider: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterSliderControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_area: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The control of a filter that is used to interact with a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date filter that is used to specify date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
            :param relative_date_time: A control from a date filter that is used to specify the relative date.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_control_property = quicksight.CfnTemplate.FilterControlProperty(
                    date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnTemplate.FilterListControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                            values=["values"]
                        ),
                        type="type"
                    ),
                    relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                        filter_control_id="filterControlId",
                        maximum_value=123,
                        minimum_value=123,
                        source_filter_id="sourceFilterId",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        type="type"
                    ),
                    text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                        filter_control_id="filterControlId",
                        source_filter_id="sourceFilterId",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dc2ef27050d0448639b1c9e5c17d996d7e0bd34f43d727ec848b5dbee34cb5e5)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument relative_date_time", value=relative_date_time, expected_type=type_hints["relative_date_time"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if relative_date_time is not None:
                self._values["relative_date_time"] = relative_date_time
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterDateTimePickerControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date filter that is used to specify date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterDateTimePickerControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterDropDownControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterDropDownControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterListControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterListControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_date_time(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterRelativeDateTimeControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date filter that is used to specify the relative date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-relativedatetime
            '''
            result = self._values.get("relative_date_time")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterRelativeDateTimeControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterSliderControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterSliderControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterTextAreaControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterTextAreaControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterTextFieldControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterTextFieldControlProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control from a date filter that is used to specify date and time.

            :param filter_control_id: The ID of the ``FilterDateTimePickerControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDateTimePickerControl`` .
            :param title: The title of the ``FilterDateTimePickerControl`` .
            :param display_options: The display options of a control.
            :param type: The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:. - ``SINGLE_VALUED`` : The filter condition is a fixed date. - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_date_time_picker_control_property = quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97b6f734a43d2db830c340a5ba9e0a308bea43af57467cb43f214b04eb1633ac)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The date time picker type of a ``FilterDateTimePickerControl`` . Choose one of the following options:.

            - ``SINGLE_VALUED`` : The filter condition is a fixed date.
            - ``DATE_RANGE`` : The filter condition is a date time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterDropDownControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param filter_control_id: The ID of the ``FilterDropDownControl`` .
            :param source_filter_id: The source filter ID of the ``FilterDropDownControl`` .
            :param title: The title of the ``FilterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of the ``FilterDropDownControl`` .
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of the ``FilterDropDownControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu. - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_drop_down_control_property = quicksight.CfnTemplate.FilterDropDownControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94444478a15e6db1c44f47cc2149bc35dd3038f4f0b613068c41b599720bf7b2)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of the ``FilterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of the ``FilterDropDownControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from a dropdown menu.
            - ``SINGLE_SELECT`` : The user can select a single entry from a dropdown menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterGroupProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cross_dataset": "crossDataset",
            "filter_group_id": "filterGroupId",
            "filters": "filters",
            "scope_configuration": "scopeConfiguration",
            "status": "status",
        },
    )
    class FilterGroupProperty:
        def __init__(
            self,
            *,
            cross_dataset: builtins.str,
            filter_group_id: builtins.str,
            filters: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            scope_configuration: typing.Union[typing.Union["CfnTemplate.FilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A grouping of individual filters. Filter groups are applied to the same group of visuals.

            For more information, see `Adding filter conditions (group filters) with AND and OR operators <https://docs.aws.amazon.com/quicksight/latest/user/add-a-compound-filter.html>`_ in the *Amazon QuickSight User Guide* .

            :param cross_dataset: The filter new feature which can apply filter group to all data sets. Choose one of the following options:. - ``ALL_DATASETS`` - ``SINGLE_DATASET``
            :param filter_group_id: The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.
            :param filters: The list of filters that are present in a ``FilterGroup`` .
            :param scope_configuration: The configuration that specifies what scope to apply to a ``FilterGroup`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param status: The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_group_property = quicksight.CfnTemplate.FilterGroupProperty(
                    cross_dataset="crossDataset",
                    filter_group_id="filterGroupId",
                    filters=[quicksight.CfnTemplate.FilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_value="categoryValue",
                                    parameter_name="parameterName",
                                    select_all_options="selectAllOptions"
                                ),
                                custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                    match_operator="matchOperator",
                                    null_option="nullOption",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                ),
                                filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                    match_operator="matchOperator",
                
                                    # the properties below are optional
                                    category_values=["categoryValues"],
                                    select_all_options="selectAllOptions"
                                )
                            ),
                            filter_id="filterId"
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            match_operator="matchOperator",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            parameter_name="parameterName",
                            select_all_options="selectAllOptions",
                            value=123
                        ),
                        numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                parameter="parameter",
                                static_value=123
                            ),
                            select_all_options="selectAllOptions"
                        ),
                        relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                            anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                anchor_option="anchorOption",
                                parameter_name="parameterName"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                            relative_date_type="relativeDateType",
                            time_granularity="timeGranularity",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            minimum_granularity="minimumGranularity",
                            parameter_name="parameterName",
                            relative_date_value=123
                        ),
                        time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            parameter_name="parameterName",
                            time_granularity="timeGranularity",
                            value="value"
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                            null_option="nullOption",
                
                            # the properties below are optional
                            exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                amount=123,
                                granularity="granularity",
                
                                # the properties below are optional
                                status="status"
                            ),
                            include_maximum=False,
                            include_minimum=False,
                            range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                parameter="parameter",
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_value="staticValue"
                            ),
                            time_granularity="timeGranularity"
                        ),
                        top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                            aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                sort_direction="sortDirection"
                            )],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            filter_id="filterId",
                
                            # the properties below are optional
                            limit=123,
                            parameter_name="parameterName",
                            time_granularity="timeGranularity"
                        )
                    )],
                    scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                        selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                            sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                scope="scope",
                                sheet_id="sheetId",
                
                                # the properties below are optional
                                visual_ids=["visualIds"]
                            )]
                        )
                    ),
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__820fa6732867ae4c1e44cebd665eeb0465b9d25b7f5eeffa5fb2e10b2e0a1570)
                check_type(argname="argument cross_dataset", value=cross_dataset, expected_type=type_hints["cross_dataset"])
                check_type(argname="argument filter_group_id", value=filter_group_id, expected_type=type_hints["filter_group_id"])
                check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
                check_type(argname="argument scope_configuration", value=scope_configuration, expected_type=type_hints["scope_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "cross_dataset": cross_dataset,
                "filter_group_id": filter_group_id,
                "filters": filters,
                "scope_configuration": scope_configuration,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def cross_dataset(self) -> builtins.str:
            '''The filter new feature which can apply filter group to all data sets. Choose one of the following options:.

            - ``ALL_DATASETS``
            - ``SINGLE_DATASET``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-crossdataset
            '''
            result = self._values.get("cross_dataset")
            assert result is not None, "Required property 'cross_dataset' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filter_group_id(self) -> builtins.str:
            '''The value that uniquely identifies a ``FilterGroup`` within a dashboard, template, or analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filtergroupid
            '''
            result = self._values.get("filter_group_id")
            assert result is not None, "Required property 'filter_group_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def filters(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilterProperty", _IResolvable_a771d0ef]]]:
            '''The list of filters that are present in a ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filters
            '''
            result = self._values.get("filters")
            assert result is not None, "Required property 'filters' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilterProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def scope_configuration(
            self,
        ) -> typing.Union["CfnTemplate.FilterScopeConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that specifies what scope to apply to a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-scopeconfiguration
            '''
            result = self._values.get("scope_configuration")
            assert result is not None, "Required property 'scope_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.FilterScopeConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``FilterGroup`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterGroupProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterListConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "match_operator": "matchOperator",
            "category_values": "categoryValues",
            "select_all_options": "selectAllOptions",
        },
    )
    class FilterListConfigurationProperty:
        def __init__(
            self,
            *,
            match_operator: builtins.str,
            category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A list of filter configurations.

            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param category_values: The list of category values for the filter.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_list_configuration_property = quicksight.CfnTemplate.FilterListConfigurationProperty(
                    match_operator="matchOperator",
                
                    # the properties below are optional
                    category_values=["categoryValues"],
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eb3f3118841e0d23065259d0bc4c4f3c1f9fad5e0c24e3b3279e4d4e50a3b18f)
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument category_values", value=category_values, expected_type=type_hints["category_values"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "match_operator": match_operator,
            }
            if category_values is not None:
                self._values["category_values"] = category_values
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def category_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The list of category values for the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-categoryvalues
            '''
            result = self._values.get("category_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class FilterListControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list of buttons or boxes.

            This is used to select either a single value or multiple values.

            :param filter_control_id: The ID of the ``FilterListControl`` .
            :param source_filter_id: The source filter ID of the ``FilterListControl`` .
            :param title: The title of the ``FilterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``FilterListControl`` . Choose one of the following options:. - ``MULTI_SELECT`` : The user can select multiple entries from the list. - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_list_control_property = quicksight.CfnTemplate.FilterListControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7ccecf28d291f90710f7b4b831ce88bb318f399bc2c6d270206fc61bedaf1872)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterListControl`` . Choose one of the following options:.

            - ``MULTI_SELECT`` : The user can select multiple entries from the list.
            - ``SINGLE_SELECT`` : The user can select a single entry from the list.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "selected_field_options": "selectedFieldOptions",
            "selected_fields": "selectedFields",
        },
    )
    class FilterOperationSelectedFieldsConfigurationProperty:
        def __init__(
            self,
            *,
            selected_field_options: typing.Optional[builtins.str] = None,
            selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of selected fields in the ``CustomActionFilterOperation`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_field_options: A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` . Valid values are defined as follows: - ``ALL_FIELDS`` : Applies the filter operation to all fields.
            :param selected_fields: Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_selected_fields_configuration_property = quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                    selected_field_options="selectedFieldOptions",
                    selected_fields=["selectedFields"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d931f120dcad043887575fb1b8ecab312f00d3315d9c9e13b0709fbcdd803b6e)
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
                check_type(argname="argument selected_fields", value=selected_fields, expected_type=type_hints["selected_fields"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options
            if selected_fields is not None:
                self._values["selected_fields"] = selected_fields

        @builtins.property
        def selected_field_options(self) -> typing.Optional[builtins.str]:
            '''A structure that contains the options that choose which fields are filtered in the ``CustomActionFilterOperation`` .

            Valid values are defined as follows:

            - ``ALL_FIELDS`` : Applies the filter operation to all fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def selected_fields(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Chooses the fields that are filtered in ``CustomActionFilterOperation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfields
            '''
            result = self._values.get("selected_fields")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationSelectedFieldsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "same_sheet_target_visual_configuration": "sameSheetTargetVisualConfiguration",
        },
    )
    class FilterOperationTargetVisualsConfigurationProperty:
        def __init__(
            self,
            *,
            same_sheet_target_visual_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.SameSheetTargetVisualConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param same_sheet_target_visual_configuration: The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_operation_target_visuals_configuration_property = quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                        target_visual_options="targetVisualOptions",
                        target_visuals=["targetVisuals"]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cfe868786332ac3d55e21706495ca7466f0585ad84376cd457a031403cb75830)
                check_type(argname="argument same_sheet_target_visual_configuration", value=same_sheet_target_visual_configuration, expected_type=type_hints["same_sheet_target_visual_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if same_sheet_target_visual_configuration is not None:
                self._values["same_sheet_target_visual_configuration"] = same_sheet_target_visual_configuration

        @builtins.property
        def same_sheet_target_visual_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SameSheetTargetVisualConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-template-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
            '''
            result = self._values.get("same_sheet_target_visual_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SameSheetTargetVisualConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterOperationTargetVisualsConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_filter": "categoryFilter",
            "numeric_equality_filter": "numericEqualityFilter",
            "numeric_range_filter": "numericRangeFilter",
            "relative_dates_filter": "relativeDatesFilter",
            "time_equality_filter": "timeEqualityFilter",
            "time_range_filter": "timeRangeFilter",
            "top_bottom_filter": "topBottomFilter",
        },
    )
    class FilterProperty:
        def __init__(
            self,
            *,
            category_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.CategoryFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_equality_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_range_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericRangeFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_dates_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.RelativeDatesFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_equality_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.TimeEqualityFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_range_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.TimeRangeFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top_bottom_filter: typing.Optional[typing.Union[typing.Union["CfnTemplate.TopBottomFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''With a ``Filter`` , you can remove portions of data from a particular visual or view.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param category_filter: A ``CategoryFilter`` filters text values. For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .
            :param numeric_equality_filter: A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.
            :param numeric_range_filter: A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.
            :param relative_dates_filter: A ``RelativeDatesFilter`` filters date values that are relative to a given date.
            :param time_equality_filter: A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.
            :param time_range_filter: A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.
            :param top_bottom_filter: A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_property = quicksight.CfnTemplate.FilterProperty(
                    category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                            custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_value="categoryValue",
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions"
                            ),
                            custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            ),
                            filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                match_operator="matchOperator",
                
                                # the properties below are optional
                                category_values=["categoryValues"],
                                select_all_options="selectAllOptions"
                            )
                        ),
                        filter_id="filterId"
                    ),
                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        match_operator="matchOperator",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        parameter_name="parameterName",
                        select_all_options="selectAllOptions",
                        value=123
                    ),
                    numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                            parameter="parameter",
                            static_value=123
                        ),
                        select_all_options="selectAllOptions"
                    ),
                    relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                        anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                            anchor_option="anchorOption",
                            parameter_name="parameterName"
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                        relative_date_type="relativeDateType",
                        time_granularity="timeGranularity",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        minimum_granularity="minimumGranularity",
                        parameter_name="parameterName",
                        relative_date_value=123
                    ),
                    time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        parameter_name="parameterName",
                        time_granularity="timeGranularity",
                        value="value"
                    ),
                    time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                        null_option="nullOption",
                
                        # the properties below are optional
                        exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                            amount=123,
                            granularity="granularity",
                
                            # the properties below are optional
                            status="status"
                        ),
                        include_maximum=False,
                        include_minimum=False,
                        range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                            parameter="parameter",
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_value="staticValue"
                        ),
                        time_granularity="timeGranularity"
                    ),
                    top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                        aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            sort_direction="sortDirection"
                        )],
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        filter_id="filterId",
                
                        # the properties below are optional
                        limit=123,
                        parameter_name="parameterName",
                        time_granularity="timeGranularity"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3ac47c33acdd391847c98dd2d53e2776dd35cbee59cf60485b88a1a140511a29)
                check_type(argname="argument category_filter", value=category_filter, expected_type=type_hints["category_filter"])
                check_type(argname="argument numeric_equality_filter", value=numeric_equality_filter, expected_type=type_hints["numeric_equality_filter"])
                check_type(argname="argument numeric_range_filter", value=numeric_range_filter, expected_type=type_hints["numeric_range_filter"])
                check_type(argname="argument relative_dates_filter", value=relative_dates_filter, expected_type=type_hints["relative_dates_filter"])
                check_type(argname="argument time_equality_filter", value=time_equality_filter, expected_type=type_hints["time_equality_filter"])
                check_type(argname="argument time_range_filter", value=time_range_filter, expected_type=type_hints["time_range_filter"])
                check_type(argname="argument top_bottom_filter", value=top_bottom_filter, expected_type=type_hints["top_bottom_filter"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_filter is not None:
                self._values["category_filter"] = category_filter
            if numeric_equality_filter is not None:
                self._values["numeric_equality_filter"] = numeric_equality_filter
            if numeric_range_filter is not None:
                self._values["numeric_range_filter"] = numeric_range_filter
            if relative_dates_filter is not None:
                self._values["relative_dates_filter"] = relative_dates_filter
            if time_equality_filter is not None:
                self._values["time_equality_filter"] = time_equality_filter
            if time_range_filter is not None:
                self._values["time_range_filter"] = time_range_filter
            if top_bottom_filter is not None:
                self._values["top_bottom_filter"] = top_bottom_filter

        @builtins.property
        def category_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CategoryFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``CategoryFilter`` filters text values.

            For more information, see `Adding text filters <https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-categoryfilter
            '''
            result = self._values.get("category_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CategoryFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericEqualityFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``NumericEqualityFilter`` filters numeric values that equal or do not equal a given numeric value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericequalityfilter
            '''
            result = self._values.get("numeric_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericEqualityFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericRangeFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``NumericRangeFilter`` filters numeric values that are either inside or outside a given numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericrangefilter
            '''
            result = self._values.get("numeric_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericRangeFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_dates_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RelativeDatesFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``RelativeDatesFilter`` filters date values that are relative to a given date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-relativedatesfilter
            '''
            result = self._values.get("relative_dates_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RelativeDatesFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_equality_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TimeEqualityFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TimeEqualityFilter`` filters date-time values that equal or do not equal a given date/time value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timeequalityfilter
            '''
            result = self._values.get("time_equality_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TimeEqualityFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_range_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TimeRangeFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TimeRangeFilter`` filters date-time values that are either inside or outside a given date/time range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timerangefilter
            '''
            result = self._values.get("time_range_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TimeRangeFilterProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top_bottom_filter(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TopBottomFilterProperty", _IResolvable_a771d0ef]]:
            '''A ``TopBottomFilter`` filters data to the top or bottom values for a given column.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-topbottomfilter
            '''
            result = self._values.get("top_bottom_filter")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TopBottomFilterProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterRelativeDateTimeControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control from a date filter that is used to specify the relative date.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_relative_date_time_control_property = quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0a84c57b168371a2b5f6c287e1df1f93908c7f9143f6bbe0c3933e3cb97666f3)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterRelativeDateTimeControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"selected_sheets": "selectedSheets"},
    )
    class FilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            selected_sheets: typing.Optional[typing.Union[typing.Union["CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The scope configuration for a ``FilterGroup`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param selected_sheets: The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_scope_configuration_property = quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                    selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                        sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                            scope="scope",
                            sheet_id="sheetId",
                
                            # the properties below are optional
                            visual_ids=["visualIds"]
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ffd0c0b1b6a2fcb037e574bda4bb942b8d0fef73a9d7d9b6d97f6e9ecb7a2962)
                check_type(argname="argument selected_sheets", value=selected_sheets, expected_type=type_hints["selected_sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if selected_sheets is not None:
                self._values["selected_sheets"] = selected_sheets

        @builtins.property
        def selected_sheets(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for applying a filter to specific sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-selectedsheets
            '''
            result = self._values.get("selected_sheets")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class FilterSelectableValuesProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param values: The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_selectable_values_property = quicksight.CfnTemplate.FilterSelectableValuesProperty(
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2c73f0193a2b4ac8a122ae22272b26d25076e1e3aa867473002ce12d9984b936)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in the ``FilterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html#cfn-quicksight-template-filterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "source_filter_id": "sourceFilterId",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
            "type": "type",
        },
    )
    class FilterSliderControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            source_filter_id: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param filter_control_id: The ID of the ``FilterSliderControl`` .
            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param source_filter_id: The source filter ID of the ``FilterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``FilterSliderControl`` .
            :param display_options: The display options of a control.
            :param type: The type of ``FilterSliderControl`` . Choose one of the following options:. - ``SINGLE_POINT`` : Filter against(equals) a single data point. - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_slider_control_property = quicksight.CfnTemplate.FilterSliderControlProperty(
                    filter_control_id="filterControlId",
                    maximum_value=123,
                    minimum_value=123,
                    source_filter_id="sourceFilterId",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9b374ed79c9cbd0892752aaa152d42078d5f46b5780059515327263dfab51a31)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "source_filter_id": source_filter_id,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``FilterSliderControl`` . Choose one of the following options:.

            - ``SINGLE_POINT`` : Filter against(equals) a single data point.
            - ``RANGE`` : Filter data that is in a specified range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class FilterTextAreaControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param filter_control_id: The ID of the ``FilterTextAreaControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextAreaControl`` .
            :param title: The title of the ``FilterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_text_area_control_property = quicksight.CfnTemplate.FilterTextAreaControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a1afdfdc90f9e67fd2760502a24fedd006f01d92fd3c5397af63bf0b81299354)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FilterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_control_id": "filterControlId",
            "source_filter_id": "sourceFilterId",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class FilterTextFieldControlProperty:
        def __init__(
            self,
            *,
            filter_control_id: builtins.str,
            source_filter_id: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param filter_control_id: The ID of the ``FilterTextFieldControl`` .
            :param source_filter_id: The source filter ID of the ``FilterTextFieldControl`` .
            :param title: The title of the ``FilterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                filter_text_field_control_property = quicksight.CfnTemplate.FilterTextFieldControlProperty(
                    filter_control_id="filterControlId",
                    source_filter_id="sourceFilterId",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4323424946d47926768625cd653528845a977556c9d321371d89f1b10f894915)
                check_type(argname="argument filter_control_id", value=filter_control_id, expected_type=type_hints["filter_control_id"])
                check_type(argname="argument source_filter_id", value=source_filter_id, expected_type=type_hints["source_filter_id"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "filter_control_id": filter_control_id,
                "source_filter_id": source_filter_id,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def filter_control_id(self) -> builtins.str:
            '''The ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-filtercontrolid
            '''
            result = self._values.get("filter_control_id")
            assert result is not None, "Required property 'filter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_filter_id(self) -> builtins.str:
            '''The source filter ID of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-sourcefilterid
            '''
            result = self._values.get("source_filter_id")
            assert result is not None, "Required property 'source_filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``FilterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FilterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FontConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_color": "fontColor",
            "font_decoration": "fontDecoration",
            "font_size": "fontSize",
            "font_style": "fontStyle",
            "font_weight": "fontWeight",
        },
    )
    class FontConfigurationProperty:
        def __init__(
            self,
            *,
            font_color: typing.Optional[builtins.str] = None,
            font_decoration: typing.Optional[builtins.str] = None,
            font_size: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontSizeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_style: typing.Optional[builtins.str] = None,
            font_weight: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontWeightProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configures the display properties of the given text.

            :param font_color: Determines the color of the text.
            :param font_decoration: Determines the appearance of decorative lines on the text.
            :param font_size: The option that determines the text display size.
            :param font_style: Determines the text display face that is inherited by the given font family.
            :param font_weight: The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_configuration_property = quicksight.CfnTemplate.FontConfigurationProperty(
                    font_color="fontColor",
                    font_decoration="fontDecoration",
                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                        relative="relative"
                    ),
                    font_style="fontStyle",
                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                        name="name"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__11056436016ade194f96da4855855153ae841cf02be1852bab6112f9b461620f)
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_decoration", value=font_decoration, expected_type=type_hints["font_decoration"])
                check_type(argname="argument font_size", value=font_size, expected_type=type_hints["font_size"])
                check_type(argname="argument font_style", value=font_style, expected_type=type_hints["font_style"])
                check_type(argname="argument font_weight", value=font_weight, expected_type=type_hints["font_weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_decoration is not None:
                self._values["font_decoration"] = font_decoration
            if font_size is not None:
                self._values["font_size"] = font_size
            if font_style is not None:
                self._values["font_style"] = font_style
            if font_weight is not None:
                self._values["font_weight"] = font_weight

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''Determines the color of the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_decoration(self) -> typing.Optional[builtins.str]:
            '''Determines the appearance of decorative lines on the text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontdecoration
            '''
            result = self._values.get("font_decoration")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_size(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontSizeProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the text display size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontsize
            '''
            result = self._values.get("font_size")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontSizeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_style(self) -> typing.Optional[builtins.str]:
            '''Determines the text display face that is inherited by the given font family.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontstyle
            '''
            result = self._values.get("font_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_weight(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontWeightProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the text display weight, or boldness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontweight
            '''
            result = self._values.get("font_weight")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontWeightProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FontSizeProperty",
        jsii_struct_bases=[],
        name_mapping={"relative": "relative"},
    )
    class FontSizeProperty:
        def __init__(self, *, relative: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display size.

            :param relative: The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_size_property = quicksight.CfnTemplate.FontSizeProperty(
                    relative="relative"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__67262f15dc7af7d69e9cc22c2041a9b2505f2111a885506eef640569443ba39b)
                check_type(argname="argument relative", value=relative, expected_type=type_hints["relative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if relative is not None:
                self._values["relative"] = relative

        @builtins.property
        def relative(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the text size, proportional to its surrounding context.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html#cfn-quicksight-template-fontsize-relative
            '''
            result = self._values.get("relative")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontSizeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FontWeightProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name"},
    )
    class FontWeightProperty:
        def __init__(self, *, name: typing.Optional[builtins.str] = None) -> None:
            '''The option that determines the text display weight, or boldness.

            :param name: The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_weight_property = quicksight.CfnTemplate.FontWeightProperty(
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ab620fc7850dc312fc90ed18d0910e4fd86d053961bdc7ba0f60cc90cbdf7a6)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The lexical name for the level of boldness of the text display.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html#cfn-quicksight-template-fontweight-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontWeightProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ForecastComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "custom_seasonality_value": "customSeasonalityValue",
            "lower_boundary": "lowerBoundary",
            "name": "name",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
            "value": "value",
        },
    )
    class ForecastComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            custom_seasonality_value: typing.Optional[jsii.Number] = None,
            lower_boundary: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[builtins.str] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param custom_seasonality_value: The custom seasonality value setup of a forecast computation.
            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param name: The name of a computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``AUTOMATIC`` - ``CUSTOM`` : Checks the custom seasonality value.
            :param upper_boundary: The upper boundary setup of a forecast computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_computation_property = quicksight.CfnTemplate.ForecastComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    custom_seasonality_value=123,
                    lower_boundary=123,
                    name="name",
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality="seasonality",
                    upper_boundary=123,
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ebc5681a6b1d537ae9dce93f223424895da55d6bbeb66f40f407dd3bffd5d9d7)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument custom_seasonality_value", value=custom_seasonality_value, expected_type=type_hints["custom_seasonality_value"])
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if custom_seasonality_value is not None:
                self._values["custom_seasonality_value"] = custom_seasonality_value
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if name is not None:
                self._values["name"] = name
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def custom_seasonality_value(self) -> typing.Optional[jsii.Number]:
            '''The custom seasonality value setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-customseasonalityvalue
            '''
            result = self._values.get("custom_seasonality_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[builtins.str]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``AUTOMATIC``
            - ``CUSTOM`` : Checks the custom seasonality value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ForecastConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "forecast_properties": "forecastProperties",
            "scenario": "scenario",
        },
    )
    class ForecastConfigurationProperty:
        def __init__(
            self,
            *,
            forecast_properties: typing.Optional[typing.Union[typing.Union["CfnTemplate.TimeBasedForecastPropertiesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scenario: typing.Optional[typing.Union[typing.Union["CfnTemplate.ForecastScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast configuration that is used in a line chart's display properties.

            :param forecast_properties: The forecast properties setup of a forecast in the line chart.
            :param scenario: The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_configuration_property = quicksight.CfnTemplate.ForecastConfigurationProperty(
                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                        lower_boundary=123,
                        periods_backward=123,
                        periods_forward=123,
                        prediction_interval=123,
                        seasonality=123,
                        upper_boundary=123
                    ),
                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                            date="date",
                            value=123
                        ),
                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                            end_date="endDate",
                            start_date="startDate",
                            value=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa33914fac5e7e808f4dc5c9ac3e4213a0e934b32660920724398a8be6bdb47e)
                check_type(argname="argument forecast_properties", value=forecast_properties, expected_type=type_hints["forecast_properties"])
                check_type(argname="argument scenario", value=scenario, expected_type=type_hints["scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if forecast_properties is not None:
                self._values["forecast_properties"] = forecast_properties
            if scenario is not None:
                self._values["scenario"] = scenario

        @builtins.property
        def forecast_properties(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TimeBasedForecastPropertiesProperty", _IResolvable_a771d0ef]]:
            '''The forecast properties setup of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-forecastproperties
            '''
            result = self._values.get("forecast_properties")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TimeBasedForecastPropertiesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ForecastScenarioProperty", _IResolvable_a771d0ef]]:
            '''The forecast scenario of a forecast in the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-scenario
            '''
            result = self._values.get("scenario")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ForecastScenarioProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ForecastScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "what_if_point_scenario": "whatIfPointScenario",
            "what_if_range_scenario": "whatIfRangeScenario",
        },
    )
    class ForecastScenarioProperty:
        def __init__(
            self,
            *,
            what_if_point_scenario: typing.Optional[typing.Union[typing.Union["CfnTemplate.WhatIfPointScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            what_if_range_scenario: typing.Optional[typing.Union[typing.Union["CfnTemplate.WhatIfRangeScenarioProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The forecast scenario of a forecast in the line chart.

            :param what_if_point_scenario: The what-if analysis forecast setup with the target date.
            :param what_if_range_scenario: The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                forecast_scenario_property = quicksight.CfnTemplate.ForecastScenarioProperty(
                    what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                        date="date",
                        value=123
                    ),
                    what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                        end_date="endDate",
                        start_date="startDate",
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__598d2cd7c47ba5f83e59db98d5c0e7b0b8333291e2c0d9704ca37a99014697be)
                check_type(argname="argument what_if_point_scenario", value=what_if_point_scenario, expected_type=type_hints["what_if_point_scenario"])
                check_type(argname="argument what_if_range_scenario", value=what_if_range_scenario, expected_type=type_hints["what_if_range_scenario"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if what_if_point_scenario is not None:
                self._values["what_if_point_scenario"] = what_if_point_scenario
            if what_if_range_scenario is not None:
                self._values["what_if_range_scenario"] = what_if_range_scenario

        @builtins.property
        def what_if_point_scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WhatIfPointScenarioProperty", _IResolvable_a771d0ef]]:
            '''The what-if analysis forecast setup with the target date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifpointscenario
            '''
            result = self._values.get("what_if_point_scenario")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WhatIfPointScenarioProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def what_if_range_scenario(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WhatIfRangeScenarioProperty", _IResolvable_a771d0ef]]:
            '''The what-if analysis forecast setup with the date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifrangescenario
            '''
            result = self._values.get("what_if_range_scenario")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WhatIfRangeScenarioProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ForecastScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format_configuration": "dateTimeFormatConfiguration",
            "number_format_configuration": "numberFormatConfiguration",
            "string_format_configuration": "stringFormatConfiguration",
        },
    )
    class FormatConfigurationProperty:
        def __init__(
            self,
            *,
            date_time_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            string_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.StringFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The formatting configuration for all types of field.

            :param date_time_format_configuration: Formatting configuration for ``DateTime`` fields.
            :param number_format_configuration: Formatting configuration for number fields.
            :param string_format_configuration: Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                format_configuration_property = quicksight.CfnTemplate.FormatConfigurationProperty(
                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                        date_time_format="dateTimeFormat",
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f12ab8249a1d8e0ce750539979eeaee82eb1bc3d21e6b147e5b564e73b490ab)
                check_type(argname="argument date_time_format_configuration", value=date_time_format_configuration, expected_type=type_hints["date_time_format_configuration"])
                check_type(argname="argument number_format_configuration", value=number_format_configuration, expected_type=type_hints["number_format_configuration"])
                check_type(argname="argument string_format_configuration", value=string_format_configuration, expected_type=type_hints["string_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format_configuration is not None:
                self._values["date_time_format_configuration"] = date_time_format_configuration
            if number_format_configuration is not None:
                self._values["number_format_configuration"] = number_format_configuration
            if string_format_configuration is not None:
                self._values["string_format_configuration"] = string_format_configuration

        @builtins.property
        def date_time_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for ``DateTime`` fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-datetimeformatconfiguration
            '''
            result = self._values.get("date_time_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for number fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-numberformatconfiguration
            '''
            result = self._values.get("number_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def string_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.StringFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Formatting configuration for string fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-stringformatconfiguration
            '''
            result = self._values.get("string_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.StringFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class FreeFormLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configuration options for the canvas of a free-form layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_canvas_size_options_property = quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7b114c854beab8b22946a7799b84ad2cc87aea8373ecf471d41fb43bb31af52)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html#cfn-quicksight-template-freeformlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class FreeFormLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a free-form layout.

            :param elements: The elements that are included in a free-form layout.
            :param canvas_size_options: ``CfnTemplate.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_configuration_property = quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__084c64bd95f9881469ac15b2be2bce930df0cb5a0a3f81e4d81068043e2c233e)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.FreeFormLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBackgroundStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The background color of a free-form layout element.
            :param visibility: The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_background_style_property = quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a07ab7b072aec45a8553007a82f562ba5798a2a04d4b59a8d4f923c3c3f373c1)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The background color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The background visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBackgroundStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "visibility": "visibility"},
    )
    class FreeFormLayoutElementBorderStyleProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The background style configuration of a free-form layout element.

            :param color: The border color of a free-form layout element.
            :param visibility: The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_border_style_property = quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                    color="color",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7aac355a0ce9265f6f7a63fe84ec48db62c97e5df17e18312c8f82b5984da46)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The border color of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The border visibility of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementBorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "element_id": "elementId",
            "element_type": "elementType",
            "height": "height",
            "width": "width",
            "x_axis_location": "xAxisLocation",
            "y_axis_location": "yAxisLocation",
            "background_style": "backgroundStyle",
            "border_style": "borderStyle",
            "loading_animation": "loadingAnimation",
            "rendering_rules": "renderingRules",
            "selected_border_style": "selectedBorderStyle",
            "visibility": "visibility",
        },
    )
    class FreeFormLayoutElementProperty:
        def __init__(
            self,
            *,
            element_id: builtins.str,
            element_type: builtins.str,
            height: builtins.str,
            width: builtins.str,
            x_axis_location: builtins.str,
            y_axis_location: builtins.str,
            background_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            border_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            loading_animation: typing.Optional[typing.Union[typing.Union["CfnTemplate.LoadingAnimationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            rendering_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SheetElementRenderingRuleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            selected_border_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''An element within a free-form layout.

            :param element_id: A unique identifier for an element within a free-form layout.
            :param element_type: The type of element.
            :param height: The height of an element within a free-form layout.
            :param width: The width of an element within a free-form layout.
            :param x_axis_location: The x-axis coordinate of the element.
            :param y_axis_location: The y-axis coordinate of the element.
            :param background_style: The background style configuration of a free-form layout element.
            :param border_style: The border style configuration of a free-form layout element.
            :param loading_animation: The loading animation configuration of a free-form layout element.
            :param rendering_rules: The rendering rules that determine when an element should be displayed within a free-form layout.
            :param selected_border_style: The border style configuration of a free-form layout element. This border style is used when the element is selected.
            :param visibility: The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_element_property = quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                    element_id="elementId",
                    element_type="elementType",
                    height="height",
                    width="width",
                    x_axis_location="xAxisLocation",
                    y_axis_location="yAxisLocation",
                
                    # the properties below are optional
                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                        visibility="visibility"
                    ),
                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                            visibility="visibility"
                        ),
                        expression="expression"
                    )],
                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                        color="color",
                        visibility="visibility"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75d0de9941a75a2af6e9b15199d3ad7820f6f6af98b0e76818cfd9d304526b16)
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
                check_type(argname="argument x_axis_location", value=x_axis_location, expected_type=type_hints["x_axis_location"])
                check_type(argname="argument y_axis_location", value=y_axis_location, expected_type=type_hints["y_axis_location"])
                check_type(argname="argument background_style", value=background_style, expected_type=type_hints["background_style"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument loading_animation", value=loading_animation, expected_type=type_hints["loading_animation"])
                check_type(argname="argument rendering_rules", value=rendering_rules, expected_type=type_hints["rendering_rules"])
                check_type(argname="argument selected_border_style", value=selected_border_style, expected_type=type_hints["selected_border_style"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "element_id": element_id,
                "element_type": element_type,
                "height": height,
                "width": width,
                "x_axis_location": x_axis_location,
                "y_axis_location": y_axis_location,
            }
            if background_style is not None:
                self._values["background_style"] = background_style
            if border_style is not None:
                self._values["border_style"] = border_style
            if loading_animation is not None:
                self._values["loading_animation"] = loading_animation
            if rendering_rules is not None:
                self._values["rendering_rules"] = rendering_rules
            if selected_border_style is not None:
                self._values["selected_border_style"] = selected_border_style
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def height(self) -> builtins.str:
            '''The height of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-height
            '''
            result = self._values.get("height")
            assert result is not None, "Required property 'height' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def width(self) -> builtins.str:
            '''The width of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-width
            '''
            result = self._values.get("width")
            assert result is not None, "Required property 'width' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def x_axis_location(self) -> builtins.str:
            '''The x-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-xaxislocation
            '''
            result = self._values.get("x_axis_location")
            assert result is not None, "Required property 'x_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def y_axis_location(self) -> builtins.str:
            '''The y-axis coordinate of the element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-yaxislocation
            '''
            result = self._values.get("y_axis_location")
            assert result is not None, "Required property 'y_axis_location' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def background_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty", _IResolvable_a771d0ef]]:
            '''The background style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-backgroundstyle
            '''
            result = self._values.get("background_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def border_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border style configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def loading_animation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LoadingAnimationProperty", _IResolvable_a771d0ef]]:
            '''The loading animation configuration of a free-form layout element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-loadinganimation
            '''
            result = self._values.get("loading_animation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LoadingAnimationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def rendering_rules(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetElementRenderingRuleProperty", _IResolvable_a771d0ef]]]]:
            '''The rendering rules that determine when an element should be displayed within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-renderingrules
            '''
            result = self._values.get("rendering_rules")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetElementRenderingRuleProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def selected_border_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border style configuration of a free-form layout element.

            This border style is used when the element is selected.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-selectedborderstyle
            '''
            result = self._values.get("selected_border_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutElementBorderStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of an element within a free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"optimized_view_port_width": "optimizedViewPortWidth"},
    )
    class FreeFormLayoutScreenCanvasSizeOptionsProperty:
        def __init__(self, *, optimized_view_port_width: builtins.str) -> None:
            '''The options that determine the sizing of the canvas used in a free-form layout.

            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_layout_screen_canvas_size_options_property = quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__972621417721a29edd24e84ce54cb0a1b655367ac4a013b1636bb08af6f2e57e)
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "optimized_view_port_width": optimized_view_port_width,
            }

        @builtins.property
        def optimized_view_port_width(self) -> builtins.str:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-template-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            assert result is not None, "Required property 'optimized_view_port_width' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"elements": "elements"},
    )
    class FreeFormSectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The free-form layout configuration of a section.

            :param elements: The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                free_form_section_layout_configuration_property = quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                        element_id="elementId",
                        element_type="elementType",
                        height="height",
                        width="width",
                        x_axis_location="xAxisLocation",
                        y_axis_location="yAxisLocation",
                
                        # the properties below are optional
                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                            visibility="visibility"
                        ),
                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                visibility="visibility"
                            ),
                            expression="expression"
                        )],
                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                            color="color",
                            visibility="visibility"
                        ),
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2d3cd5e56683bd63ddc5da92da247da4e8162ced1c924a6910211c89f1d5f562)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in the free-form layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html#cfn-quicksight-template-freeformsectionlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FreeFormLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FreeFormSectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "values": "values"},
    )
    class FunnelChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :param category: The category field wells of a funnel chart. Values are grouped by category fields.
            :param values: The value field wells of a funnel chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_aggregated_field_wells_property = quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0870b8bf7791e1b6da61b39d4d11947e604483f1ef2cd5da654d61db09828029)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a funnel chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a funnel chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FunnelChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "data_label_options": "dataLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class FunnelChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.FunnelChartDataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.FunnelChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FunnelChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``FunnelChartVisual`` .

            :param category_label_options: The label options of the categories that are displayed in a ``FunnelChartVisual`` .
            :param data_label_options: The options that determine the presentation of the data labels.
            :param field_wells: The field well configuration of a ``FunnelChartVisual`` .
            :param sort_configuration: The sort configuration of a ``FunnelChartVisual`` .
            :param tooltip: The tooltip configuration of a ``FunnelChartVisual`` .
            :param value_label_options: The label options for the values that are displayed in a ``FunnelChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_configuration_property = quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        label_color="labelColor",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_data_label_style="measureDataLabelStyle",
                        measure_label_visibility="measureLabelVisibility",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                        funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__807b480191d11edd66af1f8633c5b8b8d2acc0353c9392b6a2d9a56d6cde0319)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument data_label_options", value=data_label_options, expected_type=type_hints["data_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if data_label_options is not None:
                self._values["data_label_options"] = data_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the categories that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FunnelChartDataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-datalabeloptions
            '''
            result = self._values.get("data_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FunnelChartDataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FunnelChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FunnelChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FunnelChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FunnelChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options for the values that are displayed in a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_visibility": "categoryLabelVisibility",
            "label_color": "labelColor",
            "label_font_configuration": "labelFontConfiguration",
            "measure_data_label_style": "measureDataLabelStyle",
            "measure_label_visibility": "measureLabelVisibility",
            "position": "position",
            "visibility": "visibility",
        },
    )
    class FunnelChartDataLabelOptionsProperty:
        def __init__(
            self,
            *,
            category_label_visibility: typing.Optional[builtins.str] = None,
            label_color: typing.Optional[builtins.str] = None,
            label_font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            measure_data_label_style: typing.Optional[builtins.str] = None,
            measure_label_visibility: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of the data labels.

            :param category_label_visibility: The visibility of the category labels within the data labels.
            :param label_color: The color of the data label text.
            :param label_font_configuration: The font configuration for the data labels. Only the ``FontSize`` attribute of the font configuration is used for data labels.
            :param measure_data_label_style: Determines the style of the metric labels.
            :param measure_label_visibility: The visibility of the measure labels within the data labels.
            :param position: Determines the positioning of the data label relative to a section of the funnel.
            :param visibility: The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_data_label_options_property = quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                    category_label_visibility="categoryLabelVisibility",
                    label_color="labelColor",
                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    measure_data_label_style="measureDataLabelStyle",
                    measure_label_visibility="measureLabelVisibility",
                    position="position",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__474bd70423e770ff2330d5730e78fdd594b4519f6b080c1fa9524bd20f8f27d5)
                check_type(argname="argument category_label_visibility", value=category_label_visibility, expected_type=type_hints["category_label_visibility"])
                check_type(argname="argument label_color", value=label_color, expected_type=type_hints["label_color"])
                check_type(argname="argument label_font_configuration", value=label_font_configuration, expected_type=type_hints["label_font_configuration"])
                check_type(argname="argument measure_data_label_style", value=measure_data_label_style, expected_type=type_hints["measure_data_label_style"])
                check_type(argname="argument measure_label_visibility", value=measure_label_visibility, expected_type=type_hints["measure_label_visibility"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_visibility is not None:
                self._values["category_label_visibility"] = category_label_visibility
            if label_color is not None:
                self._values["label_color"] = label_color
            if label_font_configuration is not None:
                self._values["label_font_configuration"] = label_font_configuration
            if measure_data_label_style is not None:
                self._values["measure_data_label_style"] = measure_data_label_style
            if measure_label_visibility is not None:
                self._values["measure_label_visibility"] = measure_label_visibility
            if position is not None:
                self._values["position"] = position
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def category_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the category labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-categorylabelvisibility
            '''
            result = self._values.get("category_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_color(self) -> typing.Optional[builtins.str]:
            '''The color of the data label text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelcolor
            '''
            result = self._values.get("label_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def label_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration for the data labels.

            Only the ``FontSize`` attribute of the font configuration is used for data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelfontconfiguration
            '''
            result = self._values.get("label_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def measure_data_label_style(self) -> typing.Optional[builtins.str]:
            '''Determines the style of the metric labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measuredatalabelstyle
            '''
            result = self._values.get("measure_data_label_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_label_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the measure labels within the data labels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measurelabelvisibility
            '''
            result = self._values.get("measure_label_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''Determines the positioning of the data label relative to a section of the funnel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility option that determines if data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartDataLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FunnelChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "funnel_chart_aggregated_field_wells": "funnelChartAggregatedFieldWells",
        },
    )
    class FunnelChartFieldWellsProperty:
        def __init__(
            self,
            *,
            funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.FunnelChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a ``FunnelChartVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param funnel_chart_aggregated_field_wells: The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_field_wells_property = quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__da17c9d0c7302116e672650fc49aa156d44aca52bd1c6ba6b28e5ba9b0ab0d35)
                check_type(argname="argument funnel_chart_aggregated_field_wells", value=funnel_chart_aggregated_field_wells, expected_type=type_hints["funnel_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if funnel_chart_aggregated_field_wells is not None:
                self._values["funnel_chart_aggregated_field_wells"] = funnel_chart_aggregated_field_wells

        @builtins.property
        def funnel_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FunnelChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html#cfn-quicksight-template-funnelchartfieldwells-funnelchartaggregatedfieldwells
            '''
            result = self._values.get("funnel_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FunnelChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FunnelChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class FunnelChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``FunnelChartVisual`` .

            :param category_items_limit: The limit on the number of categories displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_sort_configuration_property = quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4bbba75d3122a55ca5bbf9d4913d0a70f78d49574a4814efe328752820ddb6a)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.FunnelChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class FunnelChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FunnelChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``FunnelChartVisual`` .
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                funnel_chart_visual_property = quicksight.CfnTemplate.FunnelChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            label_color="labelColor",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_data_label_style="measureDataLabelStyle",
                            measure_label_visibility="measureLabelVisibility",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                            funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7f0c5b85b18013bb225f6053a0102821de77dcba293c4618ae867c0f5f589ba3)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FunnelChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``FunnelChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FunnelChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FunnelChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class GaugeChartArcConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :param foreground_color: The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_arc_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__963e9df0d828a42e486124395f4f7acb75db90a94e98a2625657a83735d62000)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the arc foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html#cfn-quicksight-template-gaugechartarcconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartArcConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"arc": "arc", "primary_value": "primaryValue"},
    )
    class GaugeChartConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartArcConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :param arc: The options that determine the presentation of the arc of a ``GaugeChartVisual`` .
            :param primary_value: The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_option_property = quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8510330bbb1483018cb23aa19bc018b66ed1dc013bf6efe00f693fd8c1b2c86a)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if primary_value is not None:
                self._values["primary_value"] = primary_value

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartArcConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the arc of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartArcConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class GaugeChartConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.GaugeChartConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :param conditional_formatting_options: Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b6a461052ae994106ab67bd24d116469f2f54aec60cb34839905c82a0ca53cae)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.GaugeChartConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html#cfn-quicksight-template-gaugechartconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.GaugeChartConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "gauge_chart_options": "gaugeChartOptions",
            "tooltip_options": "tooltipOptions",
            "visual_palette": "visualPalette",
        },
    )
    class GaugeChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            gauge_chart_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``GaugeChartVisual`` .

            :param data_labels: The data label configuration of a ``GaugeChartVisual`` .
            :param field_wells: The field well configuration of a ``GaugeChartVisual`` .
            :param gauge_chart_options: The options that determine the presentation of the ``GaugeChartVisual`` .
            :param tooltip_options: The tooltip configuration of a ``GaugeChartVisual`` .
            :param visual_palette: The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_configuration_property = quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                        arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                            arc_angle=123,
                            arc_thickness="arcThickness"
                        ),
                        arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                            range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                max=123,
                                min=123
                            ),
                            reserve_range=123
                        ),
                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        )
                    ),
                    tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e20a21a32656654aaa1e2012cbd79ae29c4e51ff0a83ee22d53c261a8504fca2)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument gauge_chart_options", value=gauge_chart_options, expected_type=type_hints["gauge_chart_options"])
                check_type(argname="argument tooltip_options", value=tooltip_options, expected_type=type_hints["tooltip_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if gauge_chart_options is not None:
                self._values["gauge_chart_options"] = gauge_chart_options
            if tooltip_options is not None:
                self._values["tooltip_options"] = tooltip_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def gauge_chart_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-gaugechartoptions
            '''
            result = self._values.get("gauge_chart_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-tooltipoptions
            '''
            result = self._values.get("tooltip_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"target_values": "targetValues", "values": "values"},
    )
    class GaugeChartFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a ``GaugeChartVisual`` .

            :param target_values: The target value field wells of a ``GaugeChartVisual`` .
            :param values: The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_field_wells_property = quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a4401a773fbcb50a9a8f4ab7be4cb70f9accc011877324276042c4d955de63db)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The target value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arc": "arc",
            "arc_axis": "arcAxis",
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
        },
    )
    class GaugeChartOptionsProperty:
        def __init__(
            self,
            *,
            arc: typing.Optional[typing.Union[typing.Union["CfnTemplate.ArcConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            arc_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.ArcAxisConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            comparison: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of the ``GaugeChartVisual`` .

            :param arc: The arc configuration of a ``GaugeChartVisual`` .
            :param arc_axis: The arc axis configuration of a ``GaugeChartVisual`` .
            :param comparison: The comparison configuration of a ``GaugeChartVisual`` .
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_options_property = quicksight.CfnTemplate.GaugeChartOptionsProperty(
                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                        arc_angle=123,
                        arc_thickness="arcThickness"
                    ),
                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                            max=123,
                            min=123
                        ),
                        reserve_range=123
                    ),
                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43b6129318c8258bd6274c88b028a2b33493761808cc6c1ab26a3cb2d8f5b178)
                check_type(argname="argument arc", value=arc, expected_type=type_hints["arc"])
                check_type(argname="argument arc_axis", value=arc_axis, expected_type=type_hints["arc_axis"])
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arc is not None:
                self._values["arc"] = arc
            if arc_axis is not None:
                self._values["arc_axis"] = arc_axis
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration

        @builtins.property
        def arc(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ArcConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The arc configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arc
            '''
            result = self._values.get("arc")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ArcConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def arc_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ArcAxisConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The arc axis configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arcaxis
            '''
            result = self._values.get("arc_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ArcAxisConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComparisonConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The comparison configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComparisonConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class GaugeChartPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a ``GaugeChartVisual`` .

            :param icon: The conditional formatting of the primary value icon.
            :param text_color: The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_primary_value_conditional_formatting_property = quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b53889f5419839873ce8f21b111f9029495e73e095212979f53f6d33442a958c)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GaugeChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GaugeChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a ``GaugeChartVisual`` .
            :param conditional_formatting: The conditional formatting of a ``GaugeChartVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gauge_chart_visual_property = quicksight.CfnTemplate.GaugeChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                            target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                            arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                arc_angle=123,
                                arc_thickness="arcThickness"
                            ),
                            arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                    max=123,
                                    min=123
                                ),
                                reserve_range=123
                            ),
                            comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        ),
                        tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                            arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7beabdab608b18f5afad3c5780af7a316410134772f2d78e43be87dc95c4ae34)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a ``GaugeChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GaugeChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "east": "east",
            "north": "north",
            "south": "south",
            "west": "west",
        },
    )
    class GeospatialCoordinateBoundsProperty:
        def __init__(
            self,
            *,
            east: jsii.Number,
            north: jsii.Number,
            south: jsii.Number,
            west: jsii.Number,
        ) -> None:
            '''The bound options (north, south, west, east) of the geospatial window options.

            :param east: The longitude of the east bound of the geospatial coordinate bounds.
            :param north: The latitude of the north bound of the geospatial coordinate bounds.
            :param south: The latitude of the south bound of the geospatial coordinate bounds.
            :param west: The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_coordinate_bounds_property = quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                    east=123,
                    north=123,
                    south=123,
                    west=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__516bd7b5341d6059cd6adced219da15398447e0a0a2d8a43203b676317c11f86)
                check_type(argname="argument east", value=east, expected_type=type_hints["east"])
                check_type(argname="argument north", value=north, expected_type=type_hints["north"])
                check_type(argname="argument south", value=south, expected_type=type_hints["south"])
                check_type(argname="argument west", value=west, expected_type=type_hints["west"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "east": east,
                "north": north,
                "south": south,
                "west": west,
            }

        @builtins.property
        def east(self) -> jsii.Number:
            '''The longitude of the east bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-east
            '''
            result = self._values.get("east")
            assert result is not None, "Required property 'east' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def north(self) -> jsii.Number:
            '''The latitude of the north bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-north
            '''
            result = self._values.get("north")
            assert result is not None, "Required property 'north' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def south(self) -> jsii.Number:
            '''The latitude of the south bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-south
            '''
            result = self._values.get("south")
            assert result is not None, "Required property 'south' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def west(self) -> jsii.Number:
            '''The longitude of the west bound of the geospatial coordinate bounds.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-west
            '''
            result = self._values.get("west")
            assert result is not None, "Required property 'west' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialCoordinateBoundsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "geospatial": "geospatial",
            "values": "values",
        },
    )
    class GeospatialMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells for a geospatial map.

            :param colors: The color field wells of a geospatial map.
            :param geospatial: The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
            :param values: The size field wells of a geospatial map. Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_aggregated_field_wells_property = quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3d5710c2cda26a9cd102e6063b8fc093b1a7463c7434c0ff1c32b508fd4d4f2)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument geospatial", value=geospatial, expected_type=type_hints["geospatial"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if geospatial is not None:
                self._values["geospatial"] = geospatial
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field wells of a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def geospatial(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The geospatial field wells of a geospatial map.

            Values are grouped by geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-geospatial
            '''
            result = self._values.get("geospatial")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field wells of a geospatial map.

            Values are aggregated based on geospatial fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "legend": "legend",
            "map_style_options": "mapStyleOptions",
            "point_style_options": "pointStyleOptions",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "window_options": "windowOptions",
        },
    )
    class GeospatialMapConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_style_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            point_style_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialPointStyleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            window_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``GeospatialMapVisual`` .

            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param map_style_options: The map style options of the geospatial map.
            :param point_style_options: The point style options of the geospatial map.
            :param tooltip: The tooltip display setup of the visual.
            :param visual_palette: ``CfnTemplate.GeospatialMapConfigurationProperty.VisualPalette``.
            :param window_options: The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_configuration_property = quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                    field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                        geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                        base_map_style="baseMapStyle"
                    ),
                    point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                        cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                            cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                    color="color"
                                )
                            )
                        ),
                        selected_point_style="selectedPointStyle"
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                            east=123,
                            north=123,
                            south=123,
                            west=123
                        ),
                        map_zoom_mode="mapZoomMode"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d275e7a7b8ac35bae52c7a5eadb523f50d665220d8a1f77d26472152a6cffad)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument map_style_options", value=map_style_options, expected_type=type_hints["map_style_options"])
                check_type(argname="argument point_style_options", value=point_style_options, expected_type=type_hints["point_style_options"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument window_options", value=window_options, expected_type=type_hints["window_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if map_style_options is not None:
                self._values["map_style_options"] = map_style_options
            if point_style_options is not None:
                self._values["point_style_options"] = point_style_options
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if window_options is not None:
                self._values["window_options"] = window_options

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The map style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-mapstyleoptions
            '''
            result = self._values.get("map_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialMapStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def point_style_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialPointStyleOptionsProperty", _IResolvable_a771d0ef]]:
            '''The point style options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-pointstyleoptions
            '''
            result = self._values.get("point_style_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialPointStyleOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.GeospatialMapConfigurationProperty.VisualPalette``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def window_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The window options of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-windowoptions
            '''
            result = self._values.get("window_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialWindowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "geospatial_map_aggregated_field_wells": "geospatialMapAggregatedFieldWells",
        },
    )
    class GeospatialMapFieldWellsProperty:
        def __init__(
            self,
            *,
            geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a ``GeospatialMapVisual`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param geospatial_map_aggregated_field_wells: The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_field_wells_property = quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                    geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f43c9d3f29bfb089f3483cd8d8889febd6a39553d8f75ba04e4241076e3772ce)
                check_type(argname="argument geospatial_map_aggregated_field_wells", value=geospatial_map_aggregated_field_wells, expected_type=type_hints["geospatial_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if geospatial_map_aggregated_field_wells is not None:
                self._values["geospatial_map_aggregated_field_wells"] = geospatial_map_aggregated_field_wells

        @builtins.property
        def geospatial_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for a geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html#cfn-quicksight-template-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
            '''
            result = self._values.get("geospatial_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"base_map_style": "baseMapStyle"},
    )
    class GeospatialMapStyleOptionsProperty:
        def __init__(
            self,
            *,
            base_map_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The map style options of the geospatial map.

            :param base_map_style: The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_style_options_property = quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                    base_map_style="baseMapStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0ad55b13c9bd3403cbe9999dc11596762fd20f5af63e58159bc60ef98ee223e)
                check_type(argname="argument base_map_style", value=base_map_style, expected_type=type_hints["base_map_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if base_map_style is not None:
                self._values["base_map_style"] = base_map_style

        @builtins.property
        def base_map_style(self) -> typing.Optional[builtins.str]:
            '''The base map style of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html#cfn-quicksight-template-geospatialmapstyleoptions-basemapstyle
            '''
            result = self._values.get("base_map_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class GeospatialMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_map_visual_property = quicksight.CfnTemplate.GeospatialMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                        field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                            geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                            base_map_style="baseMapStyle"
                        ),
                        point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                            cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                    simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                        color="color"
                                    )
                                )
                            ),
                            selected_point_style="selectedPointStyle"
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                            bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                east=123,
                                north=123,
                                south=123,
                                west=123
                            ),
                            map_zoom_mode="mapZoomMode"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d4aff519fe76c3159473fea305f7524c8b896b0f11faadab06d311668c82c714)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cluster_marker_configuration": "clusterMarkerConfiguration",
            "selected_point_style": "selectedPointStyle",
        },
    )
    class GeospatialPointStyleOptionsProperty:
        def __init__(
            self,
            *,
            cluster_marker_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ClusterMarkerConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_point_style: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The point style of the geospatial map.

            :param cluster_marker_configuration: The cluster marker configuration of the geospatial point style.
            :param selected_point_style: The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_point_style_options_property = quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                color="color"
                            )
                        )
                    ),
                    selected_point_style="selectedPointStyle"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d9f9ed1162f3d6136bd0f345a06419110f39d851811c102db1eff924e94f040b)
                check_type(argname="argument cluster_marker_configuration", value=cluster_marker_configuration, expected_type=type_hints["cluster_marker_configuration"])
                check_type(argname="argument selected_point_style", value=selected_point_style, expected_type=type_hints["selected_point_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cluster_marker_configuration is not None:
                self._values["cluster_marker_configuration"] = cluster_marker_configuration
            if selected_point_style is not None:
                self._values["selected_point_style"] = selected_point_style

        @builtins.property
        def cluster_marker_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ClusterMarkerConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The cluster marker configuration of the geospatial point style.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-clustermarkerconfiguration
            '''
            result = self._values.get("cluster_marker_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ClusterMarkerConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_point_style(self) -> typing.Optional[builtins.str]:
            '''The selected point styles (point, cluster) of the geospatial map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-selectedpointstyle
            '''
            result = self._values.get("selected_point_style")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialPointStyleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GeospatialWindowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"bounds": "bounds", "map_zoom_mode": "mapZoomMode"},
    )
    class GeospatialWindowOptionsProperty:
        def __init__(
            self,
            *,
            bounds: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialCoordinateBoundsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            map_zoom_mode: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The window options of the geospatial map visual.

            :param bounds: The bounds options (north, south, west, east) of the geospatial window options.
            :param map_zoom_mode: The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                geospatial_window_options_property = quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                        east=123,
                        north=123,
                        south=123,
                        west=123
                    ),
                    map_zoom_mode="mapZoomMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f3e47a0324cd7679cca980562032826519a0dc53adc4137f7905ec9e588a78d)
                check_type(argname="argument bounds", value=bounds, expected_type=type_hints["bounds"])
                check_type(argname="argument map_zoom_mode", value=map_zoom_mode, expected_type=type_hints["map_zoom_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bounds is not None:
                self._values["bounds"] = bounds
            if map_zoom_mode is not None:
                self._values["map_zoom_mode"] = map_zoom_mode

        @builtins.property
        def bounds(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialCoordinateBoundsProperty", _IResolvable_a771d0ef]]:
            '''The bounds options (north, south, west, east) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-bounds
            '''
            result = self._values.get("bounds")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialCoordinateBoundsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def map_zoom_mode(self) -> typing.Optional[builtins.str]:
            '''The map zoom modes (manual, auto) of the geospatial window options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-mapzoommode
            '''
            result = self._values.get("map_zoom_mode")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GeospatialWindowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GlobalTableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "side_specific_border": "sideSpecificBorder",
            "uniform_border": "uniformBorder",
        },
    )
    class GlobalTableBorderOptionsProperty:
        def __init__(
            self,
            *,
            side_specific_border: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableSideBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            uniform_border: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Determines the border options for a table visual.

            :param side_specific_border: Determines the options for side specific border.
            :param uniform_border: Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                global_table_border_options_property = quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        ),
                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e035b7e8786fe1aade478e81f11c4ef0aee40801f59b958635a60f9a7e64052d)
                check_type(argname="argument side_specific_border", value=side_specific_border, expected_type=type_hints["side_specific_border"])
                check_type(argname="argument uniform_border", value=uniform_border, expected_type=type_hints["uniform_border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if side_specific_border is not None:
                self._values["side_specific_border"] = side_specific_border
            if uniform_border is not None:
                self._values["uniform_border"] = uniform_border

        @builtins.property
        def side_specific_border(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableSideBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines the options for side specific border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-sidespecificborder
            '''
            result = self._values.get("side_specific_border")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableSideBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def uniform_border(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''Determines the options for uniform border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-uniformborder
            '''
            result = self._values.get("uniform_border")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GlobalTableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GradientColorProperty",
        jsii_struct_bases=[],
        name_mapping={"stops": "stops"},
    )
    class GradientColorProperty:
        def __init__(
            self,
            *,
            stops: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.GradientStopProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Determines the gradient color settings.

            :param stops: The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gradient_color_property = quicksight.CfnTemplate.GradientColorProperty(
                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                        gradient_offset=123,
                
                        # the properties below are optional
                        color="color",
                        data_value=123
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3023c66802cd6873588984dd9fdb6bf027ea256b0da63ab588685edaccaa32c)
                check_type(argname="argument stops", value=stops, expected_type=type_hints["stops"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if stops is not None:
                self._values["stops"] = stops

        @builtins.property
        def stops(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.GradientStopProperty", _IResolvable_a771d0ef]]]]:
            '''The list of gradient color stops.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html#cfn-quicksight-template-gradientcolor-stops
            '''
            result = self._values.get("stops")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.GradientStopProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientColorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GradientStopProperty",
        jsii_struct_bases=[],
        name_mapping={
            "gradient_offset": "gradientOffset",
            "color": "color",
            "data_value": "dataValue",
        },
    )
    class GradientStopProperty:
        def __init__(
            self,
            *,
            gradient_offset: jsii.Number,
            color: typing.Optional[builtins.str] = None,
            data_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''Determines the gradient stop configuration.

            :param gradient_offset: Determines gradient offset value.
            :param color: Determines the color.
            :param data_value: Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gradient_stop_property = quicksight.CfnTemplate.GradientStopProperty(
                    gradient_offset=123,
                
                    # the properties below are optional
                    color="color",
                    data_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1cc5770ba3abcd68192f034694a880768c75a3ba29d9cbc8b507c5bfc5eaeda6)
                check_type(argname="argument gradient_offset", value=gradient_offset, expected_type=type_hints["gradient_offset"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument data_value", value=data_value, expected_type=type_hints["data_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "gradient_offset": gradient_offset,
            }
            if color is not None:
                self._values["color"] = color
            if data_value is not None:
                self._values["data_value"] = data_value

        @builtins.property
        def gradient_offset(self) -> jsii.Number:
            '''Determines gradient offset value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-gradientoffset
            '''
            result = self._values.get("gradient_offset")
            assert result is not None, "Required property 'gradient_offset' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''Determines the color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_value(self) -> typing.Optional[jsii.Number]:
            '''Determines the data value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-datavalue
            '''
            result = self._values.get("data_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GradientStopProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"screen_canvas_size_options": "screenCanvasSizeOptions"},
    )
    class GridLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            screen_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Configuration options for the canvas of a grid layout.

            :param screen_canvas_size_options: The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_canvas_size_options_property = quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                        resize_option="resizeOption",
                
                        # the properties below are optional
                        optimized_view_port_width="optimizedViewPortWidth"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__78c86eec2ab21a179e9dfe6ea705e8e7a6e6a48cf8dcca022a973ba345c2efc2)
                check_type(argname="argument screen_canvas_size_options", value=screen_canvas_size_options, expected_type=type_hints["screen_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if screen_canvas_size_options is not None:
                self._values["screen_canvas_size_options"] = screen_canvas_size_options

        @builtins.property
        def screen_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html#cfn-quicksight-template-gridlayoutcanvassizeoptions-screencanvassizeoptions
            '''
            result = self._values.get("screen_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GridLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "elements": "elements",
            "canvas_size_options": "canvasSizeOptions",
        },
    )
    class GridLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.GridLayoutElementProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a grid layout. Also called a tiled layout.

            Visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size.

            :param elements: The elements that are included in a grid layout.
            :param canvas_size_options: ``CfnTemplate.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_configuration_property = quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                        column_span=123,
                        element_id="elementId",
                        element_type="elementType",
                        row_span=123,
                
                        # the properties below are optional
                        column_index=123,
                        row_index=123
                    )],
                
                    # the properties below are optional
                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                            resize_option="resizeOption",
                
                            # the properties below are optional
                            optimized_view_port_width="optimizedViewPortWidth"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2946eede0323e9965f493d53681e8c48650de1ed5050f14e2d7092e00f06190a)
                check_type(argname="argument elements", value=elements, expected_type=type_hints["elements"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "elements": elements,
            }
            if canvas_size_options is not None:
                self._values["canvas_size_options"] = canvas_size_options

        @builtins.property
        def elements(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.GridLayoutElementProperty", _IResolvable_a771d0ef]]]:
            '''The elements that are included in a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-elements
            '''
            result = self._values.get("elements")
            assert result is not None, "Required property 'elements' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.GridLayoutElementProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.GridLayoutConfigurationProperty.CanvasSizeOptions``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GridLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GridLayoutElementProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_span": "columnSpan",
            "element_id": "elementId",
            "element_type": "elementType",
            "row_span": "rowSpan",
            "column_index": "columnIndex",
            "row_index": "rowIndex",
        },
    )
    class GridLayoutElementProperty:
        def __init__(
            self,
            *,
            column_span: jsii.Number,
            element_id: builtins.str,
            element_type: builtins.str,
            row_span: jsii.Number,
            column_index: typing.Optional[jsii.Number] = None,
            row_index: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An element within a grid layout.

            :param column_span: The width of a grid element expressed as a number of grid columns.
            :param element_id: A unique identifier for an element within a grid layout.
            :param element_type: The type of element.
            :param row_span: The height of a grid element expressed as a number of grid rows.
            :param column_index: The column index for the upper left corner of an element.
            :param row_index: The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_element_property = quicksight.CfnTemplate.GridLayoutElementProperty(
                    column_span=123,
                    element_id="elementId",
                    element_type="elementType",
                    row_span=123,
                
                    # the properties below are optional
                    column_index=123,
                    row_index=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e84d041b92ec1815aa5816dcac73802553589a363ec9fc8a22b3fae7bfbcb8a)
                check_type(argname="argument column_span", value=column_span, expected_type=type_hints["column_span"])
                check_type(argname="argument element_id", value=element_id, expected_type=type_hints["element_id"])
                check_type(argname="argument element_type", value=element_type, expected_type=type_hints["element_type"])
                check_type(argname="argument row_span", value=row_span, expected_type=type_hints["row_span"])
                check_type(argname="argument column_index", value=column_index, expected_type=type_hints["column_index"])
                check_type(argname="argument row_index", value=row_index, expected_type=type_hints["row_index"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column_span": column_span,
                "element_id": element_id,
                "element_type": element_type,
                "row_span": row_span,
            }
            if column_index is not None:
                self._values["column_index"] = column_index
            if row_index is not None:
                self._values["row_index"] = row_index

        @builtins.property
        def column_span(self) -> jsii.Number:
            '''The width of a grid element expressed as a number of grid columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnspan
            '''
            result = self._values.get("column_span")
            assert result is not None, "Required property 'column_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def element_id(self) -> builtins.str:
            '''A unique identifier for an element within a grid layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementid
            '''
            result = self._values.get("element_id")
            assert result is not None, "Required property 'element_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def element_type(self) -> builtins.str:
            '''The type of element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementtype
            '''
            result = self._values.get("element_type")
            assert result is not None, "Required property 'element_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def row_span(self) -> jsii.Number:
            '''The height of a grid element expressed as a number of grid rows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowspan
            '''
            result = self._values.get("row_span")
            assert result is not None, "Required property 'row_span' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def column_index(self) -> typing.Optional[jsii.Number]:
            '''The column index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnindex
            '''
            result = self._values.get("column_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def row_index(self) -> typing.Optional[jsii.Number]:
            '''The row index for the upper left corner of an element.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowindex
            '''
            result = self._values.get("row_index")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutElementProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "resize_option": "resizeOption",
            "optimized_view_port_width": "optimizedViewPortWidth",
        },
    )
    class GridLayoutScreenCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            resize_option: builtins.str,
            optimized_view_port_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the sizing of the canvas used in a grid layout.

            :param resize_option: This value determines the layout behavior when the viewport is resized. - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` . - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .
            :param optimized_view_port_width: The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                grid_layout_screen_canvas_size_options_property = quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                    resize_option="resizeOption",
                
                    # the properties below are optional
                    optimized_view_port_width="optimizedViewPortWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__980a898eb1fd9df145843e5551f39dfd2379957c54cd1b647b1b4bd6a077d292)
                check_type(argname="argument resize_option", value=resize_option, expected_type=type_hints["resize_option"])
                check_type(argname="argument optimized_view_port_width", value=optimized_view_port_width, expected_type=type_hints["optimized_view_port_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "resize_option": resize_option,
            }
            if optimized_view_port_width is not None:
                self._values["optimized_view_port_width"] = optimized_view_port_width

        @builtins.property
        def resize_option(self) -> builtins.str:
            '''This value determines the layout behavior when the viewport is resized.

            - ``FIXED`` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called ``Classic`` .
            - ``RESPONSIVE`` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called ``Tiled`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-resizeoption
            '''
            result = self._values.get("resize_option")
            assert result is not None, "Required property 'resize_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def optimized_view_port_width(self) -> typing.Optional[builtins.str]:
            '''The width that the view port will be optimized for when the layout renders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
            '''
            result = self._values.get("optimized_view_port_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GridLayoutScreenCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.GrowthRateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_size": "periodSize",
            "value": "value",
        },
    )
    class GrowthRateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            period_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The growth rate computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_size: The period size setup of a growth rate computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                growth_rate_computation_property = quicksight.CfnTemplate.GrowthRateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_size=123,
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d665bcdf0b1d9fca7a1ed1a78dbe4623d00e7635b39b988833b3dadf858b2ae)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_size", value=period_size, expected_type=type_hints["period_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_size is not None:
                self._values["period_size"] = period_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_size(self) -> typing.Optional[jsii.Number]:
            '''The period size setup of a growth rate computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-periodsize
            '''
            result = self._values.get("period_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GrowthRateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"layout": "layout", "section_id": "sectionId", "style": "style"},
    )
    class HeaderFooterSectionConfigurationProperty:
        def __init__(
            self,
            *,
            layout: typing.Union[typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            section_id: builtins.str,
            style: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a header or footer section.

            :param layout: The layout configuration of the header or footer section.
            :param section_id: The unique identifier of the header or footer section.
            :param style: The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                header_footer_section_configuration_property = quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )]
                        )
                    ),
                    section_id="sectionId",
                
                    # the properties below are optional
                    style=quicksight.CfnTemplate.SectionStyleProperty(
                        height="height",
                        padding=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6b0d9e407ed91524f824c775e39889b2e7f3e111847d40ff83dc33658f928c9)
                check_type(argname="argument layout", value=layout, expected_type=type_hints["layout"])
                check_type(argname="argument section_id", value=section_id, expected_type=type_hints["section_id"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "layout": layout,
                "section_id": section_id,
            }
            if style is not None:
                self._values["style"] = style

        @builtins.property
        def layout(
            self,
        ) -> typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The layout configuration of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-layout
            '''
            result = self._values.get("layout")
            assert result is not None, "Required property 'layout' is missing"
            return typing.cast(typing.Union["CfnTemplate.SectionLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def section_id(self) -> builtins.str:
            '''The unique identifier of the header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-sectionid
            '''
            result = self._values.get("section_id")
            assert result is not None, "Required property 'section_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionStyleProperty", _IResolvable_a771d0ef]]:
            '''The style options of a header or footer section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeaderFooterSectionConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class HeatMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a heat map.

            :param columns: The columns field well of a heat map.
            :param rows: The rows field well of a heat map.
            :param values: The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_aggregated_field_wells_property = quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af23009d190c734de496e3cee0bad14c51a9dc4f83817588e46f21274768a15f)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The columns field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The rows field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HeatMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_scale": "colorScale",
            "column_label_options": "columnLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "row_label_options": "rowLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class HeatMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_scale: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.HeatMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.HeatMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a heat map.

            :param color_scale: The color options (gradient color, point of divergence) in a heat map.
            :param column_label_options: The label options of the column that is displayed in a heat map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param row_label_options: The label options of the row that is displayed in a ``heat map`` .
            :param sort_configuration: The sort configuration of a heat map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_configuration_property = quicksight.CfnTemplate.HeatMapConfigurationProperty(
                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                        heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                        heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7096f07208f22005baa66805c7992bfade1170e4b23cf6ada2127397994e8f9f)
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument column_label_options", value=column_label_options, expected_type=type_hints["column_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument row_label_options", value=row_label_options, expected_type=type_hints["row_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if column_label_options is not None:
                self._values["column_label_options"] = column_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if row_label_options is not None:
                self._values["row_label_options"] = row_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColorScaleProperty", _IResolvable_a771d0ef]]:
            '''The color options (gradient color, point of divergence) in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColorScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the column that is displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-columnlabeloptions
            '''
            result = self._values.get("column_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HeatMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HeatMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the row that is displayed in a ``heat map`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-rowlabeloptions
            '''
            result = self._values.get("row_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HeatMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HeatMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HeatMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_aggregated_field_wells": "heatMapAggregatedFieldWells",
        },
    )
    class HeatMapFieldWellsProperty:
        def __init__(
            self,
            *,
            heat_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.HeatMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a heat map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param heat_map_aggregated_field_wells: The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_field_wells_property = quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                    heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d74dfdd511bd241fd78bab7c6bb6052b7fbbaf54f4ff74bc2840cecb4ac94557)
                check_type(argname="argument heat_map_aggregated_field_wells", value=heat_map_aggregated_field_wells, expected_type=type_hints["heat_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_aggregated_field_wells is not None:
                self._values["heat_map_aggregated_field_wells"] = heat_map_aggregated_field_wells

        @builtins.property
        def heat_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HeatMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html#cfn-quicksight-template-heatmapfieldwells-heatmapaggregatedfieldwells
            '''
            result = self._values.get("heat_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HeatMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HeatMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "heat_map_column_items_limit_configuration": "heatMapColumnItemsLimitConfiguration",
            "heat_map_column_sort": "heatMapColumnSort",
            "heat_map_row_items_limit_configuration": "heatMapRowItemsLimitConfiguration",
            "heat_map_row_sort": "heatMapRowSort",
        },
    )
    class HeatMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            heat_map_column_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            heat_map_row_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a heat map.

            :param heat_map_column_items_limit_configuration: The limit on the number of columns that are displayed in a heat map.
            :param heat_map_column_sort: The column sort configuration for heat map for columns that aren't a part of a field well.
            :param heat_map_row_items_limit_configuration: The limit on the number of rows that are displayed in a heat map.
            :param heat_map_row_sort: The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_sort_configuration_property = quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8cc70f417887305f61d5e22af6caf91f228d6737698ea60b291990bff6055485)
                check_type(argname="argument heat_map_column_items_limit_configuration", value=heat_map_column_items_limit_configuration, expected_type=type_hints["heat_map_column_items_limit_configuration"])
                check_type(argname="argument heat_map_column_sort", value=heat_map_column_sort, expected_type=type_hints["heat_map_column_sort"])
                check_type(argname="argument heat_map_row_items_limit_configuration", value=heat_map_row_items_limit_configuration, expected_type=type_hints["heat_map_row_items_limit_configuration"])
                check_type(argname="argument heat_map_row_sort", value=heat_map_row_sort, expected_type=type_hints["heat_map_row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if heat_map_column_items_limit_configuration is not None:
                self._values["heat_map_column_items_limit_configuration"] = heat_map_column_items_limit_configuration
            if heat_map_column_sort is not None:
                self._values["heat_map_column_sort"] = heat_map_column_sort
            if heat_map_row_items_limit_configuration is not None:
                self._values["heat_map_row_items_limit_configuration"] = heat_map_row_items_limit_configuration
            if heat_map_row_sort is not None:
                self._values["heat_map_row_sort"] = heat_map_row_sort

        @builtins.property
        def heat_map_column_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of columns that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
            '''
            result = self._values.get("heat_map_column_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_column_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The column sort configuration for heat map for columns that aren't a part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnsort
            '''
            result = self._values.get("heat_map_column_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def heat_map_row_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of rows that are displayed in a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
            '''
            result = self._values.get("heat_map_row_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort configuration of the rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowsort
            '''
            result = self._values.get("heat_map_row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HeatMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HeatMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.HeatMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a heat map.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                heat_map_visual_property = quicksight.CfnTemplate.HeatMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                        color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                            heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                            heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e74e90e54c6a55837f5cde04895c55b5f712403c72ffbaa792fe2fef42d76f95)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HeatMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a heat map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HeatMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HeatMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class HistogramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param values: The value field wells of a histogram. Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_aggregated_field_wells_property = quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__abf03f119215c08941333c006ea4989eb59ac54501c14cea4f31ba7d43d336a4)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a histogram.

            Values are aggregated by ``COUNT`` or ``DISTINCT_COUNT`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html#cfn-quicksight-template-histogramaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HistogramBinOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_count": "binCount",
            "bin_width": "binWidth",
            "selected_bin_type": "selectedBinType",
            "start_value": "startValue",
        },
    )
    class HistogramBinOptionsProperty:
        def __init__(
            self,
            *,
            bin_count: typing.Optional[typing.Union[typing.Union["CfnTemplate.BinCountOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            bin_width: typing.Optional[typing.Union[typing.Union["CfnTemplate.BinWidthOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_bin_type: typing.Optional[builtins.str] = None,
            start_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The options that determine the presentation of histogram bins.

            :param bin_count: The options that determine the bin count of a histogram.
            :param bin_width: The options that determine the bin width of a histogram.
            :param selected_bin_type: The options that determine the selected bin type.
            :param start_value: The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_bin_options_property = quicksight.CfnTemplate.HistogramBinOptionsProperty(
                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                        value=123
                    ),
                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                        bin_count_limit=123,
                        value=123
                    ),
                    selected_bin_type="selectedBinType",
                    start_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dad86f8b692d74fcf0f80f3bd77897862a96fe4a98f7a16227c437ce92a540ce)
                check_type(argname="argument bin_count", value=bin_count, expected_type=type_hints["bin_count"])
                check_type(argname="argument bin_width", value=bin_width, expected_type=type_hints["bin_width"])
                check_type(argname="argument selected_bin_type", value=selected_bin_type, expected_type=type_hints["selected_bin_type"])
                check_type(argname="argument start_value", value=start_value, expected_type=type_hints["start_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_count is not None:
                self._values["bin_count"] = bin_count
            if bin_width is not None:
                self._values["bin_width"] = bin_width
            if selected_bin_type is not None:
                self._values["selected_bin_type"] = selected_bin_type
            if start_value is not None:
                self._values["start_value"] = start_value

        @builtins.property
        def bin_count(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BinCountOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the bin count of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-bincount
            '''
            result = self._values.get("bin_count")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BinCountOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def bin_width(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BinWidthOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the bin width of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-binwidth
            '''
            result = self._values.get("bin_width")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BinWidthOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_bin_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the selected bin type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-selectedbintype
            '''
            result = self._values.get("selected_bin_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def start_value(self) -> typing.Optional[jsii.Number]:
            '''The options that determine the bin start value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-startvalue
            '''
            result = self._values.get("start_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramBinOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HistogramConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bin_options": "binOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
        },
    )
    class HistogramConfigurationProperty:
        def __init__(
            self,
            *,
            bin_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.HistogramBinOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.HistogramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``HistogramVisual`` .

            :param bin_options: The options that determine the presentation of histogram bins.
            :param data_labels: The data label configuration of a histogram.
            :param field_wells: The field well configuration of a histogram.
            :param tooltip: The tooltip configuration of a histogram.
            :param visual_palette: The visual palette configuration of a histogram.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.
            :param y_axis_display_options: The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_configuration_property = quicksight.CfnTemplate.HistogramConfigurationProperty(
                    bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                        bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                            value=123
                        ),
                        bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                            bin_count_limit=123,
                            value=123
                        ),
                        selected_bin_type="selectedBinType",
                        start_value=123
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                        histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6fe2c6fea6c98fa485252a851f62f2e12cf1e9b3c65336baae8119479d367bb2)
                check_type(argname="argument bin_options", value=bin_options, expected_type=type_hints["bin_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bin_options is not None:
                self._values["bin_options"] = bin_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options

        @builtins.property
        def bin_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HistogramBinOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of histogram bins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-binoptions
            '''
            result = self._values.get("bin_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HistogramBinOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HistogramFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HistogramFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HistogramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "histogram_aggregated_field_wells": "histogramAggregatedFieldWells",
        },
    )
    class HistogramFieldWellsProperty:
        def __init__(
            self,
            *,
            histogram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.HistogramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a histogram.

            :param histogram_aggregated_field_wells: The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                histogram_field_wells_property = quicksight.CfnTemplate.HistogramFieldWellsProperty(
                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32a39293db042892cdd3e62d4573206c65395c099d4f32e8ede8338f1bd7cd27)
                check_type(argname="argument histogram_aggregated_field_wells", value=histogram_aggregated_field_wells, expected_type=type_hints["histogram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if histogram_aggregated_field_wells is not None:
                self._values["histogram_aggregated_field_wells"] = histogram_aggregated_field_wells

        @builtins.property
        def histogram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HistogramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a histogram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html#cfn-quicksight-template-histogramfieldwells-histogramaggregatedfieldwells
            '''
            result = self._values.get("histogram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HistogramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.HistogramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class HistogramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.HistogramConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a ``HistogramVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                histogram_visual_property = quicksight.CfnTemplate.HistogramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                        bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                            bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                value=123
                            ),
                            bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                bin_count_limit=123,
                                value=123
                            ),
                            selected_bin_type="selectedBinType",
                            start_value=123
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                            histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        )
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eec91f5a2d0470d5d88168312bdbbf133128273d8027d5b77225c05f368e288e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HistogramConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for a ``HistogramVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HistogramConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "HistogramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.InsightConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computations": "computations",
            "custom_narrative": "customNarrative",
        },
    )
    class InsightConfigurationProperty:
        def __init__(
            self,
            *,
            computations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ComputationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            custom_narrative: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomNarrativeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of an insight visual.

            :param computations: The computations configurations of the insight visual.
            :param custom_narrative: The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                insight_configuration_property = quicksight.CfnTemplate.InsightConfigurationProperty(
                    computations=[quicksight.CfnTemplate.ComputationProperty(
                        forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            custom_seasonality_value=123,
                            lower_boundary=123,
                            name="name",
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality="seasonality",
                            upper_boundary=123,
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_size=123,
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                            computation_id="computationId",
                            from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                
                            # the properties below are optional
                            name="name",
                            period_time_granularity="periodTimeGranularity",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            type="type",
                
                            # the properties below are optional
                            mover_size=123,
                            name="name",
                            sort_order="sortOrder",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                            type="type",
                
                            # the properties below are optional
                            name="name",
                            result_size=123,
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )
                        ),
                        total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                            computation_id="computationId",
                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            ),
                
                            # the properties below are optional
                            name="name"
                        ),
                        unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            ),
                            computation_id="computationId",
                
                            # the properties below are optional
                            name="name"
                        )
                    )],
                    custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                        narrative="narrative"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ad0a2fe0c078b2ec333dcfdcb9f8a1d6d8470adce30e18c983ef9810812ea2d8)
                check_type(argname="argument computations", value=computations, expected_type=type_hints["computations"])
                check_type(argname="argument custom_narrative", value=custom_narrative, expected_type=type_hints["custom_narrative"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if computations is not None:
                self._values["computations"] = computations
            if custom_narrative is not None:
                self._values["custom_narrative"] = custom_narrative

        @builtins.property
        def computations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ComputationProperty", _IResolvable_a771d0ef]]]]:
            '''The computations configurations of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-computations
            '''
            result = self._values.get("computations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ComputationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def custom_narrative(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomNarrativeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The custom narrative of the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-customnarrative
            '''
            result = self._values.get("custom_narrative")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomNarrativeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.InsightVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "visual_id": "visualId",
            "actions": "actions",
            "insight_configuration": "insightConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class InsightVisualProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            insight_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.InsightConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :param data_set_identifier: The dataset that is used in the insight visual.
            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param insight_configuration: The configuration of an insight visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                insight_visual_property = quicksight.CfnTemplate.InsightVisualProperty(
                    data_set_identifier="dataSetIdentifier",
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                        computations=[quicksight.CfnTemplate.ComputationProperty(
                            forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                custom_seasonality_value=123,
                                lower_boundary=123,
                                name="name",
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality="seasonality",
                                upper_boundary=123,
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_size=123,
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                computation_id="computationId",
                                from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                
                                # the properties below are optional
                                name="name",
                                period_time_granularity="periodTimeGranularity",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                category=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                time=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                type="type",
                
                                # the properties below are optional
                                mover_size=123,
                                name="name",
                                sort_order="sortOrder",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                category=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                                type="type",
                
                                # the properties below are optional
                                name="name",
                                result_size=123,
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )
                            ),
                            total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                computation_id="computationId",
                                value=quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                ),
                
                                # the properties below are optional
                                name="name"
                            ),
                            unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                category=quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                ),
                                computation_id="computationId",
                
                                # the properties below are optional
                                name="name"
                            )
                        )],
                        custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                            narrative="narrative"
                        )
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0da04957de9f36c20499971f9fb9c255bf5c27df7884a69ee06a2d443a6594ab)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument insight_configuration", value=insight_configuration, expected_type=type_hints["insight_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if insight_configuration is not None:
                self._values["insight_configuration"] = insight_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''The dataset that is used in the insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def insight_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.InsightConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of an insight visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-insightconfiguration
            '''
            result = self._values.get("insight_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.InsightConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "InsightVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.IntegerDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class IntegerDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
        ) -> None:
            '''The default values of the ``IntegerParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``IntegerDefaultValues`` . Different defaults are displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_default_values_property = quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=[123]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__27eea6a1f5e5507de8b0cd121abfdce49a3a9bdd752a56d3e9692f6e5b91e0bc)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``IntegerDefaultValues`` .

            Different defaults are displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]]:
            '''The static values of the ``IntegerDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[jsii.Number]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.IntegerParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class IntegerParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.IntegerDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnTemplate.IntegerValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.IntegerParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_parameter_declaration_property = quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=[123]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                        custom_value=123,
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e11a10d8b1ed6efcb216a9e0a01a53a71fec4383aaac2fbde564de1ec399e9f8)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.IntegerDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.IntegerDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnTemplate.IntegerParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.IntegerValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.IntegerValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class IntegerValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[jsii.Number] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A parameter declaration for the ``Integer`` data type.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                integer_value_when_unset_configuration_property = quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                    custom_value=123,
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__06efa9152e8b90b8866f7902b0edd0ac8df943aaea861535914cf799bbf60a30)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[jsii.Number]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "IntegerValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ItemsLimitConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "items_limit": "itemsLimit",
            "other_categories": "otherCategories",
        },
    )
    class ItemsLimitConfigurationProperty:
        def __init__(
            self,
            *,
            items_limit: typing.Optional[jsii.Number] = None,
            other_categories: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The limit configuration of the visual display for an axis.

            :param items_limit: The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
            :param other_categories: The ``Show other`` of an axis in the chart. Choose one of the following options:. - ``INCLUDE`` - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                items_limit_configuration_property = quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                    items_limit=123,
                    other_categories="otherCategories"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__957778ce9e752fc8ead5ba0eadfa9af0c08de7be548fcd1a347fd02c3d55ef3c)
                check_type(argname="argument items_limit", value=items_limit, expected_type=type_hints["items_limit"])
                check_type(argname="argument other_categories", value=other_categories, expected_type=type_hints["other_categories"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if items_limit is not None:
                self._values["items_limit"] = items_limit
            if other_categories is not None:
                self._values["other_categories"] = other_categories

        @builtins.property
        def items_limit(self) -> typing.Optional[jsii.Number]:
            '''The limit on how many items of a field are showed in the chart.

            For example, the number of slices that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-itemslimit
            '''
            result = self._values.get("items_limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def other_categories(self) -> typing.Optional[builtins.str]:
            '''The ``Show other`` of an axis in the chart. Choose one of the following options:.

            - ``INCLUDE``
            - ``EXCLUDE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-othercategories
            '''
            result = self._values.get("other_categories")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ItemsLimitConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"primary_value": "primaryValue", "progress_bar": "progressBar"},
    )
    class KPIConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            primary_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIPrimaryValueConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            progress_bar: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIProgressBarConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting options of a KPI visual.

            :param primary_value: The conditional formatting for the primary value of a KPI visual.
            :param progress_bar: The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_option_property = quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    ),
                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f9362857ed11194af5faa248daab97baef140433eccf60ede2c58a3ec4c65376)
                check_type(argname="argument primary_value", value=primary_value, expected_type=type_hints["primary_value"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if primary_value is not None:
                self._values["primary_value"] = primary_value
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar

        @builtins.property
        def primary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the primary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-primaryvalue
            '''
            result = self._values.get("primary_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIPrimaryValueConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIProgressBarConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIProgressBarConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class KPIConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.KPIConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting of a KPI visual.

            :param conditional_formatting_options: The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConditional_formatting_property = quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        ),
                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a646abbf0dcb1675f34f399d0fa352f7f199eaecc7522b204632b75a17762eee)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.KPIConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The conditional formatting options of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html#cfn-quicksight-template-kpiconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.KPIConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_wells": "fieldWells",
            "kpi_options": "kpiOptions",
            "sort_configuration": "sortConfiguration",
        },
    )
    class KPIConfigurationProperty:
        def __init__(
            self,
            *,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            kpi_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPISortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a KPI visual.

            :param field_wells: The field well configuration of a KPI visual.
            :param kpi_options: The options that determine the presentation of a KPI visual.
            :param sort_configuration: The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIConfiguration_property = quicksight.CfnTemplate.KPIConfigurationProperty(
                    field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            comparison_method="comparisonMethod"
                        ),
                        primary_value_display_type="primaryValueDisplayType",
                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                            visibility="visibility"
                        ),
                        secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                            visibility="visibility"
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                        trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ac167d937fd51f11fae318fa636ee47ea95f17c9b70ff0e11224232bc137b891)
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument kpi_options", value=kpi_options, expected_type=type_hints["kpi_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if kpi_options is not None:
                self._values["kpi_options"] = kpi_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def kpi_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-kpioptions
            '''
            result = self._values.get("kpi_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPISortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPISortConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_values": "targetValues",
            "trend_groups": "trendGroups",
            "values": "values",
        },
    )
    class KPIFieldWellsProperty:
        def __init__(
            self,
            *,
            target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            trend_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a KPI visual.

            :param target_values: The target value field wells of a KPI visual.
            :param trend_groups: The trend group field wells of a KPI visual.
            :param values: The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIField_wells_property = quicksight.CfnTemplate.KPIFieldWellsProperty(
                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c211579ac63d2209518031a73400d003fee5302cbe2a5ae66b6cc0f0d365e1e4)
                check_type(argname="argument target_values", value=target_values, expected_type=type_hints["target_values"])
                check_type(argname="argument trend_groups", value=trend_groups, expected_type=type_hints["trend_groups"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_values is not None:
                self._values["target_values"] = target_values
            if trend_groups is not None:
                self._values["trend_groups"] = trend_groups
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def target_values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The target value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-targetvalues
            '''
            result = self._values.get("target_values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def trend_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The trend group field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-trendgroups
            '''
            result = self._values.get("trend_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "comparison": "comparison",
            "primary_value_display_type": "primaryValueDisplayType",
            "primary_value_font_configuration": "primaryValueFontConfiguration",
            "progress_bar": "progressBar",
            "secondary_value": "secondaryValue",
            "secondary_value_font_configuration": "secondaryValueFontConfiguration",
            "trend_arrows": "trendArrows",
        },
    )
    class KPIOptionsProperty:
        def __init__(
            self,
            *,
            comparison: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComparisonConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_value_display_type: typing.Optional[builtins.str] = None,
            primary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            progress_bar: typing.Optional[typing.Union[typing.Union["CfnTemplate.ProgressBarOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.SecondaryValueOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_value_font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            trend_arrows: typing.Optional[typing.Union[typing.Union["CfnTemplate.TrendArrowOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of a KPI visual.

            :param comparison: The comparison configuration of a KPI visual.
            :param primary_value_display_type: The options that determine the primary value display type.
            :param primary_value_font_configuration: The options that determine the primary value font configuration.
            :param progress_bar: The options that determine the presentation of the progress bar of a KPI visual.
            :param secondary_value: The options that determine the presentation of the secondary value of a KPI visual.
            :param secondary_value_font_configuration: The options that determine the secondary value font configuration.
            :param trend_arrows: The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIOptions_property = quicksight.CfnTemplate.KPIOptionsProperty(
                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        comparison_method="comparisonMethod"
                    ),
                    primary_value_display_type="primaryValueDisplayType",
                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                        visibility="visibility"
                    ),
                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__718b0519543d0a84b8e415033dfab96e4440358db575e02f60fcdd9ad63c9517)
                check_type(argname="argument comparison", value=comparison, expected_type=type_hints["comparison"])
                check_type(argname="argument primary_value_display_type", value=primary_value_display_type, expected_type=type_hints["primary_value_display_type"])
                check_type(argname="argument primary_value_font_configuration", value=primary_value_font_configuration, expected_type=type_hints["primary_value_font_configuration"])
                check_type(argname="argument progress_bar", value=progress_bar, expected_type=type_hints["progress_bar"])
                check_type(argname="argument secondary_value", value=secondary_value, expected_type=type_hints["secondary_value"])
                check_type(argname="argument secondary_value_font_configuration", value=secondary_value_font_configuration, expected_type=type_hints["secondary_value_font_configuration"])
                check_type(argname="argument trend_arrows", value=trend_arrows, expected_type=type_hints["trend_arrows"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if comparison is not None:
                self._values["comparison"] = comparison
            if primary_value_display_type is not None:
                self._values["primary_value_display_type"] = primary_value_display_type
            if primary_value_font_configuration is not None:
                self._values["primary_value_font_configuration"] = primary_value_font_configuration
            if progress_bar is not None:
                self._values["progress_bar"] = progress_bar
            if secondary_value is not None:
                self._values["secondary_value"] = secondary_value
            if secondary_value_font_configuration is not None:
                self._values["secondary_value_font_configuration"] = secondary_value_font_configuration
            if trend_arrows is not None:
                self._values["trend_arrows"] = trend_arrows

        @builtins.property
        def comparison(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComparisonConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The comparison configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-comparison
            '''
            result = self._values.get("comparison")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComparisonConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_value_display_type(self) -> typing.Optional[builtins.str]:
            '''The options that determine the primary value display type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluedisplaytype
            '''
            result = self._values.get("primary_value_display_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the primary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluefontconfiguration
            '''
            result = self._values.get("primary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def progress_bar(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ProgressBarOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-progressbar
            '''
            result = self._values.get("progress_bar")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ProgressBarOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SecondaryValueOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvalue
            '''
            result = self._values.get("secondary_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SecondaryValueOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_value_font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the secondary value font configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvaluefontconfiguration
            '''
            result = self._values.get("secondary_value_font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def trend_arrows(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TrendArrowOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-trendarrows
            '''
            result = self._values.get("trend_arrows")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TrendArrowOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon", "text_color": "textColor"},
    )
    class KPIPrimaryValueConditionalFormattingProperty:
        def __init__(
            self,
            *,
            icon: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the primary value of a KPI visual.

            :param icon: The conditional formatting of the primary value's icon.
            :param text_color: The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIPrimary_value_conditional_formatting_property = quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cacbbabccb4050782cee7574d81be780e5a0d9dc4d01dccb16695d05da046951)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value's icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the primary value's text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIPrimaryValueConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"foreground_color": "foregroundColor"},
    )
    class KPIProgressBarConditionalFormattingProperty:
        def __init__(
            self,
            *,
            foreground_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the progress bar of a KPI visual.

            :param foreground_color: The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIProgress_bar_conditional_formatting_property = quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5e1c49f4402f15b8fce01210cfeb48e47e338a85cf1cf5e0efca67f5d4ed32b)
                check_type(argname="argument foreground_color", value=foreground_color, expected_type=type_hints["foreground_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if foreground_color is not None:
                self._values["foreground_color"] = foreground_color

        @builtins.property
        def foreground_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of the progress bar's foreground color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html#cfn-quicksight-template-kpiprogressbarconditionalformatting-foregroundcolor
            '''
            result = self._values.get("foreground_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIProgressBarConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPISortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"trend_group_sort": "trendGroupSort"},
    )
    class KPISortConfigurationProperty:
        def __init__(
            self,
            *,
            trend_group_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a KPI visual.

            :param trend_group_sort: The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pISort_configuration_property = quicksight.CfnTemplate.KPISortConfigurationProperty(
                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea107a2dab5c2cfbffd84a25e4921a770e7d0b84c1af0f7a643292930ea3c1ac)
                check_type(argname="argument trend_group_sort", value=trend_group_sort, expected_type=type_hints["trend_group_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if trend_group_sort is not None:
                self._values["trend_group_sort"] = trend_group_sort

        @builtins.property
        def trend_group_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the trend group fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html#cfn-quicksight-template-kpisortconfiguration-trendgroupsort
            '''
            result = self._values.get("trend_group_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPISortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.KPIVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class KPIVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a KPI visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param conditional_formatting: The conditional formatting of a KPI visual.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                k_pIVisual_property = quicksight.CfnTemplate.KPIVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                        field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                            target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                            comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                comparison_method="comparisonMethod"
                            ),
                            primary_value_display_type="primaryValueDisplayType",
                            primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                visibility="visibility"
                            ),
                            secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                visibility="visibility"
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                            trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                            primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            ),
                            progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f67a6c809b1127cd232db69b92fc4b69abf2dddcf29db1e6f22aa28a2d3ffd32)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting of a KPI visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "KPIVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "font_configuration": "fontConfiguration",
            "visibility": "visibility",
        },
    )
    class LabelOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The share label options for the labels.

            :param custom_label: The text for the label.
            :param font_configuration: The font configuration of the label.
            :param visibility: Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                label_options_property = quicksight.CfnTemplate.LabelOptionsProperty(
                    custom_label="customLabel",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1d6dd7b3b7e59fca518f04b92335ef66bede6442f72f80c3f81e92ba67df114e)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The text for the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the label is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "free_form_layout": "freeFormLayout",
            "grid_layout": "gridLayout",
            "section_based_layout": "sectionBasedLayout",
        },
    )
    class LayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Optional[typing.Union[typing.Union["CfnTemplate.FreeFormLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            grid_layout: typing.Optional[typing.Union[typing.Union["CfnTemplate.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            section_based_layout: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionBasedLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration that determines what the type of layout will be used on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param free_form_layout: A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
            :param grid_layout: A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .
            :param section_based_layout: A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                layout_configuration_property = quicksight.CfnTemplate.LayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    ),
                    section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                        body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                            content=quicksight.CfnTemplate.BodySectionContentProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                    status="status"
                                )
                            ),
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                            paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                ),
                                paper_orientation="paperOrientation",
                                paper_size="paperSize"
                            )
                        ),
                        footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )],
                        header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            ),
                            section_id="sectionId",
                
                            # the properties below are optional
                            style=quicksight.CfnTemplate.SectionStyleProperty(
                                height="height",
                                padding=quicksight.CfnTemplate.SpacingProperty(
                                    bottom="bottom",
                                    left="left",
                                    right="right",
                                    top="top"
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6abce898bb6b7fd713e79a0ff77f08521d605f449aff83f223f793dd180e3f1b)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
                check_type(argname="argument section_based_layout", value=section_based_layout, expected_type=type_hints["section_based_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if free_form_layout is not None:
                self._values["free_form_layout"] = free_form_layout
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout
            if section_based_layout is not None:
                self._values["section_based_layout"] = section_based_layout

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FreeFormLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A type of layout that can be used on a sheet.

            In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: ``FIXED`` or ``RESPONSIVE`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def section_based_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''A section based layout organizes visuals into multiple sections and has customized header, footer and page break.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-sectionbasedlayout
            '''
            result = self._values.get("section_based_layout")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionBasedLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class LayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[typing.Union["CfnTemplate.LayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''A ``Layout`` defines the placement of elements within a sheet.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param configuration: The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                layout_property = quicksight.CfnTemplate.LayoutProperty(
                    configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                        free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                element_id="elementId",
                                element_type="elementType",
                                height="height",
                                width="width",
                                x_axis_location="xAxisLocation",
                                y_axis_location="yAxisLocation",
                
                                # the properties below are optional
                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                    visibility="visibility"
                                ),
                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                        visibility="visibility"
                                    ),
                                    expression="expression"
                                )],
                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                    color="color",
                                    visibility="visibility"
                                ),
                                visibility="visibility"
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        ),
                        section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                            body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                content=quicksight.CfnTemplate.BodySectionContentProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                    after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                        status="status"
                                    )
                                ),
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    ),
                                    paper_orientation="paperOrientation",
                                    paper_size="paperSize"
                                )
                            ),
                            footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )],
                            header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                            element_id="elementId",
                                            element_type="elementType",
                                            height="height",
                                            width="width",
                                            x_axis_location="xAxisLocation",
                                            y_axis_location="yAxisLocation",
                
                                            # the properties below are optional
                                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                visibility="visibility"
                                            ),
                                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                    visibility="visibility"
                                                ),
                                                expression="expression"
                                            )],
                                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                color="color",
                                                visibility="visibility"
                                            ),
                                            visibility="visibility"
                                        )]
                                    )
                                ),
                                section_id="sectionId",
                
                                # the properties below are optional
                                style=quicksight.CfnTemplate.SectionStyleProperty(
                                    height="height",
                                    padding=quicksight.CfnTemplate.SpacingProperty(
                                        bottom="bottom",
                                        left="left",
                                        right="right",
                                        top="top"
                                    )
                                )
                            )]
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c3d74c79a897c9be0797b3e262950526b724df7c902cb34229c0a35959c44633)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnTemplate.LayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that determines what the type of layout for a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html#cfn-quicksight-template-layout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.LayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LegendOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "height": "height",
            "position": "position",
            "title": "title",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class LegendOptionsProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            position: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for the legend setup of a visual.

            :param height: The height of the legend. If this value is omitted, a default height is used when rendering.
            :param position: The positions for the legend. Choose one of the following options:. - ``AUTO`` - ``RIGHT`` - ``BOTTOM`` - ``LEFT``
            :param title: The custom title for the legend.
            :param visibility: Determines whether or not the legend is visible.
            :param width: The width of the legend. If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                legend_options_property = quicksight.CfnTemplate.LegendOptionsProperty(
                    height="height",
                    position="position",
                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__230106ba299b65e567940bc8c1da0c4424077dc479b60bfe2843690c82232b1d)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument position", value=position, expected_type=type_hints["position"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if position is not None:
                self._values["position"] = position
            if title is not None:
                self._values["title"] = title
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of the legend.

            If this value is omitted, a default height is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def position(self) -> typing.Optional[builtins.str]:
            '''The positions for the legend. Choose one of the following options:.

            - ``AUTO``
            - ``RIGHT``
            - ``BOTTOM``
            - ``LEFT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-position
            '''
            result = self._values.get("position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The custom title for the legend.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the legend is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the legend.

            If this value is omitted, a default width is used when rendering.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LegendOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "colors": "colors",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class LineChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param category: The category field wells of a line chart. Values are grouped by category fields.
            :param colors: The color field wells of a line chart. Values are grouped by category fields.
            :param small_multiples: The small multiples field well of a line chart.
            :param values: The value field wells of a line chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_aggregated_field_wells_property = quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__97325fed1f49ba6661f5d76b1e21b976240c9961e1c7564cc31fa839087ffa02)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if colors is not None:
                self._values["colors"] = colors
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field wells of a line chart.

            Values are grouped by category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a line chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "default_series_settings": "defaultSeriesSettings",
            "field_wells": "fieldWells",
            "forecast_configurations": "forecastConfigurations",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "reference_lines": "referenceLines",
            "secondary_y_axis_display_options": "secondaryYAxisDisplayOptions",
            "secondary_y_axis_label_options": "secondaryYAxisLabelOptions",
            "series": "series",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "type": "type",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
        },
    )
    class LineChartConfigurationProperty:
        def __init__(
            self,
            *,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            default_series_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartDefaultSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            forecast_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ForecastConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ReferenceLineProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            series: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a line chart.

            :param contribution_analysis_defaults: The default configuration of a line chart's contribution analysis.
            :param data_labels: The data label configuration of a line chart.
            :param default_series_settings: The options that determine the default presentation of all line series in ``LineChartVisual`` .
            :param field_wells: The field well configuration of a line chart.
            :param forecast_configurations: The forecast configuration of a line chart.
            :param legend: The legend configuration of a line chart.
            :param primary_y_axis_display_options: The series axis configuration of a line chart.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param reference_lines: The reference lines configuration of a line chart.
            :param secondary_y_axis_display_options: The series axis configuration of a line chart.
            :param secondary_y_axis_label_options: The options that determine the presentation of the secondary y-axis label.
            :param series: The series item configuration of a line chart.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a line chart.
            :param tooltip: The tooltip configuration of a line chart.
            :param type: Determines the type of the line chart.
            :param visual_palette: The visual palette configuration of a line chart.
            :param x_axis_display_options: The options that determine the presentation of the x-axis.
            :param x_axis_label_options: The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_configuration_property = quicksight.CfnTemplate.LineChartConfigurationProperty(
                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                        axis_binding="axisBinding",
                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                            line_interpolation="lineInterpolation",
                            line_style="lineStyle",
                            line_visibility="lineVisibility",
                            line_width="lineWidth"
                        ),
                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                            marker_color="markerColor",
                            marker_shape="markerShape",
                            marker_size="markerSize",
                            marker_visibility="markerVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                        line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                        forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                            lower_boundary=123,
                            periods_backward=123,
                            periods_forward=123,
                            prediction_interval=123,
                            seasonality=123,
                            upper_boundary=123
                        ),
                        scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                            what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                date="date",
                                value=123
                            ),
                            what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                end_date="endDate",
                                start_date="startDate",
                                value=123
                            )
                        )
                    )],
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                            axis_binding="axisBinding",
                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                value=123
                            )
                        ),
                
                        # the properties below are optional
                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                custom_label="customLabel"
                            ),
                            font_color="fontColor",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_position="horizontalPosition",
                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                ),
                                relative_position="relativePosition"
                            ),
                            vertical_position="verticalPosition"
                        ),
                        status="status",
                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                            color="color",
                            pattern="pattern"
                        )
                    )],
                    secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                            treatment_option="treatmentOption"
                        )]
                    ),
                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    series=[quicksight.CfnTemplate.SeriesItemProperty(
                        data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            field_value="fieldValue",
                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        ),
                        field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                            axis_binding="axisBinding",
                            field_id="fieldId",
                
                            # the properties below are optional
                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            )
                        )
                    )],
                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                        category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    type="type",
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce00e91b2e0273efa7f488476a6ca606dde3dd6c3df4dc2f080898ef6feb850d)
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument default_series_settings", value=default_series_settings, expected_type=type_hints["default_series_settings"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument forecast_configurations", value=forecast_configurations, expected_type=type_hints["forecast_configurations"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument reference_lines", value=reference_lines, expected_type=type_hints["reference_lines"])
                check_type(argname="argument secondary_y_axis_display_options", value=secondary_y_axis_display_options, expected_type=type_hints["secondary_y_axis_display_options"])
                check_type(argname="argument secondary_y_axis_label_options", value=secondary_y_axis_label_options, expected_type=type_hints["secondary_y_axis_label_options"])
                check_type(argname="argument series", value=series, expected_type=type_hints["series"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if default_series_settings is not None:
                self._values["default_series_settings"] = default_series_settings
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if forecast_configurations is not None:
                self._values["forecast_configurations"] = forecast_configurations
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if reference_lines is not None:
                self._values["reference_lines"] = reference_lines
            if secondary_y_axis_display_options is not None:
                self._values["secondary_y_axis_display_options"] = secondary_y_axis_display_options
            if secondary_y_axis_label_options is not None:
                self._values["secondary_y_axis_label_options"] = secondary_y_axis_label_options
            if series is not None:
                self._values["series"] = series
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if type is not None:
                self._values["type"] = type
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The default configuration of a line chart's contribution analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def default_series_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartDefaultSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-defaultseriessettings
            '''
            result = self._values.get("default_series_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartDefaultSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def forecast_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ForecastConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The forecast configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-forecastconfigurations
            '''
            result = self._values.get("forecast_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ForecastConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def reference_lines(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]]:
            '''The reference lines configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-referencelines
            '''
            result = self._values.get("reference_lines")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ReferenceLineProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def secondary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The series axis configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxisdisplayoptions
            '''
            result = self._values.get("secondary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineSeriesAxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def secondary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the secondary y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxislabeloptions
            '''
            result = self._values.get("secondary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def series(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SeriesItemProperty", _IResolvable_a771d0ef]]]]:
            '''The series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-series
            '''
            result = self._values.get("series")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SeriesItemProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Determines the type of the line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the x-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartDefaultSeriesSettingsProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            line_style_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            marker_style_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the default presentation of all line series in ``LineChartVisual`` .

            :param axis_binding: The axis to which you are binding all line series to.
            :param line_style_settings: Line styles options for all line series in the visual.
            :param marker_style_settings: Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_default_series_settings_property = quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                    axis_binding="axisBinding",
                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dd0a4ad0d8ecf9e7b4ceb62daccb27521aafd05724de04f66cc600137948a118)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis to which you are binding all line series to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Line styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Marker styles options for all line series in the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartDefaultSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_chart_aggregated_field_wells": "lineChartAggregatedFieldWells",
        },
    )
    class LineChartFieldWellsProperty:
        def __init__(
            self,
            *,
            line_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a line chart.

            :param line_chart_aggregated_field_wells: The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_field_wells_property = quicksight.CfnTemplate.LineChartFieldWellsProperty(
                    line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__773c6ee424454a3a867fcf8087f930b9e99629eaa8104af75b49fed4087d42a3)
                check_type(argname="argument line_chart_aggregated_field_wells", value=line_chart_aggregated_field_wells, expected_type=type_hints["line_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_chart_aggregated_field_wells is not None:
                self._values["line_chart_aggregated_field_wells"] = line_chart_aggregated_field_wells

        @builtins.property
        def line_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html#cfn-quicksight-template-linechartfieldwells-linechartaggregatedfieldwells
            '''
            result = self._values.get("line_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartLineStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_interpolation": "lineInterpolation",
            "line_style": "lineStyle",
            "line_visibility": "lineVisibility",
            "line_width": "lineWidth",
        },
    )
    class LineChartLineStyleSettingsProperty:
        def __init__(
            self,
            *,
            line_interpolation: typing.Optional[builtins.str] = None,
            line_style: typing.Optional[builtins.str] = None,
            line_visibility: typing.Optional[builtins.str] = None,
            line_width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :param line_interpolation: Interpolation style for line series. - ``LINEAR`` : Show as default, linear style. - ``SMOOTH`` : Show as a smooth curve. - ``STEPPED`` : Show steps in line.
            :param line_style: Line style for line series. - ``SOLID`` : Show as a solid line. - ``DOTTED`` : Show as a dotted line. - ``DASHED`` : Show as a dashed line.
            :param line_visibility: Configuration option that determines whether to show the line for the series.
            :param line_width: Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_line_style_settings_property = quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                    line_interpolation="lineInterpolation",
                    line_style="lineStyle",
                    line_visibility="lineVisibility",
                    line_width="lineWidth"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4479b5bb96503d17c6b198947c616b6ecdf1c728eee49486598bfae33ac47438)
                check_type(argname="argument line_interpolation", value=line_interpolation, expected_type=type_hints["line_interpolation"])
                check_type(argname="argument line_style", value=line_style, expected_type=type_hints["line_style"])
                check_type(argname="argument line_visibility", value=line_visibility, expected_type=type_hints["line_visibility"])
                check_type(argname="argument line_width", value=line_width, expected_type=type_hints["line_width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_interpolation is not None:
                self._values["line_interpolation"] = line_interpolation
            if line_style is not None:
                self._values["line_style"] = line_style
            if line_visibility is not None:
                self._values["line_visibility"] = line_visibility
            if line_width is not None:
                self._values["line_width"] = line_width

        @builtins.property
        def line_interpolation(self) -> typing.Optional[builtins.str]:
            '''Interpolation style for line series.

            - ``LINEAR`` : Show as default, linear style.
            - ``SMOOTH`` : Show as a smooth curve.
            - ``STEPPED`` : Show steps in line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-lineinterpolation
            '''
            result = self._values.get("line_interpolation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_style(self) -> typing.Optional[builtins.str]:
            '''Line style for line series.

            - ``SOLID`` : Show as a solid line.
            - ``DOTTED`` : Show as a dotted line.
            - ``DASHED`` : Show as a dashed line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linestyle
            '''
            result = self._values.get("line_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the line for the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linevisibility
            '''
            result = self._values.get("line_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def line_width(self) -> typing.Optional[builtins.str]:
            '''Width that determines the line thickness.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linewidth
            '''
            result = self._values.get("line_width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartLineStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "marker_color": "markerColor",
            "marker_shape": "markerShape",
            "marker_size": "markerSize",
            "marker_visibility": "markerVisibility",
        },
    )
    class LineChartMarkerStyleSettingsProperty:
        def __init__(
            self,
            *,
            marker_color: typing.Optional[builtins.str] = None,
            marker_shape: typing.Optional[builtins.str] = None,
            marker_size: typing.Optional[builtins.str] = None,
            marker_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :param marker_color: Color of marker in the series.
            :param marker_shape: Shape option for markers in the series. - ``CIRCLE`` : Show marker as a circle. - ``TRIANGLE`` : Show marker as a triangle. - ``SQUARE`` : Show marker as a square. - ``DIAMOND`` : Show marker as a diamond. - ``ROUNDED_SQUARE`` : Show marker as a rounded square.
            :param marker_size: Size of marker in the series.
            :param marker_visibility: Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_marker_style_settings_property = quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                    marker_color="markerColor",
                    marker_shape="markerShape",
                    marker_size="markerSize",
                    marker_visibility="markerVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__88187e0520828ef737dcac79a4c49221dc6225ddcc6d484b1c6d9220e7cc6eac)
                check_type(argname="argument marker_color", value=marker_color, expected_type=type_hints["marker_color"])
                check_type(argname="argument marker_shape", value=marker_shape, expected_type=type_hints["marker_shape"])
                check_type(argname="argument marker_size", value=marker_size, expected_type=type_hints["marker_size"])
                check_type(argname="argument marker_visibility", value=marker_visibility, expected_type=type_hints["marker_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if marker_color is not None:
                self._values["marker_color"] = marker_color
            if marker_shape is not None:
                self._values["marker_shape"] = marker_shape
            if marker_size is not None:
                self._values["marker_size"] = marker_size
            if marker_visibility is not None:
                self._values["marker_visibility"] = marker_visibility

        @builtins.property
        def marker_color(self) -> typing.Optional[builtins.str]:
            '''Color of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markercolor
            '''
            result = self._values.get("marker_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_shape(self) -> typing.Optional[builtins.str]:
            '''Shape option for markers in the series.

            - ``CIRCLE`` : Show marker as a circle.
            - ``TRIANGLE`` : Show marker as a triangle.
            - ``SQUARE`` : Show marker as a square.
            - ``DIAMOND`` : Show marker as a diamond.
            - ``ROUNDED_SQUARE`` : Show marker as a rounded square.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markershape
            '''
            result = self._values.get("marker_shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_size(self) -> typing.Optional[builtins.str]:
            '''Size of marker in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markersize
            '''
            result = self._values.get("marker_size")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def marker_visibility(self) -> typing.Optional[builtins.str]:
            '''Configuration option that determines whether to show the markers in the series.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markervisibility
            '''
            result = self._values.get("marker_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartMarkerStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "line_style_settings": "lineStyleSettings",
            "marker_style_settings": "markerStyleSettings",
        },
    )
    class LineChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            line_style_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            marker_style_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the presentation of a line series in the visual.

            :param line_style_settings: Line styles options for a line series in ``LineChartVisual`` .
            :param marker_style_settings: Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_series_settings_property = quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                        line_interpolation="lineInterpolation",
                        line_style="lineStyle",
                        line_visibility="lineVisibility",
                        line_width="lineWidth"
                    ),
                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                        marker_color="markerColor",
                        marker_shape="markerShape",
                        marker_size="markerSize",
                        marker_visibility="markerVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea3e1f29c15813053ba8e64422a0c85d6d7723053ac36a25465e04c6854e8e18)
                check_type(argname="argument line_style_settings", value=line_style_settings, expected_type=type_hints["line_style_settings"])
                check_type(argname="argument marker_style_settings", value=marker_style_settings, expected_type=type_hints["marker_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if line_style_settings is not None:
                self._values["line_style_settings"] = line_style_settings
            if marker_style_settings is not None:
                self._values["marker_style_settings"] = marker_style_settings

        @builtins.property
        def line_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Line styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-linestylesettings
            '''
            result = self._values.get("line_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartLineStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def marker_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''Marker styles options for a line series in ``LineChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-markerstylesettings
            '''
            result = self._values.get("marker_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartMarkerStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit_configuration": "categoryItemsLimitConfiguration",
            "category_sort": "categorySort",
            "color_items_limit_configuration": "colorItemsLimitConfiguration",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class LineChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a line chart.

            :param category_items_limit_configuration: The limit on the number of categories that are displayed in a line chart.
            :param category_sort: The sort configuration of the category fields.
            :param color_items_limit_configuration: The limit on the number of lines that are displayed in a line chart.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                line_chart_sort_configuration_property = quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d1fb0e3f33db0e1f24f906b4bc7588f2c9a01b34c2cf3e6b2a365ff583a90fa7)
                check_type(argname="argument category_items_limit_configuration", value=category_items_limit_configuration, expected_type=type_hints["category_items_limit_configuration"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit_configuration", value=color_items_limit_configuration, expected_type=type_hints["color_items_limit_configuration"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit_configuration is not None:
                self._values["category_items_limit_configuration"] = category_items_limit_configuration
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit_configuration is not None:
                self._values["color_items_limit_configuration"] = color_items_limit_configuration
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categoryitemslimitconfiguration
            '''
            result = self._values.get("category_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of lines that are displayed in a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-coloritemslimitconfiguration
            '''
            result = self._values.get("color_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class LineChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a line chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_chart_visual_property = quicksight.CfnTemplate.LineChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                        contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                            axis_binding="axisBinding",
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                            line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                            forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                lower_boundary=123,
                                periods_backward=123,
                                periods_forward=123,
                                prediction_interval=123,
                                seasonality=123,
                                upper_boundary=123
                            ),
                            scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                    date="date",
                                    value=123
                                ),
                                what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                    end_date="endDate",
                                    start_date="startDate",
                                    value=123
                                )
                            )
                        )],
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                            data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                axis_binding="axisBinding",
                                dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                    value=123
                                )
                            ),
                
                            # the properties below are optional
                            label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                    custom_label="customLabel"
                                ),
                                font_color="fontColor",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_position="horizontalPosition",
                                value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    relative_position="relativePosition"
                                ),
                                vertical_position="verticalPosition"
                            ),
                            status="status",
                            style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                color="color",
                                pattern="pattern"
                            )
                        )],
                        secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                            axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                treatment_option="treatmentOption"
                            )]
                        ),
                        secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        series=[quicksight.CfnTemplate.SeriesItemProperty(
                            data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            ),
                            field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                axis_binding="axisBinding",
                                field_id="fieldId",
                
                                # the properties below are optional
                                settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                )
                            )
                        )],
                        small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                            category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        type="type",
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3302a68a6315e39ac388fac306c3f931d0723317725a94872d2da0f71d5da2de)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_options": "axisOptions",
            "missing_data_configurations": "missingDataConfigurations",
        },
    )
    class LineSeriesAxisDisplayOptionsProperty:
        def __init__(
            self,
            *,
            axis_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            missing_data_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MissingDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The series axis configuration of a line chart.

            :param axis_options: The options that determine the presentation of the line series axis.
            :param missing_data_configurations: The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                line_series_axis_display_options_property = quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                        treatment_option="treatmentOption"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6fd5ff40696ef5dc99f8141015b86015a51cac71b8ede4a47f14ab48ea57afd)
                check_type(argname="argument axis_options", value=axis_options, expected_type=type_hints["axis_options"])
                check_type(argname="argument missing_data_configurations", value=missing_data_configurations, expected_type=type_hints["missing_data_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_options is not None:
                self._values["axis_options"] = axis_options
            if missing_data_configurations is not None:
                self._values["missing_data_configurations"] = missing_data_configurations

        @builtins.property
        def axis_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the line series axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-axisoptions
            '''
            result = self._values.get("axis_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def missing_data_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MissingDataConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-missingdataconfigurations
            '''
            result = self._values.get("missing_data_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MissingDataConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LineSeriesAxisDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ListControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "search_options": "searchOptions",
            "select_all_options": "selectAllOptions",
            "title_options": "titleOptions",
        },
    )
    class ListControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            search_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ListControlSearchOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param search_options: The configuration of the search options in a list control.
            :param select_all_options: The configuration of the ``Select all`` options in a list control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_display_options_property = quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                        visibility="visibility"
                    ),
                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5a76a36283a3e7755835f4eee93e2df973db932318ec5f77b9a66b6070b7583)
                check_type(argname="argument search_options", value=search_options, expected_type=type_hints["search_options"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if search_options is not None:
                self._values["search_options"] = search_options
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def search_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ListControlSearchOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-searchoptions
            '''
            result = self._values.get("search_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ListControlSearchOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ListControlSelectAllOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ListControlSearchOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSearchOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the search options in a list control.

            :param visibility: The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_search_options_property = quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1aafab5629b0926c5cf0c6175d8facb5cfa68e684749eae908789184745c78d8)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the search options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html#cfn-quicksight-template-listcontrolsearchoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSearchOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ListControlSelectAllOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ListControlSelectAllOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the ``Select all`` options in a list control.

            :param visibility: The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                list_control_select_all_options_property = quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ef0224e7a7db39313b61c850a4b2d310beac8f8122ea8946becdc08a2c9f792)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the ``Select all`` options in a list control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html#cfn-quicksight-template-listcontrolselectalloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ListControlSelectAllOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LoadingAnimationProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class LoadingAnimationProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of loading animation in free-form layout.

            :param visibility: The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                loading_animation_property = quicksight.CfnTemplate.LoadingAnimationProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__55276ecdb065195b6afeea5dd56ba41348cebac2403a0d4961a3d91ba7cefba1)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of ``LoadingAnimation`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html#cfn-quicksight-template-loadinganimation-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LoadingAnimationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LocalNavigationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"target_sheet_id": "targetSheetId"},
    )
    class LocalNavigationConfigurationProperty:
        def __init__(self, *, target_sheet_id: builtins.str) -> None:
            '''The navigation configuration for ``CustomActionNavigationOperation`` .

            :param target_sheet_id: The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                local_navigation_configuration_property = quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                    target_sheet_id="targetSheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4ea7513d1f0dd882ce23d615414df3a0310b954109702922fd28c7e6b5753af9)
                check_type(argname="argument target_sheet_id", value=target_sheet_id, expected_type=type_hints["target_sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "target_sheet_id": target_sheet_id,
            }

        @builtins.property
        def target_sheet_id(self) -> builtins.str:
            '''The sheet that is targeted for navigation in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html#cfn-quicksight-template-localnavigationconfiguration-targetsheetid
            '''
            result = self._values.get("target_sheet_id")
            assert result is not None, "Required property 'target_sheet_id' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LocalNavigationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.LongFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class LongFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for a subtitle.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                long_format_text_property = quicksight.CfnTemplate.LongFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ebbc8579983e7d941d07a18fc367f90ed578e3b52dd5bf1db4ac000ee2d737cd)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "LongFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MappedDataSetParameterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_identifier": "dataSetIdentifier",
            "data_set_parameter_name": "dataSetParameterName",
        },
    )
    class MappedDataSetParameterProperty:
        def __init__(
            self,
            *,
            data_set_identifier: builtins.str,
            data_set_parameter_name: builtins.str,
        ) -> None:
            '''A dataset parameter that is mapped to an analysis parameter.

            :param data_set_identifier: A unique name that identifies a dataset within the analysis or dashboard.
            :param data_set_parameter_name: The name of the dataset parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                mapped_data_set_parameter_property = quicksight.CfnTemplate.MappedDataSetParameterProperty(
                    data_set_identifier="dataSetIdentifier",
                    data_set_parameter_name="dataSetParameterName"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5a322202f16b0e713afb56736eba521b5c6867d1a2959b564149b6004f1615f)
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
                check_type(argname="argument data_set_parameter_name", value=data_set_parameter_name, expected_type=type_hints["data_set_parameter_name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_identifier": data_set_identifier,
                "data_set_parameter_name": data_set_parameter_name,
            }

        @builtins.property
        def data_set_identifier(self) -> builtins.str:
            '''A unique name that identifies a dataset within the analysis or dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            assert result is not None, "Required property 'data_set_identifier' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_parameter_name(self) -> builtins.str:
            '''The name of the dataset parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetparametername
            '''
            result = self._values.get("data_set_parameter_name")
            assert result is not None, "Required property 'data_set_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MappedDataSetParameterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MaximumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MaximumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The maximum label of a data path label.

            :param visibility: The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maximum_label_type_property = quicksight.CfnTemplate.MaximumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40a22e4fb77c723c872211f1b40f5d73cee77072471b29021713754d574fb67f)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the maximum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html#cfn-quicksight-template-maximumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MaximumMinimumComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "name": "name",
            "value": "value",
        },
    )
    class MaximumMinimumComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The maximum and minimum computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The type of computation. Choose one of the following options:. - MAXIMUM: A maximum computation. - MINIMUM: A minimum computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                maximum_minimum_computation_property = quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40c3082c448762bace42a05f1f9e69877a8c86d6d974ce25c7887993ea40780b)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The type of computation. Choose one of the following options:.

            - MAXIMUM: A maximum computation.
            - MINIMUM: A minimum computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MaximumMinimumComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculated_measure_field": "calculatedMeasureField",
            "categorical_measure_field": "categoricalMeasureField",
            "date_measure_field": "dateMeasureField",
            "numerical_measure_field": "numericalMeasureField",
        },
    )
    class MeasureFieldProperty:
        def __init__(
            self,
            *,
            calculated_measure_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.CalculatedMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            categorical_measure_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.CategoricalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            date_measure_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numerical_measure_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericalMeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure (metric) type field.

            :param calculated_measure_field: The calculated measure field only used in pivot tables.
            :param categorical_measure_field: The measure type field with categorical type columns.
            :param date_measure_field: The measure type field with date type columns.
            :param numerical_measure_field: The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                measure_field_property = quicksight.CfnTemplate.MeasureFieldProperty(
                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                        expression="expression",
                        field_id="fieldId"
                    ),
                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function="aggregationFunction",
                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    ),
                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0e39517333acce9fc6b26b166973f73d647589ecf6d86a37ac66415e7a99f236)
                check_type(argname="argument calculated_measure_field", value=calculated_measure_field, expected_type=type_hints["calculated_measure_field"])
                check_type(argname="argument categorical_measure_field", value=categorical_measure_field, expected_type=type_hints["categorical_measure_field"])
                check_type(argname="argument date_measure_field", value=date_measure_field, expected_type=type_hints["date_measure_field"])
                check_type(argname="argument numerical_measure_field", value=numerical_measure_field, expected_type=type_hints["numerical_measure_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if calculated_measure_field is not None:
                self._values["calculated_measure_field"] = calculated_measure_field
            if categorical_measure_field is not None:
                self._values["categorical_measure_field"] = categorical_measure_field
            if date_measure_field is not None:
                self._values["date_measure_field"] = date_measure_field
            if numerical_measure_field is not None:
                self._values["numerical_measure_field"] = numerical_measure_field

        @builtins.property
        def calculated_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CalculatedMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The calculated measure field only used in pivot tables.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-calculatedmeasurefield
            '''
            result = self._values.get("calculated_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CalculatedMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def categorical_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CategoricalMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with categorical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-categoricalmeasurefield
            '''
            result = self._values.get("categorical_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CategoricalMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def date_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with date type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-datemeasurefield
            '''
            result = self._values.get("date_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numerical_measure_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericalMeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The measure type field with numerical type columns.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-numericalmeasurefield
            '''
            result = self._values.get("numerical_measure_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericalMeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MetricComparisonComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "from_value": "fromValue",
            "target_value": "targetValue",
            "time": "time",
            "name": "name",
        },
    )
    class MetricComparisonComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            from_value: typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target_value: typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The metric comparison computation configuration.

            :param computation_id: The ID for a computation.
            :param from_value: The field that is used in a metric comparison from value setup.
            :param target_value: The field that is used in a metric comparison to value setup.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                metric_comparison_computation_property = quicksight.CfnTemplate.MetricComparisonComputationProperty(
                    computation_id="computationId",
                    from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d71686d3ac844f0e1e109a36818cdb06b6ff3703d5ebacfa60a594f8451b8b32)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument from_value", value=from_value, expected_type=type_hints["from_value"])
                check_type(argname="argument target_value", value=target_value, expected_type=type_hints["target_value"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "from_value": from_value,
                "target_value": target_value,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def from_value(
            self,
        ) -> typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The field that is used in a metric comparison from value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-fromvalue
            '''
            result = self._values.get("from_value")
            assert result is not None, "Required property 'from_value' is missing"
            return typing.cast(typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target_value(
            self,
        ) -> typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The field that is used in a metric comparison to value setup.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-targetvalue
            '''
            result = self._values.get("target_value")
            assert result is not None, "Required property 'target_value' is missing"
            return typing.cast(typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MetricComparisonComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MinimumLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class MinimumLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The minimum label of a data path label.

            :param visibility: The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                minimum_label_type_property = quicksight.CfnTemplate.MinimumLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__822180053d07f7c50506eb6bf0c37fa0d7d0f57524556871e4ba4d6307babe98)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the minimum label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html#cfn-quicksight-template-minimumlabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MinimumLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.MissingDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"treatment_option": "treatmentOption"},
    )
    class MissingDataConfigurationProperty:
        def __init__(
            self,
            *,
            treatment_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration options that determine how missing data is treated during the rendering of a line chart.

            :param treatment_option: The treatment option that determines how missing data should be rendered. Choose from the following options:. - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value. - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` . - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                missing_data_configuration_property = quicksight.CfnTemplate.MissingDataConfigurationProperty(
                    treatment_option="treatmentOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aa70ffdd0ab9c7a7e1b8692ef1b140c093f46c70e3265c77160262b1beb8c42d)
                check_type(argname="argument treatment_option", value=treatment_option, expected_type=type_hints["treatment_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if treatment_option is not None:
                self._values["treatment_option"] = treatment_option

        @builtins.property
        def treatment_option(self) -> typing.Optional[builtins.str]:
            '''The treatment option that determines how missing data should be rendered. Choose from the following options:.

            - ``INTERPOLATE`` : Interpolate missing values between the prior and the next known value.
            - ``SHOW_AS_ZERO`` : Show missing values as the value ``0`` .
            - ``SHOW_AS_BLANK`` : Display a blank space when rendering missing data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html#cfn-quicksight-template-missingdataconfiguration-treatmentoption
            '''
            result = self._values.get("treatment_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MissingDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NegativeValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"display_mode": "displayMode"},
    )
    class NegativeValueConfigurationProperty:
        def __init__(self, *, display_mode: builtins.str) -> None:
            '''The options that determine the negative value configuration.

            :param display_mode: Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                negative_value_configuration_property = quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                    display_mode="displayMode"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7b409915d9d3e410b97354e6dfdd2867c30b902f115b9f4dee6788b88c43a80)
                check_type(argname="argument display_mode", value=display_mode, expected_type=type_hints["display_mode"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "display_mode": display_mode,
            }

        @builtins.property
        def display_mode(self) -> builtins.str:
            '''Determines the display mode of the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html#cfn-quicksight-template-negativevalueconfiguration-displaymode
            '''
            result = self._values.get("display_mode")
            assert result is not None, "Required property 'display_mode' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NegativeValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NullValueFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"null_string": "nullString"},
    )
    class NullValueFormatConfigurationProperty:
        def __init__(self, *, null_string: builtins.str) -> None:
            '''The options that determine the null value format configuration.

            :param null_string: Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                null_value_format_configuration_property = quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                    null_string="nullString"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d60606b9890f4d356572754fc97bb61c697ccbcddbf881bbe37a4f321381814e)
                check_type(argname="argument null_string", value=null_string, expected_type=type_hints["null_string"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "null_string": null_string,
            }

        @builtins.property
        def null_string(self) -> builtins.str:
            '''Determines the null string of null values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html#cfn-quicksight-template-nullvalueformatconfiguration-nullstring
            '''
            result = self._values.get("null_string")
            assert result is not None, "Required property 'null_string' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NullValueFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "number_scale": "numberScale",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class NumberDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_scale: typing.Optional[builtins.str] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the number display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param number_scale: Determines the number scale value of the number format.
            :param prefix: Determines the prefix value of the number format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                number_display_format_configuration_property = quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    number_scale="numberScale",
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ecec9364323a52b1c3b9ff51d6c3bba93d0a2cc387ec0d75147b3079ef9875fc)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument number_scale", value=number_scale, expected_type=type_hints["number_scale"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if number_scale is not None:
                self._values["number_scale"] = number_scale
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_scale(self) -> typing.Optional[builtins.str]:
            '''Determines the number scale value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-numberscale
            '''
            result = self._values.get("number_scale")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the number format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumberFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"format_configuration": "formatConfiguration"},
    )
    class NumberFormatConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for number fields.

            :param format_configuration: The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                number_format_configuration_property = quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__826ea14d3b384e916b601719aa1a9828b9883a7537a9c7cf03b2941c5ad5aec2)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html#cfn-quicksight-template-numberformatconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumberFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericAxisOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"range": "range", "scale": "scale"},
    )
    class NumericAxisOptionsProperty:
        def __init__(
            self,
            *,
            range: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scale: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for an axis with a numeric field.

            :param range: The range setup of a numeric axis.
            :param scale: The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                numeric_axis_options_property = quicksight.CfnTemplate.NumericAxisOptionsProperty(
                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                        data_driven=data_driven,
                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                            maximum=123,
                            minimum=123
                        )
                    ),
                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                            step_count=123,
                            step_size=123
                        ),
                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                            base=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__76d9d6aea9530a5d9677e0d601d8208e12d3d72ace4c68f69e5c8377c9c5572f)
                check_type(argname="argument range", value=range, expected_type=type_hints["range"])
                check_type(argname="argument scale", value=scale, expected_type=type_hints["scale"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if range is not None:
                self._values["range"] = range
            if scale is not None:
                self._values["scale"] = scale

        @builtins.property
        def range(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayRangeProperty", _IResolvable_a771d0ef]]:
            '''The range setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-range
            '''
            result = self._values.get("range")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayRangeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scale(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisScaleProperty", _IResolvable_a771d0ef]]:
            '''The scale setup of a numeric axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-scale
            '''
            result = self._values.get("scale")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisScaleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericAxisOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "value": "value"},
    )
    class NumericEqualityDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            value: jsii.Number,
        ) -> None:
            '''The category drill down filter.

            :param column: The column that the filter is applied to.
            :param value: The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_equality_drill_down_filter_property = quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c41aa855415455add09354b255788b0b552d7e399de243e05e15c2d0da4bc157)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "value": value,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The value of the double input numeric drill down filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "match_operator": "matchOperator",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "parameter_name": "parameterName",
            "select_all_options": "selectAllOptions",
            "value": "value",
        },
    )
    class NumericEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            match_operator: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            select_all_options: typing.Optional[builtins.str] = None,
            value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``NumericEqualityFilter`` filters values that are equal to the specified value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param match_operator: The match operator that is used to determine if a filter should be applied.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``
            :param value: The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_equality_filter_property = quicksight.CfnTemplate.NumericEqualityFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    match_operator="matchOperator",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    parameter_name="parameterName",
                    select_all_options="selectAllOptions",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e9b30831f8b245c660eb0b00bb22dc15ebd0e8cdabb6ef37529574a5d2c68a34)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument match_operator", value=match_operator, expected_type=type_hints["match_operator"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "match_operator": match_operator,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def match_operator(self) -> builtins.str:
            '''The match operator that is used to determine if a filter should be applied.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-matchoperator
            '''
            result = self._values.get("match_operator")
            assert result is not None, "Required property 'match_operator' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[jsii.Number]:
            '''The input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "currency_display_format_configuration": "currencyDisplayFormatConfiguration",
            "number_display_format_configuration": "numberDisplayFormatConfiguration",
            "percentage_display_format_configuration": "percentageDisplayFormatConfiguration",
        },
    )
    class NumericFormatConfigurationProperty:
        def __init__(
            self,
            *,
            currency_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CurrencyDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            number_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the numeric format configuration.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param currency_display_format_configuration: The options that determine the currency display format configuration.
            :param number_display_format_configuration: The options that determine the number display format configuration.
            :param percentage_display_format_configuration: The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_format_configuration_property = quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix",
                        symbol="symbol"
                    ),
                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        number_scale="numberScale",
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    ),
                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                            decimal_places=123
                        ),
                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                            display_mode="displayMode"
                        ),
                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                            null_string="nullString"
                        ),
                        prefix="prefix",
                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                            decimal_separator="decimalSeparator",
                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                symbol="symbol",
                                visibility="visibility"
                            )
                        ),
                        suffix="suffix"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__22186dcdd432d647fbeaaf11f5713da136819e2aa8864310f5197189237cba33)
                check_type(argname="argument currency_display_format_configuration", value=currency_display_format_configuration, expected_type=type_hints["currency_display_format_configuration"])
                check_type(argname="argument number_display_format_configuration", value=number_display_format_configuration, expected_type=type_hints["number_display_format_configuration"])
                check_type(argname="argument percentage_display_format_configuration", value=percentage_display_format_configuration, expected_type=type_hints["percentage_display_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if currency_display_format_configuration is not None:
                self._values["currency_display_format_configuration"] = currency_display_format_configuration
            if number_display_format_configuration is not None:
                self._values["number_display_format_configuration"] = number_display_format_configuration
            if percentage_display_format_configuration is not None:
                self._values["percentage_display_format_configuration"] = percentage_display_format_configuration

        @builtins.property
        def currency_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CurrencyDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the currency display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-currencydisplayformatconfiguration
            '''
            result = self._values.get("currency_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CurrencyDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def number_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the number display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-numberdisplayformatconfiguration
            '''
            result = self._values.get("number_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumberDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def percentage_display_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the percentage display format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-percentagedisplayformatconfiguration
            '''
            result = self._values.get("percentage_display_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PercentageDisplayFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "aggregation_function": "aggregationFunction",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "select_all_options": "selectAllOptions",
        },
    )
    class NumericRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            range_maximum: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_minimum: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            select_all_options: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``NumericRangeFilter`` filters values that are within the value range.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param aggregation_function: The aggregation function of the filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param select_all_options: Select all of the values. Null is not the assigned value of select all. - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_range_filter_property = quicksight.CfnTemplate.NumericRangeFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                        parameter="parameter",
                        static_value=123
                    ),
                    select_all_options="selectAllOptions"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1641cb3e0fb0d12ca5d95be7bc10afd3dcdfbff09adc404ff3f12e96d1b7288e)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument select_all_options", value=select_all_options, expected_type=type_hints["select_all_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum is not None:
                self._values["range_maximum"] = range_maximum
            if range_minimum is not None:
                self._values["range_minimum"] = range_minimum
            if select_all_options is not None:
                self._values["select_all_options"] = select_all_options

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_maximum(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_minimum(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def select_all_options(self) -> typing.Optional[builtins.str]:
            '''Select all of the values. Null is not the assigned value of select all.

            - ``FILTER_ALL_VALUES``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-selectalloptions
            '''
            result = self._values.get("select_all_options")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={"parameter": "parameter", "static_value": "staticValue"},
    )
    class NumericRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            static_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The value input pf the numeric range filter.

            :param parameter: The parameter that is used in the numeric range.
            :param static_value: The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_range_filter_value_property = quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                    parameter="parameter",
                    static_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4fa733ddc1880e87ee44941008d434496ea33fd3229c862b436f36a96afb7586)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter that is used in the numeric range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def static_value(self) -> typing.Optional[jsii.Number]:
            '''The static value of the numeric range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericSeparatorConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_separator": "decimalSeparator",
            "thousands_separator": "thousandsSeparator",
        },
    )
    class NumericSeparatorConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_separator: typing.Optional[builtins.str] = None,
            thousands_separator: typing.Optional[typing.Union[typing.Union["CfnTemplate.ThousandSeparatorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that determine the numeric separator configuration.

            :param decimal_separator: Determines the decimal separator.
            :param thousands_separator: The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numeric_separator_configuration_property = quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                    decimal_separator="decimalSeparator",
                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                        symbol="symbol",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__23d06eeeb121e6ebed4d33696647f1ed0ec353ab1663a67d2a50a5c5c937c3ef)
                check_type(argname="argument decimal_separator", value=decimal_separator, expected_type=type_hints["decimal_separator"])
                check_type(argname="argument thousands_separator", value=thousands_separator, expected_type=type_hints["thousands_separator"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_separator is not None:
                self._values["decimal_separator"] = decimal_separator
            if thousands_separator is not None:
                self._values["thousands_separator"] = thousands_separator

        @builtins.property
        def decimal_separator(self) -> typing.Optional[builtins.str]:
            '''Determines the decimal separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-decimalseparator
            '''
            result = self._values.get("decimal_separator")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thousands_separator(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ThousandSeparatorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the thousands separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-thousandsseparator
            '''
            result = self._values.get("thousands_separator")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ThousandSeparatorOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericSeparatorConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericalAggregationFunctionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "percentile_aggregation": "percentileAggregation",
            "simple_numerical_aggregation": "simpleNumericalAggregation",
        },
    )
    class NumericalAggregationFunctionProperty:
        def __init__(
            self,
            *,
            percentile_aggregation: typing.Optional[typing.Union[typing.Union["CfnTemplate.PercentileAggregationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            simple_numerical_aggregation: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Aggregation for numerical values.

            :param percentile_aggregation: An aggregation based on the percentile of values in a dimension or measure.
            :param simple_numerical_aggregation: Built-in aggregation functions for numerical values. - ``SUM`` : The sum of a dimension or measure. - ``AVERAGE`` : The average of a dimension or measure. - ``MIN`` : The minimum value of a dimension or measure. - ``MAX`` : The maximum value of a dimension or measure. - ``COUNT`` : The count of a dimension or measure. - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure. - ``VAR`` : The variance of a dimension or measure. - ``VARP`` : The partitioned variance of a dimension or measure. - ``STDEV`` : The standard deviation of a dimension or measure. - ``STDEVP`` : The partitioned standard deviation of a dimension or measure. - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_aggregation_function_property = quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                        percentile_value=123
                    ),
                    simple_numerical_aggregation="simpleNumericalAggregation"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f63a80fd9bb96ba5fcc7cf3c21e8fcc7c806f6a37f0e51b2602a0e6162416069)
                check_type(argname="argument percentile_aggregation", value=percentile_aggregation, expected_type=type_hints["percentile_aggregation"])
                check_type(argname="argument simple_numerical_aggregation", value=simple_numerical_aggregation, expected_type=type_hints["simple_numerical_aggregation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_aggregation is not None:
                self._values["percentile_aggregation"] = percentile_aggregation
            if simple_numerical_aggregation is not None:
                self._values["simple_numerical_aggregation"] = simple_numerical_aggregation

        @builtins.property
        def percentile_aggregation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PercentileAggregationProperty", _IResolvable_a771d0ef]]:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-percentileaggregation
            '''
            result = self._values.get("percentile_aggregation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PercentileAggregationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def simple_numerical_aggregation(self) -> typing.Optional[builtins.str]:
            '''Built-in aggregation functions for numerical values.

            - ``SUM`` : The sum of a dimension or measure.
            - ``AVERAGE`` : The average of a dimension or measure.
            - ``MIN`` : The minimum value of a dimension or measure.
            - ``MAX`` : The maximum value of a dimension or measure.
            - ``COUNT`` : The count of a dimension or measure.
            - ``DISTINCT_COUNT`` : The count of distinct values in a dimension or measure.
            - ``VAR`` : The variance of a dimension or measure.
            - ``VARP`` : The partitioned variance of a dimension or measure.
            - ``STDEV`` : The standard deviation of a dimension or measure.
            - ``STDEVP`` : The partitioned standard deviation of a dimension or measure.
            - ``MEDIAN`` : The median value of a dimension or measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-simplenumericalaggregation
            '''
            result = self._values.get("simple_numerical_aggregation")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalAggregationFunctionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericalDimensionFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
            "hierarchy_id": "hierarchyId",
        },
    )
    class NumericalDimensionFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            hierarchy_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The dimension type field with numerical type columns.

            :param column: The column that is used in the ``NumericalDimensionField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.
            :param hierarchy_id: The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_dimension_field_property = quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    ),
                    hierarchy_id="hierarchyId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__75897c00e01583650bd2984eb65fa1bd4a1d50b1d9285a1b161213b89d2f9b36)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if hierarchy_id is not None:
                self._values["hierarchy_id"] = hierarchy_id

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``NumericalDimensionField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def hierarchy_id(self) -> typing.Optional[builtins.str]:
            '''The custom hierarchy ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalDimensionFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.NumericalMeasureFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "aggregation_function": "aggregationFunction",
            "format_configuration": "formatConfiguration",
        },
    )
    class NumericalMeasureFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            aggregation_function: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The measure type field with numerical type columns.

            :param column: The column that is used in the ``NumericalMeasureField`` .
            :param field_id: The custom field ID.
            :param aggregation_function: The aggregation function of the measure field.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                numerical_measure_field_property = quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__240bf88d3ee3f4a21d92a240b49bf7b1ebcf54d6a0432f3d7a935ca51fc2c8e5)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument aggregation_function", value=aggregation_function, expected_type=type_hints["aggregation_function"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if aggregation_function is not None:
                self._values["aggregation_function"] = aggregation_function
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``NumericalMeasureField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def aggregation_function(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]]:
            '''The aggregation function of the measure field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-aggregationfunction
            '''
            result = self._values.get("aggregation_function")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumberFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NumericalMeasureFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PaginationConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"page_number": "pageNumber", "page_size": "pageSize"},
    )
    class PaginationConfigurationProperty:
        def __init__(self, *, page_number: jsii.Number, page_size: jsii.Number) -> None:
            '''The pagination configuration for a table visual or boxplot.

            :param page_number: Indicates the page number.
            :param page_size: Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pagination_configuration_property = quicksight.CfnTemplate.PaginationConfigurationProperty(
                    page_number=123,
                    page_size=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14d7fdff301a97171850c2c041104b5de8b4d577d64cec65d460a0742e6857ee)
                check_type(argname="argument page_number", value=page_number, expected_type=type_hints["page_number"])
                check_type(argname="argument page_size", value=page_size, expected_type=type_hints["page_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "page_number": page_number,
                "page_size": page_size,
            }

        @builtins.property
        def page_number(self) -> jsii.Number:
            '''Indicates the page number.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagenumber
            '''
            result = self._values.get("page_number")
            assert result is not None, "Required property 'page_number' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def page_size(self) -> jsii.Number:
            '''Indicates how many items render in one page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagesize
            '''
            result = self._values.get("page_size")
            assert result is not None, "Required property 'page_size' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PaginationConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PanelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "background_visibility": "backgroundVisibility",
            "border_color": "borderColor",
            "border_style": "borderStyle",
            "border_thickness": "borderThickness",
            "border_visibility": "borderVisibility",
            "gutter_spacing": "gutterSpacing",
            "gutter_visibility": "gutterVisibility",
            "title": "title",
        },
    )
    class PanelConfigurationProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            background_visibility: typing.Optional[builtins.str] = None,
            border_color: typing.Optional[builtins.str] = None,
            border_style: typing.Optional[builtins.str] = None,
            border_thickness: typing.Optional[builtins.str] = None,
            border_visibility: typing.Optional[builtins.str] = None,
            gutter_spacing: typing.Optional[builtins.str] = None,
            gutter_visibility: typing.Optional[builtins.str] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.PanelTitleOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A collection of options that configure how each panel displays in a small multiples chart.

            :param background_color: Sets the background color for each panel.
            :param background_visibility: Determines whether or not a background for each small multiples panel is rendered.
            :param border_color: Sets the line color of panel borders.
            :param border_style: Sets the line style of panel borders.
            :param border_thickness: Sets the line thickness of panel borders.
            :param border_visibility: Determines whether or not each panel displays a border.
            :param gutter_spacing: Sets the total amount of negative space to display between sibling panels.
            :param gutter_visibility: Determines whether or not negative space between sibling panels is rendered.
            :param title: Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                panel_configuration_property = quicksight.CfnTemplate.PanelConfigurationProperty(
                    background_color="backgroundColor",
                    background_visibility="backgroundVisibility",
                    border_color="borderColor",
                    border_style="borderStyle",
                    border_thickness="borderThickness",
                    border_visibility="borderVisibility",
                    gutter_spacing="gutterSpacing",
                    gutter_visibility="gutterVisibility",
                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_text_alignment="horizontalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__70a689bf9b4731a849a5f70df019d5a3b4fcd9f1b9aba0e398e614235e317fd9)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument background_visibility", value=background_visibility, expected_type=type_hints["background_visibility"])
                check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
                check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
                check_type(argname="argument border_thickness", value=border_thickness, expected_type=type_hints["border_thickness"])
                check_type(argname="argument border_visibility", value=border_visibility, expected_type=type_hints["border_visibility"])
                check_type(argname="argument gutter_spacing", value=gutter_spacing, expected_type=type_hints["gutter_spacing"])
                check_type(argname="argument gutter_visibility", value=gutter_visibility, expected_type=type_hints["gutter_visibility"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if background_visibility is not None:
                self._values["background_visibility"] = background_visibility
            if border_color is not None:
                self._values["border_color"] = border_color
            if border_style is not None:
                self._values["border_style"] = border_style
            if border_thickness is not None:
                self._values["border_thickness"] = border_thickness
            if border_visibility is not None:
                self._values["border_visibility"] = border_visibility
            if gutter_spacing is not None:
                self._values["gutter_spacing"] = gutter_spacing
            if gutter_visibility is not None:
                self._values["gutter_visibility"] = gutter_visibility
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''Sets the background color for each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def background_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not a background for each small multiples panel is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundvisibility
            '''
            result = self._values.get("background_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_color(self) -> typing.Optional[builtins.str]:
            '''Sets the line color of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordercolor
            '''
            result = self._values.get("border_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_style(self) -> typing.Optional[builtins.str]:
            '''Sets the line style of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderstyle
            '''
            result = self._values.get("border_style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_thickness(self) -> typing.Optional[builtins.str]:
            '''Sets the line thickness of panel borders.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderthickness
            '''
            result = self._values.get("border_thickness")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not each panel displays a border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordervisibility
            '''
            result = self._values.get("border_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_spacing(self) -> typing.Optional[builtins.str]:
            '''Sets the total amount of negative space to display between sibling panels.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-gutterspacing
            '''
            result = self._values.get("gutter_spacing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def gutter_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not negative space between sibling panels is rendered.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-guttervisibility
            '''
            result = self._values.get("gutter_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PanelTitleOptionsProperty", _IResolvable_a771d0ef]]:
            '''Configures the title display within each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PanelTitleOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PanelTitleOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "font_configuration": "fontConfiguration",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "visibility": "visibility",
        },
    )
    class PanelTitleOptionsProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the title styles for each small multiples panel.

            :param font_configuration: ``CfnTemplate.PanelTitleOptionsProperty.FontConfiguration``.
            :param horizontal_text_alignment: Sets the horizontal text alignment of the title within each panel.
            :param visibility: Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                panel_title_options_property = quicksight.CfnTemplate.PanelTitleOptionsProperty(
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_text_alignment="horizontalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2641f1a67716eb9cf30379e8959df63aa7b7e9dfb79aa59a12b005017a9026d4)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.PanelTitleOptionsProperty.FontConfiguration``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''Sets the horizontal text alignment of the title within each panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not panel titles are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PanelTitleOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_picker": "dateTimePicker",
            "dropdown": "dropdown",
            "list": "list",
            "slider": "slider",
            "text_area": "textArea",
            "text_field": "textField",
        },
    )
    class ParameterControlProperty:
        def __init__(
            self,
            *,
            date_time_picker: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterDateTimePickerControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            dropdown: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterDropDownControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            list: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterListControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            slider: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterSliderControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_area: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterTextAreaControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_field: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterTextFieldControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The control of a parameter that users can interact with in a dashboard or an analysis.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_picker: A control from a date parameter that specifies date and time.
            :param dropdown: A control to display a dropdown list with buttons that are used to select a single value.
            :param list: A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
            :param slider: A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
            :param text_area: A control to display a text box that is used to enter multiple entries.
            :param text_field: A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_control_property = quicksight.CfnTemplate.ParameterControlProperty(
                    date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                            date_time_format="dateTimeFormat",
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    list=quicksight.CfnTemplate.ParameterListControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                            source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                source_sheet_control_id="sourceSheetControlId"
                            )]
                        ),
                        display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                            search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                visibility="visibility"
                            ),
                            select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        ),
                        selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                            link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            values=["values"]
                        ),
                        type="type"
                    ),
                    slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                        maximum_value=123,
                        minimum_value=123,
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        step_size=123,
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        delimiter="delimiter",
                        display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    ),
                    text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                        parameter_control_id="parameterControlId",
                        source_parameter_name="sourceParameterName",
                        title="title",
                
                        # the properties below are optional
                        display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                            placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                visibility="visibility"
                            ),
                            title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__396295915be75fdc058e865040099f34c6ec453bb1bef199646c14e5eb0453de)
                check_type(argname="argument date_time_picker", value=date_time_picker, expected_type=type_hints["date_time_picker"])
                check_type(argname="argument dropdown", value=dropdown, expected_type=type_hints["dropdown"])
                check_type(argname="argument list", value=list, expected_type=type_hints["list"])
                check_type(argname="argument slider", value=slider, expected_type=type_hints["slider"])
                check_type(argname="argument text_area", value=text_area, expected_type=type_hints["text_area"])
                check_type(argname="argument text_field", value=text_field, expected_type=type_hints["text_field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_picker is not None:
                self._values["date_time_picker"] = date_time_picker
            if dropdown is not None:
                self._values["dropdown"] = dropdown
            if list is not None:
                self._values["list"] = list
            if slider is not None:
                self._values["slider"] = slider
            if text_area is not None:
                self._values["text_area"] = text_area
            if text_field is not None:
                self._values["text_field"] = text_field

        @builtins.property
        def date_time_picker(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterDateTimePickerControlProperty", _IResolvable_a771d0ef]]:
            '''A control from a date parameter that specifies date and time.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-datetimepicker
            '''
            result = self._values.get("date_time_picker")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterDateTimePickerControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def dropdown(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterDropDownControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-dropdown
            '''
            result = self._values.get("dropdown")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterDropDownControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def list(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterListControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-list
            '''
            result = self._values.get("list")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterListControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def slider(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterSliderControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-slider
            '''
            result = self._values.get("slider")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterSliderControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_area(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterTextAreaControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter multiple entries.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textarea
            '''
            result = self._values.get("text_area")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterTextAreaControlProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterTextFieldControlProperty", _IResolvable_a771d0ef]]:
            '''A control to display a text box that is used to enter a single entry.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textfield
            '''
            result = self._values.get("text_field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterTextFieldControlProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterDateTimePickerControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterDateTimePickerControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control from a date parameter that specifies date and time.

            :param parameter_control_id: The ID of the ``ParameterDateTimePickerControl`` .
            :param source_parameter_name: The name of the ``ParameterDateTimePickerControl`` .
            :param title: The title of the ``ParameterDateTimePickerControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_date_time_picker_control_property = quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                        date_time_format="dateTimeFormat",
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5a3e4f9161a8843d5ca64f3161ca10eb65397e0084b75fa1507e053edae4f595)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The name of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDateTimePickerControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimePickerControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDateTimePickerControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_parameter_declaration": "dateTimeParameterDeclaration",
            "decimal_parameter_declaration": "decimalParameterDeclaration",
            "integer_parameter_declaration": "integerParameterDeclaration",
            "string_parameter_declaration": "stringParameterDeclaration",
        },
    )
    class ParameterDeclarationProperty:
        def __init__(
            self,
            *,
            date_time_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DateTimeParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            decimal_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DecimalParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            integer_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnTemplate.IntegerParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            string_parameter_declaration: typing.Optional[typing.Union[typing.Union["CfnTemplate.StringParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The declaration definition of a parameter.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param date_time_parameter_declaration: A parameter declaration for the ``DateTime`` data type.
            :param decimal_parameter_declaration: A parameter declaration for the ``Decimal`` data type.
            :param integer_parameter_declaration: A parameter declaration for the ``Integer`` data type.
            :param string_parameter_declaration: A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_declaration_property = quicksight.CfnTemplate.ParameterDeclarationProperty(
                    date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                        name="name",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                expression="expression",
                
                                # the properties below are optional
                                data_set_identifier="dataSetIdentifier"
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        time_granularity="timeGranularity",
                        value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=[123]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                            custom_value=123,
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    ),
                    string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                        name="name",
                        parameter_value_type="parameterValueType",
                
                        # the properties below are optional
                        default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                            dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )
                            ),
                            static_values=["staticValues"]
                        ),
                        mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                            data_set_identifier="dataSetIdentifier",
                            data_set_parameter_name="dataSetParameterName"
                        )],
                        value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                            custom_value="customValue",
                            value_when_unset_option="valueWhenUnsetOption"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e7aad8c39ed03ee1add3c898da798cf1dbd8fe419249c5a02385e065b3870d1a)
                check_type(argname="argument date_time_parameter_declaration", value=date_time_parameter_declaration, expected_type=type_hints["date_time_parameter_declaration"])
                check_type(argname="argument decimal_parameter_declaration", value=decimal_parameter_declaration, expected_type=type_hints["decimal_parameter_declaration"])
                check_type(argname="argument integer_parameter_declaration", value=integer_parameter_declaration, expected_type=type_hints["integer_parameter_declaration"])
                check_type(argname="argument string_parameter_declaration", value=string_parameter_declaration, expected_type=type_hints["string_parameter_declaration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_parameter_declaration is not None:
                self._values["date_time_parameter_declaration"] = date_time_parameter_declaration
            if decimal_parameter_declaration is not None:
                self._values["decimal_parameter_declaration"] = decimal_parameter_declaration
            if integer_parameter_declaration is not None:
                self._values["integer_parameter_declaration"] = integer_parameter_declaration
            if string_parameter_declaration is not None:
                self._values["string_parameter_declaration"] = string_parameter_declaration

        @builtins.property
        def date_time_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DateTimeParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``DateTime`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-datetimeparameterdeclaration
            '''
            result = self._values.get("date_time_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DateTimeParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def decimal_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DecimalParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Decimal`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-decimalparameterdeclaration
            '''
            result = self._values.get("decimal_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DecimalParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def integer_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.IntegerParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``Integer`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-integerparameterdeclaration
            '''
            result = self._values.get("integer_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.IntegerParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def string_parameter_declaration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.StringParameterDeclarationProperty", _IResolvable_a771d0ef]]:
            '''A parameter declaration for the ``String`` data type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-stringparameterdeclaration
            '''
            result = self._values.get("string_parameter_declaration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.StringParameterDeclarationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterDropDownControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterDropDownControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a dropdown list with buttons that are used to select a single value.

            :param parameter_control_id: The ID of the ``ParameterDropDownControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterDropDownControl`` .
            :param title: The title of the ``ParameterDropDownControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_drop_down_control_property = quicksight.CfnTemplate.ParameterDropDownControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6bdcebfdc50faf2d44afea4892cdfe797a86aba6c6912b7262aaa5df1e4e5596)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DropDownControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type parameter name of the ``ParameterDropDownControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterDropDownControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterListControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "cascading_control_configuration": "cascadingControlConfiguration",
            "display_options": "displayOptions",
            "selectable_values": "selectableValues",
            "type": "type",
        },
    )
    class ParameterListControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            cascading_control_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selectable_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.ParameterSelectableValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A control to display a list with buttons or boxes that are used to select either a single value or multiple values.

            :param parameter_control_id: The ID of the ``ParameterListControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterListControl`` .
            :param title: The title of the ``ParameterListControl`` .
            :param cascading_control_configuration: The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
            :param display_options: The display options of a control.
            :param selectable_values: A list of selectable values that are used in a control.
            :param type: The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_list_control_property = quicksight.CfnTemplate.ParameterListControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                        source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                            column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            source_sheet_control_id="sourceSheetControlId"
                        )]
                    ),
                    display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                        search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                            visibility="visibility"
                        ),
                        select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    ),
                    selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                        link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        values=["values"]
                    ),
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6f5a9099c35f924313309536c2c861ac2e3403ce692f2ce03eb72e1ef141f989)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument cascading_control_configuration", value=cascading_control_configuration, expected_type=type_hints["cascading_control_configuration"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
                check_type(argname="argument selectable_values", value=selectable_values, expected_type=type_hints["selectable_values"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if cascading_control_configuration is not None:
                self._values["cascading_control_configuration"] = cascading_control_configuration
            if display_options is not None:
                self._values["display_options"] = display_options
            if selectable_values is not None:
                self._values["selectable_values"] = selectable_values
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def cascading_control_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-cascadingcontrolconfiguration
            '''
            result = self._values.get("cascading_control_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CascadingControlConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ListControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selectable_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]]:
            '''A list of selectable values that are used in a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-selectablevalues
            '''
            result = self._values.get("selectable_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ParameterSelectableValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of ``ParameterListControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterListControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterSelectableValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "link_to_data_set_column": "linkToDataSetColumn",
            "values": "values",
        },
    )
    class ParameterSelectableValuesProperty:
        def __init__(
            self,
            *,
            link_to_data_set_column: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''A list of selectable values that are used in a control.

            :param link_to_data_set_column: The column identifier that fetches values from the data set.
            :param values: The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_selectable_values_property = quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    values=["values"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6d163b40a27bc5052061bce9e5ae3a18e896a2e85b94118d83166b12e4d918ac)
                check_type(argname="argument link_to_data_set_column", value=link_to_data_set_column, expected_type=type_hints["link_to_data_set_column"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if link_to_data_set_column is not None:
                self._values["link_to_data_set_column"] = link_to_data_set_column
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def link_to_data_set_column(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]:
            '''The column identifier that fetches values from the data set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-linktodatasetcolumn
            '''
            result = self._values.get("link_to_data_set_column")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The values that are used in ``ParameterSelectableValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSelectableValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterSliderControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "maximum_value": "maximumValue",
            "minimum_value": "minimumValue",
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "step_size": "stepSize",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterSliderControlProperty:
        def __init__(
            self,
            *,
            maximum_value: jsii.Number,
            minimum_value: jsii.Number,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            step_size: jsii.Number,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a horizontal toggle bar.

            This is used to change a value by sliding the toggle.

            :param maximum_value: The smaller value that is displayed at the left of the slider.
            :param minimum_value: The larger value that is displayed at the right of the slider.
            :param parameter_control_id: The ID of the ``ParameterSliderControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterSliderControl`` .
            :param step_size: The number of increments that the slider bar is divided into.
            :param title: The title of the ``ParameterSliderControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_slider_control_property = quicksight.CfnTemplate.ParameterSliderControlProperty(
                    maximum_value=123,
                    minimum_value=123,
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    step_size=123,
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4b9c6c2314175ed0813841ac33e09bf051ddaee013f3a23483a091c5a62d3832)
                check_type(argname="argument maximum_value", value=maximum_value, expected_type=type_hints["maximum_value"])
                check_type(argname="argument minimum_value", value=minimum_value, expected_type=type_hints["minimum_value"])
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument step_size", value=step_size, expected_type=type_hints["step_size"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "maximum_value": maximum_value,
                "minimum_value": minimum_value,
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "step_size": step_size,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def maximum_value(self) -> jsii.Number:
            '''The smaller value that is displayed at the left of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-maximumvalue
            '''
            result = self._values.get("maximum_value")
            assert result is not None, "Required property 'maximum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def minimum_value(self) -> jsii.Number:
            '''The larger value that is displayed at the right of the slider.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-minimumvalue
            '''
            result = self._values.get("minimum_value")
            assert result is not None, "Required property 'minimum_value' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def step_size(self) -> jsii.Number:
            '''The number of increments that the slider bar is divided into.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-stepsize
            '''
            result = self._values.get("step_size")
            assert result is not None, "Required property 'step_size' is missing"
            return typing.cast(jsii.Number, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterSliderControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SliderControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterSliderControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterTextAreaControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "delimiter": "delimiter",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextAreaControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            delimiter: typing.Optional[builtins.str] = None,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter multiple entries.

            :param parameter_control_id: The ID of the ``ParameterTextAreaControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextAreaControl`` .
            :param title: The title of the ``ParameterTextAreaControl`` .
            :param delimiter: The delimiter that is used to separate the lines in text.
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_text_area_control_property = quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    delimiter="delimiter",
                    display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c6f7ac2ff9305f9c628e61069c64ab6fae40f856c895366322138aad1d3047a6)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument delimiter", value=delimiter, expected_type=type_hints["delimiter"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if delimiter is not None:
                self._values["delimiter"] = delimiter
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextAreaControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def delimiter(self) -> typing.Optional[builtins.str]:
            '''The delimiter that is used to separate the lines in text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-delimiter
            '''
            result = self._values.get("delimiter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextAreaControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextAreaControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ParameterTextFieldControlProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter_control_id": "parameterControlId",
            "source_parameter_name": "sourceParameterName",
            "title": "title",
            "display_options": "displayOptions",
        },
    )
    class ParameterTextFieldControlProperty:
        def __init__(
            self,
            *,
            parameter_control_id: builtins.str,
            source_parameter_name: builtins.str,
            title: builtins.str,
            display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A control to display a text box that is used to enter a single entry.

            :param parameter_control_id: The ID of the ``ParameterTextFieldControl`` .
            :param source_parameter_name: The source parameter name of the ``ParameterTextFieldControl`` .
            :param title: The title of the ``ParameterTextFieldControl`` .
            :param display_options: The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                parameter_text_field_control_property = quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                    parameter_control_id="parameterControlId",
                    source_parameter_name="sourceParameterName",
                    title="title",
                
                    # the properties below are optional
                    display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                        placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                            visibility="visibility"
                        ),
                        title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e3a8d48212e6725d84903277722488b6168e79c99c1d3f3fdbba00f4b5f3f887)
                check_type(argname="argument parameter_control_id", value=parameter_control_id, expected_type=type_hints["parameter_control_id"])
                check_type(argname="argument source_parameter_name", value=source_parameter_name, expected_type=type_hints["source_parameter_name"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument display_options", value=display_options, expected_type=type_hints["display_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "parameter_control_id": parameter_control_id,
                "source_parameter_name": source_parameter_name,
                "title": title,
            }
            if display_options is not None:
                self._values["display_options"] = display_options

        @builtins.property
        def parameter_control_id(self) -> builtins.str:
            '''The ID of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-parametercontrolid
            '''
            result = self._values.get("parameter_control_id")
            assert result is not None, "Required property 'parameter_control_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def source_parameter_name(self) -> builtins.str:
            '''The source parameter name of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-sourceparametername
            '''
            result = self._values.get("source_parameter_name")
            assert result is not None, "Required property 'source_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def title(self) -> builtins.str:
            '''The title of the ``ParameterTextFieldControl`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-title
            '''
            result = self._values.get("title")
            assert result is not None, "Required property 'title' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The display options of a control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-displayoptions
            '''
            result = self._values.get("display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextFieldControlDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ParameterTextFieldControlProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PercentVisibleRangeProperty",
        jsii_struct_bases=[],
        name_mapping={"from_": "from", "to": "to"},
    )
    class PercentVisibleRangeProperty:
        def __init__(
            self,
            *,
            from_: typing.Optional[jsii.Number] = None,
            to: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The percent range in the visible range.

            :param from_: The lower bound of the range.
            :param to: The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percent_visible_range_property = quicksight.CfnTemplate.PercentVisibleRangeProperty(
                    from=123,
                    to=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ce357b09d36a3d94cc05335b7dc503a22e89aa36fd1c7a6792f2948bf30489e1)
                check_type(argname="argument from_", value=from_, expected_type=type_hints["from_"])
                check_type(argname="argument to", value=to, expected_type=type_hints["to"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if from_ is not None:
                self._values["from_"] = from_
            if to is not None:
                self._values["to"] = to

        @builtins.property
        def from_(self) -> typing.Optional[jsii.Number]:
            '''The lower bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-from
            '''
            result = self._values.get("from_")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def to(self) -> typing.Optional[jsii.Number]:
            '''The top bound of the range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-to
            '''
            result = self._values.get("to")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentVisibleRangeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "decimal_places_configuration": "decimalPlacesConfiguration",
            "negative_value_configuration": "negativeValueConfiguration",
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "prefix": "prefix",
            "separator_configuration": "separatorConfiguration",
            "suffix": "suffix",
        },
    )
    class PercentageDisplayFormatConfigurationProperty:
        def __init__(
            self,
            *,
            decimal_places_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            negative_value_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            prefix: typing.Optional[builtins.str] = None,
            separator_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            suffix: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the percentage display format configuration.

            :param decimal_places_configuration: The option that determines the decimal places configuration.
            :param negative_value_configuration: The options that determine the negative value configuration.
            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param prefix: Determines the prefix value of the percentage format.
            :param separator_configuration: The options that determine the numeric separator configuration.
            :param suffix: Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percentage_display_format_configuration_property = quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                        decimal_places=123
                    ),
                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                        display_mode="displayMode"
                    ),
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    prefix="prefix",
                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                        decimal_separator="decimalSeparator",
                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                            symbol="symbol",
                            visibility="visibility"
                        )
                    ),
                    suffix="suffix"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a6751189570be48744e4e9d216262a7eb1a84b6b1f1567597da50cc1ee02ead0)
                check_type(argname="argument decimal_places_configuration", value=decimal_places_configuration, expected_type=type_hints["decimal_places_configuration"])
                check_type(argname="argument negative_value_configuration", value=negative_value_configuration, expected_type=type_hints["negative_value_configuration"])
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
                check_type(argname="argument separator_configuration", value=separator_configuration, expected_type=type_hints["separator_configuration"])
                check_type(argname="argument suffix", value=suffix, expected_type=type_hints["suffix"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if decimal_places_configuration is not None:
                self._values["decimal_places_configuration"] = decimal_places_configuration
            if negative_value_configuration is not None:
                self._values["negative_value_configuration"] = negative_value_configuration
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if prefix is not None:
                self._values["prefix"] = prefix
            if separator_configuration is not None:
                self._values["separator_configuration"] = separator_configuration
            if suffix is not None:
                self._values["suffix"] = suffix

        @builtins.property
        def decimal_places_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The option that determines the decimal places configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-decimalplacesconfiguration
            '''
            result = self._values.get("decimal_places_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DecimalPlacesConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def negative_value_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the negative value configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-negativevalueconfiguration
            '''
            result = self._values.get("negative_value_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NegativeValueConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def prefix(self) -> typing.Optional[builtins.str]:
            '''Determines the prefix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-prefix
            '''
            result = self._values.get("prefix")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def separator_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the numeric separator configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-separatorconfiguration
            '''
            result = self._values.get("separator_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericSeparatorConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def suffix(self) -> typing.Optional[builtins.str]:
            '''Determines the suffix value of the percentage format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-suffix
            '''
            result = self._values.get("suffix")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentageDisplayFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PercentileAggregationProperty",
        jsii_struct_bases=[],
        name_mapping={"percentile_value": "percentileValue"},
    )
    class PercentileAggregationProperty:
        def __init__(
            self,
            *,
            percentile_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''An aggregation based on the percentile of values in a dimension or measure.

            :param percentile_value: The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                percentile_aggregation_property = quicksight.CfnTemplate.PercentileAggregationProperty(
                    percentile_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7336e8802535f497b0040ea68a2755a5774735cd661e25a74f911aa841407e1)
                check_type(argname="argument percentile_value", value=percentile_value, expected_type=type_hints["percentile_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percentile_value is not None:
                self._values["percentile_value"] = percentile_value

        @builtins.property
        def percentile_value(self) -> typing.Optional[jsii.Number]:
            '''The percentile value.

            This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html#cfn-quicksight-template-percentileaggregation-percentilevalue
            '''
            result = self._values.get("percentile_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PercentileAggregationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PeriodOverPeriodComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "value": "value",
        },
    )
    class PeriodOverPeriodComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The period over period computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                period_over_period_computation_property = quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__72a6cdd81d2c42dc2cf1486df94ec27d161023dfcec0e0e9afca4890e457b9ee)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodOverPeriodComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PeriodToDateComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "time": "time",
            "name": "name",
            "period_time_granularity": "periodTimeGranularity",
            "value": "value",
        },
    )
    class PeriodToDateComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
            period_time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The period to date computation configuration.

            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param name: The name of a computation.
            :param period_time_granularity: The time granularity setup of period to date computation. Choose from the following options:. - YEAR: Year to date. - MONTH: Month to date.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                period_to_date_computation_property = quicksight.CfnTemplate.PeriodToDateComputationProperty(
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                
                    # the properties below are optional
                    name="name",
                    period_time_granularity="periodTimeGranularity",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4533291348f707825df21d81075de06f67bc048e69dde1c005bfe03e9f02294c)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument period_time_granularity", value=period_time_granularity, expected_type=type_hints["period_time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "time": time,
            }
            if name is not None:
                self._values["name"] = name
            if period_time_granularity is not None:
                self._values["period_time_granularity"] = period_time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def period_time_granularity(self) -> typing.Optional[builtins.str]:
            '''The time granularity setup of period to date computation. Choose from the following options:.

            - YEAR: Year to date.
            - MONTH: Month to date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-periodtimegranularity
            '''
            result = self._values.get("period_time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PeriodToDateComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "small_multiples": "smallMultiples",
            "values": "values",
        },
    )
    class PieChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            :param category: The category (group/color) field wells of a pie chart.
            :param small_multiples: The small multiples field well of a pie chart.
            :param values: The value field wells of a pie chart. Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_aggregated_field_wells_property = quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59e6f7e22b5e83a9ee64d49b13df156139f158e8b287366fd0c146a799cf08f3)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument small_multiples", value=small_multiples, expected_type=type_hints["small_multiples"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if small_multiples is not None:
                self._values["small_multiples"] = small_multiples
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category (group/color) field wells of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The small multiples field well of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-smallmultiples
            '''
            result = self._values.get("small_multiples")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a pie chart.

            Values are aggregated based on categories.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PieChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "contribution_analysis_defaults": "contributionAnalysisDefaults",
            "data_labels": "dataLabels",
            "donut_options": "donutOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "small_multiples_options": "smallMultiplesOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
            "value_label_options": "valueLabelOptions",
            "visual_palette": "visualPalette",
        },
    )
    class PieChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            donut_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.DonutOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.PieChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PieChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            value_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a pie chart.

            :param category_label_options: The label options of the group/color that is displayed in a pie chart.
            :param contribution_analysis_defaults: The contribution analysis (anomaly configuration) setup of the visual.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param donut_options: The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param small_multiples_options: The small multiples setup for the visual.
            :param sort_configuration: The sort configuration of a pie chart.
            :param tooltip: The tooltip display setup of the visual.
            :param value_label_options: The label options for the value that is displayed in a pie chart.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_configuration_property = quicksight.CfnTemplate.PieChartConfigurationProperty(
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )],
                        measure_field_id="measureFieldId"
                    )],
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                        arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                            arc_thickness="arcThickness"
                        ),
                        donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                            label_visibility="labelVisibility"
                        )
                    ),
                    field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                        pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                        max_visible_columns=123,
                        max_visible_rows=123,
                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                            background_color="backgroundColor",
                            background_visibility="backgroundVisibility",
                            border_color="borderColor",
                            border_style="borderStyle",
                            border_thickness="borderThickness",
                            border_visibility="borderVisibility",
                            gutter_spacing="gutterSpacing",
                            gutter_visibility="gutterVisibility",
                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                horizontal_text_alignment="horizontalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f63c73fce52600a7a5a603b1e6b79d732048aee8b58eaf98edb95ec05770237f)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument contribution_analysis_defaults", value=contribution_analysis_defaults, expected_type=type_hints["contribution_analysis_defaults"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument donut_options", value=donut_options, expected_type=type_hints["donut_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument small_multiples_options", value=small_multiples_options, expected_type=type_hints["small_multiples_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument value_label_options", value=value_label_options, expected_type=type_hints["value_label_options"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if contribution_analysis_defaults is not None:
                self._values["contribution_analysis_defaults"] = contribution_analysis_defaults
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if donut_options is not None:
                self._values["donut_options"] = donut_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if small_multiples_options is not None:
                self._values["small_multiples_options"] = small_multiples_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if value_label_options is not None:
                self._values["value_label_options"] = value_label_options
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options of the group/color that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def contribution_analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]]:
            '''The contribution analysis (anomaly configuration) setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-contributionanalysisdefaults
            '''
            result = self._values.get("contribution_analysis_defaults")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ContributionAnalysisDefaultProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def donut_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DonutOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the shape of the chart.

            This option determines whether the chart is a pie chart or a donut chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-donutoptions
            '''
            result = self._values.get("donut_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DonutOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PieChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PieChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]]:
            '''The small multiples setup for the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-smallmultiplesoptions
            '''
            result = self._values.get("small_multiples_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SmallMultiplesOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PieChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PieChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def value_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options for the value that is displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-valuelabeloptions
            '''
            result = self._values.get("value_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PieChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pie_chart_aggregated_field_wells": "pieChartAggregatedFieldWells",
        },
    )
    class PieChartFieldWellsProperty:
        def __init__(
            self,
            *,
            pie_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.PieChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a pie chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pie_chart_aggregated_field_wells: The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_field_wells_property = quicksight.CfnTemplate.PieChartFieldWellsProperty(
                    pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1392e2748877570455c789a35979721836bb8f36e589d26b9865351d441f5e18)
                check_type(argname="argument pie_chart_aggregated_field_wells", value=pie_chart_aggregated_field_wells, expected_type=type_hints["pie_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pie_chart_aggregated_field_wells is not None:
                self._values["pie_chart_aggregated_field_wells"] = pie_chart_aggregated_field_wells

        @builtins.property
        def pie_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PieChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html#cfn-quicksight-template-piechartfieldwells-piechartaggregatedfieldwells
            '''
            result = self._values.get("pie_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PieChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PieChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "small_multiples_limit_configuration": "smallMultiplesLimitConfiguration",
            "small_multiples_sort": "smallMultiplesSort",
        },
    )
    class PieChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a pie chart.

            :param category_items_limit: The limit on the number of categories that are displayed in a pie chart.
            :param category_sort: The sort configuration of the category fields.
            :param small_multiples_limit_configuration: The limit on the number of small multiples panels that are displayed.
            :param small_multiples_sort: The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_sort_configuration_property = quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__258b94810c4949283d60ecbe96bbacfa1e57060bdd78afbe3438da757c4b62fd)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument small_multiples_limit_configuration", value=small_multiples_limit_configuration, expected_type=type_hints["small_multiples_limit_configuration"])
                check_type(argname="argument small_multiples_sort", value=small_multiples_sort, expected_type=type_hints["small_multiples_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if small_multiples_limit_configuration is not None:
                self._values["small_multiples_limit_configuration"] = small_multiples_limit_configuration
            if small_multiples_sort is not None:
                self._values["small_multiples_sort"] = small_multiples_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of categories that are displayed in a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def small_multiples_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of small multiples panels that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultipleslimitconfiguration
            '''
            result = self._values.get("small_multiples_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def small_multiples_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the small multiples field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultiplessort
            '''
            result = self._values.get("small_multiples_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PieChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PieChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PieChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A pie or donut chart.

            The ``PieChartVisual`` structure describes a visual that is a member of the pie chart family.

            The following charts can be described by using this structure:

            - Pie charts
            - Donut charts

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            For more information, see `Using donut charts <https://docs.aws.amazon.com/quicksight/latest/user/donut-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a pie chart.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pie_chart_visual_property = quicksight.CfnTemplate.PieChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                            contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            measure_field_id="measureFieldId"
                        )],
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                            arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                arc_thickness="arcThickness"
                            ),
                            donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                label_visibility="labelVisibility"
                            )
                        ),
                        field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                            pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                            max_visible_columns=123,
                            max_visible_rows=123,
                            panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                background_color="backgroundColor",
                                background_visibility="backgroundVisibility",
                                border_color="borderColor",
                                border_style="borderStyle",
                                border_thickness="borderThickness",
                                border_visibility="borderVisibility",
                                gutter_spacing="gutterSpacing",
                                gutter_visibility="gutterVisibility",
                                title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__484f898738d720f8ba5ddf81dacf9716454281e64a6f079c419cd1a9060cb103)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PieChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a pie chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PieChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PieChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotFieldSortOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "sort_by": "sortBy"},
    )
    class PivotFieldSortOptionsProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            sort_by: typing.Union[typing.Union["CfnTemplate.PivotTableSortByProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The field sort options for a pivot table sort configuration.

            :param field_id: The field ID for the field sort options.
            :param sort_by: The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_field_sort_options_property = quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                    field_id="fieldId",
                    sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                        column=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        data_path=quicksight.CfnTemplate.DataPathSortProperty(
                            direction="direction",
                            sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )]
                        ),
                        field=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b0d1d7a7334d8a22926502c46d94b1ffcbe22f4df62c42960b1f85a0ccc1648e)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument sort_by", value=sort_by, expected_type=type_hints["sort_by"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
                "sort_by": sort_by,
            }

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sort_by(
            self,
        ) -> typing.Union["CfnTemplate.PivotTableSortByProperty", _IResolvable_a771d0ef]:
            '''The sort by field for the field sort options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-sortby
            '''
            result = self._values.get("sort_by")
            assert result is not None, "Required property 'sort_by' is missing"
            return typing.cast(typing.Union["CfnTemplate.PivotTableSortByProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotFieldSortOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"columns": "columns", "rows": "rows", "values": "values"},
    )
    class PivotTableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for the pivot table.

            :param columns: The columns field well for a pivot table. Values are grouped by columns fields.
            :param rows: The rows field well for a pivot table. Values are grouped by rows fields.
            :param values: The values field well for a pivot table. Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_aggregated_field_wells_property = quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__019cc3cde72aea556c1456eab3896187926f7ce0964a69b29c3f54855e5aa3bc)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument rows", value=rows, expected_type=type_hints["rows"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if columns is not None:
                self._values["columns"] = columns
            if rows is not None:
                self._values["rows"] = rows
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def columns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The columns field well for a pivot table.

            Values are grouped by columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-columns
            '''
            result = self._values.get("columns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def rows(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The rows field well for a pivot table.

            Values are grouped by rows fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-rows
            '''
            result = self._values.get("rows")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on rows and columns fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "scope": "scope",
            "text_format": "textFormat",
        },
    )
    class PivotTableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            scope: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableConditionalFormattingScopeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_format: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cell conditional formatting option for a pivot table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param scope: The scope of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_cell_conditional_formatting_property = quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                        role="role"
                    ),
                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c93f0b5d6128b95297aad7cf47f84bfa99608a57aa6b0a30aaf550dc1b887b8c)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if scope is not None:
                self._values["scope"] = scope
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def scope(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableConditionalFormattingScopeProperty", _IResolvable_a771d0ef]]:
            '''The scope of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scope
            '''
            result = self._values.get("scope")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableConditionalFormattingScopeProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell"},
    )
    class PivotTableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_option_property = quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                            role="role"
                        ),
                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80b222f1aed39172290a2b7cc288932bbd7ab4cebdabfbb807b2b8f52c36aa59)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableCellConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The cell conditional formatting option for a pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html#cfn-quicksight-template-pivottableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableCellConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class PivotTableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.PivotTableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_property = quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                role="role"
                            ),
                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__19aabb6249d1472b4a1301897a83c223e7a741ab60aba39e8afc74889cb1ec5d)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html#cfn-quicksight-template-pivottableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty",
        jsii_struct_bases=[],
        name_mapping={"role": "role"},
    )
    class PivotTableConditionalFormattingScopeProperty:
        def __init__(self, *, role: typing.Optional[builtins.str] = None) -> None:
            '''The scope of the cell for conditional formatting.

            :param role: The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_conditional_formatting_scope_property = quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                    role="role"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f5286404d6bfaf5b250f226c045d8f5808738762a451dd65bef57ce3dffedda2)
                check_type(argname="argument role", value=role, expected_type=type_hints["role"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if role is not None:
                self._values["role"] = role

        @builtins.property
        def role(self) -> typing.Optional[builtins.str]:
            '''The role (field, field total, grand total) of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html#cfn-quicksight-template-pivottableconditionalformattingscope-role
            '''
            result = self._values.get("role")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConditionalFormattingScopeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class PivotTableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_report_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``PivotTableVisual`` .

            :param field_options: The field options for a pivot table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a pivot table visual.
            :param sort_configuration: The sort configuration for a ``PivotTableVisual`` .
            :param table_options: The table options for a pivot table visual.
            :param total_options: The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_configuration_property = quicksight.CfnTemplate.PivotTableConfigurationProperty(
                    field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                        data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                            data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            )],
                
                            # the properties below are optional
                            width="width"
                        )],
                        selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            visibility="visibility"
                        )]
                    ),
                    field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                        pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                        field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                            field_id="fieldId",
                            sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                column=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                    direction="direction",
                                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )]
                                ),
                                field=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )
                        )]
                    ),
                    table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        column_names_visibility="columnNamesVisibility",
                        metric_placement="metricPlacement",
                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        ),
                        row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        single_metric_visibility="singleMetricVisibility",
                        toggle_buttons_visibility="toggleButtonsVisibility"
                    ),
                    total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                        column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                            custom_label="customLabel",
                            field_level="fieldLevel",
                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                field_id="fieldId"
                            )],
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        ),
                        row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                            custom_label="customLabel",
                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility",
                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0682fadc20d329733736fc847b4ce0508e386a261423d3b2d6acab4881d62081)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableFieldOptionsProperty", _IResolvable_a771d0ef]]:
            '''The field options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableFieldOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]]:
            '''The paginated report options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The total options for a pivot table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableDataPathOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"data_path_list": "dataPathList", "width": "width"},
    )
    class PivotTableDataPathOptionProperty:
        def __init__(
            self,
            *,
            data_path_list: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataPathValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The data path options for the pivot table field options.

            :param data_path_list: The list of data path values for the data path options.
            :param width: The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_data_path_option_property = quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                    data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                        field_id="fieldId",
                        field_value="fieldValue"
                    )],
                
                    # the properties below are optional
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c334748c26ab8545db66e0882d5cd23969244e95be73a4e1392fb4daf4e2f2e0)
                check_type(argname="argument data_path_list", value=data_path_list, expected_type=type_hints["data_path_list"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_path_list": data_path_list,
            }
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def data_path_list(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataPathValueProperty", _IResolvable_a771d0ef]]]:
            '''The list of data path values for the data path options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-datapathlist
            '''
            result = self._values.get("data_path_list")
            assert result is not None, "Required property 'data_path_list' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataPathValueProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width of the data path option.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableDataPathOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "visibility": "visibility",
        },
    )
    class PivotTableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The selected field options for the pivot table field options.

            :param field_id: The field ID of the pivot table field.
            :param custom_label: The custom label of the pivot table field.
            :param visibility: The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_option_property = quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__45ee6adaa725e3bb050c8e88116258f24b8f24d6439c992314544978f886b79c)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the pivot table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_path_options": "dataPathOptions",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class PivotTableFieldOptionsProperty:
        def __init__(
            self,
            *,
            data_path_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.PivotTableDataPathOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.PivotTableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field options for a pivot table visual.

            :param data_path_options: The data path options for the pivot table field options.
            :param selected_field_options: The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_options_property = quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )],
                
                        # the properties below are optional
                        width="width"
                    )],
                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        visibility="visibility"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc3409b1ee60d6140b84924f3ca452ab6d13c8691a7380125fc0bff7c1312436)
                check_type(argname="argument data_path_options", value=data_path_options, expected_type=type_hints["data_path_options"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_path_options is not None:
                self._values["data_path_options"] = data_path_options
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def data_path_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableDataPathOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The data path options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-datapathoptions
            '''
            result = self._values.get("data_path_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableDataPathOptionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableFieldOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The selected field options for the pivot table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableFieldOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId"},
    )
    class PivotTableFieldSubtotalOptionsProperty:
        def __init__(self, *, field_id: typing.Optional[builtins.str] = None) -> None:
            '''The optional configuration of subtotals cells.

            :param field_id: The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_subtotal_options_property = quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                    field_id="fieldId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9065f682585dea451d886827a4989ce4055ef04b4d837aef2ccdbdc688b05d9b)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_id is not None:
                self._values["field_id"] = field_id

        @builtins.property
        def field_id(self) -> typing.Optional[builtins.str]:
            '''The field ID of the subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html#cfn-quicksight-template-pivottablefieldsubtotaloptions-fieldid
            '''
            result = self._values.get("field_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldSubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pivot_table_aggregated_field_wells": "pivotTableAggregatedFieldWells",
        },
    )
    class PivotTableFieldWellsProperty:
        def __init__(
            self,
            *,
            pivot_table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells for a pivot table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param pivot_table_aggregated_field_wells: The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_field_wells_property = quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                    pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__316ce79d995d0da4a72bb01600678e5cb7877715e5c8ba9b2037de23e6dd2a06)
                check_type(argname="argument pivot_table_aggregated_field_wells", value=pivot_table_aggregated_field_wells, expected_type=type_hints["pivot_table_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pivot_table_aggregated_field_wells is not None:
                self._values["pivot_table_aggregated_field_wells"] = pivot_table_aggregated_field_wells

        @builtins.property
        def pivot_table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html#cfn-quicksight-template-pivottablefieldwells-pivottableaggregatedfieldwells
            '''
            result = self._values.get("pivot_table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "column_header_style": "columnHeaderStyle",
            "column_names_visibility": "columnNamesVisibility",
            "metric_placement": "metricPlacement",
            "row_alternate_color_options": "rowAlternateColorOptions",
            "row_field_names_style": "rowFieldNamesStyle",
            "row_header_style": "rowHeaderStyle",
            "single_metric_visibility": "singleMetricVisibility",
            "toggle_buttons_visibility": "toggleButtonsVisibility",
        },
    )
    class PivotTableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_header_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_names_visibility: typing.Optional[builtins.str] = None,
            metric_placement: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_field_names_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_header_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            single_metric_visibility: typing.Optional[builtins.str] = None,
            toggle_buttons_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table options for a pivot table visual.

            :param cell_style: The table cell style of cells.
            :param column_header_style: The table cell style of the column header.
            :param column_names_visibility: The visibility of the column names.
            :param metric_placement: The metric placement (row, column) options.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors).
            :param row_field_names_style: The table cell style of row field names.
            :param row_header_style: The table cell style of the row headers.
            :param single_metric_visibility: The visibility of the single metric options.
            :param toggle_buttons_visibility: Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_options_property = quicksight.CfnTemplate.PivotTableOptionsProperty(
                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    column_names_visibility="columnNamesVisibility",
                    metric_placement="metricPlacement",
                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    ),
                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    single_metric_visibility="singleMetricVisibility",
                    toggle_buttons_visibility="toggleButtonsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bc7ab4a9ea37e2a0063e0559bcff578b6db5561c436bf1a50bcf157bdf91dbfa)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument column_header_style", value=column_header_style, expected_type=type_hints["column_header_style"])
                check_type(argname="argument column_names_visibility", value=column_names_visibility, expected_type=type_hints["column_names_visibility"])
                check_type(argname="argument metric_placement", value=metric_placement, expected_type=type_hints["metric_placement"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
                check_type(argname="argument row_field_names_style", value=row_field_names_style, expected_type=type_hints["row_field_names_style"])
                check_type(argname="argument row_header_style", value=row_header_style, expected_type=type_hints["row_header_style"])
                check_type(argname="argument single_metric_visibility", value=single_metric_visibility, expected_type=type_hints["single_metric_visibility"])
                check_type(argname="argument toggle_buttons_visibility", value=toggle_buttons_visibility, expected_type=type_hints["toggle_buttons_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if column_header_style is not None:
                self._values["column_header_style"] = column_header_style
            if column_names_visibility is not None:
                self._values["column_names_visibility"] = column_names_visibility
            if metric_placement is not None:
                self._values["metric_placement"] = metric_placement
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options
            if row_field_names_style is not None:
                self._values["row_field_names_style"] = row_field_names_style
            if row_header_style is not None:
                self._values["row_header_style"] = row_header_style
            if single_metric_visibility is not None:
                self._values["single_metric_visibility"] = single_metric_visibility
            if toggle_buttons_visibility is not None:
                self._values["toggle_buttons_visibility"] = toggle_buttons_visibility

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of the column header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnheaderstyle
            '''
            result = self._values.get("column_header_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_names_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the column names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnnamesvisibility
            '''
            result = self._values.get("column_names_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_placement(self) -> typing.Optional[builtins.str]:
            '''The metric placement (row, column) options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-metricplacement
            '''
            result = self._values.get("metric_placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row alternate color options (widget status, row alternate colors).

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_field_names_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of row field names.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowfieldnamesstyle
            '''
            result = self._values.get("row_field_names_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of the row headers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowheaderstyle
            '''
            result = self._values.get("row_header_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def single_metric_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the single metric options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-singlemetricvisibility
            '''
            result = self._values.get("single_metric_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def toggle_buttons_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the pivot table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-togglebuttonsvisibility
            '''
            result = self._values.get("toggle_buttons_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class PivotTablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a pivot table visual.

            :param overflow_column_header_visibility: The visibility of the repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_paginated_report_options_property = quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0cc6b0252252f5165950ea28c17b40cf553ae73cbba16d8e8d0b86ff78ffd769)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableSortByProperty",
        jsii_struct_bases=[],
        name_mapping={"column": "column", "data_path": "dataPath", "field": "field"},
    )
    class PivotTableSortByProperty:
        def __init__(
            self,
            *,
            column: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_path: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataPathSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field: typing.Optional[typing.Union[typing.Union["CfnTemplate.FieldSortProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The sort by field for the field sort options.

            :param column: The column sort (field id, direction) for the pivot table sort by options.
            :param data_path: The data path sort (data path value, direction) for the pivot table sort by options.
            :param field: The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_sort_by_property = quicksight.CfnTemplate.PivotTableSortByProperty(
                    column=quicksight.CfnTemplate.ColumnSortProperty(
                        direction="direction",
                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    data_path=quicksight.CfnTemplate.DataPathSortProperty(
                        direction="direction",
                        sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        )]
                    ),
                    field=quicksight.CfnTemplate.FieldSortProperty(
                        direction="direction",
                        field_id="fieldId"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c9e298b5278188613b23deba6d44c28187e8671e2ecbf92a4f0e15e32a754a07)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
                check_type(argname="argument field", value=field, expected_type=type_hints["field"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column is not None:
                self._values["column"] = column
            if data_path is not None:
                self._values["data_path"] = data_path
            if field is not None:
                self._values["field"] = field

        @builtins.property
        def column(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnSortProperty", _IResolvable_a771d0ef]]:
            '''The column sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-column
            '''
            result = self._values.get("column")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_path(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataPathSortProperty", _IResolvable_a771d0ef]]:
            '''The data path sort (data path value, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-datapath
            '''
            result = self._values.get("data_path")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataPathSortProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FieldSortProperty", _IResolvable_a771d0ef]]:
            '''The field sort (field id, direction) for the pivot table sort by options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-field
            '''
            result = self._values.get("field")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FieldSortProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortByProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"field_sort_options": "fieldSortOptions"},
    )
    class PivotTableSortConfigurationProperty:
        def __init__(
            self,
            *,
            field_sort_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.PivotFieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration for a ``PivotTableVisual`` .

            :param field_sort_options: The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_sort_configuration_property = quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                        field_id="fieldId",
                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                direction="direction",
                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )]
                            ),
                            field=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2721ce42be0555d18b59c4e326933bc5afad1b0a32a39ab4336a1e895b444d54)
                check_type(argname="argument field_sort_options", value=field_sort_options, expected_type=type_hints["field_sort_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_sort_options is not None:
                self._values["field_sort_options"] = field_sort_options

        @builtins.property
        def field_sort_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotFieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort options for a pivot table sort configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html#cfn-quicksight-template-pivottablesortconfiguration-fieldsortoptions
            '''
            result = self._values.get("field_sort_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotFieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_subtotal_options": "columnSubtotalOptions",
            "column_total_options": "columnTotalOptions",
            "row_subtotal_options": "rowSubtotalOptions",
            "row_total_options": "rowTotalOptions",
        },
    )
    class PivotTableTotalOptionsProperty:
        def __init__(
            self,
            *,
            column_subtotal_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_total_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_subtotal_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_total_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The total options for a pivot table visual.

            :param column_subtotal_options: The column subtotal options.
            :param column_total_options: The column total options.
            :param row_subtotal_options: The row subtotal options.
            :param row_total_options: The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_total_options_property = quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                    column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                        custom_label="customLabel",
                        field_level="fieldLevel",
                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                            field_id="fieldId"
                        )],
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    ),
                    row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                        custom_label="customLabel",
                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility",
                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__440063153b2ad790eb50991280a57a253ffc0bbc6eadd3736a53aa71e3091b73)
                check_type(argname="argument column_subtotal_options", value=column_subtotal_options, expected_type=type_hints["column_subtotal_options"])
                check_type(argname="argument column_total_options", value=column_total_options, expected_type=type_hints["column_total_options"])
                check_type(argname="argument row_subtotal_options", value=row_subtotal_options, expected_type=type_hints["row_subtotal_options"])
                check_type(argname="argument row_total_options", value=row_total_options, expected_type=type_hints["row_total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_subtotal_options is not None:
                self._values["column_subtotal_options"] = column_subtotal_options
            if column_total_options is not None:
                self._values["column_total_options"] = column_total_options
            if row_subtotal_options is not None:
                self._values["row_subtotal_options"] = row_subtotal_options
            if row_total_options is not None:
                self._values["row_total_options"] = row_total_options

        @builtins.property
        def column_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SubtotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The column subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columnsubtotaloptions
            '''
            result = self._values.get("column_subtotal_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SubtotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The column total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columntotaloptions
            '''
            result = self._values.get("column_total_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_subtotal_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SubtotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row subtotal options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowsubtotaloptions
            '''
            result = self._values.get("row_subtotal_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SubtotalOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row total options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowtotaloptions
            '''
            result = self._values.get("row_total_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class PivotTableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_table_visual_property = quicksight.CfnTemplate.PivotTableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                        field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                            data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                )],
                
                                # the properties below are optional
                                width="width"
                            )],
                            selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                visibility="visibility"
                            )]
                        ),
                        field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                            pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                            field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                field_id="fieldId",
                                sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                    column=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                        direction="direction",
                                        sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )]
                                    ),
                                    field=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )
                            )]
                        ),
                        table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                            cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            column_names_visibility="columnNamesVisibility",
                            metric_placement="metricPlacement",
                            row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            ),
                            row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            single_metric_visibility="singleMetricVisibility",
                            toggle_buttons_visibility="toggleButtonsVisibility"
                        ),
                        total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                            column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                custom_label="customLabel",
                                field_level="fieldLevel",
                                field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                    field_id="fieldId"
                                )],
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            ),
                            row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                custom_label="customLabel",
                                metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility",
                                value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                )
                            )
                        )
                    ),
                    conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                    role="role"
                                ),
                                text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__7688455583ae144e4cddb7c0a95757017674f296811ae288ecdcbe266c820872)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PivotTotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class PivotTotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            metric_header_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The optional configuration of totals cells in a ``PivotTableVisual`` .

            :param custom_label: The custom label string for the total cells.
            :param metric_header_cell_style: The cell styling options for the total of header cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: The cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.
            :param value_cell_style: The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                pivot_total_options_property = quicksight.CfnTemplate.PivotTotalOptionsProperty(
                    custom_label="customLabel",
                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6ef062a6f520dd5159d5454bb36b77fcb1a7505ded9c1576dceb8a74237c2e43)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the total of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the totals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PivotTotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.PredefinedHierarchyProperty",
        jsii_struct_bases=[],
        name_mapping={
            "columns": "columns",
            "hierarchy_id": "hierarchyId",
            "drill_down_filters": "drillDownFilters",
        },
    )
    class PredefinedHierarchyProperty:
        def __init__(
            self,
            *,
            columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            hierarchy_id: builtins.str,
            drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DrillDownFilterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The option that determines the hierarchy of the fields that are defined during data preparation.

            These fields are available to use in any analysis that uses the data source.

            :param columns: The list of columns that define the predefined hierarchy.
            :param hierarchy_id: The hierarchy ID of the predefined hierarchy.
            :param drill_down_filters: The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                predefined_hierarchy_property = quicksight.CfnTemplate.PredefinedHierarchyProperty(
                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    )],
                    hierarchy_id="hierarchyId",
                
                    # the properties below are optional
                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                            category_values=["categoryValues"],
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            value=123
                        ),
                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            range_maximum="rangeMaximum",
                            range_minimum="rangeMinimum",
                            time_granularity="timeGranularity"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0b9156ad9629cb9cbd5070cfe99faa63d7ff7a126beb8518e20a8aed1faaa70b)
                check_type(argname="argument columns", value=columns, expected_type=type_hints["columns"])
                check_type(argname="argument hierarchy_id", value=hierarchy_id, expected_type=type_hints["hierarchy_id"])
                check_type(argname="argument drill_down_filters", value=drill_down_filters, expected_type=type_hints["drill_down_filters"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "columns": columns,
                "hierarchy_id": hierarchy_id,
            }
            if drill_down_filters is not None:
                self._values["drill_down_filters"] = drill_down_filters

        @builtins.property
        def columns(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]]:
            '''The list of columns that define the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-columns
            '''
            result = self._values.get("columns")
            assert result is not None, "Required property 'columns' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def hierarchy_id(self) -> builtins.str:
            '''The hierarchy ID of the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-hierarchyid
            '''
            result = self._values.get("hierarchy_id")
            assert result is not None, "Required property 'hierarchy_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def drill_down_filters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DrillDownFilterProperty", _IResolvable_a771d0ef]]]]:
            '''The option that determines the drill down filters for the predefined hierarchy.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-drilldownfilters
            '''
            result = self._values.get("drill_down_filters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DrillDownFilterProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "PredefinedHierarchyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ProgressBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class ProgressBarOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the progress bar of a KPI visual.

            :param visibility: The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                progress_bar_options_property = quicksight.CfnTemplate.ProgressBarOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec1599bf05c00e6452ae23b28f733acd9b05eb3acb089eb7b6a0e9224e6d5c97)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the progress bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html#cfn-quicksight-template-progressbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ProgressBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"category": "category", "color": "color", "values": "values"},
    )
    class RadarChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well configuration of a ``RadarChartVisual`` .

            :param category: The aggregated field well categories of a radar chart.
            :param color: The color that are assigned to the aggregated field wells of a radar chart.
            :param values: The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_aggregated_field_wells_property = quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    color=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ae11c12a0fd778e0910635b0a0ac8e90a1e738f10c6cb40e64430f6c946fc8fa)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if color is not None:
                self._values["color"] = color
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The aggregated field well categories of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values that are assigned to the aggregated field wells of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RadarChartAreaStyleSettingsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configured style settings of a radar chart.

            :param visibility: The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_area_style_settings_property = quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b92cd2267ea4265f4c1703783cdbfd13e8a9a0cf7d28afcc1f30f5d804b90f56)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html#cfn-quicksight-template-radarchartareastylesettings-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartAreaStyleSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "alternate_band_colors_visibility": "alternateBandColorsVisibility",
            "alternate_band_even_color": "alternateBandEvenColor",
            "alternate_band_odd_color": "alternateBandOddColor",
            "base_series_settings": "baseSeriesSettings",
            "category_axis": "categoryAxis",
            "category_label_options": "categoryLabelOptions",
            "color_axis": "colorAxis",
            "color_label_options": "colorLabelOptions",
            "field_wells": "fieldWells",
            "legend": "legend",
            "shape": "shape",
            "sort_configuration": "sortConfiguration",
            "start_angle": "startAngle",
            "visual_palette": "visualPalette",
        },
    )
    class RadarChartConfigurationProperty:
        def __init__(
            self,
            *,
            alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
            alternate_band_even_color: typing.Optional[builtins.str] = None,
            alternate_band_odd_color: typing.Optional[builtins.str] = None,
            base_series_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartSeriesSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_axis: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            shape: typing.Optional[builtins.str] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            start_angle: typing.Optional[jsii.Number] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a ``RadarChartVisual`` .

            :param alternate_band_colors_visibility: Determines the visibility of the colors of alternatign bands in a radar chart.
            :param alternate_band_even_color: The color of the even-numbered alternate bands of a radar chart.
            :param alternate_band_odd_color: The color of the odd-numbered alternate bands of a radar chart.
            :param base_series_settings: The base sreies settings of a radar chart.
            :param category_axis: The category axis of a radar chart.
            :param category_label_options: The category label options of a radar chart.
            :param color_axis: The color axis of a radar chart.
            :param color_label_options: The color label options of a radar chart.
            :param field_wells: The field well configuration of a ``RadarChartVisual`` .
            :param legend: The legend display setup of the visual.
            :param shape: The shape of the radar chart.
            :param sort_configuration: The sort configuration of a ``RadarChartVisual`` .
            :param start_angle: The start angle of a radar chart's axis.
            :param visual_palette: The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_configuration_property = quicksight.CfnTemplate.RadarChartConfigurationProperty(
                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                    alternate_band_even_color="alternateBandEvenColor",
                    alternate_band_odd_color="alternateBandOddColor",
                    base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                        area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                            visibility="visibility"
                        )
                    ),
                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                        radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    shape="shape",
                    sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )],
                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    start_angle=123,
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c5a513d03d2f4c49dea455f10ce3bd3a2de6636fbc171d703312e9bf1f5ea76b)
                check_type(argname="argument alternate_band_colors_visibility", value=alternate_band_colors_visibility, expected_type=type_hints["alternate_band_colors_visibility"])
                check_type(argname="argument alternate_band_even_color", value=alternate_band_even_color, expected_type=type_hints["alternate_band_even_color"])
                check_type(argname="argument alternate_band_odd_color", value=alternate_band_odd_color, expected_type=type_hints["alternate_band_odd_color"])
                check_type(argname="argument base_series_settings", value=base_series_settings, expected_type=type_hints["base_series_settings"])
                check_type(argname="argument category_axis", value=category_axis, expected_type=type_hints["category_axis"])
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument color_axis", value=color_axis, expected_type=type_hints["color_axis"])
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument start_angle", value=start_angle, expected_type=type_hints["start_angle"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if alternate_band_colors_visibility is not None:
                self._values["alternate_band_colors_visibility"] = alternate_band_colors_visibility
            if alternate_band_even_color is not None:
                self._values["alternate_band_even_color"] = alternate_band_even_color
            if alternate_band_odd_color is not None:
                self._values["alternate_band_odd_color"] = alternate_band_odd_color
            if base_series_settings is not None:
                self._values["base_series_settings"] = base_series_settings
            if category_axis is not None:
                self._values["category_axis"] = category_axis
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if color_axis is not None:
                self._values["color_axis"] = color_axis
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if shape is not None:
                self._values["shape"] = shape
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if start_angle is not None:
                self._values["start_angle"] = start_angle
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette

        @builtins.property
        def alternate_band_colors_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the colors of alternatign bands in a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandcolorsvisibility
            '''
            result = self._values.get("alternate_band_colors_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_even_color(self) -> typing.Optional[builtins.str]:
            '''The color of the even-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandevencolor
            '''
            result = self._values.get("alternate_band_even_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def alternate_band_odd_color(self) -> typing.Optional[builtins.str]:
            '''The color of the odd-numbered alternate bands of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandoddcolor
            '''
            result = self._values.get("alternate_band_odd_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_series_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartSeriesSettingsProperty", _IResolvable_a771d0ef]]:
            '''The base sreies settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-baseseriessettings
            '''
            result = self._values.get("base_series_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartSeriesSettingsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categoryaxis
            '''
            result = self._values.get("category_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The category label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_axis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The color axis of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-coloraxis
            '''
            result = self._values.get("color_axis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The color label options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def shape(self) -> typing.Optional[builtins.str]:
            '''The shape of the radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-shape
            '''
            result = self._values.get("shape")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a ``RadarChartVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def start_angle(self) -> typing.Optional[jsii.Number]:
            '''The start angle of a radar chart's axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-startangle
            '''
            result = self._values.get("start_angle")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "radar_chart_aggregated_field_wells": "radarChartAggregatedFieldWells",
        },
    )
    class RadarChartFieldWellsProperty:
        def __init__(
            self,
            *,
            radar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a radar chart visual.

            :param radar_chart_aggregated_field_wells: The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_field_wells_property = quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                    radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        color=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9c299c59542dbcf90a2d0b2f05ee53a05844949542f37ed6819dfc0f083f2d0c)
                check_type(argname="argument radar_chart_aggregated_field_wells", value=radar_chart_aggregated_field_wells, expected_type=type_hints["radar_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if radar_chart_aggregated_field_wells is not None:
                self._values["radar_chart_aggregated_field_wells"] = radar_chart_aggregated_field_wells

        @builtins.property
        def radar_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a radar chart visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html#cfn-quicksight-template-radarchartfieldwells-radarchartaggregatedfieldwells
            '''
            result = self._values.get("radar_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartSeriesSettingsProperty",
        jsii_struct_bases=[],
        name_mapping={"area_style_settings": "areaStyleSettings"},
    )
    class RadarChartSeriesSettingsProperty:
        def __init__(
            self,
            *,
            area_style_settings: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartAreaStyleSettingsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The series settings of a radar chart.

            :param area_style_settings: The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_series_settings_property = quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9d28083216f435f2d7aa4c98a4d6b69535a06f5739a96e56d98b7819814469e1)
                check_type(argname="argument area_style_settings", value=area_style_settings, expected_type=type_hints["area_style_settings"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if area_style_settings is not None:
                self._values["area_style_settings"] = area_style_settings

        @builtins.property
        def area_style_settings(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartAreaStyleSettingsProperty", _IResolvable_a771d0ef]]:
            '''The area style settings of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html#cfn-quicksight-template-radarchartseriessettings-areastylesettings
            '''
            result = self._values.get("area_style_settings")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartAreaStyleSettingsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSeriesSettingsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
            "color_items_limit": "colorItemsLimit",
            "color_sort": "colorSort",
        },
    )
    class RadarChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            color_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a ``RadarChartVisual`` .

            :param category_items_limit: The category items limit for a radar chart.
            :param category_sort: The category sort options of a radar chart.
            :param color_items_limit: The color items limit of a radar chart.
            :param color_sort: The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                radar_chart_sort_configuration_property = quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )],
                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a5234eefadc2ba491ce61af720e36fe1f564fb83e2201e73e75d472e4573cb46)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
                check_type(argname="argument color_items_limit", value=color_items_limit, expected_type=type_hints["color_items_limit"])
                check_type(argname="argument color_sort", value=color_sort, expected_type=type_hints["color_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort
            if color_items_limit is not None:
                self._values["color_items_limit"] = color_items_limit
            if color_sort is not None:
                self._values["color_sort"] = color_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The category items limit for a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The category sort options of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def color_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The color items limit of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-coloritemslimit
            '''
            result = self._values.get("color_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The color sort configuration of a radar chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-colorsort
            '''
            result = self._values.get("color_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RadarChartVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class RadarChartVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A radar chart visual.

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                radar_chart_visual_property = quicksight.CfnTemplate.RadarChartVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                        alternate_band_colors_visibility="alternateBandColorsVisibility",
                        alternate_band_even_color="alternateBandEvenColor",
                        alternate_band_odd_color="alternateBandOddColor",
                        base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                            area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                visibility="visibility"
                            )
                        ),
                        category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                            radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        shape="shape",
                        sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )],
                            color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        start_angle=123,
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f840d103e53f8f3b60595e706028c8d7b5844aa5550a747c2ade1e9b95bc79e8)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RadarChartVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RangeEndsLabelTypeProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class RangeEndsLabelTypeProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The range ends label type of a data path label.

            :param visibility: The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                range_ends_label_type_property = quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b856fe4a6efec297f4bd1389a388d3bf153b48fa6973c56b890ea4fca8787714)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the range ends label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html#cfn-quicksight-template-rangeendslabeltype-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RangeEndsLabelTypeProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"custom_label": "customLabel"},
    )
    class ReferenceLineCustomLabelConfigurationProperty:
        def __init__(self, *, custom_label: builtins.str) -> None:
            '''The configuration for a custom label on a ``ReferenceLine`` .

            :param custom_label: The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_custom_label_configuration_property = quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                    custom_label="customLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c409cd751599789325825de6bfa0afdb155e1fd992d4bbb5f28bdadb21b1f3dd)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "custom_label": custom_label,
            }

        @builtins.property
        def custom_label(self) -> builtins.str:
            '''The string text of the custom label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html#cfn-quicksight-template-referencelinecustomlabelconfiguration-customlabel
            '''
            result = self._values.get("custom_label")
            assert result is not None, "Required property 'custom_label' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineCustomLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "axis_binding": "axisBinding",
            "dynamic_configuration": "dynamicConfiguration",
            "static_configuration": "staticConfiguration",
        },
    )
    class ReferenceLineDataConfigurationProperty:
        def __init__(
            self,
            *,
            axis_binding: typing.Optional[builtins.str] = None,
            dynamic_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ReferenceLineDynamicDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ReferenceLineStaticDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The data configuration of the reference line.

            :param axis_binding: The axis binding type of the reference line. Choose one of the following options:. - PrimaryY - SecondaryY
            :param dynamic_configuration: The dynamic configuration of the reference line data configuration.
            :param static_configuration: The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_data_configuration_property = quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                    axis_binding="axisBinding",
                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        )
                    ),
                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                        value=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2388691a8a698b422b60a84c6a8436f92659bfc6eb1fb075f34164ee6c7287b)
                check_type(argname="argument axis_binding", value=axis_binding, expected_type=type_hints["axis_binding"])
                check_type(argname="argument dynamic_configuration", value=dynamic_configuration, expected_type=type_hints["dynamic_configuration"])
                check_type(argname="argument static_configuration", value=static_configuration, expected_type=type_hints["static_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if axis_binding is not None:
                self._values["axis_binding"] = axis_binding
            if dynamic_configuration is not None:
                self._values["dynamic_configuration"] = dynamic_configuration
            if static_configuration is not None:
                self._values["static_configuration"] = static_configuration

        @builtins.property
        def axis_binding(self) -> typing.Optional[builtins.str]:
            '''The axis binding type of the reference line. Choose one of the following options:.

            - PrimaryY
            - SecondaryY

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-axisbinding
            '''
            result = self._values.get("axis_binding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dynamic_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ReferenceLineDynamicDataConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The dynamic configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-dynamicconfiguration
            '''
            result = self._values.get("dynamic_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ReferenceLineDynamicDataConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ReferenceLineStaticDataConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The static data configuration of the reference line data configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-staticconfiguration
            '''
            result = self._values.get("static_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ReferenceLineStaticDataConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "calculation": "calculation",
            "column": "column",
            "measure_aggregation_function": "measureAggregationFunction",
        },
    )
    class ReferenceLineDynamicDataConfigurationProperty:
        def __init__(
            self,
            *,
            calculation: typing.Union[typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            measure_aggregation_function: typing.Union[typing.Union["CfnTemplate.AggregationFunctionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The dynamic configuration of the reference line data configuration.

            :param calculation: The calculation that is used in the dynamic data.
            :param column: The column that the dynamic data targets.
            :param measure_aggregation_function: The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_dynamic_data_configuration_property = quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                    calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                            percentile_value=123
                        ),
                        simple_numerical_aggregation="simpleNumericalAggregation"
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                        categorical_aggregation_function="categoricalAggregationFunction",
                        date_aggregation_function="dateAggregationFunction",
                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                percentile_value=123
                            ),
                            simple_numerical_aggregation="simpleNumericalAggregation"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__faa458224cec5a714c1834af17b8f421e33ebca7f4a9ae372dfc8e913a825d87)
                check_type(argname="argument calculation", value=calculation, expected_type=type_hints["calculation"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument measure_aggregation_function", value=measure_aggregation_function, expected_type=type_hints["measure_aggregation_function"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "calculation": calculation,
                "column": column,
                "measure_aggregation_function": measure_aggregation_function,
            }

        @builtins.property
        def calculation(
            self,
        ) -> typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The calculation that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-calculation
            '''
            result = self._values.get("calculation")
            assert result is not None, "Required property 'calculation' is missing"
            return typing.cast(typing.Union["CfnTemplate.NumericalAggregationFunctionProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the dynamic data targets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def measure_aggregation_function(
            self,
        ) -> typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef]:
            '''The aggregation function that is used in the dynamic data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-measureaggregationfunction
            '''
            result = self._values.get("measure_aggregation_function")
            assert result is not None, "Required property 'measure_aggregation_function' is missing"
            return typing.cast(typing.Union["CfnTemplate.AggregationFunctionProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineDynamicDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label_configuration": "customLabelConfiguration",
            "font_color": "fontColor",
            "font_configuration": "fontConfiguration",
            "horizontal_position": "horizontalPosition",
            "value_label_configuration": "valueLabelConfiguration",
            "vertical_position": "verticalPosition",
        },
    )
    class ReferenceLineLabelConfigurationProperty:
        def __init__(
            self,
            *,
            custom_label_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ReferenceLineCustomLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_color: typing.Optional[builtins.str] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            horizontal_position: typing.Optional[builtins.str] = None,
            value_label_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ReferenceLineValueLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            vertical_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The label configuration of a reference line.

            :param custom_label_configuration: The custom label configuration of the label in a reference line.
            :param font_color: The font color configuration of the label in a reference line.
            :param font_configuration: The font configuration of the label in a reference line.
            :param horizontal_position: The horizontal position configuration of the label in a reference line. Choose one of the following options:. - ``LEFT`` - ``CENTER`` - ``RIGHT``
            :param value_label_configuration: The value label configuration of the label in a reference line.
            :param vertical_position: The vertical position configuration of the label in a reference line. Choose one of the following options:. - ``ABOVE`` - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_label_configuration_property = quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                        custom_label="customLabel"
                    ),
                    font_color="fontColor",
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    horizontal_position="horizontalPosition",
                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix",
                                symbol="symbol"
                            ),
                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                number_scale="numberScale",
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            ),
                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                    decimal_places=123
                                ),
                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                    display_mode="displayMode"
                                ),
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                prefix="prefix",
                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                    decimal_separator="decimalSeparator",
                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                        symbol="symbol",
                                        visibility="visibility"
                                    )
                                ),
                                suffix="suffix"
                            )
                        ),
                        relative_position="relativePosition"
                    ),
                    vertical_position="verticalPosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__780ad04db854fd9e38df2adb2467e3e541803120555cca130543e575ffe2416b)
                check_type(argname="argument custom_label_configuration", value=custom_label_configuration, expected_type=type_hints["custom_label_configuration"])
                check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument horizontal_position", value=horizontal_position, expected_type=type_hints["horizontal_position"])
                check_type(argname="argument value_label_configuration", value=value_label_configuration, expected_type=type_hints["value_label_configuration"])
                check_type(argname="argument vertical_position", value=vertical_position, expected_type=type_hints["vertical_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label_configuration is not None:
                self._values["custom_label_configuration"] = custom_label_configuration
            if font_color is not None:
                self._values["font_color"] = font_color
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if horizontal_position is not None:
                self._values["horizontal_position"] = horizontal_position
            if value_label_configuration is not None:
                self._values["value_label_configuration"] = value_label_configuration
            if vertical_position is not None:
                self._values["vertical_position"] = vertical_position

        @builtins.property
        def custom_label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ReferenceLineCustomLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The custom label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-customlabelconfiguration
            '''
            result = self._values.get("custom_label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ReferenceLineCustomLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_color(self) -> typing.Optional[builtins.str]:
            '''The font color configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontcolor
            '''
            result = self._values.get("font_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def horizontal_position(self) -> typing.Optional[builtins.str]:
            '''The horizontal position configuration of the label in a reference line. Choose one of the following options:.

            - ``LEFT``
            - ``CENTER``
            - ``RIGHT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-horizontalposition
            '''
            result = self._values.get("horizontal_position")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ReferenceLineValueLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The value label configuration of the label in a reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-valuelabelconfiguration
            '''
            result = self._values.get("value_label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ReferenceLineValueLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def vertical_position(self) -> typing.Optional[builtins.str]:
            '''The vertical position configuration of the label in a reference line. Choose one of the following options:.

            - ``ABOVE``
            - ``BELOW``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-verticalposition
            '''
            result = self._values.get("vertical_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_configuration": "dataConfiguration",
            "label_configuration": "labelConfiguration",
            "status": "status",
            "style_configuration": "styleConfiguration",
        },
    )
    class ReferenceLineProperty:
        def __init__(
            self,
            *,
            data_configuration: typing.Union[typing.Union["CfnTemplate.ReferenceLineDataConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            label_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ReferenceLineLabelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            status: typing.Optional[builtins.str] = None,
            style_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ReferenceLineStyleConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The reference line visual display options.

            :param data_configuration: The data configuration of the reference line.
            :param label_configuration: The label configuration of the reference line.
            :param status: The status of the reference line. Choose one of the following options:. - ``ENABLE`` - ``DISABLE``
            :param style_configuration: The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_property = quicksight.CfnTemplate.ReferenceLineProperty(
                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                        axis_binding="axisBinding",
                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                            value=123
                        )
                    ),
                
                    # the properties below are optional
                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                            custom_label="customLabel"
                        ),
                        font_color="fontColor",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        horizontal_position="horizontalPosition",
                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            ),
                            relative_position="relativePosition"
                        ),
                        vertical_position="verticalPosition"
                    ),
                    status="status",
                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                        color="color",
                        pattern="pattern"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5ac42280f628c152d05f5664d0e60d61caabc5f9bcbd6bbe4398816bfd9f811b)
                check_type(argname="argument data_configuration", value=data_configuration, expected_type=type_hints["data_configuration"])
                check_type(argname="argument label_configuration", value=label_configuration, expected_type=type_hints["label_configuration"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument style_configuration", value=style_configuration, expected_type=type_hints["style_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_configuration": data_configuration,
            }
            if label_configuration is not None:
                self._values["label_configuration"] = label_configuration
            if status is not None:
                self._values["status"] = status
            if style_configuration is not None:
                self._values["style_configuration"] = style_configuration

        @builtins.property
        def data_configuration(
            self,
        ) -> typing.Union["CfnTemplate.ReferenceLineDataConfigurationProperty", _IResolvable_a771d0ef]:
            '''The data configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-dataconfiguration
            '''
            result = self._values.get("data_configuration")
            assert result is not None, "Required property 'data_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.ReferenceLineDataConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def label_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ReferenceLineLabelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The label configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-labelconfiguration
            '''
            result = self._values.get("label_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ReferenceLineLabelConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the reference line. Choose one of the following options:.

            - ``ENABLE``
            - ``DISABLE``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ReferenceLineStyleConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The style configuration of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-styleconfiguration
            '''
            result = self._values.get("style_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ReferenceLineStyleConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"value": "value"},
    )
    class ReferenceLineStaticDataConfigurationProperty:
        def __init__(self, *, value: jsii.Number) -> None:
            '''The static data configuration of the reference line data configuration.

            :param value: The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_static_data_configuration_property = quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__20421cb296491d768f685e5dfbe585fcf57b5b9fb09ff2c522ba4038511ef013)
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "value": value,
            }

        @builtins.property
        def value(self) -> jsii.Number:
            '''The double input of the static data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html#cfn-quicksight-template-referencelinestaticdataconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStaticDataConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "pattern": "pattern"},
    )
    class ReferenceLineStyleConfigurationProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            pattern: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The style configuration of the reference line.

            :param color: The hex color of the reference line.
            :param pattern: The pattern type of the line style. Choose one of the following options:. - ``SOLID`` - ``DASHED`` - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_style_configuration_property = quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                    color="color",
                    pattern="pattern"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a848471f06e2cbd5b402e73e912570cc743305a8bf0c3caa7ba0748666458b11)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if pattern is not None:
                self._values["pattern"] = pattern

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The hex color of the reference line.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def pattern(self) -> typing.Optional[builtins.str]:
            '''The pattern type of the line style. Choose one of the following options:.

            - ``SOLID``
            - ``DASHED``
            - ``DOTTED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-pattern
            '''
            result = self._values.get("pattern")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineStyleConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "format_configuration": "formatConfiguration",
            "relative_position": "relativePosition",
        },
    )
    class ReferenceLineValueLabelConfigurationProperty:
        def __init__(
            self,
            *,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            relative_position: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value label configuration of the label in a reference line.

            :param format_configuration: The format configuration of the value label.
            :param relative_position: The relative position of the value label. Choose one of the following options:. - ``BEFORE_CUSTOM_LABEL`` - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                reference_line_value_label_configuration_property = quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    ),
                    relative_position="relativePosition"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2ee8893fb1f7a392927c231f49a205e587827c53918150e5e2d3ccfd93256296)
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
                check_type(argname="argument relative_position", value=relative_position, expected_type=type_hints["relative_position"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration
            if relative_position is not None:
                self._values["relative_position"] = relative_position

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the value label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def relative_position(self) -> typing.Optional[builtins.str]:
            '''The relative position of the value label. Choose one of the following options:.

            - ``BEFORE_CUSTOM_LABEL``
            - ``AFTER_CUSTOM_LABEL``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-relativeposition
            '''
            result = self._values.get("relative_position")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ReferenceLineValueLabelConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "date_time_format": "dateTimeFormat",
            "title_options": "titleOptions",
        },
    )
    class RelativeDateTimeControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            date_time_format: typing.Optional[builtins.str] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param date_time_format: Customize how dates are formatted in controls.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relative_date_time_control_display_options_property = quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                    date_time_format="dateTimeFormat",
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__15e7af4c70cab3f4442f2eba8e6bca381ecf3b3ac9e8d8820abd3ce4b0fc21cc)
                check_type(argname="argument date_time_format", value=date_time_format, expected_type=type_hints["date_time_format"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if date_time_format is not None:
                self._values["date_time_format"] = date_time_format
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def date_time_format(self) -> typing.Optional[builtins.str]:
            '''Customize how dates are formatted in controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-datetimeformat
            '''
            result = self._values.get("date_time_format")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDateTimeControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RelativeDatesFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "anchor_date_configuration": "anchorDateConfiguration",
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "relative_date_type": "relativeDateType",
            "time_granularity": "timeGranularity",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "minimum_granularity": "minimumGranularity",
            "parameter_name": "parameterName",
            "relative_date_value": "relativeDateValue",
        },
    )
    class RelativeDatesFilterProperty:
        def __init__(
            self,
            *,
            anchor_date_configuration: typing.Union[typing.Union["CfnTemplate.AnchorDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            relative_date_type: builtins.str,
            time_granularity: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            minimum_granularity: typing.Optional[builtins.str] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            relative_date_value: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A ``RelativeDatesFilter`` filters relative dates values.

            :param anchor_date_configuration: The date configuration of the filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param relative_date_type: The range date type of the filter. Choose one of the options below:. - ``PREVIOUS`` - ``THIS`` - ``LAST`` - ``NOW`` - ``NEXT``
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param exclude_period_configuration: The configuration for the exclude period of the filter.
            :param minimum_granularity: The minimum granularity (period granularity) of the relative dates filter.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param relative_date_value: The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                relative_dates_filter_property = quicksight.CfnTemplate.RelativeDatesFilterProperty(
                    anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                        anchor_option="anchorOption",
                        parameter_name="parameterName"
                    ),
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                    relative_date_type="relativeDateType",
                    time_granularity="timeGranularity",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    minimum_granularity="minimumGranularity",
                    parameter_name="parameterName",
                    relative_date_value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c83a559811e709351dfb6a8650617b32ce8acdb833a7b994c1d5cef026643023)
                check_type(argname="argument anchor_date_configuration", value=anchor_date_configuration, expected_type=type_hints["anchor_date_configuration"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument relative_date_type", value=relative_date_type, expected_type=type_hints["relative_date_type"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument minimum_granularity", value=minimum_granularity, expected_type=type_hints["minimum_granularity"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument relative_date_value", value=relative_date_value, expected_type=type_hints["relative_date_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "anchor_date_configuration": anchor_date_configuration,
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
                "relative_date_type": relative_date_type,
                "time_granularity": time_granularity,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if minimum_granularity is not None:
                self._values["minimum_granularity"] = minimum_granularity
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if relative_date_value is not None:
                self._values["relative_date_value"] = relative_date_value

        @builtins.property
        def anchor_date_configuration(
            self,
        ) -> typing.Union["CfnTemplate.AnchorDateConfigurationProperty", _IResolvable_a771d0ef]:
            '''The date configuration of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-anchordateconfiguration
            '''
            result = self._values.get("anchor_date_configuration")
            assert result is not None, "Required property 'anchor_date_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.AnchorDateConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def relative_date_type(self) -> builtins.str:
            '''The range date type of the filter. Choose one of the options below:.

            - ``PREVIOUS``
            - ``THIS``
            - ``LAST``
            - ``NOW``
            - ``NEXT``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatetype
            '''
            result = self._values.get("relative_date_type")
            assert result is not None, "Required property 'relative_date_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for the exclude period of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def minimum_granularity(self) -> typing.Optional[builtins.str]:
            '''The minimum granularity (period granularity) of the relative dates filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-minimumgranularity
            '''
            result = self._values.get("minimum_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def relative_date_value(self) -> typing.Optional[jsii.Number]:
            '''The date value of the filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatevalue
            '''
            result = self._values.get("relative_date_value")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RelativeDatesFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "actions": "actions",
            "principal": "principal",
            "resource": "resource",
        },
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
            resource: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
            :param resource: ``CfnTemplate.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnTemplate.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
                
                    # the properties below are optional
                    resource="resource"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1ff6430548217f9089a9a350cbf73c66fb163d392075fcef7a00103036a2ecaa)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
                check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }
            if resource is not None:
                self._values["resource"] = resource

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def resource(self) -> typing.Optional[builtins.str]:
            '''``CfnTemplate.ResourcePermissionProperty.Resource``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-resource
            '''
            result = self._values.get("resource")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RollingDateConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "expression": "expression",
            "data_set_identifier": "dataSetIdentifier",
        },
    )
    class RollingDateConfigurationProperty:
        def __init__(
            self,
            *,
            expression: builtins.str,
            data_set_identifier: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The rolling date configuration of a date time filter.

            :param expression: The expression of the rolling date configuration.
            :param data_set_identifier: The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                rolling_date_configuration_property = quicksight.CfnTemplate.RollingDateConfigurationProperty(
                    expression="expression",
                
                    # the properties below are optional
                    data_set_identifier="dataSetIdentifier"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d29077dddbcb62416e6841b85a183cc0f59445ab150ce1304b260ba5b0306528)
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
                check_type(argname="argument data_set_identifier", value=data_set_identifier, expected_type=type_hints["data_set_identifier"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "expression": expression,
            }
            if data_set_identifier is not None:
                self._values["data_set_identifier"] = data_set_identifier

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_identifier(self) -> typing.Optional[builtins.str]:
            '''The data set that is used in the rolling date configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-datasetidentifier
            '''
            result = self._values.get("data_set_identifier")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RollingDateConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.RowAlternateColorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "row_alternate_colors": "rowAlternateColors",
            "status": "status",
        },
    )
    class RowAlternateColorOptionsProperty:
        def __init__(
            self,
            *,
            row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Determines the row alternate color options.

            :param row_alternate_colors: Determines the list of row alternate colors.
            :param status: Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                row_alternate_color_options_property = quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                    row_alternate_colors=["rowAlternateColors"],
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e73e2cfa65aa4a6b4e49615c8e50f4ceac04731dda528a25495d5aea6b8b1f6b)
                check_type(argname="argument row_alternate_colors", value=row_alternate_colors, expected_type=type_hints["row_alternate_colors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if row_alternate_colors is not None:
                self._values["row_alternate_colors"] = row_alternate_colors
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def row_alternate_colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''Determines the list of row alternate colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-rowalternatecolors
            '''
            result = self._values.get("row_alternate_colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''Determines the widget status.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "RowAlternateColorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "target_visual_options": "targetVisualOptions",
            "target_visuals": "targetVisuals",
        },
    )
    class SameSheetTargetVisualConfigurationProperty:
        def __init__(
            self,
            *,
            target_visual_options: typing.Optional[builtins.str] = None,
            target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The configuration of the same-sheet target visuals that you want to be filtered.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param target_visual_options: The options that choose the target visual in the same sheet. Valid values are defined as follows: - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.
            :param target_visuals: A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                same_sheet_target_visual_configuration_property = quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                    target_visual_options="targetVisualOptions",
                    target_visuals=["targetVisuals"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3d13aeec0e248717d86b9e07563c3be59f967ae12210991ea38f388e87480a11)
                check_type(argname="argument target_visual_options", value=target_visual_options, expected_type=type_hints["target_visual_options"])
                check_type(argname="argument target_visuals", value=target_visuals, expected_type=type_hints["target_visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if target_visual_options is not None:
                self._values["target_visual_options"] = target_visual_options
            if target_visuals is not None:
                self._values["target_visuals"] = target_visuals

        @builtins.property
        def target_visual_options(self) -> typing.Optional[builtins.str]:
            '''The options that choose the target visual in the same sheet.

            Valid values are defined as follows:

            - ``ALL_VISUALS`` : Applies the filter operation to all visuals in the same sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisualoptions
            '''
            result = self._values.get("target_visual_options")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def target_visuals(self) -> typing.Optional[typing.List[builtins.str]]:
            '''A list of the target visual IDs that are located in the same sheet of the analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisuals
            '''
            result = self._values.get("target_visuals")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SameSheetTargetVisualConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination": "destination",
            "source": "source",
            "weight": "weight",
        },
    )
    class SankeyDiagramAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            destination: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            source: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            weight: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param destination: The destination field wells of a sankey diagram.
            :param source: The source field wells of a sankey diagram.
            :param weight: The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_aggregated_field_wells_property = quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                    destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    source=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f95fd1cdc70ca8227a677e24cf553a61d2b6beb020dc8a8d267f31ecac8cf2be)
                check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
                check_type(argname="argument source", value=source, expected_type=type_hints["source"])
                check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination is not None:
                self._values["destination"] = destination
            if source is not None:
                self._values["source"] = source
            if weight is not None:
                self._values["weight"] = weight

        @builtins.property
        def destination(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The destination field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-destination
            '''
            result = self._values.get("destination")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def source(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The source field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-source
            '''
            result = self._values.get("source")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def weight(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The weight field wells of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-weight
            '''
            result = self._values.get("weight")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
        },
    )
    class SankeyDiagramChartConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.SankeyDiagramFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.SankeyDiagramSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a sankey diagram.

            :param data_labels: The data label configuration of a sankey diagram.
            :param field_wells: The field well configuration of a sankey diagram.
            :param sort_configuration: The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_chart_configuration_property = quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                        sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                            destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                        destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8eeb3c58381a9a3f36cab09ced8e9a51fb9216a6ac4b999b7b4e56e2c3f8b782)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SankeyDiagramFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SankeyDiagramFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SankeyDiagramSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SankeyDiagramSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sankey_diagram_aggregated_field_wells": "sankeyDiagramAggregatedFieldWells",
        },
    )
    class SankeyDiagramFieldWellsProperty:
        def __init__(
            self,
            *,
            sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a sankey diagram.

            :param sankey_diagram_aggregated_field_wells: The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_field_wells_property = quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                    sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                        destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        source=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0afb30f3ec96d06b1b86fbcf84101c0b0b4f1ad834c24414961cd9f9ce22889d)
                check_type(argname="argument sankey_diagram_aggregated_field_wells", value=sankey_diagram_aggregated_field_wells, expected_type=type_hints["sankey_diagram_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sankey_diagram_aggregated_field_wells is not None:
                self._values["sankey_diagram_aggregated_field_wells"] = sankey_diagram_aggregated_field_wells

        @builtins.property
        def sankey_diagram_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html#cfn-quicksight-template-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
            '''
            result = self._values.get("sankey_diagram_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_items_limit": "destinationItemsLimit",
            "source_items_limit": "sourceItemsLimit",
            "weight_sort": "weightSort",
        },
    )
    class SankeyDiagramSortConfigurationProperty:
        def __init__(
            self,
            *,
            destination_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            weight_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a sankey diagram.

            :param destination_items_limit: The limit on the number of destination nodes that are displayed in a sankey diagram.
            :param source_items_limit: The limit on the number of source nodes that are displayed in a sankey diagram.
            :param weight_sort: The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_sort_configuration_property = quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44800cc25e017dcb20243245eaa0f1cca1e99fb13598cca0023bf4c82d5eaa61)
                check_type(argname="argument destination_items_limit", value=destination_items_limit, expected_type=type_hints["destination_items_limit"])
                check_type(argname="argument source_items_limit", value=source_items_limit, expected_type=type_hints["source_items_limit"])
                check_type(argname="argument weight_sort", value=weight_sort, expected_type=type_hints["weight_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if destination_items_limit is not None:
                self._values["destination_items_limit"] = destination_items_limit
            if source_items_limit is not None:
                self._values["source_items_limit"] = source_items_limit
            if weight_sort is not None:
                self._values["weight_sort"] = weight_sort

        @builtins.property
        def destination_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of destination nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-destinationitemslimit
            '''
            result = self._values.get("destination_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of source nodes that are displayed in a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-sourceitemslimit
            '''
            result = self._values.get("source_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def weight_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the weight fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-weightsort
            '''
            result = self._values.get("weight_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SankeyDiagramVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class SankeyDiagramVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.SankeyDiagramChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration of a sankey diagram.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sankey_diagram_visual_property = quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                            sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                            destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        )
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__431d4dc736cd0bab0fdd0f2e3bcee972d0164fae76e0fdd87078dcfde474399b)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SankeyDiagramChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a sankey diagram.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SankeyDiagramChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SankeyDiagramVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "size": "size",
            "x_axis": "xAxis",
            "y_axis": "yAxis",
        },
    )
    class ScatterPlotCategoricallyAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well of a scatter plot.

            :param category: The category field well of a scatter plot.
            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is aggregated by category.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_categorically_aggregated_field_wells_property = quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f67d4e7b5612ffa4d1eb34e0c52cd31c3d208a8ad3647541ae3494e930b4f99a)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category is not None:
                self._values["category"] = category
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def category(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-category
            '''
            result = self._values.get("category")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is aggregated by category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotCategoricallyAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ScatterPlotConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "tooltip": "tooltip",
            "visual_palette": "visualPalette",
            "x_axis_display_options": "xAxisDisplayOptions",
            "x_axis_label_options": "xAxisLabelOptions",
            "y_axis_display_options": "yAxisDisplayOptions",
            "y_axis_label_options": "yAxisLabelOptions",
        },
    )
    class ScatterPlotConfigurationProperty:
        def __init__(
            self,
            *,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.ScatterPlotFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            x_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a scatter plot.

            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param legend: The legend display setup of the visual.
            :param tooltip: The legend display setup of the visual.
            :param visual_palette: The palette (chart color) display setup of the visual.
            :param x_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
            :param x_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
            :param y_axis_display_options: The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
            :param y_axis_label_options: The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_configuration_property = quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af3129626a0c8154487e94949dd76f182e5ae5b6b1759cf19280d9f70c06dfe4)
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument x_axis_display_options", value=x_axis_display_options, expected_type=type_hints["x_axis_display_options"])
                check_type(argname="argument x_axis_label_options", value=x_axis_label_options, expected_type=type_hints["x_axis_label_options"])
                check_type(argname="argument y_axis_display_options", value=y_axis_display_options, expected_type=type_hints["y_axis_display_options"])
                check_type(argname="argument y_axis_label_options", value=y_axis_label_options, expected_type=type_hints["y_axis_label_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if tooltip is not None:
                self._values["tooltip"] = tooltip
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if x_axis_display_options is not None:
                self._values["x_axis_display_options"] = x_axis_display_options
            if x_axis_label_options is not None:
                self._values["x_axis_label_options"] = x_axis_label_options
            if y_axis_display_options is not None:
                self._values["y_axis_display_options"] = y_axis_display_options
            if y_axis_label_options is not None:
                self._values["y_axis_label_options"] = y_axis_label_options

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ScatterPlotFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ScatterPlotFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The palette (chart color) display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxisdisplayoptions
            '''
            result = self._values.get("x_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def x_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxislabeloptions
            '''
            result = self._values.get("x_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxisdisplayoptions
            '''
            result = self._values.get("y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxislabeloptions
            '''
            result = self._values.get("y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ScatterPlotFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scatter_plot_categorically_aggregated_field_wells": "scatterPlotCategoricallyAggregatedFieldWells",
            "scatter_plot_unaggregated_field_wells": "scatterPlotUnaggregatedFieldWells",
        },
    )
    class ScatterPlotFieldWellsProperty:
        def __init__(
            self,
            *,
            scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a scatter plot.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param scatter_plot_categorically_aggregated_field_wells: The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
            :param scatter_plot_unaggregated_field_wells: The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_field_wells_property = quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7e18ca0c45b5c4f195b9d848deba88fe93baf5d39e57b5375fdb92670d910e9)
                check_type(argname="argument scatter_plot_categorically_aggregated_field_wells", value=scatter_plot_categorically_aggregated_field_wells, expected_type=type_hints["scatter_plot_categorically_aggregated_field_wells"])
                check_type(argname="argument scatter_plot_unaggregated_field_wells", value=scatter_plot_unaggregated_field_wells, expected_type=type_hints["scatter_plot_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if scatter_plot_categorically_aggregated_field_wells is not None:
                self._values["scatter_plot_categorically_aggregated_field_wells"] = scatter_plot_categorically_aggregated_field_wells
            if scatter_plot_unaggregated_field_wells is not None:
                self._values["scatter_plot_unaggregated_field_wells"] = scatter_plot_unaggregated_field_wells

        @builtins.property
        def scatter_plot_categorically_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a scatter plot.

            The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_categorically_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scatter_plot_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The unaggregated field wells of a scatter plot.

            The x and y-axes of these scatter plots are unaggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotunaggregatedfieldwells
            '''
            result = self._values.get("scatter_plot_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"size": "size", "x_axis": "xAxis", "y_axis": "yAxis"},
    )
    class ScatterPlotUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The unaggregated field wells of a scatter plot.

            :param size: The size field well of a scatter plot.
            :param x_axis: The x-axis field well of a scatter plot. The x-axis is a dimension field and cannot be aggregated.
            :param y_axis: The y-axis field well of a scatter plot. The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scatter_plot_unaggregated_field_wells_property = quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e6da0071f34f86441c5cfd7ade0bf1dc86669895e46728822e0611c14a357301)
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
                check_type(argname="argument x_axis", value=x_axis, expected_type=type_hints["x_axis"])
                check_type(argname="argument y_axis", value=y_axis, expected_type=type_hints["y_axis"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if size is not None:
                self._values["size"] = size
            if x_axis is not None:
                self._values["x_axis"] = x_axis
            if y_axis is not None:
                self._values["y_axis"] = y_axis

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a scatter plot.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def x_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The x-axis field well of a scatter plot.

            The x-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-xaxis
            '''
            result = self._values.get("x_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def y_axis(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The y-axis field well of a scatter plot.

            The y-axis is a dimension field and cannot be aggregated.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-yaxis
            '''
            result = self._values.get("y_axis")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ScatterPlotVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class ScatterPlotVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ScatterPlotConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                scatter_plot_visual_property = quicksight.CfnTemplate.ScatterPlotVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                            scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e2cfffa0f11fc9b582c2def47b161daa58832b0ab19653a356c6bd9b51467bf)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ScatterPlotConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ScatterPlotConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScatterPlotVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ScrollBarOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility", "visible_range": "visibleRange"},
    )
    class ScrollBarOptionsProperty:
        def __init__(
            self,
            *,
            visibility: typing.Optional[builtins.str] = None,
            visible_range: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisibleRangeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The visual display options for a data zoom scroll bar.

            :param visibility: The visibility of the data zoom scroll bar.
            :param visible_range: The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                scroll_bar_options_property = quicksight.CfnTemplate.ScrollBarOptionsProperty(
                    visibility="visibility",
                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                            from=123,
                            to=123
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__597f06604243680c5657e0bd55d57b001c399c027bbabbbaa6bb3c4115d024ba)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument visible_range", value=visible_range, expected_type=type_hints["visible_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility
            if visible_range is not None:
                self._values["visible_range"] = visible_range

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visible_range(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisibleRangeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The visibility range for the data zoom scroll bar.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visiblerange
            '''
            result = self._values.get("visible_range")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisibleRangeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ScrollBarOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SecondaryValueOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SecondaryValueOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of the secondary value of a KPI visual.

            :param visibility: Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                secondary_value_options_property = quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b86703e96b8aed8bc1d15c8a2357c20c3cab9dcea5882ed3eb92fd52a2f451cb)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the secondary value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html#cfn-quicksight-template-secondaryvalueoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SecondaryValueOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionAfterPageBreakProperty",
        jsii_struct_bases=[],
        name_mapping={"status": "status"},
    )
    class SectionAfterPageBreakProperty:
        def __init__(self, *, status: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of a page break after a section.

            :param status: The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_after_page_break_property = quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3ae09674090d4970a7c060d817eb027655bcf531c10268581befd007f7aac9c7)
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The option that enables or disables a page break at the end of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html#cfn-quicksight-template-sectionafterpagebreak-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionAfterPageBreakProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"paper_canvas_size_options": "paperCanvasSizeOptions"},
    )
    class SectionBasedLayoutCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_canvas_size_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options for the canvas of a section-based layout.

            :param paper_canvas_size_options: The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_canvas_size_options_property = quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                            bottom="bottom",
                            left="left",
                            right="right",
                            top="top"
                        ),
                        paper_orientation="paperOrientation",
                        paper_size="paperSize"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c7370d14d5ed68080fce67a384ae68d0c9f6b759a75f6e0acec5bb367f475a2d)
                check_type(argname="argument paper_canvas_size_options", value=paper_canvas_size_options, expected_type=type_hints["paper_canvas_size_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_canvas_size_options is not None:
                self._values["paper_canvas_size_options"] = paper_canvas_size_options

        @builtins.property
        def paper_canvas_size_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for a paper canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
            '''
            result = self._values.get("paper_canvas_size_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "body_sections": "bodySections",
            "canvas_size_options": "canvasSizeOptions",
            "footer_sections": "footerSections",
            "header_sections": "headerSections",
        },
    )
    class SectionBasedLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            body_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.BodySectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            canvas_size_options: typing.Union[typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            footer_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            header_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The configuration for a section-based layout.

            :param body_sections: A list of body section configurations.
            :param canvas_size_options: The options for the canvas of a section-based layout.
            :param footer_sections: A list of footer section configurations.
            :param header_sections: A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_configuration_property = quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )]
                                )
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                status="status"
                            )
                        ),
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            ),
                            paper_orientation="paperOrientation",
                            paper_size="paperSize"
                        )
                    ),
                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )],
                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )]
                            )
                        ),
                        section_id="sectionId",
                
                        # the properties below are optional
                        style=quicksight.CfnTemplate.SectionStyleProperty(
                            height="height",
                            padding=quicksight.CfnTemplate.SpacingProperty(
                                bottom="bottom",
                                left="left",
                                right="right",
                                top="top"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d7d9faf77550be6a08d42ca185e22c621f006a12df2a6018e68c46f347b488ab)
                check_type(argname="argument body_sections", value=body_sections, expected_type=type_hints["body_sections"])
                check_type(argname="argument canvas_size_options", value=canvas_size_options, expected_type=type_hints["canvas_size_options"])
                check_type(argname="argument footer_sections", value=footer_sections, expected_type=type_hints["footer_sections"])
                check_type(argname="argument header_sections", value=header_sections, expected_type=type_hints["header_sections"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "body_sections": body_sections,
                "canvas_size_options": canvas_size_options,
                "footer_sections": footer_sections,
                "header_sections": header_sections,
            }

        @builtins.property
        def body_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.BodySectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of body section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-bodysections
            '''
            result = self._values.get("body_sections")
            assert result is not None, "Required property 'body_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.BodySectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def canvas_size_options(
            self,
        ) -> typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef]:
            '''The options for the canvas of a section-based layout.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-canvassizeoptions
            '''
            result = self._values.get("canvas_size_options")
            assert result is not None, "Required property 'canvas_size_options' is missing"
            return typing.cast(typing.Union["CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def footer_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of footer section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-footersections
            '''
            result = self._values.get("footer_sections")
            assert result is not None, "Required property 'footer_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def header_sections(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''A list of header section configurations.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-headersections
            '''
            result = self._values.get("header_sections")
            assert result is not None, "Required property 'header_sections' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.HeaderFooterSectionConfigurationProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "paper_margin": "paperMargin",
            "paper_orientation": "paperOrientation",
            "paper_size": "paperSize",
        },
    )
    class SectionBasedLayoutPaperCanvasSizeOptionsProperty:
        def __init__(
            self,
            *,
            paper_margin: typing.Optional[typing.Union[typing.Union["CfnTemplate.SpacingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paper_orientation: typing.Optional[builtins.str] = None,
            paper_size: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a paper canvas of a section-based layout.

            :param paper_margin: Defines the spacing between the canvas content and the top, bottom, left, and right edges.
            :param paper_orientation: The paper orientation that is used to define canvas dimensions. Choose one of the following options:. - PORTRAIT - LANDSCAPE
            :param paper_size: The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_based_layout_paper_canvas_size_options_property = quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                    paper_margin=quicksight.CfnTemplate.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    ),
                    paper_orientation="paperOrientation",
                    paper_size="paperSize"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__af1adc7a1547747b87439607ca1a153ee0c400f47418d024500bb9205b7639ee)
                check_type(argname="argument paper_margin", value=paper_margin, expected_type=type_hints["paper_margin"])
                check_type(argname="argument paper_orientation", value=paper_orientation, expected_type=type_hints["paper_orientation"])
                check_type(argname="argument paper_size", value=paper_size, expected_type=type_hints["paper_size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if paper_margin is not None:
                self._values["paper_margin"] = paper_margin
            if paper_orientation is not None:
                self._values["paper_orientation"] = paper_orientation
            if paper_size is not None:
                self._values["paper_size"] = paper_size

        @builtins.property
        def paper_margin(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SpacingProperty", _IResolvable_a771d0ef]]:
            '''Defines the spacing between the canvas content and the top, bottom, left, and right edges.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papermargin
            '''
            result = self._values.get("paper_margin")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SpacingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paper_orientation(self) -> typing.Optional[builtins.str]:
            '''The paper orientation that is used to define canvas dimensions. Choose one of the following options:.

            - PORTRAIT
            - LANDSCAPE

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-paperorientation
            '''
            result = self._values.get("paper_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def paper_size(self) -> typing.Optional[builtins.str]:
            '''The paper size that is used to define canvas dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papersize
            '''
            result = self._values.get("paper_size")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionBasedLayoutPaperCanvasSizeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"free_form_layout": "freeFormLayout"},
    )
    class SectionLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            free_form_layout: typing.Union[typing.Union["CfnTemplate.FreeFormSectionLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The layout configuration of a section.

            :param free_form_layout: The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_layout_configuration_property = quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                    free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                            element_id="elementId",
                            element_type="elementType",
                            height="height",
                            width="width",
                            x_axis_location="xAxisLocation",
                            y_axis_location="yAxisLocation",
                
                            # the properties below are optional
                            background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                visibility="visibility"
                            ),
                            rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                    visibility="visibility"
                                ),
                                expression="expression"
                            )],
                            selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                color="color",
                                visibility="visibility"
                            ),
                            visibility="visibility"
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80d2effb016f398c078d293b2ba169416d278ee26bed2410a3158dcb31c69741)
                check_type(argname="argument free_form_layout", value=free_form_layout, expected_type=type_hints["free_form_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "free_form_layout": free_form_layout,
            }

        @builtins.property
        def free_form_layout(
            self,
        ) -> typing.Union["CfnTemplate.FreeFormSectionLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The free-form layout configuration of a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html#cfn-quicksight-template-sectionlayoutconfiguration-freeformlayout
            '''
            result = self._values.get("free_form_layout")
            assert result is not None, "Required property 'free_form_layout' is missing"
            return typing.cast(typing.Union["CfnTemplate.FreeFormSectionLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionPageBreakConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"after": "after"},
    )
    class SectionPageBreakConfigurationProperty:
        def __init__(
            self,
            *,
            after: typing.Optional[typing.Union[typing.Union["CfnTemplate.SectionAfterPageBreakProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a page break for a section.

            :param after: The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_page_break_configuration_property = quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                    after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4f1527de7feb066312165189d4fe52974c352bf29871dc3798b0ba17fe8dabb5)
                check_type(argname="argument after", value=after, expected_type=type_hints["after"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if after is not None:
                self._values["after"] = after

        @builtins.property
        def after(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SectionAfterPageBreakProperty", _IResolvable_a771d0ef]]:
            '''The configuration of a page break after a section.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html#cfn-quicksight-template-sectionpagebreakconfiguration-after
            '''
            result = self._values.get("after")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SectionAfterPageBreakProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionPageBreakConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SectionStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"height": "height", "padding": "padding"},
    )
    class SectionStyleProperty:
        def __init__(
            self,
            *,
            height: typing.Optional[builtins.str] = None,
            padding: typing.Optional[typing.Union[typing.Union["CfnTemplate.SpacingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The options that style a section.

            :param height: The height of a section. Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.
            :param padding: The spacing between section content and its top, bottom, left, and right edges. There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                section_style_property = quicksight.CfnTemplate.SectionStyleProperty(
                    height="height",
                    padding=quicksight.CfnTemplate.SpacingProperty(
                        bottom="bottom",
                        left="left",
                        right="right",
                        top="top"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ed389426823a71b8fcf4cb3578c0670eeab713bc07401ea3ed397edacf03b8c9)
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument padding", value=padding, expected_type=type_hints["padding"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if height is not None:
                self._values["height"] = height
            if padding is not None:
                self._values["padding"] = padding

        @builtins.property
        def height(self) -> typing.Optional[builtins.str]:
            '''The height of a section.

            Heights can only be defined for header and footer sections. The default height margin is 0.5 inches.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def padding(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SpacingProperty", _IResolvable_a771d0ef]]:
            '''The spacing between section content and its top, bottom, left, and right edges.

            There is no padding by default.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-padding
            '''
            result = self._values.get("padding")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SpacingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SectionStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_visual_scoping_configurations": "sheetVisualScopingConfigurations",
        },
    )
    class SelectedSheetsFilterScopeConfigurationProperty:
        def __init__(
            self,
            *,
            sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SheetVisualScopingConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The configuration for applying a filter to specific sheets or visuals.

            You can apply this filter to multiple visuals that are on one sheet or to all visuals on a sheet.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param sheet_visual_scoping_configurations: The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                selected_sheets_filter_scope_configuration_property = quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                    sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                        scope="scope",
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        visual_ids=["visualIds"]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3a7f004f34d534e28a219305232ccb459cd436481d06286472c4eaecc23fec31)
                check_type(argname="argument sheet_visual_scoping_configurations", value=sheet_visual_scoping_configurations, expected_type=type_hints["sheet_visual_scoping_configurations"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sheet_visual_scoping_configurations is not None:
                self._values["sheet_visual_scoping_configurations"] = sheet_visual_scoping_configurations

        @builtins.property
        def sheet_visual_scoping_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetVisualScopingConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-template-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
            '''
            result = self._values.get("sheet_visual_scoping_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetVisualScopingConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SelectedSheetsFilterScopeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SeriesItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_field_series_item": "dataFieldSeriesItem",
            "field_series_item": "fieldSeriesItem",
        },
    )
    class SeriesItemProperty:
        def __init__(
            self,
            *,
            data_field_series_item: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataFieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_series_item: typing.Optional[typing.Union[typing.Union["CfnTemplate.FieldSeriesItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The series item configuration of a line chart.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param data_field_series_item: The data field series item configuration of a line chart.
            :param field_series_item: The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                series_item_property = quicksight.CfnTemplate.SeriesItemProperty(
                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        field_value="fieldValue",
                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    ),
                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                        axis_binding="axisBinding",
                        field_id="fieldId",
                
                        # the properties below are optional
                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                line_interpolation="lineInterpolation",
                                line_style="lineStyle",
                                line_visibility="lineVisibility",
                                line_width="lineWidth"
                            ),
                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                marker_color="markerColor",
                                marker_shape="markerShape",
                                marker_size="markerSize",
                                marker_visibility="markerVisibility"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2865d448e94d60fd22ac5a77717d0aac446b58a72984101d64e214a71192bcfa)
                check_type(argname="argument data_field_series_item", value=data_field_series_item, expected_type=type_hints["data_field_series_item"])
                check_type(argname="argument field_series_item", value=field_series_item, expected_type=type_hints["field_series_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_field_series_item is not None:
                self._values["data_field_series_item"] = data_field_series_item
            if field_series_item is not None:
                self._values["field_series_item"] = field_series_item

        @builtins.property
        def data_field_series_item(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataFieldSeriesItemProperty", _IResolvable_a771d0ef]]:
            '''The data field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-datafieldseriesitem
            '''
            result = self._values.get("data_field_series_item")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataFieldSeriesItemProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_series_item(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FieldSeriesItemProperty", _IResolvable_a771d0ef]]:
            '''The field series item configuration of a line chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-fieldseriesitem
            '''
            result = self._values.get("field_series_item")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FieldSeriesItemProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SeriesItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SetParameterValueConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "destination_parameter_name": "destinationParameterName",
            "value": "value",
        },
    )
    class SetParameterValueConfigurationProperty:
        def __init__(
            self,
            *,
            destination_parameter_name: builtins.str,
            value: typing.Union[typing.Union["CfnTemplate.DestinationParameterValueConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The configuration of adding parameters in action.

            :param destination_parameter_name: The destination parameter name of the ``SetParameterValueConfiguration`` .
            :param value: ``CfnTemplate.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                set_parameter_value_configuration_property = quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                    destination_parameter_name="destinationParameterName",
                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                date_time_values=["dateTimeValues"],
                                decimal_values=[123],
                                integer_values=[123],
                                string_values=["stringValues"]
                            ),
                
                            # the properties below are optional
                            include_null_value=False
                        ),
                        select_all_value_options="selectAllValueOptions",
                        source_field="sourceField",
                        source_parameter_name="sourceParameterName"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95891fa670c7ec3582c2ea3cc192527e219bd9658b92490a692d24fecffdfca5)
                check_type(argname="argument destination_parameter_name", value=destination_parameter_name, expected_type=type_hints["destination_parameter_name"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "destination_parameter_name": destination_parameter_name,
                "value": value,
            }

        @builtins.property
        def destination_parameter_name(self) -> builtins.str:
            '''The destination parameter name of the ``SetParameterValueConfiguration`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-destinationparametername
            '''
            result = self._values.get("destination_parameter_name")
            assert result is not None, "Required property 'destination_parameter_name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union["CfnTemplate.DestinationParameterValueConfigurationProperty", _IResolvable_a771d0ef]:
            '''``CfnTemplate.SetParameterValueConfigurationProperty.Value``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union["CfnTemplate.DestinationParameterValueConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SetParameterValueConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ShapeConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={"background_color": "backgroundColor"},
    )
    class ShapeConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''The shape conditional formatting of a filled map visual.

            :param background_color: The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                shape_conditional_format_property = quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__931fb7c9aeac54d49d1c2e7a7d7249b003383c683ff411a13fbc4d516dd5e9d2)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "background_color": background_color,
            }

        @builtins.property
        def background_color(
            self,
        ) -> typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]:
            '''The conditional formatting for the shape background color of a filled map visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html#cfn-quicksight-template-shapeconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            assert result is not None, "Required property 'background_color' is missing"
            return typing.cast(typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShapeConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"grid_layout": "gridLayout"},
    )
    class SheetControlLayoutConfigurationProperty:
        def __init__(
            self,
            *,
            grid_layout: typing.Optional[typing.Union[typing.Union["CfnTemplate.GridLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :param grid_layout: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_control_layout_configuration_property = quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                    grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                        elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                            column_span=123,
                            element_id="elementId",
                            element_type="elementType",
                            row_span=123,
                
                            # the properties below are optional
                            column_index=123,
                            row_index=123
                        )],
                
                        # the properties below are optional
                        canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                            screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                resize_option="resizeOption",
                
                                # the properties below are optional
                                optimized_view_port_width="optimizedViewPortWidth"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__24819c5cec526f244999ea2e44a7954d943c256004094d0e3d15b9e3c2c225ac)
                check_type(argname="argument grid_layout", value=grid_layout, expected_type=type_hints["grid_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if grid_layout is not None:
                self._values["grid_layout"] = grid_layout

        @builtins.property
        def grid_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html#cfn-quicksight-template-sheetcontrollayoutconfiguration-gridlayout
            '''
            result = self._values.get("grid_layout")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GridLayoutConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetControlLayoutProperty",
        jsii_struct_bases=[],
        name_mapping={"configuration": "configuration"},
    )
    class SheetControlLayoutProperty:
        def __init__(
            self,
            *,
            configuration: typing.Union[typing.Union["CfnTemplate.SheetControlLayoutConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
        ) -> None:
            '''A grid layout to define the placement of sheet control.

            :param configuration: The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_control_layout_property = quicksight.CfnTemplate.SheetControlLayoutProperty(
                    configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                        grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                            elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                column_span=123,
                                element_id="elementId",
                                element_type="elementType",
                                row_span=123,
                
                                # the properties below are optional
                                column_index=123,
                                row_index=123
                            )],
                
                            # the properties below are optional
                            canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                    resize_option="resizeOption",
                
                                    # the properties below are optional
                                    optimized_view_port_width="optimizedViewPortWidth"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43fbaf712b3b0af39f246561d11aa60ab1606076e0bce5cf54b14c8e6cba1785)
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration": configuration,
            }

        @builtins.property
        def configuration(
            self,
        ) -> typing.Union["CfnTemplate.SheetControlLayoutConfigurationProperty", _IResolvable_a771d0ef]:
            '''The configuration that determines the elements and canvas size options of sheet control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html#cfn-quicksight-template-sheetcontrollayout-configuration
            '''
            result = self._values.get("configuration")
            assert result is not None, "Required property 'configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.SheetControlLayoutConfigurationProperty", _IResolvable_a771d0ef], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetControlLayoutProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "sheet_id": "sheetId",
            "content_type": "contentType",
            "description": "description",
            "filter_controls": "filterControls",
            "layouts": "layouts",
            "name": "name",
            "parameter_controls": "parameterControls",
            "sheet_control_layouts": "sheetControlLayouts",
            "text_boxes": "textBoxes",
            "title": "title",
            "visuals": "visuals",
        },
    )
    class SheetDefinitionProperty:
        def __init__(
            self,
            *,
            sheet_id: builtins.str,
            content_type: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            filter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FilterControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.LayoutProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            name: typing.Optional[builtins.str] = None,
            parameter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ParameterControlProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SheetControlLayoutProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            text_boxes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SheetTextBoxProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            title: typing.Optional[builtins.str] = None,
            visuals: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''A sheet is an object that contains a set of visuals that are viewed together on one page in a paginated report.

            Every analysis and dashboard must contain at least one sheet.

            :param sheet_id: The unique identifier of a sheet.
            :param content_type: The layout content type of the sheet. Choose one of the following options:. - ``PAGINATED`` : Creates a sheet for a paginated report. - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.
            :param description: A description of the sheet.
            :param filter_controls: The list of filter controls that are on a sheet. For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param layouts: Layouts define how the components of a sheet are arranged. For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .
            :param name: The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param parameter_controls: The list of parameter controls that are on a sheet. For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheet_control_layouts: The control layouts of the sheet.
            :param text_boxes: The text boxes that are on a sheet.
            :param title: The title of the sheet.
            :param visuals: A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                sheet_definition_property = quicksight.CfnTemplate.SheetDefinitionProperty(
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    content_type="contentType",
                    description="description",
                    filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.FilterListControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                values=["values"]
                            ),
                            type="type"
                        ),
                        relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                            filter_control_id="filterControlId",
                            maximum_value=123,
                            minimum_value=123,
                            source_filter_id="sourceFilterId",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            type="type"
                        ),
                        text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                            filter_control_id="filterControlId",
                            source_filter_id="sourceFilterId",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    layouts=[quicksight.CfnTemplate.LayoutProperty(
                        configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                            free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                    element_id="elementId",
                                    element_type="elementType",
                                    height="height",
                                    width="width",
                                    x_axis_location="xAxisLocation",
                                    y_axis_location="yAxisLocation",
                
                                    # the properties below are optional
                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                        visibility="visibility"
                                    ),
                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                            visibility="visibility"
                                        ),
                                        expression="expression"
                                    )],
                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                        color="color",
                                        visibility="visibility"
                                    ),
                                    visibility="visibility"
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            ),
                            section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                    content=quicksight.CfnTemplate.BodySectionContentProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                        after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                            status="status"
                                        )
                                    ),
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                    paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                        paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        ),
                                        paper_orientation="paperOrientation",
                                        paper_size="paperSize"
                                    )
                                ),
                                footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )],
                                header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                    layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                        free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                            elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                element_id="elementId",
                                                element_type="elementType",
                                                height="height",
                                                width="width",
                                                x_axis_location="xAxisLocation",
                                                y_axis_location="yAxisLocation",
                
                                                # the properties below are optional
                                                background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                    visibility="visibility"
                                                ),
                                                rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                        visibility="visibility"
                                                    ),
                                                    expression="expression"
                                                )],
                                                selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                    color="color",
                                                    visibility="visibility"
                                                ),
                                                visibility="visibility"
                                            )]
                                        )
                                    ),
                                    section_id="sectionId",
                
                                    # the properties below are optional
                                    style=quicksight.CfnTemplate.SectionStyleProperty(
                                        height="height",
                                        padding=quicksight.CfnTemplate.SpacingProperty(
                                            bottom="bottom",
                                            left="left",
                                            right="right",
                                            top="top"
                                        )
                                    )
                                )]
                            )
                        )
                    )],
                    name="name",
                    parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                        date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                date_time_format="dateTimeFormat",
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        list=quicksight.CfnTemplate.ParameterListControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                    column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    source_sheet_control_id="sourceSheetControlId"
                                )]
                            ),
                            display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                    visibility="visibility"
                                ),
                                select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                values=["values"]
                            ),
                            type="type"
                        ),
                        slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                            maximum_value=123,
                            minimum_value=123,
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            step_size=123,
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            delimiter="delimiter",
                            display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        ),
                        text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                            parameter_control_id="parameterControlId",
                            source_parameter_name="sourceParameterName",
                            title="title",
                
                            # the properties below are optional
                            display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                    visibility="visibility"
                                ),
                                title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )
                    )],
                    sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                        configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                            grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                    column_span=123,
                                    element_id="elementId",
                                    element_type="elementType",
                                    row_span=123,
                
                                    # the properties below are optional
                                    column_index=123,
                                    row_index=123
                                )],
                
                                # the properties below are optional
                                canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                    screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                        resize_option="resizeOption",
                
                                        # the properties below are optional
                                        optimized_view_port_width="optimizedViewPortWidth"
                                    )
                                )
                            )
                        )
                    )],
                    text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                        sheet_text_box_id="sheetTextBoxId",
                
                        # the properties below are optional
                        content="content"
                    )],
                    title="title",
                    visuals=[quicksight.CfnTemplate.VisualProperty(
                        bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                    bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                orientation="orientation",
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                    all_data_points_visibility="allDataPointsVisibility",
                                    outlier_visibility="outlierVisibility",
                                    style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                        fill_style="fillStyle"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                    box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                bars_arrangement="barsArrangement",
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                    combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                        bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                content_type="contentType",
                                content_url="contentUrl",
                                image_scaling="imageScaling"
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )]
                        ),
                        filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                    filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                    shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    label_color="labelColor",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_data_label_style="measureDataLabelStyle",
                                    measure_label_visibility="measureLabelVisibility",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                    funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                    arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                        arc_angle=123,
                                        arc_thickness="arcThickness"
                                    ),
                                    arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                        range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                            max=123,
                                            min=123
                                        ),
                                        reserve_range=123
                                    ),
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                ),
                                tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                    arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                    geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                    base_map_style="baseMapStyle"
                                ),
                                point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                    cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                        cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                            simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                color="color"
                                            )
                                        )
                                    ),
                                    selected_point_style="selectedPointStyle"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                    bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                        east=123,
                                        north=123,
                                        south=123,
                                        west=123
                                    ),
                                    map_zoom_mode="mapZoomMode"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                    heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                    heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                    bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                        value=123
                                    ),
                                    bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                        bin_count_limit=123,
                                        value=123
                                    ),
                                    selected_bin_type="selectedBinType",
                                    start_value=123
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                    histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                            data_set_identifier="dataSetIdentifier",
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                computations=[quicksight.CfnTemplate.ComputationProperty(
                                    forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        custom_seasonality_value=123,
                                        lower_boundary=123,
                                        name="name",
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality="seasonality",
                                        upper_boundary=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                        computation_id="computationId",
                                        from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name",
                                        period_time_granularity="periodTimeGranularity",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        time=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        type="type",
                
                                        # the properties below are optional
                                        mover_size=123,
                                        name="name",
                                        sort_order="sortOrder",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                                        type="type",
                
                                        # the properties below are optional
                                        name="name",
                                        result_size=123,
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                        computation_id="computationId",
                                        value=quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                
                                        # the properties below are optional
                                        name="name"
                                    ),
                                    unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                        category=quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        ),
                                        computation_id="computationId",
                
                                        # the properties below are optional
                                        name="name"
                                    )
                                )],
                                custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                    narrative="narrative"
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                    target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                    comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                        comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        comparison_method="comparisonMethod"
                                    ),
                                    primary_value_display_type="primaryValueDisplayType",
                                    primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                    trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                    primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    ),
                                    progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                        foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                    axis_binding="axisBinding",
                                    line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                        line_interpolation="lineInterpolation",
                                        line_style="lineStyle",
                                        line_visibility="lineVisibility",
                                        line_width="lineWidth"
                                    ),
                                    marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                        marker_color="markerColor",
                                        marker_shape="markerShape",
                                        marker_size="markerSize",
                                        marker_visibility="markerVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                    line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                    forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                        lower_boundary=123,
                                        periods_backward=123,
                                        periods_forward=123,
                                        prediction_interval=123,
                                        seasonality=123,
                                        upper_boundary=123
                                    ),
                                    scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                        what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                            date="date",
                                            value=123
                                        ),
                                        what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                            end_date="endDate",
                                            start_date="startDate",
                                            value=123
                                        )
                                    )
                                )],
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                    data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                        axis_binding="axisBinding",
                                        dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                            calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                            value=123
                                        )
                                    ),
                
                                    # the properties below are optional
                                    label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                        custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                            custom_label="customLabel"
                                        ),
                                        font_color="fontColor",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_position="horizontalPosition",
                                        value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            relative_position="relativePosition"
                                        ),
                                        vertical_position="verticalPosition"
                                    ),
                                    status="status",
                                    style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                        color="color",
                                        pattern="pattern"
                                    )
                                )],
                                secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                    axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                        treatment_option="treatmentOption"
                                    )]
                                ),
                                secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                series=[quicksight.CfnTemplate.SeriesItemProperty(
                                    data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        field_value="fieldValue",
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    ),
                                    field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                        axis_binding="axisBinding",
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                            line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                line_interpolation="lineInterpolation",
                                                line_style="lineStyle",
                                                line_visibility="lineVisibility",
                                                line_width="lineWidth"
                                            ),
                                            marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                marker_color="markerColor",
                                                marker_shape="markerShape",
                                                marker_size="markerSize",
                                                marker_visibility="markerVisibility"
                                            )
                                        )
                                    )
                                )],
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                    category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                type="type",
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                    contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    measure_field_id="measureFieldId"
                                )],
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                    arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                        arc_thickness="arcThickness"
                                    ),
                                    donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                        label_visibility="labelVisibility"
                                    )
                                ),
                                field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                    pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                    max_visible_columns=123,
                                    max_visible_rows=123,
                                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                        background_color="backgroundColor",
                                        background_visibility="backgroundVisibility",
                                        border_color="borderColor",
                                        border_style="borderStyle",
                                        border_thickness="borderThickness",
                                        border_visibility="borderVisibility",
                                        gutter_spacing="gutterSpacing",
                                        gutter_visibility="gutterVisibility",
                                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                    data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                        data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        )],
                
                                        # the properties below are optional
                                        width="width"
                                    )],
                                    selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        visibility="visibility"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                    pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                        columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                    field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                        field_id="fieldId",
                                        sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                            column=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                direction="direction",
                                                sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                    field_id="fieldId",
                                                    field_value="fieldValue"
                                                )]
                                            ),
                                            field=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )
                                    )]
                                ),
                                table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    column_names_visibility="columnNamesVisibility",
                                    metric_placement="metricPlacement",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    ),
                                    row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    single_metric_visibility="singleMetricVisibility",
                                    toggle_buttons_visibility="toggleButtonsVisibility"
                                ),
                                total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                    column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                        custom_label="customLabel",
                                        field_level="fieldLevel",
                                        field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                            field_id="fieldId"
                                        )],
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    ),
                                    row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                        custom_label="customLabel",
                                        metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility",
                                        value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        )
                                    )
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                            role="role"
                                        ),
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                alternate_band_colors_visibility="alternateBandColorsVisibility",
                                alternate_band_even_color="alternateBandEvenColor",
                                alternate_band_odd_color="alternateBandOddColor",
                                base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                    area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                        visibility="visibility"
                                    )
                                ),
                                category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                    radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                shape="shape",
                                sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )],
                                    color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                start_angle=123,
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                    sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                        destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                    destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                )
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                    scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                        category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        table_visual=quicksight.CfnTemplate.TableVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                    order=["order"],
                                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        custom_label="customLabel",
                                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                )
                                            ),
                                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                        icon="icon"
                                                    ),
                                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                            font_color="fontColor",
                                                            font_decoration="fontDecoration",
                                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                relative="relative"
                                                            ),
                                                            font_style="fontStyle",
                                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                name="name"
                                                            )
                                                        ),
                
                                                        # the properties below are optional
                                                        value="value"
                                                    )
                                                ),
                                                target="target"
                                            )
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    )]
                                ),
                                field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                    table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                        values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                    vertical_overflow_visibility="verticalOverflowVisibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                        page_number=123,
                                        page_size=123
                                    ),
                                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        negative_color="negativeColor",
                                        positive_color="positiveColor"
                                    )
                                )],
                                table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    orientation="orientation",
                                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                        row_alternate_colors=["rowAlternateColors"],
                                        status="status"
                                    )
                                ),
                                total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                    custom_label="customLabel",
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility"
                                )
                            ),
                            conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    ),
                                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )]
                            ),
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                    color_fill_type="colorFillType",
                                    colors=[quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )],
                
                                    # the properties below are optional
                                    null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                        color="color",
                                        data_value=123
                                    )
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                    tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                        colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                        aggregation_visibility="aggregationVisibility",
                                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                ),
                                                label="label",
                                                visibility="visibility"
                                            ),
                                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                label="label",
                                                visibility="visibility"
                                            )
                                        )],
                                        tooltip_title_type="tooltipTitleType"
                                    ),
                                    selected_tooltip_type="selectedTooltipType",
                                    tooltip_visibility="tooltipVisibility"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                    category_label_visibility="categoryLabelVisibility",
                                    data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                        data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue",
                                            visibility="visibility"
                                        ),
                                        field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                            field_id="fieldId",
                                            visibility="visibility"
                                        ),
                                        maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                            visibility="visibility"
                                        ),
                                        range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                            visibility="visibility"
                                        )
                                    )],
                                    label_color="labelColor",
                                    label_content="labelContent",
                                    label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    measure_label_visibility="measureLabelVisibility",
                                    overlap="overlap",
                                    position="position",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                    waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                        breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                    height="height",
                                    position="position",
                                    title=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    visibility="visibility",
                                    width="width"
                                ),
                                primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                    chart_color="chartColor",
                                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                        color="color",
                                        element=quicksight.CfnTemplate.DataPathValueProperty(
                                            field_id="fieldId",
                                            field_value="fieldValue"
                                        ),
                
                                        # the properties below are optional
                                        time_granularity="timeGranularity"
                                    )]
                                ),
                                waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                    total_bar_label="totalBarLabel"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        ),
                        word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                            visual_id="visualId",
                
                            # the properties below are optional
                            actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                            selected_field_options="selectedFieldOptions",
                                            selected_fields=["selectedFields"]
                                        ),
                                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                target_visual_options="targetVisualOptions",
                                                target_visuals=["targetVisuals"]
                                            )
                                        )
                                    ),
                                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                            target_sheet_id="targetSheetId"
                                        )
                                    ),
                                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                            destination_parameter_name="destinationParameterName",
                                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                        date_time_values=["dateTimeValues"],
                                                        decimal_values=[123],
                                                        integer_values=[123],
                                                        string_values=["stringValues"]
                                                    ),
                
                                                    # the properties below are optional
                                                    include_null_value=False
                                                ),
                                                select_all_value_options="selectAllValueOptions",
                                                source_field="sourceField",
                                                source_parameter_name="sourceParameterName"
                                            )
                                        )]
                                    ),
                                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                        url_target="urlTarget",
                                        url_template="urlTemplate"
                                    )
                                )],
                                custom_action_id="customActionId",
                                name="name",
                                trigger="trigger",
                
                                # the properties below are optional
                                status="status"
                            )],
                            chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                    axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                        apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId"
                                        ),
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    )],
                                    sort_icon_visibility="sortIconVisibility",
                                    visibility="visibility"
                                ),
                                field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    )
                                ),
                                sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                        items_limit=123,
                                        other_categories="otherCategories"
                                    ),
                                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )]
                                ),
                                word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                    cloud_layout="cloudLayout",
                                    maximum_string_length=123,
                                    word_casing="wordCasing",
                                    word_orientation="wordOrientation",
                                    word_padding="wordPadding",
                                    word_scaling="wordScaling"
                                )
                            ),
                            column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                ),
                                predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                    columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )],
                                    hierarchy_id="hierarchyId",
                
                                    # the properties below are optional
                                    drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                        category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                            category_values=["categoryValues"],
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            )
                                        ),
                                        numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            value=123
                                        ),
                                        time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            range_maximum="rangeMaximum",
                                            range_minimum="rangeMinimum",
                                            time_granularity="timeGranularity"
                                        )
                                    )]
                                )
                            )],
                            subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            ),
                            title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                    plain_text="plainText",
                                    rich_text="richText"
                                ),
                                visibility="visibility"
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d3c2388c54f3eb0eb16485b8231a94ec9e339da522fc53b161d751ae268865ff)
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument filter_controls", value=filter_controls, expected_type=type_hints["filter_controls"])
                check_type(argname="argument layouts", value=layouts, expected_type=type_hints["layouts"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_controls", value=parameter_controls, expected_type=type_hints["parameter_controls"])
                check_type(argname="argument sheet_control_layouts", value=sheet_control_layouts, expected_type=type_hints["sheet_control_layouts"])
                check_type(argname="argument text_boxes", value=text_boxes, expected_type=type_hints["text_boxes"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
                check_type(argname="argument visuals", value=visuals, expected_type=type_hints["visuals"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_id": sheet_id,
            }
            if content_type is not None:
                self._values["content_type"] = content_type
            if description is not None:
                self._values["description"] = description
            if filter_controls is not None:
                self._values["filter_controls"] = filter_controls
            if layouts is not None:
                self._values["layouts"] = layouts
            if name is not None:
                self._values["name"] = name
            if parameter_controls is not None:
                self._values["parameter_controls"] = parameter_controls
            if sheet_control_layouts is not None:
                self._values["sheet_control_layouts"] = sheet_control_layouts
            if text_boxes is not None:
                self._values["text_boxes"] = text_boxes
            if title is not None:
                self._values["title"] = title
            if visuals is not None:
                self._values["visuals"] = visuals

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The unique identifier of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content_type(self) -> typing.Optional[builtins.str]:
            '''The layout content type of the sheet. Choose one of the following options:.

            - ``PAGINATED`` : Creates a sheet for a paginated report.
            - ``INTERACTIVE`` : Creates a sheet for an interactive dashboard.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-contenttype
            '''
            result = self._values.get("content_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''A description of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def filter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilterControlProperty", _IResolvable_a771d0ef]]]]:
            '''The list of filter controls that are on a sheet.

            For more information, see `Adding filter controls to analysis sheets <https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-filtercontrols
            '''
            result = self._values.get("filter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilterControlProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.LayoutProperty", _IResolvable_a771d0ef]]]]:
            '''Layouts define how the components of a sheet are arranged.

            For more information, see `Types of layout <https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-layouts
            '''
            result = self._values.get("layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.LayoutProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of the sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def parameter_controls(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ParameterControlProperty", _IResolvable_a771d0ef]]]]:
            '''The list of parameter controls that are on a sheet.

            For more information, see `Using a Control with a Parameter in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-parametercontrols
            '''
            result = self._values.get("parameter_controls")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ParameterControlProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheet_control_layouts(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetControlLayoutProperty", _IResolvable_a771d0ef]]]]:
            '''The control layouts of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetcontrollayouts
            '''
            result = self._values.get("sheet_control_layouts")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetControlLayoutProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def text_boxes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetTextBoxProperty", _IResolvable_a771d0ef]]]]:
            '''The text boxes that are on a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-textboxes
            '''
            result = self._values.get("text_boxes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetTextBoxProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def title(self) -> typing.Optional[builtins.str]:
            '''The title of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visuals(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualProperty", _IResolvable_a771d0ef]]]]:
            '''A list of the visuals that are on a sheet.

            Visual placement is determined by the layout of the sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-visuals
            '''
            result = self._values.get("visuals")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class SheetElementConfigurationOverridesProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The override configuration of the rendering rules of a sheet.

            :param visibility: Determines whether or not the overrides are visible. Choose one of the following options:. - ``VISIBLE`` - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_element_configuration_overrides_property = quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__609d2714de6bdfd164ed82e4be65b6c7c806b5ea28d06c70f36210a1060245ab)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the overrides are visible. Choose one of the following options:.

            - ``VISIBLE``
            - ``HIDDEN``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html#cfn-quicksight-template-sheetelementconfigurationoverrides-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementConfigurationOverridesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetElementRenderingRuleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "configuration_overrides": "configurationOverrides",
            "expression": "expression",
        },
    )
    class SheetElementRenderingRuleProperty:
        def __init__(
            self,
            *,
            configuration_overrides: typing.Union[typing.Union["CfnTemplate.SheetElementConfigurationOverridesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            expression: builtins.str,
        ) -> None:
            '''The rendering rules of a sheet that uses a free-form layout.

            :param configuration_overrides: The override configuration of the rendering rules of a sheet.
            :param expression: The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_element_rendering_rule_property = quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                    configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                        visibility="visibility"
                    ),
                    expression="expression"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__95bdc41317bf034d261033a63b891e00f7f519faf138a89b0562fa00d2978877)
                check_type(argname="argument configuration_overrides", value=configuration_overrides, expected_type=type_hints["configuration_overrides"])
                check_type(argname="argument expression", value=expression, expected_type=type_hints["expression"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "configuration_overrides": configuration_overrides,
                "expression": expression,
            }

        @builtins.property
        def configuration_overrides(
            self,
        ) -> typing.Union["CfnTemplate.SheetElementConfigurationOverridesProperty", _IResolvable_a771d0ef]:
            '''The override configuration of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-configurationoverrides
            '''
            result = self._values.get("configuration_overrides")
            assert result is not None, "Required property 'configuration_overrides' is missing"
            return typing.cast(typing.Union["CfnTemplate.SheetElementConfigurationOverridesProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def expression(self) -> builtins.str:
            '''The expression of the rendering rules of a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-expression
            '''
            result = self._values.get("expression")
            assert result is not None, "Required property 'expression' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetElementRenderingRuleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetProperty",
        jsii_struct_bases=[],
        name_mapping={"name": "name", "sheet_id": "sheetId"},
    )
    class SheetProperty:
        def __init__(
            self,
            *,
            name: typing.Optional[builtins.str] = None,
            sheet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight.

            Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.

            :param name: The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
            :param sheet_id: The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_property = quicksight.CfnTemplate.SheetProperty(
                    name="name",
                    sheet_id="sheetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__13431325516d7446ffd9b89a46bb91b7886a4aa19137e691ff062cc3cfa6863c)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if name is not None:
                self._values["name"] = name
            if sheet_id is not None:
                self._values["sheet_id"] = sheet_id

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a sheet.

            This name is displayed on the sheet's tab in the Amazon QuickSight console.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sheet_id(self) -> typing.Optional[builtins.str]:
            '''The unique identifier associated with a sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-sheetid
            '''
            result = self._values.get("sheet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetTextBoxProperty",
        jsii_struct_bases=[],
        name_mapping={"sheet_text_box_id": "sheetTextBoxId", "content": "content"},
    )
    class SheetTextBoxProperty:
        def __init__(
            self,
            *,
            sheet_text_box_id: builtins.str,
            content: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A text box.

            :param sheet_text_box_id: The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
            :param content: The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_text_box_property = quicksight.CfnTemplate.SheetTextBoxProperty(
                    sheet_text_box_id="sheetTextBoxId",
                
                    # the properties below are optional
                    content="content"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__feebdfac4e6a5217ababbc67186e88114897b2b5fe3707c240b7d4fb888dccac)
                check_type(argname="argument sheet_text_box_id", value=sheet_text_box_id, expected_type=type_hints["sheet_text_box_id"])
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "sheet_text_box_id": sheet_text_box_id,
            }
            if content is not None:
                self._values["content"] = content

        @builtins.property
        def sheet_text_box_id(self) -> builtins.str:
            '''The unique identifier for a text box.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-sheettextboxid
            '''
            result = self._values.get("sheet_text_box_id")
            assert result is not None, "Required property 'sheet_text_box_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def content(self) -> typing.Optional[builtins.str]:
            '''The content that is displayed in the text box.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-content
            '''
            result = self._values.get("content")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetTextBoxProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "scope": "scope",
            "sheet_id": "sheetId",
            "visual_ids": "visualIds",
        },
    )
    class SheetVisualScopingConfigurationProperty:
        def __init__(
            self,
            *,
            scope: builtins.str,
            sheet_id: builtins.str,
            visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The filter that is applied to the options.

            :param scope: The scope of the applied entities. Choose one of the following options:. - ``ALL_VISUALS`` - ``SELECTED_VISUALS``
            :param sheet_id: The selected sheet that the filter is applied to.
            :param visual_ids: The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_visual_scoping_configuration_property = quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                    scope="scope",
                    sheet_id="sheetId",
                
                    # the properties below are optional
                    visual_ids=["visualIds"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__aef298c0d76678fdfb3c9a233fc81dc62aea75581d13135b057b8472fffd1cb6)
                check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
                check_type(argname="argument sheet_id", value=sheet_id, expected_type=type_hints["sheet_id"])
                check_type(argname="argument visual_ids", value=visual_ids, expected_type=type_hints["visual_ids"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "scope": scope,
                "sheet_id": sheet_id,
            }
            if visual_ids is not None:
                self._values["visual_ids"] = visual_ids

        @builtins.property
        def scope(self) -> builtins.str:
            '''The scope of the applied entities. Choose one of the following options:.

            - ``ALL_VISUALS``
            - ``SELECTED_VISUALS``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-scope
            '''
            result = self._values.get("scope")
            assert result is not None, "Required property 'scope' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def sheet_id(self) -> builtins.str:
            '''The selected sheet that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-sheetid
            '''
            result = self._values.get("sheet_id")
            assert result is not None, "Required property 'sheet_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def visual_ids(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The selected visuals that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-visualids
            '''
            result = self._values.get("visual_ids")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetVisualScopingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ShortFormatTextProperty",
        jsii_struct_bases=[],
        name_mapping={"plain_text": "plainText", "rich_text": "richText"},
    )
    class ShortFormatTextProperty:
        def __init__(
            self,
            *,
            plain_text: typing.Optional[builtins.str] = None,
            rich_text: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The text format for the title.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param plain_text: Plain text format.
            :param rich_text: Rich text. Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                short_format_text_property = quicksight.CfnTemplate.ShortFormatTextProperty(
                    plain_text="plainText",
                    rich_text="richText"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__74416675a375741e0f6f8bcacdbd55b491680721b286e91c2fbcd9b5ca17430d)
                check_type(argname="argument plain_text", value=plain_text, expected_type=type_hints["plain_text"])
                check_type(argname="argument rich_text", value=rich_text, expected_type=type_hints["rich_text"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if plain_text is not None:
                self._values["plain_text"] = plain_text
            if rich_text is not None:
                self._values["rich_text"] = rich_text

        @builtins.property
        def plain_text(self) -> typing.Optional[builtins.str]:
            '''Plain text format.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-plaintext
            '''
            result = self._values.get("plain_text")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rich_text(self) -> typing.Optional[builtins.str]:
            '''Rich text.

            Examples of rich text include bold, underline, and italics.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-richtext
            '''
            result = self._values.get("rich_text")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ShortFormatTextProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SimpleClusterMarkerProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color"},
    )
    class SimpleClusterMarkerProperty:
        def __init__(self, *, color: typing.Optional[builtins.str] = None) -> None:
            '''The simple cluster marker of the cluster marker.

            :param color: The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                simple_cluster_marker_property = quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                    color="color"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__14fe75e7fe06c2f622ff0e3fbb7ac7afa770ff9cd4d526c30e1e36101719570b)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of the simple cluster marker.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html#cfn-quicksight-template-simpleclustermarker-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SimpleClusterMarkerProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SliderControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"title_options": "titleOptions"},
    )
    class SliderControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                slider_control_display_options_property = quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3051774ccc64ec8cd7034b3dfb4a1ec421b53f465d7e7282029f06dd8b2a1c81)
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SliderControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SmallMultiplesOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "max_visible_columns": "maxVisibleColumns",
            "max_visible_rows": "maxVisibleRows",
            "panel_configuration": "panelConfiguration",
        },
    )
    class SmallMultiplesOptionsProperty:
        def __init__(
            self,
            *,
            max_visible_columns: typing.Optional[jsii.Number] = None,
            max_visible_rows: typing.Optional[jsii.Number] = None,
            panel_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PanelConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Options that determine the layout and display options of a chart's small multiples.

            :param max_visible_columns: Sets the maximum number of visible columns to display in the grid of small multiples panels. The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
            :param max_visible_rows: Sets the maximum number of visible rows to display in the grid of small multiples panels. The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
            :param panel_configuration: Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                small_multiples_options_property = quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                    max_visible_columns=123,
                    max_visible_rows=123,
                    panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                        background_color="backgroundColor",
                        background_visibility="backgroundVisibility",
                        border_color="borderColor",
                        border_style="borderStyle",
                        border_thickness="borderThickness",
                        border_visibility="borderVisibility",
                        gutter_spacing="gutterSpacing",
                        gutter_visibility="gutterVisibility",
                        title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            horizontal_text_alignment="horizontalTextAlignment",
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa471a005a76e8aed5cf36f792ee1d19d4295d00de3834b48cf7c55546265c40)
                check_type(argname="argument max_visible_columns", value=max_visible_columns, expected_type=type_hints["max_visible_columns"])
                check_type(argname="argument max_visible_rows", value=max_visible_rows, expected_type=type_hints["max_visible_rows"])
                check_type(argname="argument panel_configuration", value=panel_configuration, expected_type=type_hints["panel_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if max_visible_columns is not None:
                self._values["max_visible_columns"] = max_visible_columns
            if max_visible_rows is not None:
                self._values["max_visible_rows"] = max_visible_rows
            if panel_configuration is not None:
                self._values["panel_configuration"] = panel_configuration

        @builtins.property
        def max_visible_columns(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible columns to display in the grid of small multiples panels.

            The default is ``Auto`` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblecolumns
            '''
            result = self._values.get("max_visible_columns")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def max_visible_rows(self) -> typing.Optional[jsii.Number]:
            '''Sets the maximum number of visible rows to display in the grid of small multiples panels.

            The default value is ``Auto`` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblerows
            '''
            result = self._values.get("max_visible_rows")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def panel_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PanelConfigurationProperty", _IResolvable_a771d0ef]]:
            '''Configures the display options for each small multiples panel.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-panelconfiguration
            '''
            result = self._values.get("panel_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PanelConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SmallMultiplesOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SpacingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class SpacingProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[builtins.str] = None,
            left: typing.Optional[builtins.str] = None,
            right: typing.Optional[builtins.str] = None,
            top: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration of spacing (often a margin or padding).

            :param bottom: Define the bottom spacing.
            :param left: Define the left spacing.
            :param right: Define the right spacing.
            :param top: Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                spacing_property = quicksight.CfnTemplate.SpacingProperty(
                    bottom="bottom",
                    left="left",
                    right="right",
                    top="top"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40d47f29115b0666b48caa9d9a86b20c4896cc2121d502d3106adb8202a02e31)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(self) -> typing.Optional[builtins.str]:
            '''Define the bottom spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def left(self) -> typing.Optional[builtins.str]:
            '''Define the left spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def right(self) -> typing.Optional[builtins.str]:
            '''Define the right spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def top(self) -> typing.Optional[builtins.str]:
            '''Define the top spacing.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SpacingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.StringDefaultValuesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "dynamic_value": "dynamicValue",
            "static_values": "staticValues",
        },
    )
    class StringDefaultValuesProperty:
        def __init__(
            self,
            *,
            dynamic_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.DynamicDefaultValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The default values of the ``StringParameterDeclaration`` .

            :param dynamic_value: The dynamic value of the ``StringDefaultValues`` . Different defaults displayed according to users, groups, and values mapping.
            :param static_values: The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_default_values_property = quicksight.CfnTemplate.StringDefaultValuesProperty(
                    dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                        default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        )
                    ),
                    static_values=["staticValues"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b502b5911121fe34c752b20829b7d2ad49b939b3a204dfd4b13d125c03c0eec8)
                check_type(argname="argument dynamic_value", value=dynamic_value, expected_type=type_hints["dynamic_value"])
                check_type(argname="argument static_values", value=static_values, expected_type=type_hints["static_values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if dynamic_value is not None:
                self._values["dynamic_value"] = dynamic_value
            if static_values is not None:
                self._values["static_values"] = static_values

        @builtins.property
        def dynamic_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]]:
            '''The dynamic value of the ``StringDefaultValues`` .

            Different defaults displayed according to users, groups, and values mapping.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-dynamicvalue
            '''
            result = self._values.get("dynamic_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DynamicDefaultValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_values(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The static values of the ``DecimalDefaultValues`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-staticvalues
            '''
            result = self._values.get("static_values")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringDefaultValuesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.StringFormatConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "null_value_format_configuration": "nullValueFormatConfiguration",
            "numeric_format_configuration": "numericFormatConfiguration",
        },
    )
    class StringFormatConfigurationProperty:
        def __init__(
            self,
            *,
            null_value_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            numeric_format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Formatting configuration for string fields.

            :param null_value_format_configuration: The options that determine the null value format configuration.
            :param numeric_format_configuration: The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_format_configuration_property = quicksight.CfnTemplate.StringFormatConfigurationProperty(
                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                        null_string="nullString"
                    ),
                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix",
                            symbol="symbol"
                        ),
                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            number_scale="numberScale",
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        ),
                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                decimal_places=123
                            ),
                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                display_mode="displayMode"
                            ),
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            prefix="prefix",
                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                decimal_separator="decimalSeparator",
                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                    symbol="symbol",
                                    visibility="visibility"
                                )
                            ),
                            suffix="suffix"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e5ad39465dba0b7bb1e7aeb0c81a75e3a57533ae9c921405d41cf78893619160)
                check_type(argname="argument null_value_format_configuration", value=null_value_format_configuration, expected_type=type_hints["null_value_format_configuration"])
                check_type(argname="argument numeric_format_configuration", value=numeric_format_configuration, expected_type=type_hints["numeric_format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if null_value_format_configuration is not None:
                self._values["null_value_format_configuration"] = null_value_format_configuration
            if numeric_format_configuration is not None:
                self._values["numeric_format_configuration"] = numeric_format_configuration

        @builtins.property
        def null_value_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the null value format configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-nullvalueformatconfiguration
            '''
            result = self._values.get("null_value_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NullValueFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def numeric_format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The formatting configuration for numeric strings.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-numericformatconfiguration
            '''
            result = self._values.get("numeric_format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.NumericFormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringFormatConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.StringParameterDeclarationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "name": "name",
            "parameter_value_type": "parameterValueType",
            "default_values": "defaultValues",
            "mapped_data_set_parameters": "mappedDataSetParameters",
            "value_when_unset": "valueWhenUnset",
        },
    )
    class StringParameterDeclarationProperty:
        def __init__(
            self,
            *,
            name: builtins.str,
            parameter_value_type: builtins.str,
            default_values: typing.Optional[typing.Union[typing.Union["CfnTemplate.StringDefaultValuesProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MappedDataSetParameterProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            value_when_unset: typing.Optional[typing.Union[typing.Union["CfnTemplate.StringValueWhenUnsetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A parameter declaration for the ``String`` data type.

            :param name: The name of the parameter that is being declared.
            :param parameter_value_type: The value type determines whether the parameter is a single-value or multi-value parameter.
            :param default_values: The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
            :param mapped_data_set_parameters: ``CfnTemplate.StringParameterDeclarationProperty.MappedDataSetParameters``.
            :param value_when_unset: The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_parameter_declaration_property = quicksight.CfnTemplate.StringParameterDeclarationProperty(
                    name="name",
                    parameter_value_type="parameterValueType",
                
                    # the properties below are optional
                    default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                        dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                            default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )
                        ),
                        static_values=["staticValues"]
                    ),
                    mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                        data_set_identifier="dataSetIdentifier",
                        data_set_parameter_name="dataSetParameterName"
                    )],
                    value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                        custom_value="customValue",
                        value_when_unset_option="valueWhenUnsetOption"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__43d4f54b2e2d185aaed02141d1bc638d668650c6c95a21b4f3930271a04eee2a)
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument parameter_value_type", value=parameter_value_type, expected_type=type_hints["parameter_value_type"])
                check_type(argname="argument default_values", value=default_values, expected_type=type_hints["default_values"])
                check_type(argname="argument mapped_data_set_parameters", value=mapped_data_set_parameters, expected_type=type_hints["mapped_data_set_parameters"])
                check_type(argname="argument value_when_unset", value=value_when_unset, expected_type=type_hints["value_when_unset"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "name": name,
                "parameter_value_type": parameter_value_type,
            }
            if default_values is not None:
                self._values["default_values"] = default_values
            if mapped_data_set_parameters is not None:
                self._values["mapped_data_set_parameters"] = mapped_data_set_parameters
            if value_when_unset is not None:
                self._values["value_when_unset"] = value_when_unset

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the parameter that is being declared.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_value_type(self) -> builtins.str:
            '''The value type determines whether the parameter is a single-value or multi-value parameter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-parametervaluetype
            '''
            result = self._values.get("parameter_value_type")
            assert result is not None, "Required property 'parameter_value_type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def default_values(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.StringDefaultValuesProperty", _IResolvable_a771d0ef]]:
            '''The default values of a parameter.

            If the parameter is a single-value parameter, a maximum of one default value can be provided.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-defaultvalues
            '''
            result = self._values.get("default_values")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.StringDefaultValuesProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def mapped_data_set_parameters(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnTemplate.StringParameterDeclarationProperty.MappedDataSetParameters``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-mappeddatasetparameters
            '''
            result = self._values.get("mapped_data_set_parameters")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MappedDataSetParameterProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def value_when_unset(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.StringValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-valuewhenunset
            '''
            result = self._values.get("value_when_unset")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.StringValueWhenUnsetConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringParameterDeclarationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_value": "customValue",
            "value_when_unset_option": "valueWhenUnsetOption",
        },
    )
    class StringValueWhenUnsetConfigurationProperty:
        def __init__(
            self,
            *,
            custom_value: typing.Optional[builtins.str] = None,
            value_when_unset_option: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The configuration that defines the default value of a ``String`` parameter when a value has not been set.

            :param custom_value: A custom value that's used when the value of a parameter isn't set.
            :param value_when_unset_option: The built-in options for default values. The value can be one of the following:. - ``RECOMMENDED`` : The recommended value. - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                string_value_when_unset_configuration_property = quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                    custom_value="customValue",
                    value_when_unset_option="valueWhenUnsetOption"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9750e619dc3fc3653ba8b6825bf995d751ac7498aa5ef9ae53e72b7825b2e3e7)
                check_type(argname="argument custom_value", value=custom_value, expected_type=type_hints["custom_value"])
                check_type(argname="argument value_when_unset_option", value=value_when_unset_option, expected_type=type_hints["value_when_unset_option"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_value is not None:
                self._values["custom_value"] = custom_value
            if value_when_unset_option is not None:
                self._values["value_when_unset_option"] = value_when_unset_option

        @builtins.property
        def custom_value(self) -> typing.Optional[builtins.str]:
            '''A custom value that's used when the value of a parameter isn't set.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-customvalue
            '''
            result = self._values.get("custom_value")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_when_unset_option(self) -> typing.Optional[builtins.str]:
            '''The built-in options for default values. The value can be one of the following:.

            - ``RECOMMENDED`` : The recommended value.
            - ``NULL`` : The ``NULL`` value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-valuewhenunsetoption
            '''
            result = self._values.get("value_when_unset_option")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "StringValueWhenUnsetConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.SubtotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "field_level": "fieldLevel",
            "field_level_options": "fieldLevelOptions",
            "metric_header_cell_style": "metricHeaderCellStyle",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
            "value_cell_style": "valueCellStyle",
        },
    )
    class SubtotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            field_level: typing.Optional[builtins.str] = None,
            field_level_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.PivotTableFieldSubtotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            metric_header_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
            value_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The subtotal options.

            :param custom_label: The custom label string for the subtotal cells.
            :param field_level: The field level (all, custom, last) for the subtotal cells.
            :param field_level_options: The optional configuration of subtotal cells.
            :param metric_header_cell_style: The cell styling options for the subtotals of header cells.
            :param total_cell_style: The cell styling options for the subtotal cells.
            :param totals_visibility: The visibility configuration for the subtotal cells.
            :param value_cell_style: The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                subtotal_options_property = quicksight.CfnTemplate.SubtotalOptionsProperty(
                    custom_label="customLabel",
                    field_level="fieldLevel",
                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                        field_id="fieldId"
                    )],
                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility",
                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__25637467992b08ed4a2143af45b0248cf65bf6a8c96faeec7fe2547b82acc206)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument field_level", value=field_level, expected_type=type_hints["field_level"])
                check_type(argname="argument field_level_options", value=field_level_options, expected_type=type_hints["field_level_options"])
                check_type(argname="argument metric_header_cell_style", value=metric_header_cell_style, expected_type=type_hints["metric_header_cell_style"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
                check_type(argname="argument value_cell_style", value=value_cell_style, expected_type=type_hints["value_cell_style"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if field_level is not None:
                self._values["field_level"] = field_level
            if field_level_options is not None:
                self._values["field_level_options"] = field_level_options
            if metric_header_cell_style is not None:
                self._values["metric_header_cell_style"] = metric_header_cell_style
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility
            if value_cell_style is not None:
                self._values["value_cell_style"] = value_cell_style

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level(self) -> typing.Optional[builtins.str]:
            '''The field level (all, custom, last) for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldlevel
            '''
            result = self._values.get("field_level")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def field_level_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableFieldSubtotalOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The optional configuration of subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldleveloptions
            '''
            result = self._values.get("field_level_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.PivotTableFieldSubtotalOptionsProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def metric_header_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotals of header cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-metricheadercellstyle
            '''
            result = self._values.get("metric_header_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the subtotal cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The cell styling options for the subtotals of value cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-valuecellstyle
            '''
            result = self._values.get("value_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SubtotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "values": "values"},
    )
    class TableAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field well for the table.

            :param group_by: The group by field well for a pivot table. Values are grouped by group by fields.
            :param values: The values field well for a pivot table. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_aggregated_field_wells_property = quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__6bf88db58b984dafd9082574706809c5473b03068f51be626a1094c5f0effbe9)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well for a pivot table.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"color": "color", "style": "style", "thickness": "thickness"},
    )
    class TableBorderOptionsProperty:
        def __init__(
            self,
            *,
            color: typing.Optional[builtins.str] = None,
            style: typing.Optional[builtins.str] = None,
            thickness: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The border options for a table border.

            :param color: The color of a table border.
            :param style: The style (none, solid) of a table border.
            :param thickness: The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_border_options_property = quicksight.CfnTemplate.TableBorderOptionsProperty(
                    color="color",
                    style="style",
                    thickness=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a3d34f5e00aa0280afb90650141aafc67eb6d2523e5a6e711628ed296d5cd53c)
                check_type(argname="argument color", value=color, expected_type=type_hints["color"])
                check_type(argname="argument style", value=style, expected_type=type_hints["style"])
                check_type(argname="argument thickness", value=thickness, expected_type=type_hints["thickness"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color is not None:
                self._values["color"] = color
            if style is not None:
                self._values["style"] = style
            if thickness is not None:
                self._values["thickness"] = thickness

        @builtins.property
        def color(self) -> typing.Optional[builtins.str]:
            '''The color of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-color
            '''
            result = self._values.get("color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def style(self) -> typing.Optional[builtins.str]:
            '''The style (none, solid) of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-style
            '''
            result = self._values.get("style")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def thickness(self) -> typing.Optional[jsii.Number]:
            '''The thickness of a table border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-thickness
            '''
            result = self._values.get("thickness")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableCellConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={"field_id": "fieldId", "text_format": "textFormat"},
    )
    class TableCellConditionalFormattingProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            text_format: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextConditionalFormatProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The cell conditional formatting option for a table.

            :param field_id: The field ID of the cell for conditional formatting.
            :param text_format: The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_conditional_formatting_property = quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                expression="expression",
                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                    icon="icon",
                                    unicode_icon="unicodeIcon"
                                ),
                
                                # the properties below are optional
                                color="color",
                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                    icon_display_option="iconDisplayOption"
                                )
                            ),
                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                expression="expression",
                
                                # the properties below are optional
                                icon_set_type="iconSetType"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__343f90498bda661f85f9cc2c79aed3b1877ad20cab9e2ad481c0364352f92d59)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument text_format", value=text_format, expected_type=type_hints["text_format"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if text_format is not None:
                self._values["text_format"] = text_format

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def text_format(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextConditionalFormatProperty", _IResolvable_a771d0ef]]:
            '''The text format of the cell for conditional formatting.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-textformat
            '''
            result = self._values.get("text_format")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextConditionalFormatProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_cell_image_scaling_configuration": "tableCellImageScalingConfiguration",
        },
    )
    class TableCellImageSizingConfigurationProperty:
        def __init__(
            self,
            *,
            table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The sizing options for the table image configuration.

            :param table_cell_image_scaling_configuration: The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_image_sizing_configuration_property = quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__651627002517c298a33646aae0d7a8c19906ba12de4aa6996f7d7b9b79fb8d3e)
                check_type(argname="argument table_cell_image_scaling_configuration", value=table_cell_image_scaling_configuration, expected_type=type_hints["table_cell_image_scaling_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_cell_image_scaling_configuration is not None:
                self._values["table_cell_image_scaling_configuration"] = table_cell_image_scaling_configuration

        @builtins.property
        def table_cell_image_scaling_configuration(
            self,
        ) -> typing.Optional[builtins.str]:
            '''The cell scaling configuration of the sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html#cfn-quicksight-template-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
            '''
            result = self._values.get("table_cell_image_scaling_configuration")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellImageSizingConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableCellStyleProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "border": "border",
            "font_configuration": "fontConfiguration",
            "height": "height",
            "horizontal_text_alignment": "horizontalTextAlignment",
            "text_wrap": "textWrap",
            "vertical_text_alignment": "verticalTextAlignment",
            "visibility": "visibility",
        },
    )
    class TableCellStyleProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[builtins.str] = None,
            border: typing.Optional[typing.Union[typing.Union["CfnTemplate.GlobalTableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            font_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            height: typing.Optional[jsii.Number] = None,
            horizontal_text_alignment: typing.Optional[builtins.str] = None,
            text_wrap: typing.Optional[builtins.str] = None,
            vertical_text_alignment: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The table cell style for a cell in pivot table or table visual.

            :param background_color: The background color for the table cells.
            :param border: The borders for the table cells.
            :param font_configuration: The font configuration of the table cells.
            :param height: The height color for the table cells.
            :param horizontal_text_alignment: The horizontal text alignment (left, center, right, auto) for the table cells.
            :param text_wrap: The text wrap (none, wrap) for the table cells.
            :param vertical_text_alignment: The vertical text alignment (top, middle, bottom) for the table cells.
            :param visibility: The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_cell_style_property = quicksight.CfnTemplate.TableCellStyleProperty(
                    background_color="backgroundColor",
                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            ),
                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                            color="color",
                            style="style",
                            thickness=123
                        )
                    ),
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                    height=123,
                    horizontal_text_alignment="horizontalTextAlignment",
                    text_wrap="textWrap",
                    vertical_text_alignment="verticalTextAlignment",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f03c41c114767413af09f68dc96cc84fd5e899b9379cfe49332102d522a67e06)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument height", value=height, expected_type=type_hints["height"])
                check_type(argname="argument horizontal_text_alignment", value=horizontal_text_alignment, expected_type=type_hints["horizontal_text_alignment"])
                check_type(argname="argument text_wrap", value=text_wrap, expected_type=type_hints["text_wrap"])
                check_type(argname="argument vertical_text_alignment", value=vertical_text_alignment, expected_type=type_hints["vertical_text_alignment"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if border is not None:
                self._values["border"] = border
            if font_configuration is not None:
                self._values["font_configuration"] = font_configuration
            if height is not None:
                self._values["height"] = height
            if horizontal_text_alignment is not None:
                self._values["horizontal_text_alignment"] = horizontal_text_alignment
            if text_wrap is not None:
                self._values["text_wrap"] = text_wrap
            if vertical_text_alignment is not None:
                self._values["vertical_text_alignment"] = vertical_text_alignment
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def background_color(self) -> typing.Optional[builtins.str]:
            '''The background color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GlobalTableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The borders for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GlobalTableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The font configuration of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def height(self) -> typing.Optional[jsii.Number]:
            '''The height color for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-height
            '''
            result = self._values.get("height")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def horizontal_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The horizontal text alignment (left, center, right, auto) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-horizontaltextalignment
            '''
            result = self._values.get("horizontal_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def text_wrap(self) -> typing.Optional[builtins.str]:
            '''The text wrap (none, wrap) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-textwrap
            '''
            result = self._values.get("text_wrap")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_text_alignment(self) -> typing.Optional[builtins.str]:
            '''The vertical text alignment (top, middle, bottom) for the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-verticaltextalignment
            '''
            result = self._values.get("vertical_text_alignment")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableCellStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableConditionalFormattingOptionProperty",
        jsii_struct_bases=[],
        name_mapping={"cell": "cell", "row": "row"},
    )
    class TableConditionalFormattingOptionProperty:
        def __init__(
            self,
            *,
            cell: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableRowConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :param cell: The cell conditional formatting option for a table.
            :param row: The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_conditional_formatting_option_property = quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                    cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                    expression="expression",
                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                        icon="icon",
                                        unicode_icon="unicodeIcon"
                                    ),
                
                                    # the properties below are optional
                                    color="color",
                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                        icon_display_option="iconDisplayOption"
                                    )
                                ),
                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    icon_set_type="iconSetType"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    ),
                    row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        ),
                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                color=quicksight.CfnTemplate.GradientColorProperty(
                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                        gradient_offset=123,
                
                                        # the properties below are optional
                                        color="color",
                                        data_value=123
                                    )]
                                ),
                                expression="expression"
                            ),
                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                expression="expression",
                
                                # the properties below are optional
                                color="color"
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__07cab96eb9136d38195d0f22eaef0c1713a99e64da908c8a233260ec5d34f063)
                check_type(argname="argument cell", value=cell, expected_type=type_hints["cell"])
                check_type(argname="argument row", value=row, expected_type=type_hints["row"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell is not None:
                self._values["cell"] = cell
            if row is not None:
                self._values["row"] = row

        @builtins.property
        def cell(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The cell conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-cell
            '''
            result = self._values.get("cell")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableRowConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The row conditional formatting option for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-row
            '''
            result = self._values.get("row")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableRowConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "conditional_formatting_options": "conditionalFormattingOptions",
        },
    )
    class TableConditionalFormattingProperty:
        def __init__(
            self,
            *,
            conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.TableConditionalFormattingOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :param conditional_formatting_options: Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_conditional_formatting_property = quicksight.CfnTemplate.TableConditionalFormattingProperty(
                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                        expression="expression",
                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                            icon="icon",
                                            unicode_icon="unicodeIcon"
                                        ),
                
                                        # the properties below are optional
                                        color="color",
                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                            icon_display_option="iconDisplayOption"
                                        )
                                    ),
                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        icon_set_type="iconSetType"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        ),
                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            ),
                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                            gradient_offset=123,
                
                                            # the properties below are optional
                                            color="color",
                                            data_value=123
                                        )]
                                    ),
                                    expression="expression"
                                ),
                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    color="color"
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__32207839f10375641ac945cd8fd36fd6f7f5d8e469b40c4ebf46fa6048233d40)
                check_type(argname="argument conditional_formatting_options", value=conditional_formatting_options, expected_type=type_hints["conditional_formatting_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if conditional_formatting_options is not None:
                self._values["conditional_formatting_options"] = conditional_formatting_options

        @builtins.property
        def conditional_formatting_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]]:
            '''Conditional formatting options for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html#cfn-quicksight-template-tableconditionalformatting-conditionalformattingoptions
            '''
            result = self._values.get("conditional_formatting_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TableConditionalFormattingOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_options": "fieldOptions",
            "field_wells": "fieldWells",
            "paginated_report_options": "paginatedReportOptions",
            "sort_configuration": "sortConfiguration",
            "table_inline_visualizations": "tableInlineVisualizations",
            "table_options": "tableOptions",
            "total_options": "totalOptions",
        },
    )
    class TableConfigurationProperty:
        def __init__(
            self,
            *,
            field_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            paginated_report_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TablePaginatedReportOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.TableInlineVisualizationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            table_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            total_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TotalOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a ``TableVisual`` .

            :param field_options: The field options for a table visual.
            :param field_wells: The field wells of the visual.
            :param paginated_report_options: The paginated report options for a table visual.
            :param sort_configuration: The sort configuration for a ``TableVisual`` .
            :param table_inline_visualizations: A collection of inline visualizations to display within a chart.
            :param table_options: The table options for a table visual.
            :param total_options: The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_configuration_property = quicksight.CfnTemplate.TableConfigurationProperty(
                    field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                        order=["order"],
                        selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            custom_label="customLabel",
                            url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                    )
                                ),
                                link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                            icon="icon"
                                        ),
                                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            value="value"
                                        )
                                    ),
                                    target="target"
                                )
                            ),
                            visibility="visibility",
                            width="width"
                        )]
                    ),
                    field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                        table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                            values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                        vertical_overflow_visibility="verticalOverflowVisibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                            page_number=123,
                            page_size=123
                        ),
                        row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                        data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                            field_id="fieldId",
                
                            # the properties below are optional
                            negative_color="negativeColor",
                            positive_color="positiveColor"
                        )
                    )],
                    table_options=quicksight.CfnTemplate.TableOptionsProperty(
                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        orientation="orientation",
                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                            row_alternate_colors=["rowAlternateColors"],
                            status="status"
                        )
                    ),
                    total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                        custom_label="customLabel",
                        placement="placement",
                        scroll_status="scrollStatus",
                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                            background_color="backgroundColor",
                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    ),
                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            height=123,
                            horizontal_text_alignment="horizontalTextAlignment",
                            text_wrap="textWrap",
                            vertical_text_alignment="verticalTextAlignment",
                            visibility="visibility"
                        ),
                        totals_visibility="totalsVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d72e9dc405ca60ff0649ce15c1de6858be05d764db9ce1a50f39aba3912e106c)
                check_type(argname="argument field_options", value=field_options, expected_type=type_hints["field_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument paginated_report_options", value=paginated_report_options, expected_type=type_hints["paginated_report_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument table_inline_visualizations", value=table_inline_visualizations, expected_type=type_hints["table_inline_visualizations"])
                check_type(argname="argument table_options", value=table_options, expected_type=type_hints["table_options"])
                check_type(argname="argument total_options", value=total_options, expected_type=type_hints["total_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_options is not None:
                self._values["field_options"] = field_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if paginated_report_options is not None:
                self._values["paginated_report_options"] = paginated_report_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if table_inline_visualizations is not None:
                self._values["table_inline_visualizations"] = table_inline_visualizations
            if table_options is not None:
                self._values["table_options"] = table_options
            if total_options is not None:
                self._values["total_options"] = total_options

        @builtins.property
        def field_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldOptionsProperty", _IResolvable_a771d0ef]]:
            '''The field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldoptions
            '''
            result = self._values.get("field_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def paginated_report_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]]:
            '''The paginated report options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-paginatedreportoptions
            '''
            result = self._values.get("paginated_report_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TablePaginatedReportOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration for a ``TableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_inline_visualizations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TableInlineVisualizationProperty", _IResolvable_a771d0ef]]]]:
            '''A collection of inline visualizations to display within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableinlinevisualizations
            '''
            result = self._values.get("table_inline_visualizations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TableInlineVisualizationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def table_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableoptions
            '''
            result = self._values.get("table_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def total_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TotalOptionsProperty", _IResolvable_a771d0ef]]:
            '''The total options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-totaloptions
            '''
            result = self._values.get("total_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TotalOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldCustomIconContentProperty",
        jsii_struct_bases=[],
        name_mapping={"icon": "icon"},
    )
    class TableFieldCustomIconContentProperty:
        def __init__(self, *, icon: typing.Optional[builtins.str] = None) -> None:
            '''The custom icon content for the table link content configuration.

            :param icon: The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_custom_icon_content_property = quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                    icon="icon"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__80f6817e78ddde2fb2957ce3b71b3cfe31d96c4e5c417d4a32bb899df1c84e06)
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if icon is not None:
                self._values["icon"] = icon

        @builtins.property
        def icon(self) -> typing.Optional[builtins.str]:
            '''The icon set type (link) of the custom icon content for table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html#cfn-quicksight-template-tablefieldcustomiconcontent-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomIconContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldCustomTextContentProperty",
        jsii_struct_bases=[],
        name_mapping={"font_configuration": "fontConfiguration", "value": "value"},
    )
    class TableFieldCustomTextContentProperty:
        def __init__(
            self,
            *,
            font_configuration: typing.Union[typing.Union["CfnTemplate.FontConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :param font_configuration: The font configuration of the custom text content for the table URL link content.
            :param value: The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_custom_text_content_property = quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                        font_color="fontColor",
                        font_decoration="fontDecoration",
                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                            relative="relative"
                        ),
                        font_style="fontStyle",
                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                            name="name"
                        )
                    ),
                
                    # the properties below are optional
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__eadea6b07304dc10bd64be9c2333b048a2fb8ebf431c1ca448fe9d3d68594d13)
                check_type(argname="argument font_configuration", value=font_configuration, expected_type=type_hints["font_configuration"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "font_configuration": font_configuration,
            }
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def font_configuration(
            self,
        ) -> typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef]:
            '''The font configuration of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-fontconfiguration
            '''
            result = self._values.get("font_configuration")
            assert result is not None, "Required property 'font_configuration' is missing"
            return typing.cast(typing.Union["CfnTemplate.FontConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The string value of the custom text content for the table URL link content.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldCustomTextContentProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldImageConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"sizing_options": "sizingOptions"},
    )
    class TableFieldImageConfigurationProperty:
        def __init__(
            self,
            *,
            sizing_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellImageSizingConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The image configuration of a table field URL.

            :param sizing_options: The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_image_configuration_property = quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__40381889cf4ff57ea8b0528bdb2d3853258cf132ae7fba80491c72e3d171b778)
                check_type(argname="argument sizing_options", value=sizing_options, expected_type=type_hints["sizing_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if sizing_options is not None:
                self._values["sizing_options"] = sizing_options

        @builtins.property
        def sizing_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellImageSizingConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sizing options for the table image configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html#cfn-quicksight-template-tablefieldimageconfiguration-sizingoptions
            '''
            result = self._values.get("sizing_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellImageSizingConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldImageConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldLinkConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={"content": "content", "target": "target"},
    )
    class TableFieldLinkConfigurationProperty:
        def __init__(
            self,
            *,
            content: typing.Union[typing.Union["CfnTemplate.TableFieldLinkContentConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            target: builtins.str,
        ) -> None:
            '''The link configuration of a table field URL.

            :param content: The URL content (text, icon) for the table link configuration.
            :param target: The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_link_configuration_property = quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                            icon="icon"
                        ),
                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                
                            # the properties below are optional
                            value="value"
                        )
                    ),
                    target="target"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e58b6f323af95174dcbbe38e7edb3c8905ef3c0c0c2eb3941df00cbdf6cbe84d)
                check_type(argname="argument content", value=content, expected_type=type_hints["content"])
                check_type(argname="argument target", value=target, expected_type=type_hints["target"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "content": content,
                "target": target,
            }

        @builtins.property
        def content(
            self,
        ) -> typing.Union["CfnTemplate.TableFieldLinkContentConfigurationProperty", _IResolvable_a771d0ef]:
            '''The URL content (text, icon) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-content
            '''
            result = self._values.get("content")
            assert result is not None, "Required property 'content' is missing"
            return typing.cast(typing.Union["CfnTemplate.TableFieldLinkContentConfigurationProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def target(self) -> builtins.str:
            '''The URL target (new tab, new window, same tab) for the table link configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-target
            '''
            result = self._values.get("target")
            assert result is not None, "Required property 'target' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_icon_content": "customIconContent",
            "custom_text_content": "customTextContent",
        },
    )
    class TableFieldLinkContentConfigurationProperty:
        def __init__(
            self,
            *,
            custom_icon_content: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldCustomIconContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_text_content: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldCustomTextContentProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The URL content (text, icon) for the table link configuration.

            :param custom_icon_content: The custom icon content for the table link content configuration.
            :param custom_text_content: The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_link_content_configuration_property = quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                        icon="icon"
                    ),
                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                
                        # the properties below are optional
                        value="value"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0f785ab48b0a5c8614c90c381cd3e391c4e07d4af8d010ba88a89f3e0070ee6f)
                check_type(argname="argument custom_icon_content", value=custom_icon_content, expected_type=type_hints["custom_icon_content"])
                check_type(argname="argument custom_text_content", value=custom_text_content, expected_type=type_hints["custom_text_content"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_icon_content is not None:
                self._values["custom_icon_content"] = custom_icon_content
            if custom_text_content is not None:
                self._values["custom_text_content"] = custom_text_content

        @builtins.property
        def custom_icon_content(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldCustomIconContentProperty", _IResolvable_a771d0ef]]:
            '''The custom icon content for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customiconcontent
            '''
            result = self._values.get("custom_icon_content")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldCustomIconContentProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_text_content(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldCustomTextContentProperty", _IResolvable_a771d0ef]]:
            '''The custom text content (value, font configuration) for the table link content configuration.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customtextcontent
            '''
            result = self._values.get("custom_text_content")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldCustomTextContentProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldLinkContentConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldOptionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_id": "fieldId",
            "custom_label": "customLabel",
            "url_styling": "urlStyling",
            "visibility": "visibility",
            "width": "width",
        },
    )
    class TableFieldOptionProperty:
        def __init__(
            self,
            *,
            field_id: builtins.str,
            custom_label: typing.Optional[builtins.str] = None,
            url_styling: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldURLConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
            width: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options for a table field.

            :param field_id: The field ID for a table field.
            :param custom_label: The custom label for a table field.
            :param url_styling: The URL configuration for a table field.
            :param visibility: The visibility of a table field.
            :param width: The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_option_property = quicksight.CfnTemplate.TableFieldOptionProperty(
                    field_id="fieldId",
                
                    # the properties below are optional
                    custom_label="customLabel",
                    url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                        image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                            sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                            )
                        ),
                        link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                            content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                    icon="icon"
                                ),
                                custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    value="value"
                                )
                            ),
                            target="target"
                        )
                    ),
                    visibility="visibility",
                    width="width"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__acc3d1173a9fe4fdd861909143887bd068a0cbedc7f7cca385cc4cb572b35078)
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument url_styling", value=url_styling, expected_type=type_hints["url_styling"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
                check_type(argname="argument width", value=width, expected_type=type_hints["width"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "field_id": field_id,
            }
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if url_styling is not None:
                self._values["url_styling"] = url_styling
            if visibility is not None:
                self._values["visibility"] = visibility
            if width is not None:
                self._values["width"] = width

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The field ID for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def url_styling(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldURLConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The URL configuration for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-urlstyling
            '''
            result = self._values.get("url_styling")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldURLConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def width(self) -> typing.Optional[builtins.str]:
            '''The width for a table field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-width
            '''
            result = self._values.get("width")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "order": "order",
            "selected_field_options": "selectedFieldOptions",
        },
    )
    class TableFieldOptionsProperty:
        def __init__(
            self,
            *,
            order: typing.Optional[typing.Sequence[builtins.str]] = None,
            selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.TableFieldOptionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field options for a table visual.

            :param order: The order of field IDs of the field options for a table visual.
            :param selected_field_options: The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_options_property = quicksight.CfnTemplate.TableFieldOptionsProperty(
                    order=["order"],
                    selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        custom_label="customLabel",
                        url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                            image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                    table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                )
                            ),
                            link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                    custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                        icon="icon"
                                    ),
                                    custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                
                                        # the properties below are optional
                                        value="value"
                                    )
                                ),
                                target="target"
                            )
                        ),
                        visibility="visibility",
                        width="width"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ccb24c61d22fb761617d0113c7f5d21b0718f06bb64a508d948e0862b47716f5)
                check_type(argname="argument order", value=order, expected_type=type_hints["order"])
                check_type(argname="argument selected_field_options", value=selected_field_options, expected_type=type_hints["selected_field_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if order is not None:
                self._values["order"] = order
            if selected_field_options is not None:
                self._values["selected_field_options"] = selected_field_options

        @builtins.property
        def order(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The order of field IDs of the field options for a table visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-order
            '''
            result = self._values.get("order")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def selected_field_options(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TableFieldOptionProperty", _IResolvable_a771d0ef]]]]:
            '''The selected field options for the table field options.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-selectedfieldoptions
            '''
            result = self._values.get("selected_field_options")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TableFieldOptionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldURLConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "image_configuration": "imageConfiguration",
            "link_configuration": "linkConfiguration",
        },
    )
    class TableFieldURLConfigurationProperty:
        def __init__(
            self,
            *,
            image_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldImageConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            link_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableFieldLinkConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The URL configuration for a table field.

            :param image_configuration: The image configuration of a table field URL.
            :param link_configuration: The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_uRLConfiguration_property = quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                    image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                        sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                        )
                    ),
                    link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                        content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                            custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                icon="icon"
                            ),
                            custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                
                                # the properties below are optional
                                value="value"
                            )
                        ),
                        target="target"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3247d37ef0f1fdb2638e98a6593bd820f6062d2013a65371339157b6dfe43e08)
                check_type(argname="argument image_configuration", value=image_configuration, expected_type=type_hints["image_configuration"])
                check_type(argname="argument link_configuration", value=link_configuration, expected_type=type_hints["link_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if image_configuration is not None:
                self._values["image_configuration"] = image_configuration
            if link_configuration is not None:
                self._values["link_configuration"] = link_configuration

        @builtins.property
        def image_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldImageConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The image configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-imageconfiguration
            '''
            result = self._values.get("image_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldImageConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def link_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableFieldLinkConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The link configuration of a table field URL.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-linkconfiguration
            '''
            result = self._values.get("link_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableFieldLinkConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldURLConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "table_aggregated_field_wells": "tableAggregatedFieldWells",
            "table_unaggregated_field_wells": "tableUnaggregatedFieldWells",
        },
    )
    class TableFieldWellsProperty:
        def __init__(
            self,
            *,
            table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableUnaggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells for a table visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param table_aggregated_field_wells: The aggregated field well for the table.
            :param table_unaggregated_field_wells: The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_field_wells_property = quicksight.CfnTemplate.TableFieldWellsProperty(
                    table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    ),
                    table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                        values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__04c89356da465bc9c6713f635671c73b8528747dbab836989fe2a98eeca25d8d)
                check_type(argname="argument table_aggregated_field_wells", value=table_aggregated_field_wells, expected_type=type_hints["table_aggregated_field_wells"])
                check_type(argname="argument table_unaggregated_field_wells", value=table_unaggregated_field_wells, expected_type=type_hints["table_unaggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if table_aggregated_field_wells is not None:
                self._values["table_aggregated_field_wells"] = table_aggregated_field_wells
            if table_unaggregated_field_wells is not None:
                self._values["table_unaggregated_field_wells"] = table_unaggregated_field_wells

        @builtins.property
        def table_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableaggregatedfieldwells
            '''
            result = self._values.get("table_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_unaggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The unaggregated field well for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableunaggregatedfieldwells
            '''
            result = self._values.get("table_unaggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableUnaggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableInlineVisualizationProperty",
        jsii_struct_bases=[],
        name_mapping={"data_bars": "dataBars"},
    )
    class TableInlineVisualizationProperty:
        def __init__(
            self,
            *,
            data_bars: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataBarsOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The inline visualization of a specific type to display within a chart.

            :param data_bars: The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_inline_visualization_property = quicksight.CfnTemplate.TableInlineVisualizationProperty(
                    data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        negative_color="negativeColor",
                        positive_color="positiveColor"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbbbb0ba202416974b12502a0f94e5acc5490b28a2d04fb84d183cabf598a401)
                check_type(argname="argument data_bars", value=data_bars, expected_type=type_hints["data_bars"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_bars is not None:
                self._values["data_bars"] = data_bars

        @builtins.property
        def data_bars(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataBarsOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the inline visualization of the data bars within a chart.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html#cfn-quicksight-template-tableinlinevisualization-databars
            '''
            result = self._values.get("data_bars")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataBarsOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableInlineVisualizationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cell_style": "cellStyle",
            "header_style": "headerStyle",
            "orientation": "orientation",
            "row_alternate_color_options": "rowAlternateColorOptions",
        },
    )
    class TableOptionsProperty:
        def __init__(
            self,
            *,
            cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            header_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            orientation: typing.Optional[builtins.str] = None,
            row_alternate_color_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The table options for a table visual.

            :param cell_style: The table cell style of table cells.
            :param header_style: The table cell style of a table header.
            :param orientation: The orientation (vertical, horizontal) for a table.
            :param row_alternate_color_options: The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_options_property = quicksight.CfnTemplate.TableOptionsProperty(
                    cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    orientation="orientation",
                    row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                        row_alternate_colors=["rowAlternateColors"],
                        status="status"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__63d1aa579b8a90bdee8de5b3a01094fa74f5da0ef47e5b241ed704e4e855cd4a)
                check_type(argname="argument cell_style", value=cell_style, expected_type=type_hints["cell_style"])
                check_type(argname="argument header_style", value=header_style, expected_type=type_hints["header_style"])
                check_type(argname="argument orientation", value=orientation, expected_type=type_hints["orientation"])
                check_type(argname="argument row_alternate_color_options", value=row_alternate_color_options, expected_type=type_hints["row_alternate_color_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cell_style is not None:
                self._values["cell_style"] = cell_style
            if header_style is not None:
                self._values["header_style"] = header_style
            if orientation is not None:
                self._values["orientation"] = orientation
            if row_alternate_color_options is not None:
                self._values["row_alternate_color_options"] = row_alternate_color_options

        @builtins.property
        def cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of table cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-cellstyle
            '''
            result = self._values.get("cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def header_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''The table cell style of a table header.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-headerstyle
            '''
            result = self._values.get("header_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def orientation(self) -> typing.Optional[builtins.str]:
            '''The orientation (vertical, horizontal) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-orientation
            '''
            result = self._values.get("orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def row_alternate_color_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]]:
            '''The row alternate color options (widget status, row alternate colors) for a table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-rowalternatecoloroptions
            '''
            result = self._values.get("row_alternate_color_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RowAlternateColorOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TablePaginatedReportOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "overflow_column_header_visibility": "overflowColumnHeaderVisibility",
            "vertical_overflow_visibility": "verticalOverflowVisibility",
        },
    )
    class TablePaginatedReportOptionsProperty:
        def __init__(
            self,
            *,
            overflow_column_header_visibility: typing.Optional[builtins.str] = None,
            vertical_overflow_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The paginated report options for a table visual.

            :param overflow_column_header_visibility: The visibility of repeating header rows on each page.
            :param vertical_overflow_visibility: The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_paginated_report_options_property = quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                    overflow_column_header_visibility="overflowColumnHeaderVisibility",
                    vertical_overflow_visibility="verticalOverflowVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c87416104b5860548bc9a5516e7975895712cc93a8f7d91e7080000d191a3c93)
                check_type(argname="argument overflow_column_header_visibility", value=overflow_column_header_visibility, expected_type=type_hints["overflow_column_header_visibility"])
                check_type(argname="argument vertical_overflow_visibility", value=vertical_overflow_visibility, expected_type=type_hints["vertical_overflow_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if overflow_column_header_visibility is not None:
                self._values["overflow_column_header_visibility"] = overflow_column_header_visibility
            if vertical_overflow_visibility is not None:
                self._values["vertical_overflow_visibility"] = vertical_overflow_visibility

        @builtins.property
        def overflow_column_header_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of repeating header rows on each page.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-overflowcolumnheadervisibility
            '''
            result = self._values.get("overflow_column_header_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def vertical_overflow_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of printing table overflow across pages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-verticaloverflowvisibility
            '''
            result = self._values.get("vertical_overflow_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TablePaginatedReportOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableRowConditionalFormattingProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "text_color": "textColor",
        },
    )
    class TableRowConditionalFormattingProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting of a table row.

            :param background_color: The conditional formatting color (solid, gradient) of the background for a table row.
            :param text_color: The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_row_conditional_formatting_property = quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f1c9e911c37af79e2d25562395fa0ee62ba9e93b10a66dbdd5ee049463bc377d)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting color (solid, gradient) of the background for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting color (solid, gradient) of the text for a table row.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableRowConditionalFormattingProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableSideBorderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bottom": "bottom",
            "inner_horizontal": "innerHorizontal",
            "inner_vertical": "innerVertical",
            "left": "left",
            "right": "right",
            "top": "top",
        },
    )
    class TableSideBorderOptionsProperty:
        def __init__(
            self,
            *,
            bottom: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            inner_horizontal: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            inner_vertical: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            left: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            right: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            top: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableBorderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The side border options for a table.

            :param bottom: The table border options of the bottom border.
            :param inner_horizontal: The table border options of the inner horizontal border.
            :param inner_vertical: The table border options of the inner vertical border.
            :param left: The table border options of the left border.
            :param right: The table border options of the right border.
            :param top: The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_side_border_options_property = quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    ),
                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                        color="color",
                        style="style",
                        thickness=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0965815ba024c08dbc7db699ef33a9768e98d2c8838a25bd3abb7fe6ad6b58f3)
                check_type(argname="argument bottom", value=bottom, expected_type=type_hints["bottom"])
                check_type(argname="argument inner_horizontal", value=inner_horizontal, expected_type=type_hints["inner_horizontal"])
                check_type(argname="argument inner_vertical", value=inner_vertical, expected_type=type_hints["inner_vertical"])
                check_type(argname="argument left", value=left, expected_type=type_hints["left"])
                check_type(argname="argument right", value=right, expected_type=type_hints["right"])
                check_type(argname="argument top", value=top, expected_type=type_hints["top"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bottom is not None:
                self._values["bottom"] = bottom
            if inner_horizontal is not None:
                self._values["inner_horizontal"] = inner_horizontal
            if inner_vertical is not None:
                self._values["inner_vertical"] = inner_vertical
            if left is not None:
                self._values["left"] = left
            if right is not None:
                self._values["right"] = right
            if top is not None:
                self._values["top"] = top

        @builtins.property
        def bottom(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the bottom border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-bottom
            '''
            result = self._values.get("bottom")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def inner_horizontal(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the inner horizontal border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innerhorizontal
            '''
            result = self._values.get("inner_horizontal")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def inner_vertical(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the inner vertical border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innervertical
            '''
            result = self._values.get("inner_vertical")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def left(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the left border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-left
            '''
            result = self._values.get("left")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def right(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the right border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-right
            '''
            result = self._values.get("right")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def top(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The table border options of the top border.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-top
            '''
            result = self._values.get("top")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableBorderOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSideBorderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "pagination_configuration": "paginationConfiguration",
            "row_sort": "rowSort",
        },
    )
    class TableSortConfigurationProperty:
        def __init__(
            self,
            *,
            pagination_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.PaginationConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration for a ``TableVisual`` .

            :param pagination_configuration: The pagination configuration (page size, page number) for the table.
            :param row_sort: The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_sort_configuration_property = quicksight.CfnTemplate.TableSortConfigurationProperty(
                    pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                        page_number=123,
                        page_size=123
                    ),
                    row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a81b8941b69efac22fd8c63bad6f8b7876271ce625e4acf918d0b8027472f49a)
                check_type(argname="argument pagination_configuration", value=pagination_configuration, expected_type=type_hints["pagination_configuration"])
                check_type(argname="argument row_sort", value=row_sort, expected_type=type_hints["row_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if pagination_configuration is not None:
                self._values["pagination_configuration"] = pagination_configuration
            if row_sort is not None:
                self._values["row_sort"] = row_sort

        @builtins.property
        def pagination_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PaginationConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The pagination configuration (page size, page number) for the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-paginationconfiguration
            '''
            result = self._values.get("pagination_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PaginationConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def row_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The field sort options for rows in the table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-rowsort
            '''
            result = self._values.get("row_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"values": "values"},
    )
    class TableUnaggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.UnaggregatedFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The unaggregated field well for the table.

            :param values: The values field well for a pivot table. Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_unaggregated_field_wells_property = quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                    values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        field_id="fieldId",
                
                        # the properties below are optional
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f0cae29d6b26026c4831d4976d084a40e531d8ae78548f69ccb6aa728b42323)
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.UnaggregatedFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The values field well for a pivot table.

            Values are unaggregated for an unaggregated table.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html#cfn-quicksight-template-tableunaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.UnaggregatedFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableUnaggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TableVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "conditional_formatting": "conditionalFormatting",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TableVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            conditional_formatting: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableConditionalFormattingProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param conditional_formatting: The conditional formatting for a ``PivotTableVisual`` .
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                table_visual_property = quicksight.CfnTemplate.TableVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                        field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                            order=["order"],
                            selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                custom_label="customLabel",
                                url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                    image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                        sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                            table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                        )
                                    ),
                                    link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                        content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                            custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                icon="icon"
                                            ),
                                            custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                
                                                # the properties below are optional
                                                value="value"
                                            )
                                        ),
                                        target="target"
                                    )
                                ),
                                visibility="visibility",
                                width="width"
                            )]
                        ),
                        field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                            table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                            overflow_column_header_visibility="overflowColumnHeaderVisibility",
                            vertical_overflow_visibility="verticalOverflowVisibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                            pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                page_number=123,
                                page_size=123
                            ),
                            row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                            data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                negative_color="negativeColor",
                                positive_color="positiveColor"
                            )
                        )],
                        table_options=quicksight.CfnTemplate.TableOptionsProperty(
                            cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            orientation="orientation",
                            row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                row_alternate_colors=["rowAlternateColors"],
                                status="status"
                            )
                        ),
                        total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                            custom_label="customLabel",
                            placement="placement",
                            scroll_status="scrollStatus",
                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                background_color="backgroundColor",
                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        ),
                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                        color="color",
                                        style="style",
                                        thickness=123
                                    )
                                ),
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                height=123,
                                horizontal_text_alignment="horizontalTextAlignment",
                                text_wrap="textWrap",
                                vertical_text_alignment="verticalTextAlignment",
                                visibility="visibility"
                            ),
                            totals_visibility="totalsVisibility"
                        )
                    ),
                    conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                        conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                            cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            ),
                            row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                ),
                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                gradient_offset=123,
                
                                                # the properties below are optional
                                                color="color",
                                                data_value=123
                                            )]
                                        ),
                                        expression="expression"
                                    ),
                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        color="color"
                                    )
                                )
                            )
                        )]
                    ),
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35e7ac5eab300d766411990183b82c2f155c103d8cf5f16a5abe9a257ba2329e)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument conditional_formatting", value=conditional_formatting, expected_type=type_hints["conditional_formatting"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if conditional_formatting is not None:
                self._values["conditional_formatting"] = conditional_formatting
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def conditional_formatting(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableConditionalFormattingProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for a ``PivotTableVisual`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-conditionalformatting
            '''
            result = self._values.get("conditional_formatting")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableConditionalFormattingProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TableVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TemplateErrorProperty",
        jsii_struct_bases=[],
        name_mapping={
            "message": "message",
            "type": "type",
            "violated_entities": "violatedEntities",
        },
    )
    class TemplateErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
            violated_entities: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.EntityProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''List of errors that occurred when the template version creation failed.

            :param message: Description of the error type.
            :param type: Type of error.
            :param violated_entities: An error path that shows which entities caused the template error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                template_error_property = quicksight.CfnTemplate.TemplateErrorProperty(
                    message="message",
                    type="type",
                    violated_entities=[quicksight.CfnTemplate.EntityProperty(
                        path="path"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__500a085582bc48e9c1f14845ca9df8136fc9c5b47eac0dc8108c7a9ea3b185f2)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument violated_entities", value=violated_entities, expected_type=type_hints["violated_entities"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type
            if violated_entities is not None:
                self._values["violated_entities"] = violated_entities

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''Description of the error type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''Type of error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def violated_entities(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.EntityProperty", _IResolvable_a771d0ef]]]]:
            '''An error path that shows which entities caused the template error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-violatedentities
            '''
            result = self._values.get("violated_entities")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.EntityProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TemplateSourceAnalysisProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn", "data_set_references": "dataSetReferences"},
    )
    class TemplateSourceAnalysisProperty:
        def __init__(
            self,
            *,
            arn: builtins.str,
            data_set_references: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataSetReferenceProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
        ) -> None:
            '''The source analysis of the template.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param data_set_references: A structure containing information about the dataset references used as placeholders in the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                template_source_analysis_property = quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                    arn="arn",
                    data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                        data_set_arn="dataSetArn",
                        data_set_placeholder="dataSetPlaceholder"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__79021f944eca1eb229847b8d82f047f4dcc81486945010cb7bbb725ff1124818)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument data_set_references", value=data_set_references, expected_type=type_hints["data_set_references"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
                "data_set_references": data_set_references,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def data_set_references(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataSetReferenceProperty", _IResolvable_a771d0ef]]]:
            '''A structure containing information about the dataset references used as placeholders in the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-datasetreferences
            '''
            result = self._values.get("data_set_references")
            assert result is not None, "Required property 'data_set_references' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataSetReferenceProperty", _IResolvable_a771d0ef]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceAnalysisProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TemplateSourceEntityProperty",
        jsii_struct_bases=[],
        name_mapping={
            "source_analysis": "sourceAnalysis",
            "source_template": "sourceTemplate",
        },
    )
    class TemplateSourceEntityProperty:
        def __init__(
            self,
            *,
            source_analysis: typing.Optional[typing.Union[typing.Union["CfnTemplate.TemplateSourceAnalysisProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            source_template: typing.Optional[typing.Union[typing.Union["CfnTemplate.TemplateSourceTemplateProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The source entity of the template.

            :param source_analysis: The source analysis, if it is based on an analysis.
            :param source_template: The source template, if it is based on an template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                template_source_entity_property = quicksight.CfnTemplate.TemplateSourceEntityProperty(
                    source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    ),
                    source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                        arn="arn"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b152ab3c446928c2cc5b99951b6308a6ccce5abab28050d0cd3024fb946bffb1)
                check_type(argname="argument source_analysis", value=source_analysis, expected_type=type_hints["source_analysis"])
                check_type(argname="argument source_template", value=source_template, expected_type=type_hints["source_template"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if source_analysis is not None:
                self._values["source_analysis"] = source_analysis
            if source_template is not None:
                self._values["source_template"] = source_template

        @builtins.property
        def source_analysis(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TemplateSourceAnalysisProperty", _IResolvable_a771d0ef]]:
            '''The source analysis, if it is based on an analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourceanalysis
            '''
            result = self._values.get("source_analysis")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TemplateSourceAnalysisProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def source_template(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TemplateSourceTemplateProperty", _IResolvable_a771d0ef]]:
            '''The source template, if it is based on an template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourcetemplate
            '''
            result = self._values.get("source_template")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TemplateSourceTemplateProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceEntityProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TemplateSourceTemplateProperty",
        jsii_struct_bases=[],
        name_mapping={"arn": "arn"},
    )
    class TemplateSourceTemplateProperty:
        def __init__(self, *, arn: builtins.str) -> None:
            '''The source template of the template.

            :param arn: The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                template_source_template_property = quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                    arn="arn"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1986494b19f109bde16feff032d3456b79cb02303508959f8e28b7372d2825d6)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "arn": arn,
            }

        @builtins.property
        def arn(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html#cfn-quicksight-template-templatesourcetemplate-arn
            '''
            result = self._values.get("arn")
            assert result is not None, "Required property 'arn' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateSourceTemplateProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TemplateVersionDefinitionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_set_configurations": "dataSetConfigurations",
            "analysis_defaults": "analysisDefaults",
            "calculated_fields": "calculatedFields",
            "column_configurations": "columnConfigurations",
            "filter_groups": "filterGroups",
            "parameter_declarations": "parameterDeclarations",
            "sheets": "sheets",
        },
    )
    class TemplateVersionDefinitionProperty:
        def __init__(
            self,
            *,
            data_set_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataSetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            analysis_defaults: typing.Optional[typing.Union[typing.Union["CfnTemplate.AnalysisDefaultsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            calculated_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.CalculatedFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            column_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            filter_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FilterGroupProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            parameter_declarations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ParameterDeclarationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SheetDefinitionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The detailed definition of a template.

            :param data_set_configurations: An array of dataset configurations. These configurations define the required columns for each dataset used within a template.
            :param analysis_defaults: ``CfnTemplate.TemplateVersionDefinitionProperty.AnalysisDefaults``.
            :param calculated_fields: An array of calculated field definitions for the template.
            :param column_configurations: An array of template-level column configurations. Column configurations are used to set default formatting for a column that's used throughout a template.
            :param filter_groups: Filter definitions for a template. For more information, see `Filtering Data <https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html>`_ in the *Amazon QuickSight User Guide* .
            :param parameter_declarations: An array of parameter declarations for a template. *Parameters* are named variables that can transfer a value for use by an action or an object. For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .
            :param sheets: An array of sheet definitions for a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                template_version_definition_property = quicksight.CfnTemplate.TemplateVersionDefinitionProperty(
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
                
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnTemplate.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnTemplate.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnTemplate.ColumnConfigurationProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                                color="color",
                
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnTemplate.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnTemplate.FilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
                
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
                
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
                
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
                
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
                
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnTemplate.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                            name="name",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
                
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
                
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnTemplate.SheetDefinitionProperty(
                        sheet_id="sheetId",
                
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnTemplate.LayoutProperty(
                            configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
                
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
                
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
                
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
                
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
                
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                            configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
                
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
                
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
                
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
                
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnTemplate.VisualProperty(
                            bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                    computations=[quicksight.CfnTemplate.ComputationProperty(
                                        forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
                
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
                
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
                
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
                
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnTemplate.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                        arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
                
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                                column=quicksight.CfnTemplate.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnTemplate.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnTemplate.TableVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
                
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
                
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
                
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
                
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
                
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
                
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
                
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
                
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
                
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                                visual_id="visualId",
                
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
                
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
                
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
                
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
                
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__39510fb860e6add8b350bfe679475ea355edafb2f190a845f987566e3d64f3fc)
                check_type(argname="argument data_set_configurations", value=data_set_configurations, expected_type=type_hints["data_set_configurations"])
                check_type(argname="argument analysis_defaults", value=analysis_defaults, expected_type=type_hints["analysis_defaults"])
                check_type(argname="argument calculated_fields", value=calculated_fields, expected_type=type_hints["calculated_fields"])
                check_type(argname="argument column_configurations", value=column_configurations, expected_type=type_hints["column_configurations"])
                check_type(argname="argument filter_groups", value=filter_groups, expected_type=type_hints["filter_groups"])
                check_type(argname="argument parameter_declarations", value=parameter_declarations, expected_type=type_hints["parameter_declarations"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "data_set_configurations": data_set_configurations,
            }
            if analysis_defaults is not None:
                self._values["analysis_defaults"] = analysis_defaults
            if calculated_fields is not None:
                self._values["calculated_fields"] = calculated_fields
            if column_configurations is not None:
                self._values["column_configurations"] = column_configurations
            if filter_groups is not None:
                self._values["filter_groups"] = filter_groups
            if parameter_declarations is not None:
                self._values["parameter_declarations"] = parameter_declarations
            if sheets is not None:
                self._values["sheets"] = sheets

        @builtins.property
        def data_set_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataSetConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''An array of dataset configurations.

            These configurations define the required columns for each dataset used within a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-datasetconfigurations
            '''
            result = self._values.get("data_set_configurations")
            assert result is not None, "Required property 'data_set_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataSetConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def analysis_defaults(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AnalysisDefaultsProperty", _IResolvable_a771d0ef]]:
            '''``CfnTemplate.TemplateVersionDefinitionProperty.AnalysisDefaults``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-analysisdefaults
            '''
            result = self._values.get("analysis_defaults")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AnalysisDefaultsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def calculated_fields(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.CalculatedFieldProperty", _IResolvable_a771d0ef]]]]:
            '''An array of calculated field definitions for the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-calculatedfields
            '''
            result = self._values.get("calculated_fields")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.CalculatedFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def column_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''An array of template-level column configurations.

            Column configurations are used to set default formatting for a column that's used throughout a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-columnconfigurations
            '''
            result = self._values.get("column_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def filter_groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilterGroupProperty", _IResolvable_a771d0ef]]]]:
            '''Filter definitions for a template.

            For more information, see `Filtering Data <https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-filtergroups
            '''
            result = self._values.get("filter_groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FilterGroupProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def parameter_declarations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ParameterDeclarationProperty", _IResolvable_a771d0ef]]]]:
            '''An array of parameter declarations for a template.

            *Parameters* are named variables that can transfer a value for use by an action or an object.

            For more information, see `Parameters in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-parameterdeclarations
            '''
            result = self._values.get("parameter_declarations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ParameterDeclarationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetDefinitionProperty", _IResolvable_a771d0ef]]]]:
            '''An array of sheet definitions for a template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetDefinitionProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateVersionDefinitionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TemplateVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "created_time": "createdTime",
            "data_set_configurations": "dataSetConfigurations",
            "description": "description",
            "errors": "errors",
            "sheets": "sheets",
            "source_entity_arn": "sourceEntityArn",
            "status": "status",
            "theme_arn": "themeArn",
            "version_number": "versionNumber",
        },
    )
    class TemplateVersionProperty:
        def __init__(
            self,
            *,
            created_time: typing.Optional[builtins.str] = None,
            data_set_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataSetConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.TemplateErrorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.SheetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            source_entity_arn: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            theme_arn: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A version of a template.

            :param created_time: The time that this template version was created.
            :param data_set_configurations: Schema of the dataset identified by the placeholder. Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.
            :param description: The description of the template.
            :param errors: Errors associated with this template version.
            :param sheets: A list of the associated sheets with the unique identifier and name of each sheet.
            :param source_entity_arn: The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
            :param status: The status that is associated with the template. - ``CREATION_IN_PROGRESS`` - ``CREATION_SUCCESSFUL`` - ``CREATION_FAILED`` - ``UPDATE_IN_PROGRESS`` - ``UPDATE_SUCCESSFUL`` - ``UPDATE_FAILED`` - ``DELETED``
            :param theme_arn: The ARN of the theme associated with this version of the template.
            :param version_number: The version number of the template version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                template_version_property = quicksight.CfnTemplate.TemplateVersionProperty(
                    created_time="createdTime",
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
                    description="description",
                    errors=[quicksight.CfnTemplate.TemplateErrorProperty(
                        message="message",
                        type="type",
                        violated_entities=[quicksight.CfnTemplate.EntityProperty(
                            path="path"
                        )]
                    )],
                    sheets=[quicksight.CfnTemplate.SheetProperty(
                        name="name",
                        sheet_id="sheetId"
                    )],
                    source_entity_arn="sourceEntityArn",
                    status="status",
                    theme_arn="themeArn",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ea5d025f8c385f6d90fb2ad675905cd3b5e93d7b90a4f1557cd594fcdafbeef4)
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument data_set_configurations", value=data_set_configurations, expected_type=type_hints["data_set_configurations"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument sheets", value=sheets, expected_type=type_hints["sheets"])
                check_type(argname="argument source_entity_arn", value=source_entity_arn, expected_type=type_hints["source_entity_arn"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument theme_arn", value=theme_arn, expected_type=type_hints["theme_arn"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if created_time is not None:
                self._values["created_time"] = created_time
            if data_set_configurations is not None:
                self._values["data_set_configurations"] = data_set_configurations
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if sheets is not None:
                self._values["sheets"] = sheets
            if source_entity_arn is not None:
                self._values["source_entity_arn"] = source_entity_arn
            if status is not None:
                self._values["status"] = status
            if theme_arn is not None:
                self._values["theme_arn"] = theme_arn
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The time that this template version was created.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def data_set_configurations(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataSetConfigurationProperty", _IResolvable_a771d0ef]]]]:
            '''Schema of the dataset identified by the placeholder.

            Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-datasetconfigurations
            '''
            result = self._values.get("data_set_configurations")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataSetConfigurationProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description of the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TemplateErrorProperty", _IResolvable_a771d0ef]]]]:
            '''Errors associated with this template version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.TemplateErrorProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sheets(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetProperty", _IResolvable_a771d0ef]]]]:
            '''A list of the associated sheets with the unique identifier and name of each sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sheets
            '''
            result = self._values.get("sheets")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.SheetProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def source_entity_arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sourceentityarn
            '''
            result = self._values.get("source_entity_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status that is associated with the template.

            - ``CREATION_IN_PROGRESS``
            - ``CREATION_SUCCESSFUL``
            - ``CREATION_FAILED``
            - ``UPDATE_IN_PROGRESS``
            - ``UPDATE_SUCCESSFUL``
            - ``UPDATE_FAILED``
            - ``DELETED``

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def theme_arn(self) -> typing.Optional[builtins.str]:
            '''The ARN of the theme associated with this version of the template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-themearn
            '''
            result = self._values.get("theme_arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''The version number of the template version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TemplateVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextAreaControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text area control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_area_control_display_options_property = quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__84375717581db366e1324c0bdde09a17f42ef288567c38fe8edf01196dedf4fd)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the placeholder options in a text area control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextAreaControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TextConditionalFormatProperty",
        jsii_struct_bases=[],
        name_mapping={
            "background_color": "backgroundColor",
            "icon": "icon",
            "text_color": "textColor",
        },
    )
    class TextConditionalFormatProperty:
        def __init__(
            self,
            *,
            background_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            icon: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            text_color: typing.Optional[typing.Union[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The conditional formatting for the text.

            :param background_color: The conditional formatting for the text background color.
            :param icon: The conditional formatting for the icon.
            :param text_color: The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_conditional_format_property = quicksight.CfnTemplate.TextConditionalFormatProperty(
                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    ),
                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                            expression="expression",
                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                icon="icon",
                                unicode_icon="unicodeIcon"
                            ),
                
                            # the properties below are optional
                            color="color",
                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                icon_display_option="iconDisplayOption"
                            )
                        ),
                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                            expression="expression",
                
                            # the properties below are optional
                            icon_set_type="iconSetType"
                        )
                    ),
                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                            color=quicksight.CfnTemplate.GradientColorProperty(
                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                    gradient_offset=123,
                
                                    # the properties below are optional
                                    color="color",
                                    data_value=123
                                )]
                            ),
                            expression="expression"
                        ),
                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                            expression="expression",
                
                            # the properties below are optional
                            color="color"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9ba043d8664f9ca678ed3ce58c48bea9b4bb06fe69a96534464ad0beabc71b2c)
                check_type(argname="argument background_color", value=background_color, expected_type=type_hints["background_color"])
                check_type(argname="argument icon", value=icon, expected_type=type_hints["icon"])
                check_type(argname="argument text_color", value=text_color, expected_type=type_hints["text_color"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if background_color is not None:
                self._values["background_color"] = background_color
            if icon is not None:
                self._values["icon"] = icon
            if text_color is not None:
                self._values["text_color"] = text_color

        @builtins.property
        def background_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the text background color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-backgroundcolor
            '''
            result = self._values.get("background_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def icon(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the icon.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-icon
            '''
            result = self._values.get("icon")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingIconProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def text_color(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]]:
            '''The conditional formatting for the text color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-textcolor
            '''
            result = self._values.get("text_color")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ConditionalFormattingColorProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextConditionalFormatProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TextControlPlaceholderOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The configuration of the placeholder options in a text control.

            :param visibility: The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_control_placeholder_options_property = quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__61429e252c541a6c92e4690ced62509dff79b4692f3ae9fcdee3e55789b2fd56)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration of the placeholder options in a text control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html#cfn-quicksight-template-textcontrolplaceholderoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextControlPlaceholderOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "placeholder_options": "placeholderOptions",
            "title_options": "titleOptions",
        },
    )
    class TextFieldControlDisplayOptionsProperty:
        def __init__(
            self,
            *,
            placeholder_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.LabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options of a control.

            :param placeholder_options: The configuration of the placeholder options in a text field control.
            :param title_options: The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                text_field_control_display_options_property = quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                        visibility="visibility"
                    ),
                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                        custom_label="customLabel",
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a8817efaca677f6538e3b73bfb422383f72bbb94342f50506bc54c30faef30f9)
                check_type(argname="argument placeholder_options", value=placeholder_options, expected_type=type_hints["placeholder_options"])
                check_type(argname="argument title_options", value=title_options, expected_type=type_hints["title_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if placeholder_options is not None:
                self._values["placeholder_options"] = placeholder_options
            if title_options is not None:
                self._values["title_options"] = title_options

        @builtins.property
        def placeholder_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]]:
            '''The configuration of the placeholder options in a text field control.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-placeholderoptions
            '''
            result = self._values.get("placeholder_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TextControlPlaceholderOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options to configure the title visibility, name, and font size.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-titleoptions
            '''
            result = self._values.get("title_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TextFieldControlDisplayOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.ThousandSeparatorOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"symbol": "symbol", "visibility": "visibility"},
    )
    class ThousandSeparatorOptionsProperty:
        def __init__(
            self,
            *,
            symbol: typing.Optional[builtins.str] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the thousands separator configuration.

            :param symbol: Determines the thousands separator symbol.
            :param visibility: Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                thousand_separator_options_property = quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                    symbol="symbol",
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__3434f8795252f1a77b51f10bc1712aba04373e47413f4b160c924abe4d32a91d)
                check_type(argname="argument symbol", value=symbol, expected_type=type_hints["symbol"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if symbol is not None:
                self._values["symbol"] = symbol
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def symbol(self) -> typing.Optional[builtins.str]:
            '''Determines the thousands separator symbol.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-symbol
            '''
            result = self._values.get("symbol")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''Determines the visibility of the thousands separator.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThousandSeparatorOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty",
        jsii_struct_bases=[],
        name_mapping={
            "lower_boundary": "lowerBoundary",
            "periods_backward": "periodsBackward",
            "periods_forward": "periodsForward",
            "prediction_interval": "predictionInterval",
            "seasonality": "seasonality",
            "upper_boundary": "upperBoundary",
        },
    )
    class TimeBasedForecastPropertiesProperty:
        def __init__(
            self,
            *,
            lower_boundary: typing.Optional[jsii.Number] = None,
            periods_backward: typing.Optional[jsii.Number] = None,
            periods_forward: typing.Optional[jsii.Number] = None,
            prediction_interval: typing.Optional[jsii.Number] = None,
            seasonality: typing.Optional[jsii.Number] = None,
            upper_boundary: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''The forecast properties setup of a forecast in the line chart.

            :param lower_boundary: The lower boundary setup of a forecast computation.
            :param periods_backward: The periods backward setup of a forecast computation.
            :param periods_forward: The periods forward setup of a forecast computation.
            :param prediction_interval: The prediction interval setup of a forecast computation.
            :param seasonality: The seasonality setup of a forecast computation. Choose one of the following options:. - ``NULL`` : The input is set to ``NULL`` . - ``NON_NULL`` : The input is set to a custom value.
            :param upper_boundary: The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_based_forecast_properties_property = quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                    lower_boundary=123,
                    periods_backward=123,
                    periods_forward=123,
                    prediction_interval=123,
                    seasonality=123,
                    upper_boundary=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__bfad9cea026b1373063e417f507f22e467e93bdab69c3e3d25fac59c1974de8b)
                check_type(argname="argument lower_boundary", value=lower_boundary, expected_type=type_hints["lower_boundary"])
                check_type(argname="argument periods_backward", value=periods_backward, expected_type=type_hints["periods_backward"])
                check_type(argname="argument periods_forward", value=periods_forward, expected_type=type_hints["periods_forward"])
                check_type(argname="argument prediction_interval", value=prediction_interval, expected_type=type_hints["prediction_interval"])
                check_type(argname="argument seasonality", value=seasonality, expected_type=type_hints["seasonality"])
                check_type(argname="argument upper_boundary", value=upper_boundary, expected_type=type_hints["upper_boundary"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if lower_boundary is not None:
                self._values["lower_boundary"] = lower_boundary
            if periods_backward is not None:
                self._values["periods_backward"] = periods_backward
            if periods_forward is not None:
                self._values["periods_forward"] = periods_forward
            if prediction_interval is not None:
                self._values["prediction_interval"] = prediction_interval
            if seasonality is not None:
                self._values["seasonality"] = seasonality
            if upper_boundary is not None:
                self._values["upper_boundary"] = upper_boundary

        @builtins.property
        def lower_boundary(self) -> typing.Optional[jsii.Number]:
            '''The lower boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-lowerboundary
            '''
            result = self._values.get("lower_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_backward(self) -> typing.Optional[jsii.Number]:
            '''The periods backward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsbackward
            '''
            result = self._values.get("periods_backward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def periods_forward(self) -> typing.Optional[jsii.Number]:
            '''The periods forward setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsforward
            '''
            result = self._values.get("periods_forward")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def prediction_interval(self) -> typing.Optional[jsii.Number]:
            '''The prediction interval setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-predictioninterval
            '''
            result = self._values.get("prediction_interval")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def seasonality(self) -> typing.Optional[jsii.Number]:
            '''The seasonality setup of a forecast computation. Choose one of the following options:.

            - ``NULL`` : The input is set to ``NULL`` .
            - ``NON_NULL`` : The input is set to a custom value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-seasonality
            '''
            result = self._values.get("seasonality")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def upper_boundary(self) -> typing.Optional[jsii.Number]:
            '''The upper boundary setup of a forecast computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-upperboundary
            '''
            result = self._values.get("upper_boundary")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeBasedForecastPropertiesProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TimeEqualityFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
            "value": "value",
        },
    )
    class TimeEqualityFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
            value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeEqualityFilter`` filters values that are equal to a given value.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param parameter_name: The parameter whose value should be used for the filter value. This field is mutually exclusive to ``Value`` .
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.
            :param value: The value of a ``TimeEquality`` filter. This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_equality_filter_property = quicksight.CfnTemplate.TimeEqualityFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    parameter_name="parameterName",
                    time_granularity="timeGranularity",
                    value="value"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c2a5ed4b017cab5872752cdb9b970986cfe28b000b4455fe28660f90e5675ec8)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
            }
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            This field is mutually exclusive to ``Value`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(self) -> typing.Optional[builtins.str]:
            '''The value of a ``TimeEquality`` filter.

            This field is mutually exclusive to ``ParameterName`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeEqualityFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "range_maximum": "rangeMaximum",
            "range_minimum": "rangeMinimum",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeDrillDownFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            range_maximum: builtins.str,
            range_minimum: builtins.str,
            time_granularity: builtins.str,
        ) -> None:
            '''The time range drill down filter.

            :param column: The column that the filter is applied to.
            :param range_maximum: The maximum value for the filter value range.
            :param range_minimum: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_drill_down_filter_property = quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    range_maximum="rangeMaximum",
                    range_minimum="rangeMinimum",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__259141eece1493a338b143fab066ab513cbaeecded382919e1c363db3721bf94)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument range_maximum", value=range_maximum, expected_type=type_hints["range_maximum"])
                check_type(argname="argument range_minimum", value=range_minimum, expected_type=type_hints["range_minimum"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "range_maximum": range_maximum,
                "range_minimum": range_minimum,
                "time_granularity": time_granularity,
            }

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def range_maximum(self) -> builtins.str:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangemaximum
            '''
            result = self._values.get("range_maximum")
            assert result is not None, "Required property 'range_maximum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def range_minimum(self) -> builtins.str:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangeminimum
            '''
            result = self._values.get("range_minimum")
            assert result is not None, "Required property 'range_minimum' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time_granularity(self) -> builtins.str:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            assert result is not None, "Required property 'time_granularity' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeDrillDownFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TimeRangeFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "filter_id": "filterId",
            "null_option": "nullOption",
            "exclude_period_configuration": "excludePeriodConfiguration",
            "include_maximum": "includeMaximum",
            "include_minimum": "includeMinimum",
            "range_maximum_value": "rangeMaximumValue",
            "range_minimum_value": "rangeMinimumValue",
            "time_granularity": "timeGranularity",
        },
    )
    class TimeRangeFilterProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            null_option: builtins.str,
            exclude_period_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
            range_maximum_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            range_minimum_value: typing.Optional[typing.Union[typing.Union["CfnTemplate.TimeRangeFilterValueProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TimeRangeFilter`` filters values that are between two specified values.

            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param null_option: This option determines how null values should be treated when filtering data. - ``ALL_VALUES`` : Include null values in filtered results. - ``NULLS_ONLY`` : Only include null values in filtered results. - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.
            :param exclude_period_configuration: The exclude period of the time range filter.
            :param include_maximum: Determines whether the maximum value in the filter value range should be included in the filtered results.
            :param include_minimum: Determines whether the minimum value in the filter value range should be included in the filtered results.
            :param range_maximum_value: The maximum value for the filter value range.
            :param range_minimum_value: The minimum value for the filter value range.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_filter_property = quicksight.CfnTemplate.TimeRangeFilterProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                    null_option="nullOption",
                
                    # the properties below are optional
                    exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                        amount=123,
                        granularity="granularity",
                
                        # the properties below are optional
                        status="status"
                    ),
                    include_maximum=False,
                    include_minimum=False,
                    range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                        parameter="parameter",
                        rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                            expression="expression",
                
                            # the properties below are optional
                            data_set_identifier="dataSetIdentifier"
                        ),
                        static_value="staticValue"
                    ),
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__42fa666fe82e0e32a1787640e349ea1df8bf0eada07733c1d4ba8b3b1f6dc4c0)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument null_option", value=null_option, expected_type=type_hints["null_option"])
                check_type(argname="argument exclude_period_configuration", value=exclude_period_configuration, expected_type=type_hints["exclude_period_configuration"])
                check_type(argname="argument include_maximum", value=include_maximum, expected_type=type_hints["include_maximum"])
                check_type(argname="argument include_minimum", value=include_minimum, expected_type=type_hints["include_minimum"])
                check_type(argname="argument range_maximum_value", value=range_maximum_value, expected_type=type_hints["range_maximum_value"])
                check_type(argname="argument range_minimum_value", value=range_minimum_value, expected_type=type_hints["range_minimum_value"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "filter_id": filter_id,
                "null_option": null_option,
            }
            if exclude_period_configuration is not None:
                self._values["exclude_period_configuration"] = exclude_period_configuration
            if include_maximum is not None:
                self._values["include_maximum"] = include_maximum
            if include_minimum is not None:
                self._values["include_minimum"] = include_minimum
            if range_maximum_value is not None:
                self._values["range_maximum_value"] = range_maximum_value
            if range_minimum_value is not None:
                self._values["range_minimum_value"] = range_minimum_value
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def null_option(self) -> builtins.str:
            '''This option determines how null values should be treated when filtering data.

            - ``ALL_VALUES`` : Include null values in filtered results.
            - ``NULLS_ONLY`` : Only include null values in filtered results.
            - ``NON_NULLS_ONLY`` : Exclude null values from filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-nulloption
            '''
            result = self._values.get("null_option")
            assert result is not None, "Required property 'null_option' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def exclude_period_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The exclude period of the time range filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-excludeperiodconfiguration
            '''
            result = self._values.get("exclude_period_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ExcludePeriodConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_maximum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the maximum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includemaximum
            '''
            result = self._values.get("include_maximum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def include_minimum(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''Determines whether the minimum value in the filter value range should be included in the filtered results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includeminimum
            '''
            result = self._values.get("include_minimum")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_maximum_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The maximum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangemaximumvalue
            '''
            result = self._values.get("range_maximum_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def range_minimum_value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]]:
            '''The minimum value for the filter value range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangeminimumvalue
            '''
            result = self._values.get("range_minimum_value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TimeRangeFilterValueProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TimeRangeFilterValueProperty",
        jsii_struct_bases=[],
        name_mapping={
            "parameter": "parameter",
            "rolling_date": "rollingDate",
            "static_value": "staticValue",
        },
    )
    class TimeRangeFilterValueProperty:
        def __init__(
            self,
            *,
            parameter: typing.Optional[builtins.str] = None,
            rolling_date: typing.Optional[typing.Union[typing.Union["CfnTemplate.RollingDateConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            static_value: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The value of a time range filter.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param parameter: The parameter type input value.
            :param rolling_date: The rolling date input value.
            :param static_value: The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                time_range_filter_value_property = quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                    parameter="parameter",
                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                        expression="expression",
                
                        # the properties below are optional
                        data_set_identifier="dataSetIdentifier"
                    ),
                    static_value="staticValue"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__df85e43accecb39b61d7577981c426ff58c439ab6e806417024c054dda7f204e)
                check_type(argname="argument parameter", value=parameter, expected_type=type_hints["parameter"])
                check_type(argname="argument rolling_date", value=rolling_date, expected_type=type_hints["rolling_date"])
                check_type(argname="argument static_value", value=static_value, expected_type=type_hints["static_value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if parameter is not None:
                self._values["parameter"] = parameter
            if rolling_date is not None:
                self._values["rolling_date"] = rolling_date
            if static_value is not None:
                self._values["static_value"] = static_value

        @builtins.property
        def parameter(self) -> typing.Optional[builtins.str]:
            '''The parameter type input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-parameter
            '''
            result = self._values.get("parameter")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def rolling_date(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RollingDateConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The rolling date input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-rollingdate
            '''
            result = self._values.get("rolling_date")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RollingDateConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def static_value(self) -> typing.Optional[builtins.str]:
            '''The static input value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-staticvalue
            '''
            result = self._values.get("static_value")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TimeRangeFilterValueProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TooltipItemProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column_tooltip_item": "columnTooltipItem",
            "field_tooltip_item": "fieldTooltipItem",
        },
    )
    class TooltipItemProperty:
        def __init__(
            self,
            *,
            column_tooltip_item: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColumnTooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_tooltip_item: typing.Optional[typing.Union[typing.Union["CfnTemplate.FieldTooltipItemProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The tooltip.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param column_tooltip_item: The tooltip item for the columns that are not part of a field well.
            :param field_tooltip_item: The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tooltip_item_property = quicksight.CfnTemplate.TooltipItemProperty(
                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                
                        # the properties below are optional
                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        label="label",
                        visibility="visibility"
                    ),
                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                        field_id="fieldId",
                
                        # the properties below are optional
                        label="label",
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fa3dbf4c785b155bbd05f0995562211f248d32e220b854cca0d7a32f967182cc)
                check_type(argname="argument column_tooltip_item", value=column_tooltip_item, expected_type=type_hints["column_tooltip_item"])
                check_type(argname="argument field_tooltip_item", value=field_tooltip_item, expected_type=type_hints["field_tooltip_item"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if column_tooltip_item is not None:
                self._values["column_tooltip_item"] = column_tooltip_item
            if field_tooltip_item is not None:
                self._values["field_tooltip_item"] = field_tooltip_item

        @builtins.property
        def column_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColumnTooltipItemProperty", _IResolvable_a771d0ef]]:
            '''The tooltip item for the columns that are not part of a field well.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-columntooltipitem
            '''
            result = self._values.get("column_tooltip_item")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColumnTooltipItemProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_tooltip_item(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FieldTooltipItemProperty", _IResolvable_a771d0ef]]:
            '''The tooltip item for the fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-fieldtooltipitem
            '''
            result = self._values.get("field_tooltip_item")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FieldTooltipItemProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipItemProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TooltipOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "field_based_tooltip": "fieldBasedTooltip",
            "selected_tooltip_type": "selectedTooltipType",
            "tooltip_visibility": "tooltipVisibility",
        },
    )
    class TooltipOptionsProperty:
        def __init__(
            self,
            *,
            field_based_tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.FieldBasedTooltipProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            selected_tooltip_type: typing.Optional[builtins.str] = None,
            tooltip_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The display options for the visual tooltip.

            :param field_based_tooltip: The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
            :param selected_tooltip_type: The selected type for the tooltip. Choose one of the following options:. - ``BASIC`` : A basic tooltip. - ``DETAILED`` : A detailed tooltip.
            :param tooltip_visibility: Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tooltip_options_property = quicksight.CfnTemplate.TooltipOptionsProperty(
                    field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                        aggregation_visibility="aggregationVisibility",
                        tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                            column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                label="label",
                                visibility="visibility"
                            ),
                            field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                field_id="fieldId",
                
                                # the properties below are optional
                                label="label",
                                visibility="visibility"
                            )
                        )],
                        tooltip_title_type="tooltipTitleType"
                    ),
                    selected_tooltip_type="selectedTooltipType",
                    tooltip_visibility="tooltipVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fc163338ed93c143a54bfff923aa0f35010ca88b668ceb1c546c90d2ddd932b1)
                check_type(argname="argument field_based_tooltip", value=field_based_tooltip, expected_type=type_hints["field_based_tooltip"])
                check_type(argname="argument selected_tooltip_type", value=selected_tooltip_type, expected_type=type_hints["selected_tooltip_type"])
                check_type(argname="argument tooltip_visibility", value=tooltip_visibility, expected_type=type_hints["tooltip_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if field_based_tooltip is not None:
                self._values["field_based_tooltip"] = field_based_tooltip
            if selected_tooltip_type is not None:
                self._values["selected_tooltip_type"] = selected_tooltip_type
            if tooltip_visibility is not None:
                self._values["tooltip_visibility"] = tooltip_visibility

        @builtins.property
        def field_based_tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FieldBasedTooltipProperty", _IResolvable_a771d0ef]]:
            '''The setup for the detailed tooltip.

            The tooltip setup is always saved. The display type is decided based on the tooltip type.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-fieldbasedtooltip
            '''
            result = self._values.get("field_based_tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FieldBasedTooltipProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def selected_tooltip_type(self) -> typing.Optional[builtins.str]:
            '''The selected type for the tooltip. Choose one of the following options:.

            - ``BASIC`` : A basic tooltip.
            - ``DETAILED`` : A detailed tooltip.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-selectedtooltiptype
            '''
            result = self._values.get("selected_tooltip_type")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def tooltip_visibility(self) -> typing.Optional[builtins.str]:
            '''Determines whether or not the tooltip is visible.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-tooltipvisibility
            '''
            result = self._values.get("tooltip_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TooltipOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TopBottomFilterProperty",
        jsii_struct_bases=[],
        name_mapping={
            "aggregation_sort_configurations": "aggregationSortConfigurations",
            "column": "column",
            "filter_id": "filterId",
            "limit": "limit",
            "parameter_name": "parameterName",
            "time_granularity": "timeGranularity",
        },
    )
    class TopBottomFilterProperty:
        def __init__(
            self,
            *,
            aggregation_sort_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.AggregationSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            filter_id: builtins.str,
            limit: typing.Optional[jsii.Number] = None,
            parameter_name: typing.Optional[builtins.str] = None,
            time_granularity: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A ``TopBottomFilter`` filters values that are at the top or the bottom.

            :param aggregation_sort_configurations: The aggregation and sort configuration of the top bottom filter.
            :param column: The column that the filter is applied to.
            :param filter_id: An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
            :param limit: The number of items to include in the top bottom filter results.
            :param parameter_name: The parameter whose value should be used for the filter value.
            :param time_granularity: The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_filter_property = quicksight.CfnTemplate.TopBottomFilterProperty(
                    aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                            categorical_aggregation_function="categoricalAggregationFunction",
                            date_aggregation_function="dateAggregationFunction",
                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            )
                        ),
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
                        sort_direction="sortDirection"
                    )],
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    filter_id="filterId",
                
                    # the properties below are optional
                    limit=123,
                    parameter_name="parameterName",
                    time_granularity="timeGranularity"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b82d66d58cc3cdc2b303a5ca47f0074c043c93555779b4831ddd6bb377f970e4)
                check_type(argname="argument aggregation_sort_configurations", value=aggregation_sort_configurations, expected_type=type_hints["aggregation_sort_configurations"])
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument filter_id", value=filter_id, expected_type=type_hints["filter_id"])
                check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
                check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
                check_type(argname="argument time_granularity", value=time_granularity, expected_type=type_hints["time_granularity"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "aggregation_sort_configurations": aggregation_sort_configurations,
                "column": column,
                "filter_id": filter_id,
            }
            if limit is not None:
                self._values["limit"] = limit
            if parameter_name is not None:
                self._values["parameter_name"] = parameter_name
            if time_granularity is not None:
                self._values["time_granularity"] = time_granularity

        @builtins.property
        def aggregation_sort_configurations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.AggregationSortConfigurationProperty", _IResolvable_a771d0ef]]]:
            '''The aggregation and sort configuration of the top bottom filter.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-aggregationsortconfigurations
            '''
            result = self._values.get("aggregation_sort_configurations")
            assert result is not None, "Required property 'aggregation_sort_configurations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.AggregationSortConfigurationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that the filter is applied to.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def filter_id(self) -> builtins.str:
            '''An identifier that uniquely identifies a filter within a dashboard, analysis, or template.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-filterid
            '''
            result = self._values.get("filter_id")
            assert result is not None, "Required property 'filter_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def limit(self) -> typing.Optional[jsii.Number]:
            '''The number of items to include in the top bottom filter results.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-limit
            '''
            result = self._values.get("limit")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def parameter_name(self) -> typing.Optional[builtins.str]:
            '''The parameter whose value should be used for the filter value.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-parametername
            '''
            result = self._values.get("parameter_name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def time_granularity(self) -> typing.Optional[builtins.str]:
            '''The level of time precision that is used to aggregate ``DateTime`` values.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-timegranularity
            '''
            result = self._values.get("time_granularity")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomFilterProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TopBottomMoversComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "time": "time",
            "type": "type",
            "mover_size": "moverSize",
            "name": "name",
            "sort_order": "sortOrder",
            "value": "value",
        },
    )
    class TopBottomMoversComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            time: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            type: builtins.str,
            mover_size: typing.Optional[jsii.Number] = None,
            name: typing.Optional[builtins.str] = None,
            sort_order: typing.Optional[builtins.str] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The top movers and bottom movers computation setup.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param time: The time field that is used in a computation.
            :param type: The computation type. Choose from the following options:. - TOP: Top movers computation. - BOTTOM: Bottom movers computation.
            :param mover_size: The mover size setup of the top and bottom movers computation.
            :param name: The name of a computation.
            :param sort_order: The sort order setup of the top and bottom movers computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_movers_computation_property = quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    type="type",
                
                    # the properties below are optional
                    mover_size=123,
                    name="name",
                    sort_order="sortOrder",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__35a2bc6605b57061fc281317a286e02c39af296d2becc23dd40deab5252838cc)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument time", value=time, expected_type=type_hints["time"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument mover_size", value=mover_size, expected_type=type_hints["mover_size"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument sort_order", value=sort_order, expected_type=type_hints["sort_order"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "time": time,
                "type": type,
            }
            if mover_size is not None:
                self._values["mover_size"] = mover_size
            if name is not None:
                self._values["name"] = name
            if sort_order is not None:
                self._values["sort_order"] = sort_order
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def time(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The time field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-time
            '''
            result = self._values.get("time")
            assert result is not None, "Required property 'time' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose from the following options:.

            - TOP: Top movers computation.
            - BOTTOM: Bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def mover_size(self) -> typing.Optional[jsii.Number]:
            '''The mover size setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-moversize
            '''
            result = self._values.get("mover_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def sort_order(self) -> typing.Optional[builtins.str]:
            '''The sort order setup of the top and bottom movers computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-sortorder
            '''
            result = self._values.get("sort_order")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomMoversComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TopBottomRankedComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "type": "type",
            "name": "name",
            "result_size": "resultSize",
            "value": "value",
        },
    )
    class TopBottomRankedComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            type: builtins.str,
            name: typing.Optional[builtins.str] = None,
            result_size: typing.Optional[jsii.Number] = None,
            value: typing.Optional[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The top ranked and bottom ranked computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param type: The computation type. Choose one of the following options:. - TOP: A top ranked computation. - BOTTOM: A bottom ranked computation.
            :param name: The name of a computation.
            :param result_size: The result size of a top and bottom ranked computation.
            :param value: The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                top_bottom_ranked_computation_property = quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                    type="type",
                
                    # the properties below are optional
                    name="name",
                    result_size=123,
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__f06cccc833743502c9273ea3480c495d9010a97dfb890564886aecb4f8cc4b3f)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument result_size", value=result_size, expected_type=type_hints["result_size"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
                "type": type,
            }
            if name is not None:
                self._values["name"] = name
            if result_size is not None:
                self._values["result_size"] = result_size
            if value is not None:
                self._values["value"] = value

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def type(self) -> builtins.str:
            '''The computation type. Choose one of the following options:.

            - TOP: A top ranked computation.
            - BOTTOM: A bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-type
            '''
            result = self._values.get("type")
            assert result is not None, "Required property 'type' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def result_size(self) -> typing.Optional[jsii.Number]:
            '''The result size of a top and bottom ranked computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-resultsize
            '''
            result = self._values.get("result_size")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def value(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-value
            '''
            result = self._values.get("value")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TopBottomRankedComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TotalAggregationComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "computation_id": "computationId",
            "value": "value",
            "name": "name",
        },
    )
    class TotalAggregationComputationProperty:
        def __init__(
            self,
            *,
            computation_id: builtins.str,
            value: typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total aggregation computation configuration.

            :param computation_id: The ID for a computation.
            :param value: The value field that is used in a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                total_aggregation_computation_property = quicksight.CfnTemplate.TotalAggregationComputationProperty(
                    computation_id="computationId",
                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    ),
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1da23c68bc7b866a8aebcc515aa8acee8bbd331a311077cbe1cce72cdf6accef)
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "computation_id": computation_id,
                "value": value,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(
            self,
        ) -> typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]:
            '''The value field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalAggregationComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TotalOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "custom_label": "customLabel",
            "placement": "placement",
            "scroll_status": "scrollStatus",
            "total_cell_style": "totalCellStyle",
            "totals_visibility": "totalsVisibility",
        },
    )
    class TotalOptionsProperty:
        def __init__(
            self,
            *,
            custom_label: typing.Optional[builtins.str] = None,
            placement: typing.Optional[builtins.str] = None,
            scroll_status: typing.Optional[builtins.str] = None,
            total_cell_style: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableCellStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            totals_visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The total options for a table visual.

            :param custom_label: The custom label string for the total cells.
            :param placement: The placement (start, end) for the total cells.
            :param scroll_status: The scroll status (pinned, scrolled) for the total cells.
            :param total_cell_style: Cell styling options for the total cells.
            :param totals_visibility: The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                total_options_property = quicksight.CfnTemplate.TotalOptionsProperty(
                    custom_label="customLabel",
                    placement="placement",
                    scroll_status="scrollStatus",
                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                        background_color="backgroundColor",
                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                ),
                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                    color="color",
                                    style="style",
                                    thickness=123
                                )
                            ),
                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                color="color",
                                style="style",
                                thickness=123
                            )
                        ),
                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        height=123,
                        horizontal_text_alignment="horizontalTextAlignment",
                        text_wrap="textWrap",
                        vertical_text_alignment="verticalTextAlignment",
                        visibility="visibility"
                    ),
                    totals_visibility="totalsVisibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__77f70c87fbd5a17b4c8d53c5faba9ef1e0a30d31f5d0bce1c37a700a4da7cb09)
                check_type(argname="argument custom_label", value=custom_label, expected_type=type_hints["custom_label"])
                check_type(argname="argument placement", value=placement, expected_type=type_hints["placement"])
                check_type(argname="argument scroll_status", value=scroll_status, expected_type=type_hints["scroll_status"])
                check_type(argname="argument total_cell_style", value=total_cell_style, expected_type=type_hints["total_cell_style"])
                check_type(argname="argument totals_visibility", value=totals_visibility, expected_type=type_hints["totals_visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if custom_label is not None:
                self._values["custom_label"] = custom_label
            if placement is not None:
                self._values["placement"] = placement
            if scroll_status is not None:
                self._values["scroll_status"] = scroll_status
            if total_cell_style is not None:
                self._values["total_cell_style"] = total_cell_style
            if totals_visibility is not None:
                self._values["totals_visibility"] = totals_visibility

        @builtins.property
        def custom_label(self) -> typing.Optional[builtins.str]:
            '''The custom label string for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-customlabel
            '''
            result = self._values.get("custom_label")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def placement(self) -> typing.Optional[builtins.str]:
            '''The placement (start, end) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-placement
            '''
            result = self._values.get("placement")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def scroll_status(self) -> typing.Optional[builtins.str]:
            '''The scroll status (pinned, scrolled) for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-scrollstatus
            '''
            result = self._values.get("scroll_status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def total_cell_style(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]]:
            '''Cell styling options for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalcellstyle
            '''
            result = self._values.get("total_cell_style")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableCellStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def totals_visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility configuration for the total cells.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalsvisibility
            '''
            result = self._values.get("totals_visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TotalOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"colors": "colors", "groups": "groups", "sizes": "sizes"},
    )
    class TreeMapAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            sizes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''Aggregated field wells of a tree map.

            :param colors: The color field well of a tree map. Values are grouped by aggregations based on group by fields.
            :param groups: The group by field well of a tree map. Values are grouped based on group by fields.
            :param sizes: The size field well of a tree map. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_aggregated_field_wells_property = quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                    colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )],
                    groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__0799d2a10999c554883420d55e3654fe53787d60bf97a077811c459bd1015811)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
                check_type(argname="argument sizes", value=sizes, expected_type=type_hints["sizes"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if groups is not None:
                self._values["groups"] = groups
            if sizes is not None:
                self._values["sizes"] = sizes

        @builtins.property
        def colors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The color field well of a tree map.

            Values are grouped by aggregations based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def groups(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a tree map.

            Values are grouped based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-groups
            '''
            result = self._values.get("groups")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def sizes(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a tree map.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-sizes
            '''
            result = self._values.get("sizes")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TreeMapConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "color_label_options": "colorLabelOptions",
            "color_scale": "colorScale",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "group_label_options": "groupLabelOptions",
            "legend": "legend",
            "size_label_options": "sizeLabelOptions",
            "sort_configuration": "sortConfiguration",
            "tooltip": "tooltip",
        },
    )
    class TreeMapConfigurationProperty:
        def __init__(
            self,
            *,
            color_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            color_scale: typing.Optional[typing.Union[typing.Union["CfnTemplate.ColorScaleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.TreeMapFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            group_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            size_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.TreeMapSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tooltip: typing.Optional[typing.Union[typing.Union["CfnTemplate.TooltipOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a tree map.

            :param color_label_options: The label options (label text, label visibility) for the colors displayed in a tree map.
            :param color_scale: The color options (gradient color, point of divergence) of a tree map.
            :param data_labels: The options that determine if visual data labels are displayed.
            :param field_wells: The field wells of the visual.
            :param group_label_options: The label options (label text, label visibility) of the groups that are displayed in a tree map.
            :param legend: The legend display setup of the visual.
            :param size_label_options: The label options (label text, label visibility) of the sizes that are displayed in a tree map.
            :param sort_configuration: The sort configuration of a tree map.
            :param tooltip: The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_configuration_property = quicksight.CfnTemplate.TreeMapConfigurationProperty(
                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                        color_fill_type="colorFillType",
                        colors=[quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )],
                
                        # the properties below are optional
                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                            color="color",
                            data_value=123
                        )
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                        tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                            colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )],
                            groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                        tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                            aggregation_visibility="aggregationVisibility",
                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    label="label",
                                    visibility="visibility"
                                ),
                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    label="label",
                                    visibility="visibility"
                                )
                            )],
                            tooltip_title_type="tooltipTitleType"
                        ),
                        selected_tooltip_type="selectedTooltipType",
                        tooltip_visibility="tooltipVisibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf43d1f9d98fbf96d0e19e6416a76a06a0ed81b7a441ec8fa583e15a939f27e7)
                check_type(argname="argument color_label_options", value=color_label_options, expected_type=type_hints["color_label_options"])
                check_type(argname="argument color_scale", value=color_scale, expected_type=type_hints["color_scale"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument group_label_options", value=group_label_options, expected_type=type_hints["group_label_options"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument size_label_options", value=size_label_options, expected_type=type_hints["size_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument tooltip", value=tooltip, expected_type=type_hints["tooltip"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if color_label_options is not None:
                self._values["color_label_options"] = color_label_options
            if color_scale is not None:
                self._values["color_scale"] = color_scale
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if group_label_options is not None:
                self._values["group_label_options"] = group_label_options
            if legend is not None:
                self._values["legend"] = legend
            if size_label_options is not None:
                self._values["size_label_options"] = size_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if tooltip is not None:
                self._values["tooltip"] = tooltip

        @builtins.property
        def color_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) for the colors displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorlabeloptions
            '''
            result = self._values.get("color_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def color_scale(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ColorScaleProperty", _IResolvable_a771d0ef]]:
            '''The color options (gradient color, point of divergence) of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorscale
            '''
            result = self._values.get("color_scale")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ColorScaleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine if visual data labels are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TreeMapFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TreeMapFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def group_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) of the groups that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-grouplabeloptions
            '''
            result = self._values.get("group_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def size_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility) of the sizes that are displayed in a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sizelabeloptions
            '''
            result = self._values.get("size_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TreeMapSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TreeMapSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tooltip(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]]:
            '''The tooltip display setup of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-tooltip
            '''
            result = self._values.get("tooltip")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TooltipOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TreeMapFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_aggregated_field_wells": "treeMapAggregatedFieldWells",
        },
    )
    class TreeMapFieldWellsProperty:
        def __init__(
            self,
            *,
            tree_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.TreeMapAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a tree map.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param tree_map_aggregated_field_wells: The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_field_wells_property = quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                    tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                        colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )],
                        groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c1b2ba59f4c84a6caf6d7d113b158fce4271c974f6af8652ecc7d116130ddc09)
                check_type(argname="argument tree_map_aggregated_field_wells", value=tree_map_aggregated_field_wells, expected_type=type_hints["tree_map_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_aggregated_field_wells is not None:
                self._values["tree_map_aggregated_field_wells"] = tree_map_aggregated_field_wells

        @builtins.property
        def tree_map_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TreeMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a tree map.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html#cfn-quicksight-template-treemapfieldwells-treemapaggregatedfieldwells
            '''
            result = self._values.get("tree_map_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TreeMapAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TreeMapSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "tree_map_group_items_limit_configuration": "treeMapGroupItemsLimitConfiguration",
            "tree_map_sort": "treeMapSort",
        },
    )
    class TreeMapSortConfigurationProperty:
        def __init__(
            self,
            *,
            tree_map_group_items_limit_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tree_map_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a tree map.

            :param tree_map_group_items_limit_configuration: The limit on the number of groups that are displayed.
            :param tree_map_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_sort_configuration_property = quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                    tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__5fef032760b84daddeaa241c474db09ca40fb86d3c671e81749a28512e204a4a)
                check_type(argname="argument tree_map_group_items_limit_configuration", value=tree_map_group_items_limit_configuration, expected_type=type_hints["tree_map_group_items_limit_configuration"])
                check_type(argname="argument tree_map_sort", value=tree_map_sort, expected_type=type_hints["tree_map_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tree_map_group_items_limit_configuration is not None:
                self._values["tree_map_group_items_limit_configuration"] = tree_map_group_items_limit_configuration
            if tree_map_sort is not None:
                self._values["tree_map_sort"] = tree_map_sort

        @builtins.property
        def tree_map_group_items_limit_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapgroupitemslimitconfiguration
            '''
            result = self._values.get("tree_map_group_items_limit_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tree_map_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapsort
            '''
            result = self._values.get("tree_map_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TreeMapVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class TreeMapVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.TreeMapConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tree_map_visual_property = quicksight.CfnTemplate.TreeMapVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                        color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                            color_fill_type="colorFillType",
                            colors=[quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )],
                
                            # the properties below are optional
                            null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                color="color",
                                data_value=123
                            )
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                            tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                            tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                            field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                aggregation_visibility="aggregationVisibility",
                                tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                    column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        ),
                                        label="label",
                                        visibility="visibility"
                                    ),
                                    field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        label="label",
                                        visibility="visibility"
                                    )
                                )],
                                tooltip_title_type="tooltipTitleType"
                            ),
                            selected_tooltip_type="selectedTooltipType",
                            tooltip_visibility="tooltipVisibility"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__e0ebbc2ef9e9216782b8b43fd0f9240d3ffd0fca5a3669f9261198b3c3f4b21d)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TreeMapConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TreeMapConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TreeMapVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.TrendArrowOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"visibility": "visibility"},
    )
    class TrendArrowOptionsProperty:
        def __init__(self, *, visibility: typing.Optional[builtins.str] = None) -> None:
            '''The options that determine the presentation of trend arrows in a KPI visual.

            :param visibility: The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                trend_arrow_options_property = quicksight.CfnTemplate.TrendArrowOptionsProperty(
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cd0c9deb823f37938a63190938562cfabc4fb931938e88c6ced3933c391bd8d1)
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the trend arrows.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html#cfn-quicksight-template-trendarrowoptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TrendArrowOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.UnaggregatedFieldProperty",
        jsii_struct_bases=[],
        name_mapping={
            "column": "column",
            "field_id": "fieldId",
            "format_configuration": "formatConfiguration",
        },
    )
    class UnaggregatedFieldProperty:
        def __init__(
            self,
            *,
            column: typing.Union[typing.Union["CfnTemplate.ColumnIdentifierProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            field_id: builtins.str,
            format_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.FormatConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The unaggregated field for a table.

            :param column: The column that is used in the ``UnaggregatedField`` .
            :param field_id: The custom field ID.
            :param format_configuration: The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                unaggregated_field_property = quicksight.CfnTemplate.UnaggregatedFieldProperty(
                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                        column_name="columnName",
                        data_set_identifier="dataSetIdentifier"
                    ),
                    field_id="fieldId",
                
                    # the properties below are optional
                    format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                        date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                            date_time_format="dateTimeFormat",
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        ),
                        string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                null_string="nullString"
                            ),
                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix",
                                    symbol="symbol"
                                ),
                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    number_scale="numberScale",
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                ),
                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                        decimal_places=123
                                    ),
                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                        display_mode="displayMode"
                                    ),
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    prefix="prefix",
                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                        decimal_separator="decimalSeparator",
                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                            symbol="symbol",
                                            visibility="visibility"
                                        )
                                    ),
                                    suffix="suffix"
                                )
                            )
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__9e68d03489fd85df88cc0e5849a53f11f02329c61a1f7556d6383345a748d4e3)
                check_type(argname="argument column", value=column, expected_type=type_hints["column"])
                check_type(argname="argument field_id", value=field_id, expected_type=type_hints["field_id"])
                check_type(argname="argument format_configuration", value=format_configuration, expected_type=type_hints["format_configuration"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "column": column,
                "field_id": field_id,
            }
            if format_configuration is not None:
                self._values["format_configuration"] = format_configuration

        @builtins.property
        def column(
            self,
        ) -> typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef]:
            '''The column that is used in the ``UnaggregatedField`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-column
            '''
            result = self._values.get("column")
            assert result is not None, "Required property 'column' is missing"
            return typing.cast(typing.Union["CfnTemplate.ColumnIdentifierProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def field_id(self) -> builtins.str:
            '''The custom field ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-fieldid
            '''
            result = self._values.get("field_id")
            assert result is not None, "Required property 'field_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def format_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FormatConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The format configuration of the field.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-formatconfiguration
            '''
            result = self._values.get("format_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FormatConfigurationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UnaggregatedFieldProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.UniqueValuesComputationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category": "category",
            "computation_id": "computationId",
            "name": "name",
        },
    )
    class UniqueValuesComputationProperty:
        def __init__(
            self,
            *,
            category: typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
            computation_id: builtins.str,
            name: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The unique values computation configuration.

            :param category: The category field that is used in a computation.
            :param computation_id: The ID for a computation.
            :param name: The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                unique_values_computation_property = quicksight.CfnTemplate.UniqueValuesComputationProperty(
                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    ),
                    computation_id="computationId",
                
                    # the properties below are optional
                    name="name"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__747aefde26fdc00cda7e0e6af6b685d813baa009692cfa560ba21ec6db251122)
                check_type(argname="argument category", value=category, expected_type=type_hints["category"])
                check_type(argname="argument computation_id", value=computation_id, expected_type=type_hints["computation_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "category": category,
                "computation_id": computation_id,
            }
            if name is not None:
                self._values["name"] = name

        @builtins.property
        def category(
            self,
        ) -> typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]:
            '''The category field that is used in a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-category
            '''
            result = self._values.get("category")
            assert result is not None, "Required property 'category' is missing"
            return typing.cast(typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef], result)

        @builtins.property
        def computation_id(self) -> builtins.str:
            '''The ID for a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-computationid
            '''
            result = self._values.get("computation_id")
            assert result is not None, "Required property 'computation_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> typing.Optional[builtins.str]:
            '''The name of a computation.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-name
            '''
            result = self._values.get("name")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UniqueValuesComputationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisibleRangeOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"percent_range": "percentRange"},
    )
    class VisibleRangeOptionsProperty:
        def __init__(
            self,
            *,
            percent_range: typing.Optional[typing.Union[typing.Union["CfnTemplate.PercentVisibleRangeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The range options for the data zoom scroll bar.

            :param percent_range: The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visible_range_options_property = quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                        from=123,
                        to=123
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__03a4fc1688e4f8fd2ec3a1fe27c0fc1238bd26aca6223f3a3923468dcd30f289)
                check_type(argname="argument percent_range", value=percent_range, expected_type=type_hints["percent_range"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if percent_range is not None:
                self._values["percent_range"] = percent_range

        @builtins.property
        def percent_range(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PercentVisibleRangeProperty", _IResolvable_a771d0ef]]:
            '''The percent range in the visible range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html#cfn-quicksight-template-visiblerangeoptions-percentrange
            '''
            result = self._values.get("percent_range")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PercentVisibleRangeProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisibleRangeOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisualCustomActionOperationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "filter_operation": "filterOperation",
            "navigation_operation": "navigationOperation",
            "set_parameters_operation": "setParametersOperation",
            "url_operation": "urlOperation",
        },
    )
    class VisualCustomActionOperationProperty:
        def __init__(
            self,
            *,
            filter_operation: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomActionFilterOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            navigation_operation: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomActionNavigationOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            set_parameters_operation: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomActionSetParametersOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            url_operation: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomActionURLOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The operation that is defined by the custom action.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param filter_operation: The filter operation that filters data included in a visual or in an entire sheet.
            :param navigation_operation: The navigation operation that navigates between different sheets in the same analysis.
            :param set_parameters_operation: The set parameter operation that sets parameters in custom action.
            :param url_operation: The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_custom_action_operation_property = quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                    filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                        selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                            selected_field_options="selectedFieldOptions",
                            selected_fields=["selectedFields"]
                        ),
                        target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                            same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                target_visual_options="targetVisualOptions",
                                target_visuals=["targetVisuals"]
                            )
                        )
                    ),
                    navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                        local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                            target_sheet_id="targetSheetId"
                        )
                    ),
                    set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                        parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                            destination_parameter_name="destinationParameterName",
                            value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                    custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                        date_time_values=["dateTimeValues"],
                                        decimal_values=[123],
                                        integer_values=[123],
                                        string_values=["stringValues"]
                                    ),
                
                                    # the properties below are optional
                                    include_null_value=False
                                ),
                                select_all_value_options="selectAllValueOptions",
                                source_field="sourceField",
                                source_parameter_name="sourceParameterName"
                            )
                        )]
                    ),
                    url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                        url_target="urlTarget",
                        url_template="urlTemplate"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c23b57f7f8292971b61c601ce1e570d5305846e31cb58905c4003198ae5b2bce)
                check_type(argname="argument filter_operation", value=filter_operation, expected_type=type_hints["filter_operation"])
                check_type(argname="argument navigation_operation", value=navigation_operation, expected_type=type_hints["navigation_operation"])
                check_type(argname="argument set_parameters_operation", value=set_parameters_operation, expected_type=type_hints["set_parameters_operation"])
                check_type(argname="argument url_operation", value=url_operation, expected_type=type_hints["url_operation"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if filter_operation is not None:
                self._values["filter_operation"] = filter_operation
            if navigation_operation is not None:
                self._values["navigation_operation"] = navigation_operation
            if set_parameters_operation is not None:
                self._values["set_parameters_operation"] = set_parameters_operation
            if url_operation is not None:
                self._values["url_operation"] = url_operation

        @builtins.property
        def filter_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomActionFilterOperationProperty", _IResolvable_a771d0ef]]:
            '''The filter operation that filters data included in a visual or in an entire sheet.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-filteroperation
            '''
            result = self._values.get("filter_operation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomActionFilterOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def navigation_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomActionNavigationOperationProperty", _IResolvable_a771d0ef]]:
            '''The navigation operation that navigates between different sheets in the same analysis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-navigationoperation
            '''
            result = self._values.get("navigation_operation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomActionNavigationOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def set_parameters_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomActionSetParametersOperationProperty", _IResolvable_a771d0ef]]:
            '''The set parameter operation that sets parameters in custom action.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-setparametersoperation
            '''
            result = self._values.get("set_parameters_operation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomActionSetParametersOperationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def url_operation(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomActionURLOperationProperty", _IResolvable_a771d0ef]]:
            '''The URL operation that opens a link to another webpage.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-urloperation
            '''
            result = self._values.get("url_operation")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomActionURLOperationProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionOperationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisualCustomActionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "action_operations": "actionOperations",
            "custom_action_id": "customActionId",
            "name": "name",
            "trigger": "trigger",
            "status": "status",
        },
    )
    class VisualCustomActionProperty:
        def __init__(
            self,
            *,
            action_operations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionOperationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
            custom_action_id: builtins.str,
            name: builtins.str,
            trigger: builtins.str,
            status: typing.Optional[builtins.str] = None,
        ) -> None:
            '''A custom action defined on a visual.

            :param action_operations: A list of ``VisualCustomActionOperations`` . This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
            :param custom_action_id: The ID of the ``VisualCustomAction`` .
            :param name: The name of the ``VisualCustomAction`` .
            :param trigger: The trigger of the ``VisualCustomAction`` . Valid values are defined as follows: - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point. - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.
            :param status: The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_custom_action_property = quicksight.CfnTemplate.VisualCustomActionProperty(
                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                selected_field_options="selectedFieldOptions",
                                selected_fields=["selectedFields"]
                            ),
                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                    target_visual_options="targetVisualOptions",
                                    target_visuals=["targetVisuals"]
                                )
                            )
                        ),
                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                target_sheet_id="targetSheetId"
                            )
                        ),
                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                destination_parameter_name="destinationParameterName",
                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                            date_time_values=["dateTimeValues"],
                                            decimal_values=[123],
                                            integer_values=[123],
                                            string_values=["stringValues"]
                                        ),
                
                                        # the properties below are optional
                                        include_null_value=False
                                    ),
                                    select_all_value_options="selectAllValueOptions",
                                    source_field="sourceField",
                                    source_parameter_name="sourceParameterName"
                                )
                            )]
                        ),
                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                            url_target="urlTarget",
                            url_template="urlTemplate"
                        )
                    )],
                    custom_action_id="customActionId",
                    name="name",
                    trigger="trigger",
                
                    # the properties below are optional
                    status="status"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__64021c4826100f0b98bce59890fb62530b0431ee697e8f4bfee7a816bfef907b)
                check_type(argname="argument action_operations", value=action_operations, expected_type=type_hints["action_operations"])
                check_type(argname="argument custom_action_id", value=custom_action_id, expected_type=type_hints["custom_action_id"])
                check_type(argname="argument name", value=name, expected_type=type_hints["name"])
                check_type(argname="argument trigger", value=trigger, expected_type=type_hints["trigger"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "action_operations": action_operations,
                "custom_action_id": custom_action_id,
                "name": name,
                "trigger": trigger,
            }
            if status is not None:
                self._values["status"] = status

        @builtins.property
        def action_operations(
            self,
        ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionOperationProperty", _IResolvable_a771d0ef]]]:
            '''A list of ``VisualCustomActionOperations`` .

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-actionoperations
            '''
            result = self._values.get("action_operations")
            assert result is not None, "Required property 'action_operations' is missing"
            return typing.cast(typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionOperationProperty", _IResolvable_a771d0ef]]], result)

        @builtins.property
        def custom_action_id(self) -> builtins.str:
            '''The ID of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-customactionid
            '''
            result = self._values.get("custom_action_id")
            assert result is not None, "Required property 'custom_action_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def name(self) -> builtins.str:
            '''The name of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-name
            '''
            result = self._values.get("name")
            assert result is not None, "Required property 'name' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def trigger(self) -> builtins.str:
            '''The trigger of the ``VisualCustomAction`` .

            Valid values are defined as follows:

            - ``DATA_POINT_CLICK`` : Initiates a custom action by a left pointer click on a data point.
            - ``DATA_POINT_MENU`` : Initiates a custom action by right pointer click from the menu.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-trigger
            '''
            result = self._values.get("trigger")
            assert result is not None, "Required property 'trigger' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the ``VisualCustomAction`` .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualCustomActionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisualPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={"chart_color": "chartColor", "color_map": "colorMap"},
    )
    class VisualPaletteProperty:
        def __init__(
            self,
            *,
            chart_color: typing.Optional[builtins.str] = None,
            color_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DataPathColorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The visual display options for the visual palette.

            :param chart_color: The chart color options for the visual palette.
            :param color_map: The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_palette_property = quicksight.CfnTemplate.VisualPaletteProperty(
                    chart_color="chartColor",
                    color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                        color="color",
                        element=quicksight.CfnTemplate.DataPathValueProperty(
                            field_id="fieldId",
                            field_value="fieldValue"
                        ),
                
                        # the properties below are optional
                        time_granularity="timeGranularity"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8ec6c97ac1a08df779754feb8ecf25fe730c240e21457d73ac1f2a97547dcc65)
                check_type(argname="argument chart_color", value=chart_color, expected_type=type_hints["chart_color"])
                check_type(argname="argument color_map", value=color_map, expected_type=type_hints["color_map"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if chart_color is not None:
                self._values["chart_color"] = chart_color
            if color_map is not None:
                self._values["color_map"] = color_map

        @builtins.property
        def chart_color(self) -> typing.Optional[builtins.str]:
            '''The chart color options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-chartcolor
            '''
            result = self._values.get("chart_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def color_map(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataPathColorProperty", _IResolvable_a771d0ef]]]]:
            '''The color map options for the visual palette.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-colormap
            '''
            result = self._values.get("color_map")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DataPathColorProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "bar_chart_visual": "barChartVisual",
            "box_plot_visual": "boxPlotVisual",
            "combo_chart_visual": "comboChartVisual",
            "custom_content_visual": "customContentVisual",
            "empty_visual": "emptyVisual",
            "filled_map_visual": "filledMapVisual",
            "funnel_chart_visual": "funnelChartVisual",
            "gauge_chart_visual": "gaugeChartVisual",
            "geospatial_map_visual": "geospatialMapVisual",
            "heat_map_visual": "heatMapVisual",
            "histogram_visual": "histogramVisual",
            "insight_visual": "insightVisual",
            "kpi_visual": "kpiVisual",
            "line_chart_visual": "lineChartVisual",
            "pie_chart_visual": "pieChartVisual",
            "pivot_table_visual": "pivotTableVisual",
            "radar_chart_visual": "radarChartVisual",
            "sankey_diagram_visual": "sankeyDiagramVisual",
            "scatter_plot_visual": "scatterPlotVisual",
            "table_visual": "tableVisual",
            "tree_map_visual": "treeMapVisual",
            "waterfall_visual": "waterfallVisual",
            "word_cloud_visual": "wordCloudVisual",
        },
    )
    class VisualProperty:
        def __init__(
            self,
            *,
            bar_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.BarChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            box_plot_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.BoxPlotVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            combo_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.ComboChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            custom_content_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.CustomContentVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            empty_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.EmptyVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            filled_map_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.FilledMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            funnel_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.FunnelChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            gauge_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.GaugeChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            geospatial_map_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.GeospatialMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            heat_map_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.HeatMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            histogram_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.HistogramVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            insight_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.InsightVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            kpi_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.KPIVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            line_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.LineChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            pie_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.PieChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            pivot_table_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.PivotTableVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            radar_chart_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.RadarChartVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sankey_diagram_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.SankeyDiagramVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            scatter_plot_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.ScatterPlotVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            table_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.TableVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tree_map_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.TreeMapVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            waterfall_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.WaterfallVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            word_cloud_visual: typing.Optional[typing.Union[typing.Union["CfnTemplate.WordCloudVisualProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A visual displayed on a sheet in an analysis, dashboard, or template.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param bar_chart_visual: A bar chart. For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param box_plot_visual: A box plot. For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .
            :param combo_chart_visual: A combo chart. For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param custom_content_visual: A visual that contains custom content. For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param empty_visual: An empty visual.
            :param filled_map_visual: A filled map. For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param funnel_chart_visual: A funnel chart. For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .
            :param gauge_chart_visual: A gauge chart. For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param geospatial_map_visual: A geospatial map or a points on map visual. For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .
            :param heat_map_visual: A heat map. For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param histogram_visual: A histogram. For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param insight_visual: An insight visual. For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .
            :param kpi_visual: A key performance indicator (KPI). For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .
            :param line_chart_visual: A line chart. For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .
            :param pie_chart_visual: A pie or donut chart. For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param pivot_table_visual: A pivot table. For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .
            :param radar_chart_visual: A radar chart visual. For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param sankey_diagram_visual: A sankey diagram. For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .
            :param scatter_plot_visual: A scatter plot. For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .
            :param table_visual: A table visual. For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .
            :param tree_map_visual: A tree map. For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .
            :param waterfall_visual: A waterfall chart. For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .
            :param word_cloud_visual: A word cloud. For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                visual_property = quicksight.CfnTemplate.VisualProperty(
                    bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            orientation="orientation",
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                            box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                all_data_points_visibility="allDataPointsVisibility",
                                outlier_visibility="outlierVisibility",
                                style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                    fill_style="fillStyle"
                                )
                            ),
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                )
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                            bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            bars_arrangement="barsArrangement",
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                    bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                            content_type="contentType",
                            content_url="contentUrl",
                            image_scaling="imageScaling"
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )]
                    ),
                    filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                            field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                label_color="labelColor",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_data_label_style="measureDataLabelStyle",
                                measure_label_visibility="measureLabelVisibility",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                    arc_angle=123,
                                    arc_thickness="arcThickness"
                                ),
                                arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                    range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                        max=123,
                                        min=123
                                    ),
                                    reserve_range=123
                                ),
                                comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            ),
                            tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                            field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                base_map_style="baseMapStyle"
                            ),
                            point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                    cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                        simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                            color="color"
                                        )
                                    )
                                ),
                                selected_point_style="selectedPointStyle"
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                    east=123,
                                    north=123,
                                    south=123,
                                    west=123
                                ),
                                map_zoom_mode="mapZoomMode"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                            color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                            bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                    value=123
                                ),
                                bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                    bin_count_limit=123,
                                    value=123
                                ),
                                selected_bin_type="selectedBinType",
                                start_value=123
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            )
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                        data_set_identifier="dataSetIdentifier",
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                            computations=[quicksight.CfnTemplate.ComputationProperty(
                                forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    custom_seasonality_value=123,
                                    lower_boundary=123,
                                    name="name",
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality="seasonality",
                                    upper_boundary=123,
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_size=123,
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                    computation_id="computationId",
                                    from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name",
                                    period_time_granularity="periodTimeGranularity",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    time=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    type="type",
                
                                    # the properties below are optional
                                    mover_size=123,
                                    name="name",
                                    sort_order="sortOrder",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                                    type="type",
                
                                    # the properties below are optional
                                    name="name",
                                    result_size=123,
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )
                                ),
                                total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                    computation_id="computationId",
                                    value=quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    ),
                
                                    # the properties below are optional
                                    name="name"
                                ),
                                unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                    category=quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    ),
                                    computation_id="computationId",
                
                                    # the properties below are optional
                                    name="name"
                                )
                            )],
                            custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                narrative="narrative"
                            )
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                            field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )],
                                trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            ),
                            kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                    comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    ),
                                    comparison_method="comparisonMethod"
                                ),
                                primary_value_display_type="primaryValueDisplayType",
                                primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                    visibility="visibility"
                                ),
                                secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                    visibility="visibility"
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                    icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                        custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                            expression="expression",
                                            icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                icon="icon",
                                                unicode_icon="unicodeIcon"
                                            ),
                
                                            # the properties below are optional
                                            color="color",
                                            display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                icon_display_option="iconDisplayOption"
                                            )
                                        ),
                                        icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            icon_set_type="iconSetType"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                ),
                                progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                    foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                            contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                axis_binding="axisBinding",
                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                    line_interpolation="lineInterpolation",
                                    line_style="lineStyle",
                                    line_visibility="lineVisibility",
                                    line_width="lineWidth"
                                ),
                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                    marker_color="markerColor",
                                    marker_shape="markerShape",
                                    marker_size="markerSize",
                                    marker_visibility="markerVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                    lower_boundary=123,
                                    periods_backward=123,
                                    periods_forward=123,
                                    prediction_interval=123,
                                    seasonality=123,
                                    upper_boundary=123
                                ),
                                scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                    what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                        date="date",
                                        value=123
                                    ),
                                    what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                        end_date="endDate",
                                        start_date="startDate",
                                        value=123
                                    )
                                )
                            )],
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                    axis_binding="axisBinding",
                                    dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                        calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                        value=123
                                    )
                                ),
                
                                # the properties below are optional
                                label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                    custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                        custom_label="customLabel"
                                    ),
                                    font_color="fontColor",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    horizontal_position="horizontalPosition",
                                    value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        ),
                                        relative_position="relativePosition"
                                    ),
                                    vertical_position="verticalPosition"
                                ),
                                status="status",
                                style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                    color="color",
                                    pattern="pattern"
                                )
                            )],
                            secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                    axis_line_visibility="axisLineVisibility",
                                    axis_offset="axisOffset",
                                    data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                        date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                            missing_date_visibility="missingDateVisibility"
                                        ),
                                        numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                            range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                data_driven=data_driven,
                                                min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                    maximum=123,
                                                    minimum=123
                                                )
                                            ),
                                            scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                    step_count=123,
                                                    step_size=123
                                                ),
                                                logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                    base=123
                                                )
                                            )
                                        )
                                    ),
                                    grid_line_visibility="gridLineVisibility",
                                    scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                        visibility="visibility",
                                        visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                            percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                from=123,
                                                to=123
                                            )
                                        )
                                    ),
                                    tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                        label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        rotation_angle=123
                                    )
                                ),
                                missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                    treatment_option="treatmentOption"
                                )]
                            ),
                            secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            series=[quicksight.CfnTemplate.SeriesItemProperty(
                                data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    field_value="fieldValue",
                                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                ),
                                field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                    axis_binding="axisBinding",
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    )
                                )
                            )],
                            small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            type="type",
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                measure_field_id="measureFieldId"
                            )],
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                    arc_thickness="arcThickness"
                                ),
                                donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                    label_visibility="labelVisibility"
                                )
                            ),
                            field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                max_visible_columns=123,
                                max_visible_rows=123,
                                panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                    background_color="backgroundColor",
                                    background_visibility="backgroundVisibility",
                                    border_color="borderColor",
                                    border_style="borderStyle",
                                    border_thickness="borderThickness",
                                    border_visibility="borderVisibility",
                                    gutter_spacing="gutterSpacing",
                                    gutter_visibility="gutterVisibility",
                                    title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                            field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                    data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    )],
                
                                    # the properties below are optional
                                    width="width"
                                )],
                                selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    visibility="visibility"
                                )]
                            ),
                            field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                    columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                    field_id="fieldId",
                                    sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                        column=quicksight.CfnTemplate.ColumnSortProperty(
                                            direction="direction",
                                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            )
                                        ),
                                        data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                            direction="direction",
                                            sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )]
                                        ),
                                        field=quicksight.CfnTemplate.FieldSortProperty(
                                            direction="direction",
                                            field_id="fieldId"
                                        )
                                    )
                                )]
                            ),
                            table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                column_names_visibility="columnNamesVisibility",
                                metric_placement="metricPlacement",
                                row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                ),
                                row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                single_metric_visibility="singleMetricVisibility",
                                toggle_buttons_visibility="toggleButtonsVisibility"
                            ),
                            total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                    custom_label="customLabel",
                                    field_level="fieldLevel",
                                    field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                        field_id="fieldId"
                                    )],
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                ),
                                row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                    custom_label="customLabel",
                                    metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    placement="placement",
                                    scroll_status="scrollStatus",
                                    total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    ),
                                    totals_visibility="totalsVisibility",
                                    value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                        background_color="backgroundColor",
                                        border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                            side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                ),
                                                top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        height=123,
                                        horizontal_text_alignment="horizontalTextAlignment",
                                        text_wrap="textWrap",
                                        vertical_text_alignment="verticalTextAlignment",
                                        visibility="visibility"
                                    )
                                )
                            )
                        ),
                        conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                        role="role"
                                    ),
                                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                            alternate_band_colors_visibility="alternateBandColorsVisibility",
                            alternate_band_even_color="alternateBandEvenColor",
                            alternate_band_odd_color="alternateBandOddColor",
                            base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                    visibility="visibility"
                                )
                            ),
                            category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            shape="shape",
                            sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )],
                                color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            start_angle=123,
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                    destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            )
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                    category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    table_visual=quicksight.CfnTemplate.TableVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                            field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                order=["order"],
                                selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    custom_label="customLabel",
                                    url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                        image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                            sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                            )
                                        ),
                                        link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                            content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                    icon="icon"
                                                ),
                                                custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                
                                                    # the properties below are optional
                                                    value="value"
                                                )
                                            ),
                                            target="target"
                                        )
                                    ),
                                    visibility="visibility",
                                    width="width"
                                )]
                            ),
                            field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                    values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                vertical_overflow_visibility="verticalOverflowVisibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                    page_number=123,
                                    page_size=123
                                ),
                                row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    negative_color="negativeColor",
                                    positive_color="positiveColor"
                                )
                            )],
                            table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                orientation="orientation",
                                row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                    row_alternate_colors=["rowAlternateColors"],
                                    status="status"
                                )
                            ),
                            total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                custom_label="customLabel",
                                placement="placement",
                                scroll_status="scrollStatus",
                                total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                    background_color="backgroundColor",
                                    border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                        side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                            bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            ),
                                            top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                color="color",
                                                style="style",
                                                thickness=123
                                            )
                                        ),
                                        uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                            color="color",
                                            style="style",
                                            thickness=123
                                        )
                                    ),
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    height=123,
                                    horizontal_text_alignment="horizontalTextAlignment",
                                    text_wrap="textWrap",
                                    vertical_text_alignment="verticalTextAlignment",
                                    visibility="visibility"
                                ),
                                totals_visibility="totalsVisibility"
                            )
                        ),
                        conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                            conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                        background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        ),
                                        icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                            custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                expression="expression",
                                                icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                    icon="icon",
                                                    unicode_icon="unicodeIcon"
                                                ),
                
                                                # the properties below are optional
                                                color="color",
                                                display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                    icon_display_option="iconDisplayOption"
                                                )
                                            ),
                                            icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                icon_set_type="iconSetType"
                                            )
                                        ),
                                        text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                            gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                color=quicksight.CfnTemplate.GradientColorProperty(
                                                    stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                        gradient_offset=123,
                
                                                        # the properties below are optional
                                                        color="color",
                                                        data_value=123
                                                    )]
                                                ),
                                                expression="expression"
                                            ),
                                            solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                expression="expression",
                
                                                # the properties below are optional
                                                color="color"
                                            )
                                        )
                                    )
                                ),
                                row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                    background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    ),
                                    text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                        gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                            color=quicksight.CfnTemplate.GradientColorProperty(
                                                stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                    gradient_offset=123,
                
                                                    # the properties below are optional
                                                    color="color",
                                                    data_value=123
                                                )]
                                            ),
                                            expression="expression"
                                        ),
                                        solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                            expression="expression",
                
                                            # the properties below are optional
                                            color="color"
                                        )
                                    )
                                )
                            )]
                        ),
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                            color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                color_fill_type="colorFillType",
                                colors=[quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )],
                
                                # the properties below are optional
                                null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                    color="color",
                                    data_value=123
                                )
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                    colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )],
                                    groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                    aggregation_visibility="aggregationVisibility",
                                    tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                        column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                
                                            # the properties below are optional
                                            aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                categorical_aggregation_function="categoricalAggregationFunction",
                                                date_aggregation_function="dateAggregationFunction",
                                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                )
                                            ),
                                            label="label",
                                            visibility="visibility"
                                        ),
                                        field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            label="label",
                                            visibility="visibility"
                                        )
                                    )],
                                    tooltip_title_type="tooltipTitleType"
                                ),
                                selected_tooltip_type="selectedTooltipType",
                                tooltip_visibility="tooltipVisibility"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                            category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                category_label_visibility="categoryLabelVisibility",
                                data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                    data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue",
                                        visibility="visibility"
                                    ),
                                    field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                        field_id="fieldId",
                                        visibility="visibility"
                                    ),
                                    maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                        visibility="visibility"
                                    ),
                                    range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                        visibility="visibility"
                                    )
                                )],
                                label_color="labelColor",
                                label_content="labelContent",
                                label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                measure_label_visibility="measureLabelVisibility",
                                overlap="overlap",
                                position="position",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                    breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                height="height",
                                position="position",
                                title=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                visibility="visibility",
                                width="width"
                            ),
                            primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                axis_line_visibility="axisLineVisibility",
                                axis_offset="axisOffset",
                                data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                    date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                        missing_date_visibility="missingDateVisibility"
                                    ),
                                    numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                        range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                            data_driven=data_driven,
                                            min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                maximum=123,
                                                minimum=123
                                            )
                                        ),
                                        scale=quicksight.CfnTemplate.AxisScaleProperty(
                                            linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                step_count=123,
                                                step_size=123
                                            ),
                                            logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                base=123
                                            )
                                        )
                                    )
                                ),
                                grid_line_visibility="gridLineVisibility",
                                scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                    visibility="visibility",
                                    visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                        percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                            from=123,
                                            to=123
                                        )
                                    )
                                ),
                                tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                    label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    ),
                                    rotation_angle=123
                                )
                            ),
                            primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                chart_color="chartColor",
                                color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                    color="color",
                                    element=quicksight.CfnTemplate.DataPathValueProperty(
                                        field_id="fieldId",
                                        field_value="fieldValue"
                                    ),
                
                                    # the properties below are optional
                                    time_granularity="timeGranularity"
                                )]
                            ),
                            waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                total_bar_label="totalBarLabel"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    ),
                    word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                        visual_id="visualId",
                
                        # the properties below are optional
                        actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                            action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                    selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                        selected_field_options="selectedFieldOptions",
                                        selected_fields=["selectedFields"]
                                    ),
                                    target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                        same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                            target_visual_options="targetVisualOptions",
                                            target_visuals=["targetVisuals"]
                                        )
                                    )
                                ),
                                navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                    local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                        target_sheet_id="targetSheetId"
                                    )
                                ),
                                set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                    parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                        destination_parameter_name="destinationParameterName",
                                        value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                            custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                    date_time_values=["dateTimeValues"],
                                                    decimal_values=[123],
                                                    integer_values=[123],
                                                    string_values=["stringValues"]
                                                ),
                
                                                # the properties below are optional
                                                include_null_value=False
                                            ),
                                            select_all_value_options="selectAllValueOptions",
                                            source_field="sourceField",
                                            source_parameter_name="sourceParameterName"
                                        )
                                    )]
                                ),
                                url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                    url_target="urlTarget",
                                    url_template="urlTemplate"
                                )
                            )],
                            custom_action_id="customActionId",
                            name="name",
                            trigger="trigger",
                
                            # the properties below are optional
                            status="status"
                        )],
                        chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                            category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                    apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId"
                                    ),
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    )
                                )],
                                sort_icon_visibility="sortIconVisibility",
                                visibility="visibility"
                            ),
                            field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            date_granularity="dateGranularity",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        ),
                                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            ),
                                            hierarchy_id="hierarchyId"
                                        )
                                    )],
                                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                            expression="expression",
                                            field_id="fieldId"
                                        ),
                                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function="aggregationFunction",
                                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                date_time_format="dateTimeFormat",
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        ),
                                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                column_name="columnName",
                                                data_set_identifier="dataSetIdentifier"
                                            ),
                                            field_id="fieldId",
                
                                            # the properties below are optional
                                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            ),
                                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                )
                            ),
                            sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                    items_limit=123,
                                    other_categories="otherCategories"
                                ),
                                category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                    column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                        direction="direction",
                                        sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                            categorical_aggregation_function="categoricalAggregationFunction",
                                            date_aggregation_function="dateAggregationFunction",
                                            numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                    percentile_value=123
                                                ),
                                                simple_numerical_aggregation="simpleNumericalAggregation"
                                            )
                                        )
                                    ),
                                    field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                        direction="direction",
                                        field_id="fieldId"
                                    )
                                )]
                            ),
                            word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                cloud_layout="cloudLayout",
                                maximum_string_length=123,
                                word_casing="wordCasing",
                                word_orientation="wordOrientation",
                                word_padding="wordPadding",
                                word_scaling="wordScaling"
                            )
                        ),
                        column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                            date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            ),
                            predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                )],
                                hierarchy_id="hierarchyId",
                
                                # the properties below are optional
                                drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                    category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                        category_values=["categoryValues"],
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )
                                    ),
                                    numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        value=123
                                    ),
                                    time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        range_maximum="rangeMaximum",
                                        range_minimum="rangeMinimum",
                                        time_granularity="timeGranularity"
                                    )
                                )]
                            )
                        )],
                        subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        ),
                        title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                            format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                plain_text="plainText",
                                rich_text="richText"
                            ),
                            visibility="visibility"
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__94617066dac431d6d1e9cc4cc969863ddd38f9d3baed868407524d9b482e111f)
                check_type(argname="argument bar_chart_visual", value=bar_chart_visual, expected_type=type_hints["bar_chart_visual"])
                check_type(argname="argument box_plot_visual", value=box_plot_visual, expected_type=type_hints["box_plot_visual"])
                check_type(argname="argument combo_chart_visual", value=combo_chart_visual, expected_type=type_hints["combo_chart_visual"])
                check_type(argname="argument custom_content_visual", value=custom_content_visual, expected_type=type_hints["custom_content_visual"])
                check_type(argname="argument empty_visual", value=empty_visual, expected_type=type_hints["empty_visual"])
                check_type(argname="argument filled_map_visual", value=filled_map_visual, expected_type=type_hints["filled_map_visual"])
                check_type(argname="argument funnel_chart_visual", value=funnel_chart_visual, expected_type=type_hints["funnel_chart_visual"])
                check_type(argname="argument gauge_chart_visual", value=gauge_chart_visual, expected_type=type_hints["gauge_chart_visual"])
                check_type(argname="argument geospatial_map_visual", value=geospatial_map_visual, expected_type=type_hints["geospatial_map_visual"])
                check_type(argname="argument heat_map_visual", value=heat_map_visual, expected_type=type_hints["heat_map_visual"])
                check_type(argname="argument histogram_visual", value=histogram_visual, expected_type=type_hints["histogram_visual"])
                check_type(argname="argument insight_visual", value=insight_visual, expected_type=type_hints["insight_visual"])
                check_type(argname="argument kpi_visual", value=kpi_visual, expected_type=type_hints["kpi_visual"])
                check_type(argname="argument line_chart_visual", value=line_chart_visual, expected_type=type_hints["line_chart_visual"])
                check_type(argname="argument pie_chart_visual", value=pie_chart_visual, expected_type=type_hints["pie_chart_visual"])
                check_type(argname="argument pivot_table_visual", value=pivot_table_visual, expected_type=type_hints["pivot_table_visual"])
                check_type(argname="argument radar_chart_visual", value=radar_chart_visual, expected_type=type_hints["radar_chart_visual"])
                check_type(argname="argument sankey_diagram_visual", value=sankey_diagram_visual, expected_type=type_hints["sankey_diagram_visual"])
                check_type(argname="argument scatter_plot_visual", value=scatter_plot_visual, expected_type=type_hints["scatter_plot_visual"])
                check_type(argname="argument table_visual", value=table_visual, expected_type=type_hints["table_visual"])
                check_type(argname="argument tree_map_visual", value=tree_map_visual, expected_type=type_hints["tree_map_visual"])
                check_type(argname="argument waterfall_visual", value=waterfall_visual, expected_type=type_hints["waterfall_visual"])
                check_type(argname="argument word_cloud_visual", value=word_cloud_visual, expected_type=type_hints["word_cloud_visual"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if bar_chart_visual is not None:
                self._values["bar_chart_visual"] = bar_chart_visual
            if box_plot_visual is not None:
                self._values["box_plot_visual"] = box_plot_visual
            if combo_chart_visual is not None:
                self._values["combo_chart_visual"] = combo_chart_visual
            if custom_content_visual is not None:
                self._values["custom_content_visual"] = custom_content_visual
            if empty_visual is not None:
                self._values["empty_visual"] = empty_visual
            if filled_map_visual is not None:
                self._values["filled_map_visual"] = filled_map_visual
            if funnel_chart_visual is not None:
                self._values["funnel_chart_visual"] = funnel_chart_visual
            if gauge_chart_visual is not None:
                self._values["gauge_chart_visual"] = gauge_chart_visual
            if geospatial_map_visual is not None:
                self._values["geospatial_map_visual"] = geospatial_map_visual
            if heat_map_visual is not None:
                self._values["heat_map_visual"] = heat_map_visual
            if histogram_visual is not None:
                self._values["histogram_visual"] = histogram_visual
            if insight_visual is not None:
                self._values["insight_visual"] = insight_visual
            if kpi_visual is not None:
                self._values["kpi_visual"] = kpi_visual
            if line_chart_visual is not None:
                self._values["line_chart_visual"] = line_chart_visual
            if pie_chart_visual is not None:
                self._values["pie_chart_visual"] = pie_chart_visual
            if pivot_table_visual is not None:
                self._values["pivot_table_visual"] = pivot_table_visual
            if radar_chart_visual is not None:
                self._values["radar_chart_visual"] = radar_chart_visual
            if sankey_diagram_visual is not None:
                self._values["sankey_diagram_visual"] = sankey_diagram_visual
            if scatter_plot_visual is not None:
                self._values["scatter_plot_visual"] = scatter_plot_visual
            if table_visual is not None:
                self._values["table_visual"] = table_visual
            if tree_map_visual is not None:
                self._values["tree_map_visual"] = tree_map_visual
            if waterfall_visual is not None:
                self._values["waterfall_visual"] = waterfall_visual
            if word_cloud_visual is not None:
                self._values["word_cloud_visual"] = word_cloud_visual

        @builtins.property
        def bar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BarChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A bar chart.

            For more information, see `Using bar charts <https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-barchartvisual
            '''
            result = self._values.get("bar_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BarChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def box_plot_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.BoxPlotVisualProperty", _IResolvable_a771d0ef]]:
            '''A box plot.

            For more information, see `Using box plots <https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-boxplotvisual
            '''
            result = self._values.get("box_plot_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.BoxPlotVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def combo_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ComboChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A combo chart.

            For more information, see `Using combo charts <https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-combochartvisual
            '''
            result = self._values.get("combo_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ComboChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def custom_content_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.CustomContentVisualProperty", _IResolvable_a771d0ef]]:
            '''A visual that contains custom content.

            For more information, see `Using custom visual content <https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-customcontentvisual
            '''
            result = self._values.get("custom_content_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.CustomContentVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def empty_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.EmptyVisualProperty", _IResolvable_a771d0ef]]:
            '''An empty visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-emptyvisual
            '''
            result = self._values.get("empty_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.EmptyVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def filled_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FilledMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A filled map.

            For more information, see `Creating filled maps <https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-filledmapvisual
            '''
            result = self._values.get("filled_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FilledMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def funnel_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.FunnelChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A funnel chart.

            For more information, see `Using funnel charts <https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-funnelchartvisual
            '''
            result = self._values.get("funnel_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.FunnelChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def gauge_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GaugeChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A gauge chart.

            For more information, see `Using gauge charts <https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-gaugechartvisual
            '''
            result = self._values.get("gauge_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GaugeChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def geospatial_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.GeospatialMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A geospatial map or a points on map visual.

            For more information, see `Creating point maps <https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-geospatialmapvisual
            '''
            result = self._values.get("geospatial_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.GeospatialMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def heat_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HeatMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A heat map.

            For more information, see `Using heat maps <https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-heatmapvisual
            '''
            result = self._values.get("heat_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HeatMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def histogram_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.HistogramVisualProperty", _IResolvable_a771d0ef]]:
            '''A histogram.

            For more information, see `Using histograms <https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-histogramvisual
            '''
            result = self._values.get("histogram_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.HistogramVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def insight_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.InsightVisualProperty", _IResolvable_a771d0ef]]:
            '''An insight visual.

            For more information, see `Working with insights <https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-insightvisual
            '''
            result = self._values.get("insight_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.InsightVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def kpi_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.KPIVisualProperty", _IResolvable_a771d0ef]]:
            '''A key performance indicator (KPI).

            For more information, see `Using KPIs <https://docs.aws.amazon.com/quicksight/latest/user/kpi.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-kpivisual
            '''
            result = self._values.get("kpi_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.KPIVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def line_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LineChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A line chart.

            For more information, see `Using line charts <https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-linechartvisual
            '''
            result = self._values.get("line_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LineChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def pie_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PieChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A pie or donut chart.

            For more information, see `Using pie charts <https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-piechartvisual
            '''
            result = self._values.get("pie_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PieChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def pivot_table_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.PivotTableVisualProperty", _IResolvable_a771d0ef]]:
            '''A pivot table.

            For more information, see `Using pivot tables <https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-pivottablevisual
            '''
            result = self._values.get("pivot_table_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.PivotTableVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def radar_chart_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.RadarChartVisualProperty", _IResolvable_a771d0ef]]:
            '''A radar chart visual.

            For more information, see `Using radar charts <https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-radarchartvisual
            '''
            result = self._values.get("radar_chart_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.RadarChartVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sankey_diagram_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.SankeyDiagramVisualProperty", _IResolvable_a771d0ef]]:
            '''A sankey diagram.

            For more information, see `Using Sankey diagrams <https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-sankeydiagramvisual
            '''
            result = self._values.get("sankey_diagram_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.SankeyDiagramVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def scatter_plot_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ScatterPlotVisualProperty", _IResolvable_a771d0ef]]:
            '''A scatter plot.

            For more information, see `Using scatter plots <https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-scatterplotvisual
            '''
            result = self._values.get("scatter_plot_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ScatterPlotVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def table_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TableVisualProperty", _IResolvable_a771d0ef]]:
            '''A table visual.

            For more information, see `Using tables as visuals <https://docs.aws.amazon.com/quicksight/latest/user/tabular.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-tablevisual
            '''
            result = self._values.get("table_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TableVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tree_map_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.TreeMapVisualProperty", _IResolvable_a771d0ef]]:
            '''A tree map.

            For more information, see `Using tree maps <https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-treemapvisual
            '''
            result = self._values.get("tree_map_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.TreeMapVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def waterfall_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WaterfallVisualProperty", _IResolvable_a771d0ef]]:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-waterfallvisual
            '''
            result = self._values.get("waterfall_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WaterfallVisualProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def word_cloud_visual(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WordCloudVisualProperty", _IResolvable_a771d0ef]]:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-wordcloudvisual
            '''
            result = self._values.get("word_cloud_visual")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WordCloudVisualProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualSubtitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[typing.Union["CfnTemplate.LongFormatTextProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The subtitle label options for a visual.

            :param format_text: The long text format of the subtitle label, such as plain text or rich text.
            :param visibility: The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_subtitle_label_options_property = quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__ec0457fd4f894e454f189fd73e7dd67b571dff3bc026a28388230b40bd065fdf)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LongFormatTextProperty", _IResolvable_a771d0ef]]:
            '''The long text format of the subtitle label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LongFormatTextProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the subtitle label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualSubtitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.VisualTitleLabelOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"format_text": "formatText", "visibility": "visibility"},
    )
    class VisualTitleLabelOptionsProperty:
        def __init__(
            self,
            *,
            format_text: typing.Optional[typing.Union[typing.Union["CfnTemplate.ShortFormatTextProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visibility: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The title label options for a visual.

            :param format_text: The short text format of the title label, such as plain text or rich text.
            :param visibility: The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                visual_title_label_options_property = quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                        plain_text="plainText",
                        rich_text="richText"
                    ),
                    visibility="visibility"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__99d156a534868d61dffa0b770f962b2ac7bdcce87b038bee4085ecf9700bafcb)
                check_type(argname="argument format_text", value=format_text, expected_type=type_hints["format_text"])
                check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if format_text is not None:
                self._values["format_text"] = format_text
            if visibility is not None:
                self._values["visibility"] = visibility

        @builtins.property
        def format_text(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ShortFormatTextProperty", _IResolvable_a771d0ef]]:
            '''The short text format of the title label, such as plain text or rich text.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-formattext
            '''
            result = self._values.get("format_text")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ShortFormatTextProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visibility(self) -> typing.Optional[builtins.str]:
            '''The visibility of the title label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-visibility
            '''
            result = self._values.get("visibility")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "VisualTitleLabelOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdowns": "breakdowns",
            "categories": "categories",
            "values": "values",
        },
    )
    class WaterfallChartAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            breakdowns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            categories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param breakdowns: The breakdown field wells of a waterfall visual.
            :param categories: The category field wells of a waterfall visual.
            :param values: The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_aggregated_field_wells_property = quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                    breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    values=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fae73bd55d45c795e1b57adaa16088621aacf974d1781c1d779a41b5a86350bd)
                check_type(argname="argument breakdowns", value=breakdowns, expected_type=type_hints["breakdowns"])
                check_type(argname="argument categories", value=categories, expected_type=type_hints["categories"])
                check_type(argname="argument values", value=values, expected_type=type_hints["values"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdowns is not None:
                self._values["breakdowns"] = breakdowns
            if categories is not None:
                self._values["categories"] = categories
            if values is not None:
                self._values["values"] = values

        @builtins.property
        def breakdowns(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The breakdown field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-breakdowns
            '''
            result = self._values.get("breakdowns")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def categories(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The category field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-categories
            '''
            result = self._values.get("categories")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def values(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The value field wells of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-values
            '''
            result = self._values.get("values")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WaterfallChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_axis_display_options": "categoryAxisDisplayOptions",
            "category_axis_label_options": "categoryAxisLabelOptions",
            "data_labels": "dataLabels",
            "field_wells": "fieldWells",
            "legend": "legend",
            "primary_y_axis_display_options": "primaryYAxisDisplayOptions",
            "primary_y_axis_label_options": "primaryYAxisLabelOptions",
            "sort_configuration": "sortConfiguration",
            "visual_palette": "visualPalette",
            "waterfall_chart_options": "waterfallChartOptions",
        },
    )
    class WaterfallChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            data_labels: typing.Optional[typing.Union[typing.Union["CfnTemplate.DataLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.WaterfallChartFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            legend: typing.Optional[typing.Union[typing.Union["CfnTemplate.LegendOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.WaterfallChartSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            visual_palette: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            waterfall_chart_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.WaterfallChartOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration for a waterfall visual.

            :param category_axis_display_options: The options that determine the presentation of the category axis.
            :param category_axis_label_options: The options that determine the presentation of the category axis label.
            :param data_labels: The data label configuration of a waterfall visual.
            :param field_wells: The field well configuration of a waterfall visual.
            :param legend: The legend configuration of a waterfall visual.
            :param primary_y_axis_display_options: The options that determine the presentation of the y-axis.
            :param primary_y_axis_label_options: The options that determine the presentation of the y-axis label.
            :param sort_configuration: The sort configuration of a waterfall visual.
            :param visual_palette: The visual palette configuration of a waterfall visual.
            :param waterfall_chart_options: The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_chart_configuration_property = quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                    category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                        category_label_visibility="categoryLabelVisibility",
                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                field_id="fieldId",
                                field_value="fieldValue",
                                visibility="visibility"
                            ),
                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                field_id="fieldId",
                                visibility="visibility"
                            ),
                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                visibility="visibility"
                            ),
                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                visibility="visibility"
                            )
                        )],
                        label_color="labelColor",
                        label_content="labelContent",
                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                            font_color="fontColor",
                            font_decoration="fontDecoration",
                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                relative="relative"
                            ),
                            font_style="fontStyle",
                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                name="name"
                            )
                        ),
                        measure_label_visibility="measureLabelVisibility",
                        overlap="overlap",
                        position="position",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                        waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                            breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                        height="height",
                        position="position",
                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            visibility="visibility"
                        ),
                        visibility="visibility",
                        width="width"
                    ),
                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                        axis_line_visibility="axisLineVisibility",
                        axis_offset="axisOffset",
                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                missing_date_visibility="missingDateVisibility"
                            ),
                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                    data_driven=data_driven,
                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                        maximum=123,
                                        minimum=123
                                    )
                                ),
                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                        step_count=123,
                                        step_size=123
                                    ),
                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                        base=123
                                    )
                                )
                            )
                        ),
                        grid_line_visibility="gridLineVisibility",
                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                            visibility="visibility",
                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                    from=123,
                                    to=123
                                )
                            )
                        ),
                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            rotation_angle=123
                        )
                    ),
                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                        breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                        chart_color="chartColor",
                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                            color="color",
                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                field_id="fieldId",
                                field_value="fieldValue"
                            ),
                
                            # the properties below are optional
                            time_granularity="timeGranularity"
                        )]
                    ),
                    waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                        total_bar_label="totalBarLabel"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b7770c9ee5b6f7cad35e8fa10aa668bf90463319caf6a5d77f19918d58775cc6)
                check_type(argname="argument category_axis_display_options", value=category_axis_display_options, expected_type=type_hints["category_axis_display_options"])
                check_type(argname="argument category_axis_label_options", value=category_axis_label_options, expected_type=type_hints["category_axis_label_options"])
                check_type(argname="argument data_labels", value=data_labels, expected_type=type_hints["data_labels"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument legend", value=legend, expected_type=type_hints["legend"])
                check_type(argname="argument primary_y_axis_display_options", value=primary_y_axis_display_options, expected_type=type_hints["primary_y_axis_display_options"])
                check_type(argname="argument primary_y_axis_label_options", value=primary_y_axis_label_options, expected_type=type_hints["primary_y_axis_label_options"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument visual_palette", value=visual_palette, expected_type=type_hints["visual_palette"])
                check_type(argname="argument waterfall_chart_options", value=waterfall_chart_options, expected_type=type_hints["waterfall_chart_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_axis_display_options is not None:
                self._values["category_axis_display_options"] = category_axis_display_options
            if category_axis_label_options is not None:
                self._values["category_axis_label_options"] = category_axis_label_options
            if data_labels is not None:
                self._values["data_labels"] = data_labels
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if legend is not None:
                self._values["legend"] = legend
            if primary_y_axis_display_options is not None:
                self._values["primary_y_axis_display_options"] = primary_y_axis_display_options
            if primary_y_axis_label_options is not None:
                self._values["primary_y_axis_label_options"] = primary_y_axis_label_options
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if visual_palette is not None:
                self._values["visual_palette"] = visual_palette
            if waterfall_chart_options is not None:
                self._values["waterfall_chart_options"] = waterfall_chart_options

        @builtins.property
        def category_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the category axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxisdisplayoptions
            '''
            result = self._values.get("category_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the category axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxislabeloptions
            '''
            result = self._values.get("category_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def data_labels(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The data label configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-datalabels
            '''
            result = self._values.get("data_labels")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.DataLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WaterfallChartFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WaterfallChartFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def legend(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]]:
            '''The legend configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-legend
            '''
            result = self._values.get("legend")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.LegendOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_display_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxisdisplayoptions
            '''
            result = self._values.get("primary_y_axis_display_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.AxisDisplayOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def primary_y_axis_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of the y-axis label.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxislabeloptions
            '''
            result = self._values.get("primary_y_axis_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WaterfallChartSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WaterfallChartSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def visual_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]]:
            '''The visual palette configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-visualpalette
            '''
            result = self._values.get("visual_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def waterfall_chart_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WaterfallChartOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options that determine the presentation of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-waterfallchartoptions
            '''
            result = self._values.get("waterfall_chart_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WaterfallChartOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WaterfallChartFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "waterfall_chart_aggregated_field_wells": "waterfallChartAggregatedFieldWells",
        },
    )
    class WaterfallChartFieldWellsProperty:
        def __init__(
            self,
            *,
            waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.WaterfallChartAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field well configuration of a waterfall visual.

            :param waterfall_chart_aggregated_field_wells: The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_field_wells_property = quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                    waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                        breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__44aa950d675113619606f670b6d66af14eda5977c5431dc0a07ed1993f36c026)
                check_type(argname="argument waterfall_chart_aggregated_field_wells", value=waterfall_chart_aggregated_field_wells, expected_type=type_hints["waterfall_chart_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if waterfall_chart_aggregated_field_wells is not None:
                self._values["waterfall_chart_aggregated_field_wells"] = waterfall_chart_aggregated_field_wells

        @builtins.property
        def waterfall_chart_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WaterfallChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field well configuration of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html#cfn-quicksight-template-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
            '''
            result = self._values.get("waterfall_chart_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WaterfallChartAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WaterfallChartOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={"total_bar_label": "totalBarLabel"},
    )
    class WaterfallChartOptionsProperty:
        def __init__(
            self,
            *,
            total_bar_label: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The options that determine the presentation of a waterfall visual.

            :param total_bar_label: This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_options_property = quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                    total_bar_label="totalBarLabel"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b3d4450fccecebae263839daa7cecc84ac23bd7e4599c0b872382593aa77b92f)
                check_type(argname="argument total_bar_label", value=total_bar_label, expected_type=type_hints["total_bar_label"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if total_bar_label is not None:
                self._values["total_bar_label"] = total_bar_label

        @builtins.property
        def total_bar_label(self) -> typing.Optional[builtins.str]:
            '''This option determines the total bar label of a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html#cfn-quicksight-template-waterfallchartoptions-totalbarlabel
            '''
            result = self._values.get("total_bar_label")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "breakdown_items_limit": "breakdownItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WaterfallChartSortConfigurationProperty:
        def __init__(
            self,
            *,
            breakdown_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a waterfall visual.

            :param breakdown_items_limit: The limit on the number of bar groups that are displayed.
            :param category_sort: The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                waterfall_chart_sort_configuration_property = quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                    breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__4d07b0596770d9530fdfa5f95b993ecb1a4a2de93bff84ad7d9c12481c25f5c2)
                check_type(argname="argument breakdown_items_limit", value=breakdown_items_limit, expected_type=type_hints["breakdown_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if breakdown_items_limit is not None:
                self._values["breakdown_items_limit"] = breakdown_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def breakdown_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of bar groups that are displayed.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-breakdownitemslimit
            '''
            result = self._values.get("breakdown_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of the category fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallChartSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WaterfallVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WaterfallVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.WaterfallChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A waterfall chart.

            For more information, see `Using waterfall charts <https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration for a waterfall visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                # data_driven: Any
                
                waterfall_visual_property = quicksight.CfnTemplate.WaterfallVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                        category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                            category_label_visibility="categoryLabelVisibility",
                            data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue",
                                    visibility="visibility"
                                ),
                                field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                    field_id="fieldId",
                                    visibility="visibility"
                                ),
                                maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                    visibility="visibility"
                                ),
                                range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                    visibility="visibility"
                                )
                            )],
                            label_color="labelColor",
                            label_content="labelContent",
                            label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            ),
                            measure_label_visibility="measureLabelVisibility",
                            overlap="overlap",
                            position="position",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                            waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        legend=quicksight.CfnTemplate.LegendOptionsProperty(
                            height="height",
                            position="position",
                            title=quicksight.CfnTemplate.LabelOptionsProperty(
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                ),
                                visibility="visibility"
                            ),
                            visibility="visibility",
                            width="width"
                        ),
                        primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                            axis_line_visibility="axisLineVisibility",
                            axis_offset="axisOffset",
                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                    missing_date_visibility="missingDateVisibility"
                                ),
                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                        data_driven=data_driven,
                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                            maximum=123,
                                            minimum=123
                                        )
                                    ),
                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                            step_count=123,
                                            step_size=123
                                        ),
                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                            base=123
                                        )
                                    )
                                )
                            ),
                            grid_line_visibility="gridLineVisibility",
                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                visibility="visibility",
                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                        from=123,
                                        to=123
                                    )
                                )
                            ),
                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                    custom_label="customLabel",
                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                        font_color="fontColor",
                                        font_decoration="fontDecoration",
                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                            relative="relative"
                                        ),
                                        font_style="fontStyle",
                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                            name="name"
                                        )
                                    ),
                                    visibility="visibility"
                                ),
                                rotation_angle=123
                            )
                        ),
                        primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                            breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                            chart_color="chartColor",
                            color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                color="color",
                                element=quicksight.CfnTemplate.DataPathValueProperty(
                                    field_id="fieldId",
                                    field_value="fieldValue"
                                ),
                
                                # the properties below are optional
                                time_granularity="timeGranularity"
                            )]
                        ),
                        waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                            total_bar_label="totalBarLabel"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__349931aa27d35e365adafc4ecf5d589c25992ee8dafcd6cb2436e1d2843a6ab9)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WaterfallChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration for a waterfall visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WaterfallChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WaterfallVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WhatIfPointScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={"date": "date", "value": "value"},
    )
    class WhatIfPointScenarioProperty:
        def __init__(self, *, date: builtins.str, value: jsii.Number) -> None:
            '''Provides the forecast to meet the target for a particular date.

            :param date: The date that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                what_if_point_scenario_property = quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                    date="date",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__db466a8f201bac80314ce2aa6052fd09f80de7a3dc33c514a0e204828dde66ed)
                check_type(argname="argument date", value=date, expected_type=type_hints["date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "date": date,
                "value": value,
            }

        @builtins.property
        def date(self) -> builtins.str:
            '''The date that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-date
            '''
            result = self._values.get("date")
            assert result is not None, "Required property 'date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfPointScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WhatIfRangeScenarioProperty",
        jsii_struct_bases=[],
        name_mapping={
            "end_date": "endDate",
            "start_date": "startDate",
            "value": "value",
        },
    )
    class WhatIfRangeScenarioProperty:
        def __init__(
            self,
            *,
            end_date: builtins.str,
            start_date: builtins.str,
            value: jsii.Number,
        ) -> None:
            '''Provides the forecast to meet the target for a particular date range.

            :param end_date: The end date in the date range that you need the forecast results for.
            :param start_date: The start date in the date range that you need the forecast results for.
            :param value: The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                what_if_range_scenario_property = quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                    end_date="endDate",
                    start_date="startDate",
                    value=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b4e75f5d566010e31b97cb53ad3f77cf4cc5d6eb86a0ffbf18dd8cba73bcdc85)
                check_type(argname="argument end_date", value=end_date, expected_type=type_hints["end_date"])
                check_type(argname="argument start_date", value=start_date, expected_type=type_hints["start_date"])
                check_type(argname="argument value", value=value, expected_type=type_hints["value"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "end_date": end_date,
                "start_date": start_date,
                "value": value,
            }

        @builtins.property
        def end_date(self) -> builtins.str:
            '''The end date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-enddate
            '''
            result = self._values.get("end_date")
            assert result is not None, "Required property 'end_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def start_date(self) -> builtins.str:
            '''The start date in the date range that you need the forecast results for.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-startdate
            '''
            result = self._values.get("start_date")
            assert result is not None, "Required property 'start_date' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def value(self) -> jsii.Number:
            '''The target value that you want to meet for the provided date range.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-value
            '''
            result = self._values.get("value")
            assert result is not None, "Required property 'value' is missing"
            return typing.cast(jsii.Number, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WhatIfRangeScenarioProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={"group_by": "groupBy", "size": "size"},
    )
    class WordCloudAggregatedFieldWellsProperty:
        def __init__(
            self,
            *,
            group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.DimensionFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.MeasureFieldProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The aggregated field wells of a word cloud.

            :param group_by: The group by field well of a word cloud. Values are grouped by group by fields.
            :param size: The size field well of a word cloud. Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_aggregated_field_wells_property = quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                    group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                        categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            date_granularity="dateGranularity",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        ),
                        numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            hierarchy_id="hierarchyId"
                        )
                    )],
                    size=[quicksight.CfnTemplate.MeasureFieldProperty(
                        calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                            expression="expression",
                            field_id="fieldId"
                        ),
                        categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function="aggregationFunction",
                            format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                            column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                            field_id="fieldId",
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                    percentile_value=123
                                ),
                                simple_numerical_aggregation="simpleNumericalAggregation"
                            ),
                            format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__2a894ae8004f4a15e1255485902243a214aa76ba738111b84c923876f263d5e2)
                check_type(argname="argument group_by", value=group_by, expected_type=type_hints["group_by"])
                check_type(argname="argument size", value=size, expected_type=type_hints["size"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if group_by is not None:
                self._values["group_by"] = group_by
            if size is not None:
                self._values["size"] = size

        @builtins.property
        def group_by(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The group by field well of a word cloud.

            Values are grouped by group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-groupby
            '''
            result = self._values.get("group_by")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.DimensionFieldProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def size(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]]:
            '''The size field well of a word cloud.

            Values are aggregated based on group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-size
            '''
            result = self._values.get("size")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.MeasureFieldProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudAggregatedFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WordCloudChartConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_label_options": "categoryLabelOptions",
            "field_wells": "fieldWells",
            "sort_configuration": "sortConfiguration",
            "word_cloud_options": "wordCloudOptions",
        },
    )
    class WordCloudChartConfigurationProperty:
        def __init__(
            self,
            *,
            category_label_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.WordCloudFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sort_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.WordCloudSortConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            word_cloud_options: typing.Optional[typing.Union[typing.Union["CfnTemplate.WordCloudOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The configuration of a word cloud visual.

            :param category_label_options: The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
            :param field_wells: The field wells of the visual.
            :param sort_configuration: The sort configuration of a word cloud visual.
            :param word_cloud_options: The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_chart_configuration_property = quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId"
                            ),
                            custom_label="customLabel",
                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                font_color="fontColor",
                                font_decoration="fontDecoration",
                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                    relative="relative"
                                ),
                                font_style="fontStyle",
                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                    name="name"
                                )
                            )
                        )],
                        sort_icon_visibility="sortIconVisibility",
                        visibility="visibility"
                    ),
                    field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                        word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    date_granularity="dateGranularity",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                ),
                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    ),
                                    hierarchy_id="hierarchyId"
                                )
                            )],
                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                    expression="expression",
                                    field_id="fieldId"
                                ),
                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function="aggregationFunction",
                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                        date_time_format="dateTimeFormat",
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                ),
                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId",
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    ),
                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix",
                                                symbol="symbol"
                                            ),
                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                number_scale="numberScale",
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            ),
                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                    decimal_places=123
                                                ),
                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                    display_mode="displayMode"
                                                ),
                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                    null_string="nullString"
                                                ),
                                                prefix="prefix",
                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                    decimal_separator="decimalSeparator",
                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                        symbol="symbol",
                                                        visibility="visibility"
                                                    )
                                                ),
                                                suffix="suffix"
                                            )
                                        )
                                    )
                                )
                            )]
                        )
                    ),
                    sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                            items_limit=123,
                            other_categories="otherCategories"
                        ),
                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                direction="direction",
                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                )
                            ),
                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                direction="direction",
                                field_id="fieldId"
                            )
                        )]
                    ),
                    word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                        cloud_layout="cloudLayout",
                        maximum_string_length=123,
                        word_casing="wordCasing",
                        word_orientation="wordOrientation",
                        word_padding="wordPadding",
                        word_scaling="wordScaling"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__90eea703566cd49cbfbb1bc905a08243b9a7da7f9f36bd5e9bd33397cbbf6bfe)
                check_type(argname="argument category_label_options", value=category_label_options, expected_type=type_hints["category_label_options"])
                check_type(argname="argument field_wells", value=field_wells, expected_type=type_hints["field_wells"])
                check_type(argname="argument sort_configuration", value=sort_configuration, expected_type=type_hints["sort_configuration"])
                check_type(argname="argument word_cloud_options", value=word_cloud_options, expected_type=type_hints["word_cloud_options"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_label_options is not None:
                self._values["category_label_options"] = category_label_options
            if field_wells is not None:
                self._values["field_wells"] = field_wells
            if sort_configuration is not None:
                self._values["sort_configuration"] = sort_configuration
            if word_cloud_options is not None:
                self._values["word_cloud_options"] = word_cloud_options

        @builtins.property
        def category_label_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The label options (label text, label visibility, and sort icon visibility) for the word cloud category.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-categorylabeloptions
            '''
            result = self._values.get("category_label_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ChartAxisLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WordCloudFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The field wells of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-fieldwells
            '''
            result = self._values.get("field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WordCloudFieldWellsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sort_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WordCloudSortConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The sort configuration of a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-sortconfiguration
            '''
            result = self._values.get("sort_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WordCloudSortConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def word_cloud_options(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WordCloudOptionsProperty", _IResolvable_a771d0ef]]:
            '''The options for a word cloud visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-wordcloudoptions
            '''
            result = self._values.get("word_cloud_options")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WordCloudOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudChartConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WordCloudFieldWellsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "word_cloud_aggregated_field_wells": "wordCloudAggregatedFieldWells",
        },
    )
    class WordCloudFieldWellsProperty:
        def __init__(
            self,
            *,
            word_cloud_aggregated_field_wells: typing.Optional[typing.Union[typing.Union["CfnTemplate.WordCloudAggregatedFieldWellsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The field wells of a word cloud visual.

            This is a union type structure. For this structure to be valid, only one of the attributes can be defined.

            :param word_cloud_aggregated_field_wells: The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_field_wells_property = quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                    word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                        group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                date_granularity="dateGranularity",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            ),
                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                ),
                                hierarchy_id="hierarchyId"
                            )
                        )],
                        size=[quicksight.CfnTemplate.MeasureFieldProperty(
                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                expression="expression",
                                field_id="fieldId"
                            ),
                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function="aggregationFunction",
                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                    date_time_format="dateTimeFormat",
                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                        null_string="nullString"
                                    ),
                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            ),
                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                field_id="fieldId",
                
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                ),
                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix",
                                            symbol="symbol"
                                        ),
                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            number_scale="numberScale",
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        ),
                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                decimal_places=123
                                            ),
                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                display_mode="displayMode"
                                            ),
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            prefix="prefix",
                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                decimal_separator="decimalSeparator",
                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                    symbol="symbol",
                                                    visibility="visibility"
                                                )
                                            ),
                                            suffix="suffix"
                                        )
                                    )
                                )
                            )
                        )]
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__a10a28e8deeca1e1d0db3b5c40903878c7824a172b9b9a0784598da367c85c47)
                check_type(argname="argument word_cloud_aggregated_field_wells", value=word_cloud_aggregated_field_wells, expected_type=type_hints["word_cloud_aggregated_field_wells"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if word_cloud_aggregated_field_wells is not None:
                self._values["word_cloud_aggregated_field_wells"] = word_cloud_aggregated_field_wells

        @builtins.property
        def word_cloud_aggregated_field_wells(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WordCloudAggregatedFieldWellsProperty", _IResolvable_a771d0ef]]:
            '''The aggregated field wells of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html#cfn-quicksight-template-wordcloudfieldwells-wordcloudaggregatedfieldwells
            '''
            result = self._values.get("word_cloud_aggregated_field_wells")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WordCloudAggregatedFieldWellsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudFieldWellsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WordCloudOptionsProperty",
        jsii_struct_bases=[],
        name_mapping={
            "cloud_layout": "cloudLayout",
            "maximum_string_length": "maximumStringLength",
            "word_casing": "wordCasing",
            "word_orientation": "wordOrientation",
            "word_padding": "wordPadding",
            "word_scaling": "wordScaling",
        },
    )
    class WordCloudOptionsProperty:
        def __init__(
            self,
            *,
            cloud_layout: typing.Optional[builtins.str] = None,
            maximum_string_length: typing.Optional[jsii.Number] = None,
            word_casing: typing.Optional[builtins.str] = None,
            word_orientation: typing.Optional[builtins.str] = None,
            word_padding: typing.Optional[builtins.str] = None,
            word_scaling: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The word cloud options for a word cloud visual.

            :param cloud_layout: The cloud layout options (fluid, normal) of a word cloud.
            :param maximum_string_length: The length limit of each word from 1-100.
            :param word_casing: The word casing options (lower_case, existing_case) for the words in a word cloud.
            :param word_orientation: The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
            :param word_padding: The word padding options (none, small, medium, large) for the words in a word cloud.
            :param word_scaling: The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_options_property = quicksight.CfnTemplate.WordCloudOptionsProperty(
                    cloud_layout="cloudLayout",
                    maximum_string_length=123,
                    word_casing="wordCasing",
                    word_orientation="wordOrientation",
                    word_padding="wordPadding",
                    word_scaling="wordScaling"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__59de0ecf1a2d393a508663c061e016f99705f118c32f5e96179eed6539faf04b)
                check_type(argname="argument cloud_layout", value=cloud_layout, expected_type=type_hints["cloud_layout"])
                check_type(argname="argument maximum_string_length", value=maximum_string_length, expected_type=type_hints["maximum_string_length"])
                check_type(argname="argument word_casing", value=word_casing, expected_type=type_hints["word_casing"])
                check_type(argname="argument word_orientation", value=word_orientation, expected_type=type_hints["word_orientation"])
                check_type(argname="argument word_padding", value=word_padding, expected_type=type_hints["word_padding"])
                check_type(argname="argument word_scaling", value=word_scaling, expected_type=type_hints["word_scaling"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if cloud_layout is not None:
                self._values["cloud_layout"] = cloud_layout
            if maximum_string_length is not None:
                self._values["maximum_string_length"] = maximum_string_length
            if word_casing is not None:
                self._values["word_casing"] = word_casing
            if word_orientation is not None:
                self._values["word_orientation"] = word_orientation
            if word_padding is not None:
                self._values["word_padding"] = word_padding
            if word_scaling is not None:
                self._values["word_scaling"] = word_scaling

        @builtins.property
        def cloud_layout(self) -> typing.Optional[builtins.str]:
            '''The cloud layout options (fluid, normal) of a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-cloudlayout
            '''
            result = self._values.get("cloud_layout")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def maximum_string_length(self) -> typing.Optional[jsii.Number]:
            '''The length limit of each word from 1-100.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-maximumstringlength
            '''
            result = self._values.get("maximum_string_length")
            return typing.cast(typing.Optional[jsii.Number], result)

        @builtins.property
        def word_casing(self) -> typing.Optional[builtins.str]:
            '''The word casing options (lower_case, existing_case) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordcasing
            '''
            result = self._values.get("word_casing")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_orientation(self) -> typing.Optional[builtins.str]:
            '''The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordorientation
            '''
            result = self._values.get("word_orientation")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_padding(self) -> typing.Optional[builtins.str]:
            '''The word padding options (none, small, medium, large) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordpadding
            '''
            result = self._values.get("word_padding")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def word_scaling(self) -> typing.Optional[builtins.str]:
            '''The word scaling options (emphasize, normal) for the words in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordscaling
            '''
            result = self._values.get("word_scaling")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudOptionsProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WordCloudSortConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "category_items_limit": "categoryItemsLimit",
            "category_sort": "categorySort",
        },
    )
    class WordCloudSortConfigurationProperty:
        def __init__(
            self,
            *,
            category_items_limit: typing.Optional[typing.Union[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.FieldSortOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''The sort configuration of a word cloud visual.

            :param category_items_limit: The limit on the number of groups that are displayed in a word cloud.
            :param category_sort: The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_sort_configuration_property = quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                    category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                        items_limit=123,
                        other_categories="otherCategories"
                    ),
                    category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                        column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                            direction="direction",
                            sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            ),
                
                            # the properties below are optional
                            aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                categorical_aggregation_function="categoricalAggregationFunction",
                                date_aggregation_function="dateAggregationFunction",
                                numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                        percentile_value=123
                                    ),
                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                )
                            )
                        ),
                        field_sort=quicksight.CfnTemplate.FieldSortProperty(
                            direction="direction",
                            field_id="fieldId"
                        )
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__daf26766c1808f1a3d31f5f2e6b376b85037677e1754584dd891a789cd12d670)
                check_type(argname="argument category_items_limit", value=category_items_limit, expected_type=type_hints["category_items_limit"])
                check_type(argname="argument category_sort", value=category_sort, expected_type=type_hints["category_sort"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if category_items_limit is not None:
                self._values["category_items_limit"] = category_items_limit
            if category_sort is not None:
                self._values["category_sort"] = category_sort

        @builtins.property
        def category_items_limit(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The limit on the number of groups that are displayed in a word cloud.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categoryitemslimit
            '''
            result = self._values.get("category_items_limit")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.ItemsLimitConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def category_sort(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]]:
            '''The sort configuration of group by fields.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categorysort
            '''
            result = self._values.get("category_sort")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.FieldSortOptionsProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudSortConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTemplate.WordCloudVisualProperty",
        jsii_struct_bases=[],
        name_mapping={
            "visual_id": "visualId",
            "actions": "actions",
            "chart_configuration": "chartConfiguration",
            "column_hierarchies": "columnHierarchies",
            "subtitle": "subtitle",
            "title": "title",
        },
    )
    class WordCloudVisualProperty:
        def __init__(
            self,
            *,
            visual_id: builtins.str,
            actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.VisualCustomActionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            chart_configuration: typing.Optional[typing.Union[typing.Union["CfnTemplate.WordCloudChartConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTemplate.ColumnHierarchyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            subtitle: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            title: typing.Optional[typing.Union[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''A word cloud.

            For more information, see `Using word clouds <https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html>`_ in the *Amazon QuickSight User Guide* .

            :param visual_id: The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
            :param actions: The list of custom actions that are configured for a visual.
            :param chart_configuration: The configuration settings of the visual.
            :param column_hierarchies: The column hierarchy that is used during drill-downs and drill-ups.
            :param subtitle: The subtitle that is displayed on the visual.
            :param title: The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                word_cloud_visual_property = quicksight.CfnTemplate.WordCloudVisualProperty(
                    visual_id="visualId",
                
                    # the properties below are optional
                    actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                        action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                            filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                    selected_field_options="selectedFieldOptions",
                                    selected_fields=["selectedFields"]
                                ),
                                target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                    same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                        target_visual_options="targetVisualOptions",
                                        target_visuals=["targetVisuals"]
                                    )
                                )
                            ),
                            navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                    target_sheet_id="targetSheetId"
                                )
                            ),
                            set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                    destination_parameter_name="destinationParameterName",
                                    value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                        custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                            custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                date_time_values=["dateTimeValues"],
                                                decimal_values=[123],
                                                integer_values=[123],
                                                string_values=["stringValues"]
                                            ),
                
                                            # the properties below are optional
                                            include_null_value=False
                                        ),
                                        select_all_value_options="selectAllValueOptions",
                                        source_field="sourceField",
                                        source_parameter_name="sourceParameterName"
                                    )
                                )]
                            ),
                            url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                url_target="urlTarget",
                                url_template="urlTemplate"
                            )
                        )],
                        custom_action_id="customActionId",
                        name="name",
                        trigger="trigger",
                
                        # the properties below are optional
                        status="status"
                    )],
                    chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                        category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                            axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    field_id="fieldId"
                                ),
                                custom_label="customLabel",
                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                    font_color="fontColor",
                                    font_decoration="fontDecoration",
                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                        relative="relative"
                                    ),
                                    font_style="fontStyle",
                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                        name="name"
                                    )
                                )
                            )],
                            sort_icon_visibility="sortIconVisibility",
                            visibility="visibility"
                        ),
                        field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                            word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                    categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        date_granularity="dateGranularity",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    ),
                                    numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        ),
                                        hierarchy_id="hierarchyId"
                                    )
                                )],
                                size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                    calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                        expression="expression",
                                        field_id="fieldId"
                                    ),
                                    categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function="aggregationFunction",
                                        format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                            date_time_format="dateTimeFormat",
                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                null_string="nullString"
                                            ),
                                            numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    ),
                                    numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        field_id="fieldId",
                
                                        # the properties below are optional
                                        aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        ),
                                        format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                            format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix",
                                                    symbol="symbol"
                                                ),
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            )
                                        )
                                    )
                                )]
                            )
                        ),
                        sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                            category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                items_limit=123,
                                other_categories="otherCategories"
                            ),
                            category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                    direction="direction",
                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                
                                    # the properties below are optional
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    )
                                ),
                                field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                    direction="direction",
                                    field_id="fieldId"
                                )
                            )]
                        ),
                        word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                            cloud_layout="cloudLayout",
                            maximum_string_length=123,
                            word_casing="wordCasing",
                            word_orientation="wordOrientation",
                            word_padding="wordPadding",
                            word_scaling="wordScaling"
                        )
                    ),
                    column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                        date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        ),
                        predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                            columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                column_name="columnName",
                                data_set_identifier="dataSetIdentifier"
                            )],
                            hierarchy_id="hierarchyId",
                
                            # the properties below are optional
                            drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                    category_values=["categoryValues"],
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    value=123
                                ),
                                time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    range_maximum="rangeMaximum",
                                    range_minimum="rangeMinimum",
                                    time_granularity="timeGranularity"
                                )
                            )]
                        )
                    )],
                    subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    ),
                    title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                        format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                            plain_text="plainText",
                            rich_text="richText"
                        ),
                        visibility="visibility"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dbba2b5b96dd68e2ea09ffee22657fa4f8dcec50ad9e048ecc43f2aa9711dc38)
                check_type(argname="argument visual_id", value=visual_id, expected_type=type_hints["visual_id"])
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument chart_configuration", value=chart_configuration, expected_type=type_hints["chart_configuration"])
                check_type(argname="argument column_hierarchies", value=column_hierarchies, expected_type=type_hints["column_hierarchies"])
                check_type(argname="argument subtitle", value=subtitle, expected_type=type_hints["subtitle"])
                check_type(argname="argument title", value=title, expected_type=type_hints["title"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "visual_id": visual_id,
            }
            if actions is not None:
                self._values["actions"] = actions
            if chart_configuration is not None:
                self._values["chart_configuration"] = chart_configuration
            if column_hierarchies is not None:
                self._values["column_hierarchies"] = column_hierarchies
            if subtitle is not None:
                self._values["subtitle"] = subtitle
            if title is not None:
                self._values["title"] = title

        @builtins.property
        def visual_id(self) -> builtins.str:
            '''The unique identifier of a visual.

            This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-visualid
            '''
            result = self._values.get("visual_id")
            assert result is not None, "Required property 'visual_id' is missing"
            return typing.cast(builtins.str, result)

        @builtins.property
        def actions(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]]:
            '''The list of custom actions that are configured for a visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-actions
            '''
            result = self._values.get("actions")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.VisualCustomActionProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def chart_configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.WordCloudChartConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The configuration settings of the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-chartconfiguration
            '''
            result = self._values.get("chart_configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.WordCloudChartConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def column_hierarchies(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]]:
            '''The column hierarchy that is used during drill-downs and drill-ups.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-columnhierarchies
            '''
            result = self._values.get("column_hierarchies")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTemplate.ColumnHierarchyProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def subtitle(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The subtitle that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-subtitle
            '''
            result = self._values.get("subtitle")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualSubtitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def title(
            self,
        ) -> typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]]:
            '''The title that is displayed on the visual.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-title
            '''
            result = self._values.get("title")
            return typing.cast(typing.Optional[typing.Union["CfnTemplate.VisualTitleLabelOptionsProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "WordCloudVisualProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnTemplateProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "template_id": "templateId",
        "definition": "definition",
        "name": "name",
        "permissions": "permissions",
        "source_entity": "sourceEntity",
        "tags": "tags",
        "version_description": "versionDescription",
    },
)
class CfnTemplateProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        template_id: builtins.str,
        definition: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        source_entity: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTemplate``.

        :param aws_account_id: The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
        :param template_id: An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
        :param definition: ``AWS::QuickSight::Template.Definition``.
        :param name: A display name for the template.
        :param permissions: A list of resource permissions to be set on the template.
        :param source_entity: The entity that you are using as a source when you create the template. In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region . Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.
        :param tags: Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
        :param version_description: A description of the current template version being created. This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            # data_driven: Any
            
            cfn_template_props = quicksight.CfnTemplateProps(
                aws_account_id="awsAccountId",
                template_id="templateId",
            
                # the properties below are optional
                definition=quicksight.CfnTemplate.TemplateVersionDefinitionProperty(
                    data_set_configurations=[quicksight.CfnTemplate.DataSetConfigurationProperty(
                        column_group_schema_list=[quicksight.CfnTemplate.ColumnGroupSchemaProperty(
                            column_group_column_schema_list=[quicksight.CfnTemplate.ColumnGroupColumnSchemaProperty(
                                name="name"
                            )],
                            name="name"
                        )],
                        data_set_schema=quicksight.CfnTemplate.DataSetSchemaProperty(
                            column_schema_list=[quicksight.CfnTemplate.ColumnSchemaProperty(
                                data_type="dataType",
                                geographic_role="geographicRole",
                                name="name"
                            )]
                        ),
                        placeholder="placeholder"
                    )],
            
                    # the properties below are optional
                    analysis_defaults=quicksight.CfnTemplate.AnalysisDefaultsProperty(
                        default_new_sheet_configuration=quicksight.CfnTemplate.DefaultNewSheetConfigurationProperty(
                            interactive_layout_configuration=quicksight.CfnTemplate.DefaultInteractiveLayoutConfigurationProperty(
                                free_form=quicksight.CfnTemplate.DefaultFreeFormLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid=quicksight.CfnTemplate.DefaultGridLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            ),
                            paginated_layout_configuration=quicksight.CfnTemplate.DefaultPaginatedLayoutConfigurationProperty(
                                section_based=quicksight.CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty(
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    )
                                )
                            ),
                            sheet_content_type="sheetContentType"
                        )
                    ),
                    calculated_fields=[quicksight.CfnTemplate.CalculatedFieldProperty(
                        data_set_identifier="dataSetIdentifier",
                        expression="expression",
                        name="name"
                    )],
                    column_configurations=[quicksight.CfnTemplate.ColumnConfigurationProperty(
                        column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                            column_name="columnName",
                            data_set_identifier="dataSetIdentifier"
                        ),
            
                        # the properties below are optional
                        colors_configuration=quicksight.CfnTemplate.ColorsConfigurationProperty(
                            custom_colors=[quicksight.CfnTemplate.CustomColorProperty(
                                color="color",
            
                                # the properties below are optional
                                field_value="fieldValue",
                                special_value="specialValue"
                            )]
                        ),
                        format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                            date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                date_time_format="dateTimeFormat",
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            ),
                            string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                    null_string="nullString"
                                ),
                                numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix",
                                        symbol="symbol"
                                    ),
                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        number_scale="numberScale",
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    ),
                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                            decimal_places=123
                                        ),
                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                            display_mode="displayMode"
                                        ),
                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                            null_string="nullString"
                                        ),
                                        prefix="prefix",
                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                            decimal_separator="decimalSeparator",
                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                symbol="symbol",
                                                visibility="visibility"
                                            )
                                        ),
                                        suffix="suffix"
                                    )
                                )
                            )
                        ),
                        role="role"
                    )],
                    filter_groups=[quicksight.CfnTemplate.FilterGroupProperty(
                        cross_dataset="crossDataset",
                        filter_group_id="filterGroupId",
                        filters=[quicksight.CfnTemplate.FilterProperty(
                            category_filter=quicksight.CfnTemplate.CategoryFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                configuration=quicksight.CfnTemplate.CategoryFilterConfigurationProperty(
                                    custom_filter_configuration=quicksight.CfnTemplate.CustomFilterConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_value="categoryValue",
                                        parameter_name="parameterName",
                                        select_all_options="selectAllOptions"
                                    ),
                                    custom_filter_list_configuration=quicksight.CfnTemplate.CustomFilterListConfigurationProperty(
                                        match_operator="matchOperator",
                                        null_option="nullOption",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    ),
                                    filter_list_configuration=quicksight.CfnTemplate.FilterListConfigurationProperty(
                                        match_operator="matchOperator",
            
                                        # the properties below are optional
                                        category_values=["categoryValues"],
                                        select_all_options="selectAllOptions"
                                    )
                                ),
                                filter_id="filterId"
                            ),
                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                match_operator="matchOperator",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                parameter_name="parameterName",
                                select_all_options="selectAllOptions",
                                value=123
                            ),
                            numeric_range_filter=quicksight.CfnTemplate.NumericRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                    categorical_aggregation_function="categoricalAggregationFunction",
                                    date_aggregation_function="dateAggregationFunction",
                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                            percentile_value=123
                                        ),
                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                    )
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                range_minimum=quicksight.CfnTemplate.NumericRangeFilterValueProperty(
                                    parameter="parameter",
                                    static_value=123
                                ),
                                select_all_options="selectAllOptions"
                            ),
                            relative_dates_filter=quicksight.CfnTemplate.RelativeDatesFilterProperty(
                                anchor_date_configuration=quicksight.CfnTemplate.AnchorDateConfigurationProperty(
                                    anchor_option="anchorOption",
                                    parameter_name="parameterName"
                                ),
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
                                relative_date_type="relativeDateType",
                                time_granularity="timeGranularity",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                minimum_granularity="minimumGranularity",
                                parameter_name="parameterName",
                                relative_date_value=123
                            ),
                            time_equality_filter=quicksight.CfnTemplate.TimeEqualityFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                parameter_name="parameterName",
                                time_granularity="timeGranularity",
                                value="value"
                            ),
                            time_range_filter=quicksight.CfnTemplate.TimeRangeFilterProperty(
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
                                null_option="nullOption",
            
                                # the properties below are optional
                                exclude_period_configuration=quicksight.CfnTemplate.ExcludePeriodConfigurationProperty(
                                    amount=123,
                                    granularity="granularity",
            
                                    # the properties below are optional
                                    status="status"
                                ),
                                include_maximum=False,
                                include_minimum=False,
                                range_maximum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                range_minimum_value=quicksight.CfnTemplate.TimeRangeFilterValueProperty(
                                    parameter="parameter",
                                    rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                        expression="expression",
            
                                        # the properties below are optional
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    static_value="staticValue"
                                ),
                                time_granularity="timeGranularity"
                            ),
                            top_bottom_filter=quicksight.CfnTemplate.TopBottomFilterProperty(
                                aggregation_sort_configurations=[quicksight.CfnTemplate.AggregationSortConfigurationProperty(
                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                        categorical_aggregation_function="categoricalAggregationFunction",
                                        date_aggregation_function="dateAggregationFunction",
                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                percentile_value=123
                                            ),
                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                        )
                                    ),
                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    sort_direction="sortDirection"
                                )],
                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                    column_name="columnName",
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                filter_id="filterId",
            
                                # the properties below are optional
                                limit=123,
                                parameter_name="parameterName",
                                time_granularity="timeGranularity"
                            )
                        )],
                        scope_configuration=quicksight.CfnTemplate.FilterScopeConfigurationProperty(
                            selected_sheets=quicksight.CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty(
                                sheet_visual_scoping_configurations=[quicksight.CfnTemplate.SheetVisualScopingConfigurationProperty(
                                    scope="scope",
                                    sheet_id="sheetId",
            
                                    # the properties below are optional
                                    visual_ids=["visualIds"]
                                )]
                            )
                        ),
            
                        # the properties below are optional
                        status="status"
                    )],
                    parameter_declarations=[quicksight.CfnTemplate.ParameterDeclarationProperty(
                        date_time_parameter_declaration=quicksight.CfnTemplate.DateTimeParameterDeclarationProperty(
                            name="name",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DateTimeDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                rolling_date=quicksight.CfnTemplate.RollingDateConfigurationProperty(
                                    expression="expression",
            
                                    # the properties below are optional
                                    data_set_identifier="dataSetIdentifier"
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            time_granularity="timeGranularity",
                            value_when_unset=quicksight.CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        decimal_parameter_declaration=quicksight.CfnTemplate.DecimalParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.DecimalDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.DecimalValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        integer_parameter_declaration=quicksight.CfnTemplate.IntegerParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.IntegerDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=[123]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.IntegerValueWhenUnsetConfigurationProperty(
                                custom_value=123,
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        ),
                        string_parameter_declaration=quicksight.CfnTemplate.StringParameterDeclarationProperty(
                            name="name",
                            parameter_value_type="parameterValueType",
            
                            # the properties below are optional
                            default_values=quicksight.CfnTemplate.StringDefaultValuesProperty(
                                dynamic_value=quicksight.CfnTemplate.DynamicDefaultValueProperty(
                                    default_value_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
            
                                    # the properties below are optional
                                    group_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    user_name_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    )
                                ),
                                static_values=["staticValues"]
                            ),
                            mapped_data_set_parameters=[quicksight.CfnTemplate.MappedDataSetParameterProperty(
                                data_set_identifier="dataSetIdentifier",
                                data_set_parameter_name="dataSetParameterName"
                            )],
                            value_when_unset=quicksight.CfnTemplate.StringValueWhenUnsetConfigurationProperty(
                                custom_value="customValue",
                                value_when_unset_option="valueWhenUnsetOption"
                            )
                        )
                    )],
                    sheets=[quicksight.CfnTemplate.SheetDefinitionProperty(
                        sheet_id="sheetId",
            
                        # the properties below are optional
                        content_type="contentType",
                        description="description",
                        filter_controls=[quicksight.CfnTemplate.FilterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.FilterDateTimePickerControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            dropdown=quicksight.CfnTemplate.FilterDropDownControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.FilterListControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.FilterSelectableValuesProperty(
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            relative_date_time=quicksight.CfnTemplate.FilterRelativeDateTimeControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            slider=quicksight.CfnTemplate.FilterSliderControlProperty(
                                filter_control_id="filterControlId",
                                maximum_value=123,
                                minimum_value=123,
                                source_filter_id="sourceFilterId",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                type="type"
                            ),
                            text_area=quicksight.CfnTemplate.FilterTextAreaControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.FilterTextFieldControlProperty(
                                filter_control_id="filterControlId",
                                source_filter_id="sourceFilterId",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        layouts=[quicksight.CfnTemplate.LayoutProperty(
                            configuration=quicksight.CfnTemplate.LayoutConfigurationProperty(
                                free_form_layout=quicksight.CfnTemplate.FreeFormLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                        element_id="elementId",
                                        element_type="elementType",
                                        height="height",
                                        width="width",
                                        x_axis_location="xAxisLocation",
                                        y_axis_location="yAxisLocation",
            
                                        # the properties below are optional
                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                            visibility="visibility"
                                        ),
                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                visibility="visibility"
                                            ),
                                            expression="expression"
                                        )],
                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                            color="color",
                                            visibility="visibility"
                                        ),
                                        visibility="visibility"
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty(
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                ),
                                section_based_layout=quicksight.CfnTemplate.SectionBasedLayoutConfigurationProperty(
                                    body_sections=[quicksight.CfnTemplate.BodySectionConfigurationProperty(
                                        content=quicksight.CfnTemplate.BodySectionContentProperty(
                                            layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                                free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                    elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                        element_id="elementId",
                                                        element_type="elementType",
                                                        height="height",
                                                        width="width",
                                                        x_axis_location="xAxisLocation",
                                                        y_axis_location="yAxisLocation",
            
                                                        # the properties below are optional
                                                        background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                            visibility="visibility"
                                                        ),
                                                        rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                            configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                                visibility="visibility"
                                                            ),
                                                            expression="expression"
                                                        )],
                                                        selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                            color="color",
                                                            visibility="visibility"
                                                        ),
                                                        visibility="visibility"
                                                    )]
                                                )
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        page_break_configuration=quicksight.CfnTemplate.SectionPageBreakConfigurationProperty(
                                            after=quicksight.CfnTemplate.SectionAfterPageBreakProperty(
                                                status="status"
                                            )
                                        ),
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty(
                                        paper_canvas_size_options=quicksight.CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty(
                                            paper_margin=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            ),
                                            paper_orientation="paperOrientation",
                                            paper_size="paperSize"
                                        )
                                    ),
                                    footer_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )],
                                    header_sections=[quicksight.CfnTemplate.HeaderFooterSectionConfigurationProperty(
                                        layout=quicksight.CfnTemplate.SectionLayoutConfigurationProperty(
                                            free_form_layout=quicksight.CfnTemplate.FreeFormSectionLayoutConfigurationProperty(
                                                elements=[quicksight.CfnTemplate.FreeFormLayoutElementProperty(
                                                    element_id="elementId",
                                                    element_type="elementType",
                                                    height="height",
                                                    width="width",
                                                    x_axis_location="xAxisLocation",
                                                    y_axis_location="yAxisLocation",
            
                                                    # the properties below are optional
                                                    background_style=quicksight.CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    loading_animation=quicksight.CfnTemplate.LoadingAnimationProperty(
                                                        visibility="visibility"
                                                    ),
                                                    rendering_rules=[quicksight.CfnTemplate.SheetElementRenderingRuleProperty(
                                                        configuration_overrides=quicksight.CfnTemplate.SheetElementConfigurationOverridesProperty(
                                                            visibility="visibility"
                                                        ),
                                                        expression="expression"
                                                    )],
                                                    selected_border_style=quicksight.CfnTemplate.FreeFormLayoutElementBorderStyleProperty(
                                                        color="color",
                                                        visibility="visibility"
                                                    ),
                                                    visibility="visibility"
                                                )]
                                            )
                                        ),
                                        section_id="sectionId",
            
                                        # the properties below are optional
                                        style=quicksight.CfnTemplate.SectionStyleProperty(
                                            height="height",
                                            padding=quicksight.CfnTemplate.SpacingProperty(
                                                bottom="bottom",
                                                left="left",
                                                right="right",
                                                top="top"
                                            )
                                        )
                                    )]
                                )
                            )
                        )],
                        name="name",
                        parameter_controls=[quicksight.CfnTemplate.ParameterControlProperty(
                            date_time_picker=quicksight.CfnTemplate.ParameterDateTimePickerControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.DateTimePickerControlDisplayOptionsProperty(
                                    date_time_format="dateTimeFormat",
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            dropdown=quicksight.CfnTemplate.ParameterDropDownControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.DropDownControlDisplayOptionsProperty(
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            list=quicksight.CfnTemplate.ParameterListControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                cascading_control_configuration=quicksight.CfnTemplate.CascadingControlConfigurationProperty(
                                    source_controls=[quicksight.CfnTemplate.CascadingControlSourceProperty(
                                        column_to_match=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        ),
                                        source_sheet_control_id="sourceSheetControlId"
                                    )]
                                ),
                                display_options=quicksight.CfnTemplate.ListControlDisplayOptionsProperty(
                                    search_options=quicksight.CfnTemplate.ListControlSearchOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    select_all_options=quicksight.CfnTemplate.ListControlSelectAllOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                ),
                                selectable_values=quicksight.CfnTemplate.ParameterSelectableValuesProperty(
                                    link_to_data_set_column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                        column_name="columnName",
                                        data_set_identifier="dataSetIdentifier"
                                    ),
                                    values=["values"]
                                ),
                                type="type"
                            ),
                            slider=quicksight.CfnTemplate.ParameterSliderControlProperty(
                                maximum_value=123,
                                minimum_value=123,
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                step_size=123,
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.SliderControlDisplayOptionsProperty(
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_area=quicksight.CfnTemplate.ParameterTextAreaControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                delimiter="delimiter",
                                display_options=quicksight.CfnTemplate.TextAreaControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            ),
                            text_field=quicksight.CfnTemplate.ParameterTextFieldControlProperty(
                                parameter_control_id="parameterControlId",
                                source_parameter_name="sourceParameterName",
                                title="title",
            
                                # the properties below are optional
                                display_options=quicksight.CfnTemplate.TextFieldControlDisplayOptionsProperty(
                                    placeholder_options=quicksight.CfnTemplate.TextControlPlaceholderOptionsProperty(
                                        visibility="visibility"
                                    ),
                                    title_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                        custom_label="customLabel",
                                        font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        visibility="visibility"
                                    )
                                )
                            )
                        )],
                        sheet_control_layouts=[quicksight.CfnTemplate.SheetControlLayoutProperty(
                            configuration=quicksight.CfnTemplate.SheetControlLayoutConfigurationProperty(
                                grid_layout=quicksight.CfnTemplate.GridLayoutConfigurationProperty(
                                    elements=[quicksight.CfnTemplate.GridLayoutElementProperty(
                                        column_span=123,
                                        element_id="elementId",
                                        element_type="elementType",
                                        row_span=123,
            
                                        # the properties below are optional
                                        column_index=123,
                                        row_index=123
                                    )],
            
                                    # the properties below are optional
                                    canvas_size_options=quicksight.CfnTemplate.GridLayoutCanvasSizeOptionsProperty(
                                        screen_canvas_size_options=quicksight.CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty(
                                            resize_option="resizeOption",
            
                                            # the properties below are optional
                                            optimized_view_port_width="optimizedViewPortWidth"
                                        )
                                    )
                                )
                            )
                        )],
                        text_boxes=[quicksight.CfnTemplate.SheetTextBoxProperty(
                            sheet_text_box_id="sheetTextBoxId",
            
                            # the properties below are optional
                            content="content"
                        )],
                        title="title",
                        visuals=[quicksight.CfnTemplate.VisualProperty(
                            bar_chart_visual=quicksight.CfnTemplate.BarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BarChartConfigurationProperty(
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BarChartFieldWellsProperty(
                                        bar_chart_aggregated_field_wells=quicksight.CfnTemplate.BarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    orientation="orientation",
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.BarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            box_plot_visual=quicksight.CfnTemplate.BoxPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.BoxPlotChartConfigurationProperty(
                                    box_plot_options=quicksight.CfnTemplate.BoxPlotOptionsProperty(
                                        all_data_points_visibility="allDataPointsVisibility",
                                        outlier_visibility="outlierVisibility",
                                        style_options=quicksight.CfnTemplate.BoxPlotStyleOptionsProperty(
                                            fill_style="fillStyle"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.BoxPlotFieldWellsProperty(
                                        box_plot_aggregated_field_wells=quicksight.CfnTemplate.BoxPlotAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    sort_configuration=quicksight.CfnTemplate.BoxPlotSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            combo_chart_visual=quicksight.CfnTemplate.ComboChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ComboChartConfigurationProperty(
                                    bar_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    bars_arrangement="barsArrangement",
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ComboChartFieldWellsProperty(
                                        combo_chart_aggregated_field_wells=quicksight.CfnTemplate.ComboChartAggregatedFieldWellsProperty(
                                            bar_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            line_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    line_data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.ComboChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            custom_content_visual=quicksight.CfnTemplate.CustomContentVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.CustomContentConfigurationProperty(
                                    content_type="contentType",
                                    content_url="contentUrl",
                                    image_scaling="imageScaling"
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            empty_visual=quicksight.CfnTemplate.EmptyVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )]
                            ),
                            filled_map_visual=quicksight.CfnTemplate.FilledMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FilledMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.FilledMapFieldWellsProperty(
                                        filled_map_aggregated_field_wells=quicksight.CfnTemplate.FilledMapAggregatedFieldWellsProperty(
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FilledMapSortConfigurationProperty(
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.FilledMapConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.FilledMapConditionalFormattingOptionProperty(
                                        shape=quicksight.CfnTemplate.FilledMapShapeConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            format=quicksight.CfnTemplate.ShapeConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            funnel_chart_visual=quicksight.CfnTemplate.FunnelChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.FunnelChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_label_options=quicksight.CfnTemplate.FunnelChartDataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        label_color="labelColor",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_data_label_style="measureDataLabelStyle",
                                        measure_label_visibility="measureLabelVisibility",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.FunnelChartFieldWellsProperty(
                                        funnel_chart_aggregated_field_wells=quicksight.CfnTemplate.FunnelChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.FunnelChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            gauge_chart_visual=quicksight.CfnTemplate.GaugeChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GaugeChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.GaugeChartFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    gauge_chart_options=quicksight.CfnTemplate.GaugeChartOptionsProperty(
                                        arc=quicksight.CfnTemplate.ArcConfigurationProperty(
                                            arc_angle=123,
                                            arc_thickness="arcThickness"
                                        ),
                                        arc_axis=quicksight.CfnTemplate.ArcAxisConfigurationProperty(
                                            range=quicksight.CfnTemplate.ArcAxisDisplayRangeProperty(
                                                max=123,
                                                min=123
                                            ),
                                            reserve_range=123
                                        ),
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        )
                                    ),
                                    tooltip_options=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.GaugeChartConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.GaugeChartConditionalFormattingOptionProperty(
                                        arc=quicksight.CfnTemplate.GaugeChartArcConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        primary_value=quicksight.CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            geospatial_map_visual=quicksight.CfnTemplate.GeospatialMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.GeospatialMapConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.GeospatialMapFieldWellsProperty(
                                        geospatial_map_aggregated_field_wells=quicksight.CfnTemplate.GeospatialMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            geospatial=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    map_style_options=quicksight.CfnTemplate.GeospatialMapStyleOptionsProperty(
                                        base_map_style="baseMapStyle"
                                    ),
                                    point_style_options=quicksight.CfnTemplate.GeospatialPointStyleOptionsProperty(
                                        cluster_marker_configuration=quicksight.CfnTemplate.ClusterMarkerConfigurationProperty(
                                            cluster_marker=quicksight.CfnTemplate.ClusterMarkerProperty(
                                                simple_cluster_marker=quicksight.CfnTemplate.SimpleClusterMarkerProperty(
                                                    color="color"
                                                )
                                            )
                                        ),
                                        selected_point_style="selectedPointStyle"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    window_options=quicksight.CfnTemplate.GeospatialWindowOptionsProperty(
                                        bounds=quicksight.CfnTemplate.GeospatialCoordinateBoundsProperty(
                                            east=123,
                                            north=123,
                                            south=123,
                                            west=123
                                        ),
                                        map_zoom_mode="mapZoomMode"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            heat_map_visual=quicksight.CfnTemplate.HeatMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HeatMapConfigurationProperty(
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    column_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HeatMapFieldWellsProperty(
                                        heat_map_aggregated_field_wells=quicksight.CfnTemplate.HeatMapAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    row_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.HeatMapSortConfigurationProperty(
                                        heat_map_column_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_column_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        heat_map_row_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        heat_map_row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            histogram_visual=quicksight.CfnTemplate.HistogramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.HistogramConfigurationProperty(
                                    bin_options=quicksight.CfnTemplate.HistogramBinOptionsProperty(
                                        bin_count=quicksight.CfnTemplate.BinCountOptionsProperty(
                                            value=123
                                        ),
                                        bin_width=quicksight.CfnTemplate.BinWidthOptionsProperty(
                                            bin_count_limit=123,
                                            value=123
                                        ),
                                        selected_bin_type="selectedBinType",
                                        start_value=123
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.HistogramFieldWellsProperty(
                                        histogram_aggregated_field_wells=quicksight.CfnTemplate.HistogramAggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            insight_visual=quicksight.CfnTemplate.InsightVisualProperty(
                                data_set_identifier="dataSetIdentifier",
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                insight_configuration=quicksight.CfnTemplate.InsightConfigurationProperty(
                                    computations=[quicksight.CfnTemplate.ComputationProperty(
                                        forecast=quicksight.CfnTemplate.ForecastComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            custom_seasonality_value=123,
                                            lower_boundary=123,
                                            name="name",
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality="seasonality",
                                            upper_boundary=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        growth_rate=quicksight.CfnTemplate.GrowthRateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        maximum_minimum=quicksight.CfnTemplate.MaximumMinimumComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        metric_comparison=quicksight.CfnTemplate.MetricComparisonComputationProperty(
                                            computation_id="computationId",
                                            from_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            target_value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        period_over_period=quicksight.CfnTemplate.PeriodOverPeriodComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        period_to_date=quicksight.CfnTemplate.PeriodToDateComputationProperty(
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name",
                                            period_time_granularity="periodTimeGranularity",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_movers=quicksight.CfnTemplate.TopBottomMoversComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            time=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            type="type",
            
                                            # the properties below are optional
                                            mover_size=123,
                                            name="name",
                                            sort_order="sortOrder",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        top_bottom_ranked=quicksight.CfnTemplate.TopBottomRankedComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
                                            type="type",
            
                                            # the properties below are optional
                                            name="name",
                                            result_size=123,
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )
                                        ),
                                        total_aggregation=quicksight.CfnTemplate.TotalAggregationComputationProperty(
                                            computation_id="computationId",
                                            value=quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            ),
            
                                            # the properties below are optional
                                            name="name"
                                        ),
                                        unique_values=quicksight.CfnTemplate.UniqueValuesComputationProperty(
                                            category=quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            ),
                                            computation_id="computationId",
            
                                            # the properties below are optional
                                            name="name"
                                        )
                                    )],
                                    custom_narrative=quicksight.CfnTemplate.CustomNarrativeOptionsProperty(
                                        narrative="narrative"
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            kpi_visual=quicksight.CfnTemplate.KPIVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.KPIConfigurationProperty(
                                    field_wells=quicksight.CfnTemplate.KPIFieldWellsProperty(
                                        target_values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )],
                                        trend_groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                            categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                date_granularity="dateGranularity",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            ),
                                            numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                ),
                                                hierarchy_id="hierarchyId"
                                            )
                                        )],
                                        values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                            calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                expression="expression",
                                                field_id="fieldId"
                                            ),
                                            categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function="aggregationFunction",
                                                format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                    date_time_format="dateTimeFormat",
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            ),
                                            numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                    format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                        currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix",
                                                            symbol="symbol"
                                                        ),
                                                        number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            number_scale="numberScale",
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        ),
                                                        percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                            decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                decimal_places=123
                                                            ),
                                                            negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                display_mode="displayMode"
                                                            ),
                                                            null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                null_string="nullString"
                                                            ),
                                                            prefix="prefix",
                                                            separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                decimal_separator="decimalSeparator",
                                                                thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                    symbol="symbol",
                                                                    visibility="visibility"
                                                                )
                                                            ),
                                                            suffix="suffix"
                                                        )
                                                    )
                                                )
                                            )
                                        )]
                                    ),
                                    kpi_options=quicksight.CfnTemplate.KPIOptionsProperty(
                                        comparison=quicksight.CfnTemplate.ComparisonConfigurationProperty(
                                            comparison_format=quicksight.CfnTemplate.ComparisonFormatConfigurationProperty(
                                                number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    number_scale="numberScale",
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                ),
                                                percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                    decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                        decimal_places=123
                                                    ),
                                                    negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                        display_mode="displayMode"
                                                    ),
                                                    null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                        null_string="nullString"
                                                    ),
                                                    prefix="prefix",
                                                    separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                        decimal_separator="decimalSeparator",
                                                        thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                            symbol="symbol",
                                                            visibility="visibility"
                                                        )
                                                    ),
                                                    suffix="suffix"
                                                )
                                            ),
                                            comparison_method="comparisonMethod"
                                        ),
                                        primary_value_display_type="primaryValueDisplayType",
                                        primary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.ProgressBarOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value=quicksight.CfnTemplate.SecondaryValueOptionsProperty(
                                            visibility="visibility"
                                        ),
                                        secondary_value_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        trend_arrows=quicksight.CfnTemplate.TrendArrowOptionsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.KPISortConfigurationProperty(
                                        trend_group_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                conditional_formatting=quicksight.CfnTemplate.KPIConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.KPIConditionalFormattingOptionProperty(
                                        primary_value=quicksight.CfnTemplate.KPIPrimaryValueConditionalFormattingProperty(
                                            icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                    expression="expression",
                                                    icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                        icon="icon",
                                                        unicode_icon="unicodeIcon"
                                                    ),
            
                                                    # the properties below are optional
                                                    color="color",
                                                    display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                        icon_display_option="iconDisplayOption"
                                                    )
                                                ),
                                                icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    icon_set_type="iconSetType"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        ),
                                        progress_bar=quicksight.CfnTemplate.KPIProgressBarConditionalFormattingProperty(
                                            foreground_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            line_chart_visual=quicksight.CfnTemplate.LineChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.LineChartConfigurationProperty(
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    default_series_settings=quicksight.CfnTemplate.LineChartDefaultSeriesSettingsProperty(
                                        axis_binding="axisBinding",
                                        line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                            line_interpolation="lineInterpolation",
                                            line_style="lineStyle",
                                            line_visibility="lineVisibility",
                                            line_width="lineWidth"
                                        ),
                                        marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                            marker_color="markerColor",
                                            marker_shape="markerShape",
                                            marker_size="markerSize",
                                            marker_visibility="markerVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.LineChartFieldWellsProperty(
                                        line_chart_aggregated_field_wells=quicksight.CfnTemplate.LineChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            colors=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    forecast_configurations=[quicksight.CfnTemplate.ForecastConfigurationProperty(
                                        forecast_properties=quicksight.CfnTemplate.TimeBasedForecastPropertiesProperty(
                                            lower_boundary=123,
                                            periods_backward=123,
                                            periods_forward=123,
                                            prediction_interval=123,
                                            seasonality=123,
                                            upper_boundary=123
                                        ),
                                        scenario=quicksight.CfnTemplate.ForecastScenarioProperty(
                                            what_if_point_scenario=quicksight.CfnTemplate.WhatIfPointScenarioProperty(
                                                date="date",
                                                value=123
                                            ),
                                            what_if_range_scenario=quicksight.CfnTemplate.WhatIfRangeScenarioProperty(
                                                end_date="endDate",
                                                start_date="startDate",
                                                value=123
                                            )
                                        )
                                    )],
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    reference_lines=[quicksight.CfnTemplate.ReferenceLineProperty(
                                        data_configuration=quicksight.CfnTemplate.ReferenceLineDataConfigurationProperty(
                                            axis_binding="axisBinding",
                                            dynamic_configuration=quicksight.CfnTemplate.ReferenceLineDynamicDataConfigurationProperty(
                                                calculation=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                    percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                        percentile_value=123
                                                    ),
                                                    simple_numerical_aggregation="simpleNumericalAggregation"
                                                ),
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                measure_aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            static_configuration=quicksight.CfnTemplate.ReferenceLineStaticDataConfigurationProperty(
                                                value=123
                                            )
                                        ),
            
                                        # the properties below are optional
                                        label_configuration=quicksight.CfnTemplate.ReferenceLineLabelConfigurationProperty(
                                            custom_label_configuration=quicksight.CfnTemplate.ReferenceLineCustomLabelConfigurationProperty(
                                                custom_label="customLabel"
                                            ),
                                            font_color="fontColor",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            horizontal_position="horizontalPosition",
                                            value_label_configuration=quicksight.CfnTemplate.ReferenceLineValueLabelConfigurationProperty(
                                                format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                    currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix",
                                                        symbol="symbol"
                                                    ),
                                                    number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        number_scale="numberScale",
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    ),
                                                    percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                        decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                            decimal_places=123
                                                        ),
                                                        negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                            display_mode="displayMode"
                                                        ),
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        prefix="prefix",
                                                        separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                            decimal_separator="decimalSeparator",
                                                            thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                symbol="symbol",
                                                                visibility="visibility"
                                                            )
                                                        ),
                                                        suffix="suffix"
                                                    )
                                                ),
                                                relative_position="relativePosition"
                                            ),
                                            vertical_position="verticalPosition"
                                        ),
                                        status="status",
                                        style_configuration=quicksight.CfnTemplate.ReferenceLineStyleConfigurationProperty(
                                            color="color",
                                            pattern="pattern"
                                        )
                                    )],
                                    secondary_yAxis_display_options=quicksight.CfnTemplate.LineSeriesAxisDisplayOptionsProperty(
                                        axis_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                            axis_line_visibility="axisLineVisibility",
                                            axis_offset="axisOffset",
                                            data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                                date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                    missing_date_visibility="missingDateVisibility"
                                                ),
                                                numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                    range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                        data_driven=data_driven,
                                                        min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                            maximum=123,
                                                            minimum=123
                                                        )
                                                    ),
                                                    scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                        linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                            step_count=123,
                                                            step_size=123
                                                        ),
                                                        logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                            base=123
                                                        )
                                                    )
                                                )
                                            ),
                                            grid_line_visibility="gridLineVisibility",
                                            scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                                visibility="visibility",
                                                visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                    percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                        from=123,
                                                        to=123
                                                    )
                                                )
                                            ),
                                            tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                                label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                    custom_label="customLabel",
                                                    font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                        font_color="fontColor",
                                                        font_decoration="fontDecoration",
                                                        font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                            relative="relative"
                                                        ),
                                                        font_style="fontStyle",
                                                        font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                            name="name"
                                                        )
                                                    ),
                                                    visibility="visibility"
                                                ),
                                                rotation_angle=123
                                            )
                                        ),
                                        missing_data_configurations=[quicksight.CfnTemplate.MissingDataConfigurationProperty(
                                            treatment_option="treatmentOption"
                                        )]
                                    ),
                                    secondary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    series=[quicksight.CfnTemplate.SeriesItemProperty(
                                        data_field_series_item=quicksight.CfnTemplate.DataFieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            field_value="fieldValue",
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        ),
                                        field_series_item=quicksight.CfnTemplate.FieldSeriesItemProperty(
                                            axis_binding="axisBinding",
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            settings=quicksight.CfnTemplate.LineChartSeriesSettingsProperty(
                                                line_style_settings=quicksight.CfnTemplate.LineChartLineStyleSettingsProperty(
                                                    line_interpolation="lineInterpolation",
                                                    line_style="lineStyle",
                                                    line_visibility="lineVisibility",
                                                    line_width="lineWidth"
                                                ),
                                                marker_style_settings=quicksight.CfnTemplate.LineChartMarkerStyleSettingsProperty(
                                                    marker_color="markerColor",
                                                    marker_shape="markerShape",
                                                    marker_size="markerSize",
                                                    marker_visibility="markerVisibility"
                                                )
                                            )
                                        )
                                    )],
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.LineChartSortConfigurationProperty(
                                        category_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    type="type",
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pie_chart_visual=quicksight.CfnTemplate.PieChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PieChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    contribution_analysis_defaults=[quicksight.CfnTemplate.ContributionAnalysisDefaultProperty(
                                        contributor_dimensions=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        measure_field_id="measureFieldId"
                                    )],
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    donut_options=quicksight.CfnTemplate.DonutOptionsProperty(
                                        arc_options=quicksight.CfnTemplate.ArcOptionsProperty(
                                            arc_thickness="arcThickness"
                                        ),
                                        donut_center_options=quicksight.CfnTemplate.DonutCenterOptionsProperty(
                                            label_visibility="labelVisibility"
                                        )
                                    ),
                                    field_wells=quicksight.CfnTemplate.PieChartFieldWellsProperty(
                                        pie_chart_aggregated_field_wells=quicksight.CfnTemplate.PieChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            small_multiples=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    small_multiples_options=quicksight.CfnTemplate.SmallMultiplesOptionsProperty(
                                        max_visible_columns=123,
                                        max_visible_rows=123,
                                        panel_configuration=quicksight.CfnTemplate.PanelConfigurationProperty(
                                            background_color="backgroundColor",
                                            background_visibility="backgroundVisibility",
                                            border_color="borderColor",
                                            border_style="borderStyle",
                                            border_thickness="borderThickness",
                                            border_visibility="borderVisibility",
                                            gutter_spacing="gutterSpacing",
                                            gutter_visibility="gutterVisibility",
                                            title=quicksight.CfnTemplate.PanelTitleOptionsProperty(
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PieChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        small_multiples_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        small_multiples_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    value_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            pivot_table_visual=quicksight.CfnTemplate.PivotTableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.PivotTableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.PivotTableFieldOptionsProperty(
                                        data_path_options=[quicksight.CfnTemplate.PivotTableDataPathOptionProperty(
                                            data_path_list=[quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            )],
            
                                            # the properties below are optional
                                            width="width"
                                        )],
                                        selected_field_options=[quicksight.CfnTemplate.PivotTableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            visibility="visibility"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.PivotTableFieldWellsProperty(
                                        pivot_table_aggregated_field_wells=quicksight.CfnTemplate.PivotTableAggregatedFieldWellsProperty(
                                            columns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            rows=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.PivotTablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.PivotTableSortConfigurationProperty(
                                        field_sort_options=[quicksight.CfnTemplate.PivotFieldSortOptionsProperty(
                                            field_id="fieldId",
                                            sort_by=quicksight.CfnTemplate.PivotTableSortByProperty(
                                                column=quicksight.CfnTemplate.ColumnSortProperty(
                                                    direction="direction",
                                                    sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    )
                                                ),
                                                data_path=quicksight.CfnTemplate.DataPathSortProperty(
                                                    direction="direction",
                                                    sort_paths=[quicksight.CfnTemplate.DataPathValueProperty(
                                                        field_id="fieldId",
                                                        field_value="fieldValue"
                                                    )]
                                                ),
                                                field=quicksight.CfnTemplate.FieldSortProperty(
                                                    direction="direction",
                                                    field_id="fieldId"
                                                )
                                            )
                                        )]
                                    ),
                                    table_options=quicksight.CfnTemplate.PivotTableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        column_names_visibility="columnNamesVisibility",
                                        metric_placement="metricPlacement",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        ),
                                        row_field_names_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        row_header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        single_metric_visibility="singleMetricVisibility",
                                        toggle_buttons_visibility="toggleButtonsVisibility"
                                    ),
                                    total_options=quicksight.CfnTemplate.PivotTableTotalOptionsProperty(
                                        column_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        column_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_subtotal_options=quicksight.CfnTemplate.SubtotalOptionsProperty(
                                            custom_label="customLabel",
                                            field_level="fieldLevel",
                                            field_level_options=[quicksight.CfnTemplate.PivotTableFieldSubtotalOptionsProperty(
                                                field_id="fieldId"
                                            )],
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        ),
                                        row_total_options=quicksight.CfnTemplate.PivotTotalOptionsProperty(
                                            custom_label="customLabel",
                                            metric_header_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            placement="placement",
                                            scroll_status="scrollStatus",
                                            total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            ),
                                            totals_visibility="totalsVisibility",
                                            value_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                                background_color="backgroundColor",
                                                border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                    side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                        bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        ),
                                                        top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                            color="color",
                                                            style="style",
                                                            thickness=123
                                                        )
                                                    ),
                                                    uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                height=123,
                                                horizontal_text_alignment="horizontalTextAlignment",
                                                text_wrap="textWrap",
                                                vertical_text_alignment="verticalTextAlignment",
                                                visibility="visibility"
                                            )
                                        )
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.PivotTableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.PivotTableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.PivotTableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            scope=quicksight.CfnTemplate.PivotTableConditionalFormattingScopeProperty(
                                                role="role"
                                            ),
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            radar_chart_visual=quicksight.CfnTemplate.RadarChartVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.RadarChartConfigurationProperty(
                                    alternate_band_colors_visibility="alternateBandColorsVisibility",
                                    alternate_band_even_color="alternateBandEvenColor",
                                    alternate_band_odd_color="alternateBandOddColor",
                                    base_series_settings=quicksight.CfnTemplate.RadarChartSeriesSettingsProperty(
                                        area_style_settings=quicksight.CfnTemplate.RadarChartAreaStyleSettingsProperty(
                                            visibility="visibility"
                                        )
                                    ),
                                    category_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_axis=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.RadarChartFieldWellsProperty(
                                        radar_chart_aggregated_field_wells=quicksight.CfnTemplate.RadarChartAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            color=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    shape="shape",
                                    sort_configuration=quicksight.CfnTemplate.RadarChartSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )],
                                        color_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        color_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    start_angle=123,
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            sankey_diagram_visual=quicksight.CfnTemplate.SankeyDiagramVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.SankeyDiagramChartConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.SankeyDiagramFieldWellsProperty(
                                        sankey_diagram_aggregated_field_wells=quicksight.CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty(
                                            destination=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            source=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            weight=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.SankeyDiagramSortConfigurationProperty(
                                        destination_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        source_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        weight_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    )
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            scatter_plot_visual=quicksight.CfnTemplate.ScatterPlotVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.ScatterPlotConfigurationProperty(
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.ScatterPlotFieldWellsProperty(
                                        scatter_plot_categorically_aggregated_field_wells=quicksight.CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty(
                                            category=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        scatter_plot_unaggregated_field_wells=quicksight.CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty(
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            x_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            y_axis=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    x_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    x_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    y_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    y_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            table_visual=quicksight.CfnTemplate.TableVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TableConfigurationProperty(
                                    field_options=quicksight.CfnTemplate.TableFieldOptionsProperty(
                                        order=["order"],
                                        selected_field_options=[quicksight.CfnTemplate.TableFieldOptionProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            custom_label="customLabel",
                                            url_styling=quicksight.CfnTemplate.TableFieldURLConfigurationProperty(
                                                image_configuration=quicksight.CfnTemplate.TableFieldImageConfigurationProperty(
                                                    sizing_options=quicksight.CfnTemplate.TableCellImageSizingConfigurationProperty(
                                                        table_cell_image_scaling_configuration="tableCellImageScalingConfiguration"
                                                    )
                                                ),
                                                link_configuration=quicksight.CfnTemplate.TableFieldLinkConfigurationProperty(
                                                    content=quicksight.CfnTemplate.TableFieldLinkContentConfigurationProperty(
                                                        custom_icon_content=quicksight.CfnTemplate.TableFieldCustomIconContentProperty(
                                                            icon="icon"
                                                        ),
                                                        custom_text_content=quicksight.CfnTemplate.TableFieldCustomTextContentProperty(
                                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                                font_color="fontColor",
                                                                font_decoration="fontDecoration",
                                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                                    relative="relative"
                                                                ),
                                                                font_style="fontStyle",
                                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                                    name="name"
                                                                )
                                                            ),
            
                                                            # the properties below are optional
                                                            value="value"
                                                        )
                                                    ),
                                                    target="target"
                                                )
                                            ),
                                            visibility="visibility",
                                            width="width"
                                        )]
                                    ),
                                    field_wells=quicksight.CfnTemplate.TableFieldWellsProperty(
                                        table_aggregated_field_wells=quicksight.CfnTemplate.TableAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        ),
                                        table_unaggregated_field_wells=quicksight.CfnTemplate.TableUnaggregatedFieldWellsProperty(
                                            values=[quicksight.CfnTemplate.UnaggregatedFieldProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId",
            
                                                # the properties below are optional
                                                format_configuration=quicksight.CfnTemplate.FormatConfigurationProperty(
                                                    date_time_format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    number_format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    string_format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    paginated_report_options=quicksight.CfnTemplate.TablePaginatedReportOptionsProperty(
                                        overflow_column_header_visibility="overflowColumnHeaderVisibility",
                                        vertical_overflow_visibility="verticalOverflowVisibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TableSortConfigurationProperty(
                                        pagination_configuration=quicksight.CfnTemplate.PaginationConfigurationProperty(
                                            page_number=123,
                                            page_size=123
                                        ),
                                        row_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    table_inline_visualizations=[quicksight.CfnTemplate.TableInlineVisualizationProperty(
                                        data_bars=quicksight.CfnTemplate.DataBarsOptionsProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            negative_color="negativeColor",
                                            positive_color="positiveColor"
                                        )
                                    )],
                                    table_options=quicksight.CfnTemplate.TableOptionsProperty(
                                        cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        header_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        orientation="orientation",
                                        row_alternate_color_options=quicksight.CfnTemplate.RowAlternateColorOptionsProperty(
                                            row_alternate_colors=["rowAlternateColors"],
                                            status="status"
                                        )
                                    ),
                                    total_options=quicksight.CfnTemplate.TotalOptionsProperty(
                                        custom_label="customLabel",
                                        placement="placement",
                                        scroll_status="scrollStatus",
                                        total_cell_style=quicksight.CfnTemplate.TableCellStyleProperty(
                                            background_color="backgroundColor",
                                            border=quicksight.CfnTemplate.GlobalTableBorderOptionsProperty(
                                                side_specific_border=quicksight.CfnTemplate.TableSideBorderOptionsProperty(
                                                    bottom=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_horizontal=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    inner_vertical=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    left=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    right=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    ),
                                                    top=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                        color="color",
                                                        style="style",
                                                        thickness=123
                                                    )
                                                ),
                                                uniform_border=quicksight.CfnTemplate.TableBorderOptionsProperty(
                                                    color="color",
                                                    style="style",
                                                    thickness=123
                                                )
                                            ),
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            height=123,
                                            horizontal_text_alignment="horizontalTextAlignment",
                                            text_wrap="textWrap",
                                            vertical_text_alignment="verticalTextAlignment",
                                            visibility="visibility"
                                        ),
                                        totals_visibility="totalsVisibility"
                                    )
                                ),
                                conditional_formatting=quicksight.CfnTemplate.TableConditionalFormattingProperty(
                                    conditional_formatting_options=[quicksight.CfnTemplate.TableConditionalFormattingOptionProperty(
                                        cell=quicksight.CfnTemplate.TableCellConditionalFormattingProperty(
                                            field_id="fieldId",
            
                                            # the properties below are optional
                                            text_format=quicksight.CfnTemplate.TextConditionalFormatProperty(
                                                background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                ),
                                                icon=quicksight.CfnTemplate.ConditionalFormattingIconProperty(
                                                    custom_condition=quicksight.CfnTemplate.ConditionalFormattingCustomIconConditionProperty(
                                                        expression="expression",
                                                        icon_options=quicksight.CfnTemplate.ConditionalFormattingCustomIconOptionsProperty(
                                                            icon="icon",
                                                            unicode_icon="unicodeIcon"
                                                        ),
            
                                                        # the properties below are optional
                                                        color="color",
                                                        display_configuration=quicksight.CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty(
                                                            icon_display_option="iconDisplayOption"
                                                        )
                                                    ),
                                                    icon_set=quicksight.CfnTemplate.ConditionalFormattingIconSetProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        icon_set_type="iconSetType"
                                                    )
                                                ),
                                                text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                    gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                        color=quicksight.CfnTemplate.GradientColorProperty(
                                                            stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                                gradient_offset=123,
            
                                                                # the properties below are optional
                                                                color="color",
                                                                data_value=123
                                                            )]
                                                        ),
                                                        expression="expression"
                                                    ),
                                                    solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                        expression="expression",
            
                                                        # the properties below are optional
                                                        color="color"
                                                    )
                                                )
                                            )
                                        ),
                                        row=quicksight.CfnTemplate.TableRowConditionalFormattingProperty(
                                            background_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            ),
                                            text_color=quicksight.CfnTemplate.ConditionalFormattingColorProperty(
                                                gradient=quicksight.CfnTemplate.ConditionalFormattingGradientColorProperty(
                                                    color=quicksight.CfnTemplate.GradientColorProperty(
                                                        stops=[quicksight.CfnTemplate.GradientStopProperty(
                                                            gradient_offset=123,
            
                                                            # the properties below are optional
                                                            color="color",
                                                            data_value=123
                                                        )]
                                                    ),
                                                    expression="expression"
                                                ),
                                                solid=quicksight.CfnTemplate.ConditionalFormattingSolidColorProperty(
                                                    expression="expression",
            
                                                    # the properties below are optional
                                                    color="color"
                                                )
                                            )
                                        )
                                    )]
                                ),
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            tree_map_visual=quicksight.CfnTemplate.TreeMapVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.TreeMapConfigurationProperty(
                                    color_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    color_scale=quicksight.CfnTemplate.ColorScaleProperty(
                                        color_fill_type="colorFillType",
                                        colors=[quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )],
            
                                        # the properties below are optional
                                        null_value_color=quicksight.CfnTemplate.DataColorProperty(
                                            color="color",
                                            data_value=123
                                        )
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.TreeMapFieldWellsProperty(
                                        tree_map_aggregated_field_wells=quicksight.CfnTemplate.TreeMapAggregatedFieldWellsProperty(
                                            colors=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )],
                                            groups=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            sizes=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    group_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    size_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.TreeMapSortConfigurationProperty(
                                        tree_map_group_items_limit_configuration=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        tree_map_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    tooltip=quicksight.CfnTemplate.TooltipOptionsProperty(
                                        field_based_tooltip=quicksight.CfnTemplate.FieldBasedTooltipProperty(
                                            aggregation_visibility="aggregationVisibility",
                                            tooltip_fields=[quicksight.CfnTemplate.TooltipItemProperty(
                                                column_tooltip_item=quicksight.CfnTemplate.ColumnTooltipItemProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
            
                                                    # the properties below are optional
                                                    aggregation=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                        categorical_aggregation_function="categoricalAggregationFunction",
                                                        date_aggregation_function="dateAggregationFunction",
                                                        numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                            percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                                percentile_value=123
                                                            ),
                                                            simple_numerical_aggregation="simpleNumericalAggregation"
                                                        )
                                                    ),
                                                    label="label",
                                                    visibility="visibility"
                                                ),
                                                field_tooltip_item=quicksight.CfnTemplate.FieldTooltipItemProperty(
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    label="label",
                                                    visibility="visibility"
                                                )
                                            )],
                                            tooltip_title_type="tooltipTitleType"
                                        ),
                                        selected_tooltip_type="selectedTooltipType",
                                        tooltip_visibility="tooltipVisibility"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            waterfall_visual=quicksight.CfnTemplate.WaterfallVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WaterfallChartConfigurationProperty(
                                    category_axis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    category_axis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    data_labels=quicksight.CfnTemplate.DataLabelOptionsProperty(
                                        category_label_visibility="categoryLabelVisibility",
                                        data_label_types=[quicksight.CfnTemplate.DataLabelTypeProperty(
                                            data_path_label_type=quicksight.CfnTemplate.DataPathLabelTypeProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue",
                                                visibility="visibility"
                                            ),
                                            field_label_type=quicksight.CfnTemplate.FieldLabelTypeProperty(
                                                field_id="fieldId",
                                                visibility="visibility"
                                            ),
                                            maximum_label_type=quicksight.CfnTemplate.MaximumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            minimum_label_type=quicksight.CfnTemplate.MinimumLabelTypeProperty(
                                                visibility="visibility"
                                            ),
                                            range_ends_label_type=quicksight.CfnTemplate.RangeEndsLabelTypeProperty(
                                                visibility="visibility"
                                            )
                                        )],
                                        label_color="labelColor",
                                        label_content="labelContent",
                                        label_font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                            font_color="fontColor",
                                            font_decoration="fontDecoration",
                                            font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                relative="relative"
                                            ),
                                            font_style="fontStyle",
                                            font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                name="name"
                                            )
                                        ),
                                        measure_label_visibility="measureLabelVisibility",
                                        overlap="overlap",
                                        position="position",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WaterfallChartFieldWellsProperty(
                                        waterfall_chart_aggregated_field_wells=quicksight.CfnTemplate.WaterfallChartAggregatedFieldWellsProperty(
                                            breakdowns=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            categories=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            values=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    legend=quicksight.CfnTemplate.LegendOptionsProperty(
                                        height="height",
                                        position="position",
                                        title=quicksight.CfnTemplate.LabelOptionsProperty(
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            ),
                                            visibility="visibility"
                                        ),
                                        visibility="visibility",
                                        width="width"
                                    ),
                                    primary_yAxis_display_options=quicksight.CfnTemplate.AxisDisplayOptionsProperty(
                                        axis_line_visibility="axisLineVisibility",
                                        axis_offset="axisOffset",
                                        data_options=quicksight.CfnTemplate.AxisDataOptionsProperty(
                                            date_axis_options=quicksight.CfnTemplate.DateAxisOptionsProperty(
                                                missing_date_visibility="missingDateVisibility"
                                            ),
                                            numeric_axis_options=quicksight.CfnTemplate.NumericAxisOptionsProperty(
                                                range=quicksight.CfnTemplate.AxisDisplayRangeProperty(
                                                    data_driven=data_driven,
                                                    min_max=quicksight.CfnTemplate.AxisDisplayMinMaxRangeProperty(
                                                        maximum=123,
                                                        minimum=123
                                                    )
                                                ),
                                                scale=quicksight.CfnTemplate.AxisScaleProperty(
                                                    linear=quicksight.CfnTemplate.AxisLinearScaleProperty(
                                                        step_count=123,
                                                        step_size=123
                                                    ),
                                                    logarithmic=quicksight.CfnTemplate.AxisLogarithmicScaleProperty(
                                                        base=123
                                                    )
                                                )
                                            )
                                        ),
                                        grid_line_visibility="gridLineVisibility",
                                        scrollbar_options=quicksight.CfnTemplate.ScrollBarOptionsProperty(
                                            visibility="visibility",
                                            visible_range=quicksight.CfnTemplate.VisibleRangeOptionsProperty(
                                                percent_range=quicksight.CfnTemplate.PercentVisibleRangeProperty(
                                                    from=123,
                                                    to=123
                                                )
                                            )
                                        ),
                                        tick_label_options=quicksight.CfnTemplate.AxisTickLabelOptionsProperty(
                                            label_options=quicksight.CfnTemplate.LabelOptionsProperty(
                                                custom_label="customLabel",
                                                font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                    font_color="fontColor",
                                                    font_decoration="fontDecoration",
                                                    font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                        relative="relative"
                                                    ),
                                                    font_style="fontStyle",
                                                    font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                        name="name"
                                                    )
                                                ),
                                                visibility="visibility"
                                            ),
                                            rotation_angle=123
                                        )
                                    ),
                                    primary_yAxis_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WaterfallChartSortConfigurationProperty(
                                        breakdown_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    visual_palette=quicksight.CfnTemplate.VisualPaletteProperty(
                                        chart_color="chartColor",
                                        color_map=[quicksight.CfnTemplate.DataPathColorProperty(
                                            color="color",
                                            element=quicksight.CfnTemplate.DataPathValueProperty(
                                                field_id="fieldId",
                                                field_value="fieldValue"
                                            ),
            
                                            # the properties below are optional
                                            time_granularity="timeGranularity"
                                        )]
                                    ),
                                    waterfall_chart_options=quicksight.CfnTemplate.WaterfallChartOptionsProperty(
                                        total_bar_label="totalBarLabel"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            ),
                            word_cloud_visual=quicksight.CfnTemplate.WordCloudVisualProperty(
                                visual_id="visualId",
            
                                # the properties below are optional
                                actions=[quicksight.CfnTemplate.VisualCustomActionProperty(
                                    action_operations=[quicksight.CfnTemplate.VisualCustomActionOperationProperty(
                                        filter_operation=quicksight.CfnTemplate.CustomActionFilterOperationProperty(
                                            selected_fields_configuration=quicksight.CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty(
                                                selected_field_options="selectedFieldOptions",
                                                selected_fields=["selectedFields"]
                                            ),
                                            target_visuals_configuration=quicksight.CfnTemplate.FilterOperationTargetVisualsConfigurationProperty(
                                                same_sheet_target_visual_configuration=quicksight.CfnTemplate.SameSheetTargetVisualConfigurationProperty(
                                                    target_visual_options="targetVisualOptions",
                                                    target_visuals=["targetVisuals"]
                                                )
                                            )
                                        ),
                                        navigation_operation=quicksight.CfnTemplate.CustomActionNavigationOperationProperty(
                                            local_navigation_configuration=quicksight.CfnTemplate.LocalNavigationConfigurationProperty(
                                                target_sheet_id="targetSheetId"
                                            )
                                        ),
                                        set_parameters_operation=quicksight.CfnTemplate.CustomActionSetParametersOperationProperty(
                                            parameter_value_configurations=[quicksight.CfnTemplate.SetParameterValueConfigurationProperty(
                                                destination_parameter_name="destinationParameterName",
                                                value=quicksight.CfnTemplate.DestinationParameterValueConfigurationProperty(
                                                    custom_values_configuration=quicksight.CfnTemplate.CustomValuesConfigurationProperty(
                                                        custom_values=quicksight.CfnTemplate.CustomParameterValuesProperty(
                                                            date_time_values=["dateTimeValues"],
                                                            decimal_values=[123],
                                                            integer_values=[123],
                                                            string_values=["stringValues"]
                                                        ),
            
                                                        # the properties below are optional
                                                        include_null_value=False
                                                    ),
                                                    select_all_value_options="selectAllValueOptions",
                                                    source_field="sourceField",
                                                    source_parameter_name="sourceParameterName"
                                                )
                                            )]
                                        ),
                                        url_operation=quicksight.CfnTemplate.CustomActionURLOperationProperty(
                                            url_target="urlTarget",
                                            url_template="urlTemplate"
                                        )
                                    )],
                                    custom_action_id="customActionId",
                                    name="name",
                                    trigger="trigger",
            
                                    # the properties below are optional
                                    status="status"
                                )],
                                chart_configuration=quicksight.CfnTemplate.WordCloudChartConfigurationProperty(
                                    category_label_options=quicksight.CfnTemplate.ChartAxisLabelOptionsProperty(
                                        axis_label_options=[quicksight.CfnTemplate.AxisLabelOptionsProperty(
                                            apply_to=quicksight.CfnTemplate.AxisLabelReferenceOptionsProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                field_id="fieldId"
                                            ),
                                            custom_label="customLabel",
                                            font_configuration=quicksight.CfnTemplate.FontConfigurationProperty(
                                                font_color="fontColor",
                                                font_decoration="fontDecoration",
                                                font_size=quicksight.CfnTemplate.FontSizeProperty(
                                                    relative="relative"
                                                ),
                                                font_style="fontStyle",
                                                font_weight=quicksight.CfnTemplate.FontWeightProperty(
                                                    name="name"
                                                )
                                            )
                                        )],
                                        sort_icon_visibility="sortIconVisibility",
                                        visibility="visibility"
                                    ),
                                    field_wells=quicksight.CfnTemplate.WordCloudFieldWellsProperty(
                                        word_cloud_aggregated_field_wells=quicksight.CfnTemplate.WordCloudAggregatedFieldWellsProperty(
                                            group_by=[quicksight.CfnTemplate.DimensionFieldProperty(
                                                categorical_dimension_field=quicksight.CfnTemplate.CategoricalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                date_dimension_field=quicksight.CfnTemplate.DateDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    date_granularity="dateGranularity",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                ),
                                                numerical_dimension_field=quicksight.CfnTemplate.NumericalDimensionFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    ),
                                                    hierarchy_id="hierarchyId"
                                                )
                                            )],
                                            size=[quicksight.CfnTemplate.MeasureFieldProperty(
                                                calculated_measure_field=quicksight.CfnTemplate.CalculatedMeasureFieldProperty(
                                                    expression="expression",
                                                    field_id="fieldId"
                                                ),
                                                categorical_measure_field=quicksight.CfnTemplate.CategoricalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.StringFormatConfigurationProperty(
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                date_measure_field=quicksight.CfnTemplate.DateMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function="aggregationFunction",
                                                    format_configuration=quicksight.CfnTemplate.DateTimeFormatConfigurationProperty(
                                                        date_time_format="dateTimeFormat",
                                                        null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                            null_string="nullString"
                                                        ),
                                                        numeric_format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                ),
                                                numerical_measure_field=quicksight.CfnTemplate.NumericalMeasureFieldProperty(
                                                    column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                        column_name="columnName",
                                                        data_set_identifier="dataSetIdentifier"
                                                    ),
                                                    field_id="fieldId",
            
                                                    # the properties below are optional
                                                    aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    ),
                                                    format_configuration=quicksight.CfnTemplate.NumberFormatConfigurationProperty(
                                                        format_configuration=quicksight.CfnTemplate.NumericFormatConfigurationProperty(
                                                            currency_display_format_configuration=quicksight.CfnTemplate.CurrencyDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix",
                                                                symbol="symbol"
                                                            ),
                                                            number_display_format_configuration=quicksight.CfnTemplate.NumberDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                number_scale="numberScale",
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            ),
                                                            percentage_display_format_configuration=quicksight.CfnTemplate.PercentageDisplayFormatConfigurationProperty(
                                                                decimal_places_configuration=quicksight.CfnTemplate.DecimalPlacesConfigurationProperty(
                                                                    decimal_places=123
                                                                ),
                                                                negative_value_configuration=quicksight.CfnTemplate.NegativeValueConfigurationProperty(
                                                                    display_mode="displayMode"
                                                                ),
                                                                null_value_format_configuration=quicksight.CfnTemplate.NullValueFormatConfigurationProperty(
                                                                    null_string="nullString"
                                                                ),
                                                                prefix="prefix",
                                                                separator_configuration=quicksight.CfnTemplate.NumericSeparatorConfigurationProperty(
                                                                    decimal_separator="decimalSeparator",
                                                                    thousands_separator=quicksight.CfnTemplate.ThousandSeparatorOptionsProperty(
                                                                        symbol="symbol",
                                                                        visibility="visibility"
                                                                    )
                                                                ),
                                                                suffix="suffix"
                                                            )
                                                        )
                                                    )
                                                )
                                            )]
                                        )
                                    ),
                                    sort_configuration=quicksight.CfnTemplate.WordCloudSortConfigurationProperty(
                                        category_items_limit=quicksight.CfnTemplate.ItemsLimitConfigurationProperty(
                                            items_limit=123,
                                            other_categories="otherCategories"
                                        ),
                                        category_sort=[quicksight.CfnTemplate.FieldSortOptionsProperty(
                                            column_sort=quicksight.CfnTemplate.ColumnSortProperty(
                                                direction="direction",
                                                sort_by=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
            
                                                # the properties below are optional
                                                aggregation_function=quicksight.CfnTemplate.AggregationFunctionProperty(
                                                    categorical_aggregation_function="categoricalAggregationFunction",
                                                    date_aggregation_function="dateAggregationFunction",
                                                    numerical_aggregation_function=quicksight.CfnTemplate.NumericalAggregationFunctionProperty(
                                                        percentile_aggregation=quicksight.CfnTemplate.PercentileAggregationProperty(
                                                            percentile_value=123
                                                        ),
                                                        simple_numerical_aggregation="simpleNumericalAggregation"
                                                    )
                                                )
                                            ),
                                            field_sort=quicksight.CfnTemplate.FieldSortProperty(
                                                direction="direction",
                                                field_id="fieldId"
                                            )
                                        )]
                                    ),
                                    word_cloud_options=quicksight.CfnTemplate.WordCloudOptionsProperty(
                                        cloud_layout="cloudLayout",
                                        maximum_string_length=123,
                                        word_casing="wordCasing",
                                        word_orientation="wordOrientation",
                                        word_padding="wordPadding",
                                        word_scaling="wordScaling"
                                    )
                                ),
                                column_hierarchies=[quicksight.CfnTemplate.ColumnHierarchyProperty(
                                    date_time_hierarchy=quicksight.CfnTemplate.DateTimeHierarchyProperty(
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    explicit_hierarchy=quicksight.CfnTemplate.ExplicitHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    ),
                                    predefined_hierarchy=quicksight.CfnTemplate.PredefinedHierarchyProperty(
                                        columns=[quicksight.CfnTemplate.ColumnIdentifierProperty(
                                            column_name="columnName",
                                            data_set_identifier="dataSetIdentifier"
                                        )],
                                        hierarchy_id="hierarchyId",
            
                                        # the properties below are optional
                                        drill_down_filters=[quicksight.CfnTemplate.DrillDownFilterProperty(
                                            category_filter=quicksight.CfnTemplate.CategoryDrillDownFilterProperty(
                                                category_values=["categoryValues"],
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                )
                                            ),
                                            numeric_equality_filter=quicksight.CfnTemplate.NumericEqualityDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                value=123
                                            ),
                                            time_range_filter=quicksight.CfnTemplate.TimeRangeDrillDownFilterProperty(
                                                column=quicksight.CfnTemplate.ColumnIdentifierProperty(
                                                    column_name="columnName",
                                                    data_set_identifier="dataSetIdentifier"
                                                ),
                                                range_maximum="rangeMaximum",
                                                range_minimum="rangeMinimum",
                                                time_granularity="timeGranularity"
                                            )
                                        )]
                                    )
                                )],
                                subtitle=quicksight.CfnTemplate.VisualSubtitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.LongFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                ),
                                title=quicksight.CfnTemplate.VisualTitleLabelOptionsProperty(
                                    format_text=quicksight.CfnTemplate.ShortFormatTextProperty(
                                        plain_text="plainText",
                                        rich_text="richText"
                                    ),
                                    visibility="visibility"
                                )
                            )
                        )]
                    )]
                ),
                name="name",
                permissions=[quicksight.CfnTemplate.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal",
            
                    # the properties below are optional
                    resource="resource"
                )],
                source_entity=quicksight.CfnTemplate.TemplateSourceEntityProperty(
                    source_analysis=quicksight.CfnTemplate.TemplateSourceAnalysisProperty(
                        arn="arn",
                        data_set_references=[quicksight.CfnTemplate.DataSetReferenceProperty(
                            data_set_arn="dataSetArn",
                            data_set_placeholder="dataSetPlaceholder"
                        )]
                    ),
                    source_template=quicksight.CfnTemplate.TemplateSourceTemplateProperty(
                        arn="arn"
                    )
                ),
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b9126e0fc1cd990180f181ea366ec8684272453b6f2ffad0d170394314326e46)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument template_id", value=template_id, expected_type=type_hints["template_id"])
            check_type(argname="argument definition", value=definition, expected_type=type_hints["definition"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument source_entity", value=source_entity, expected_type=type_hints["source_entity"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "template_id": template_id,
        }
        if definition is not None:
            self._values["definition"] = definition
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if source_entity is not None:
            self._values["source_entity"] = source_entity
        if tags is not None:
            self._values["tags"] = tags
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID for the AWS account that the group is in.

        You use the ID for the AWS account that contains your Amazon QuickSight account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def template_id(self) -> builtins.str:
        '''An ID for the template that you want to create.

        This template is unique per AWS Region ; in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
        '''
        result = self._values.get("template_id")
        assert result is not None, "Required property 'template_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def definition(
        self,
    ) -> typing.Optional[typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, _IResolvable_a771d0ef]]:
        '''``AWS::QuickSight::Template.Definition``.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
        '''
        result = self._values.get("definition")
        return typing.cast(typing.Optional[typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnTemplate.ResourcePermissionProperty, _IResolvable_a771d0ef]]]]:
        '''A list of resource permissions to be set on the template.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnTemplate.ResourcePermissionProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def source_entity(
        self,
    ) -> typing.Optional[typing.Union[CfnTemplate.TemplateSourceEntityProperty, _IResolvable_a771d0ef]]:
        '''The entity that you are using as a source when you create the template.

        In ``SourceEntity`` , you specify the type of object you're using as source: ``SourceTemplate`` for a template or ``SourceAnalysis`` for an analysis. Both of these require an Amazon Resource Name (ARN). For ``SourceTemplate`` , specify the ARN of the source template. For ``SourceAnalysis`` , specify the ARN of the source analysis. The ``SourceTemplate`` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .

        Use the ``DataSetReferences`` entity within ``SourceTemplate`` or ``SourceAnalysis`` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.

        Either a ``SourceEntity`` or a ``Definition`` must be provided in order for the request to be valid.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
        '''
        result = self._values.get("source_entity")
        return typing.cast(typing.Optional[typing.Union[CfnTemplate.TemplateSourceEntityProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the current template version being created.

        This API operation creates the first version of the template. Every time ``UpdateTemplate`` is called, a new version is created. Each version of the template maintains a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnTemplateProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnTheme(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnTheme",
):
    '''A CloudFormation ``AWS::QuickSight::Theme``.

    Creates a theme.

    A *theme* is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see `Using Themes in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html>`_ in the *Amazon QuickSight User Guide* .

    :cloudformationResource: AWS::QuickSight::Theme
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        cfn_theme = quicksight.CfnTheme(self, "MyCfnTheme",
            aws_account_id="awsAccountId",
            theme_id="themeId",
        
            # the properties below are optional
            base_theme_id="baseThemeId",
            configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                    colors=["colors"],
                    empty_fill_color="emptyFillColor",
                    min_max_gradient=["minMaxGradient"]
                ),
                sheet=quicksight.CfnTheme.SheetStyleProperty(
                    tile=quicksight.CfnTheme.TileStyleProperty(
                        border=quicksight.CfnTheme.BorderStyleProperty(
                            show=False
                        )
                    ),
                    tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                        gutter=quicksight.CfnTheme.GutterStyleProperty(
                            show=False
                        ),
                        margin=quicksight.CfnTheme.MarginStyleProperty(
                            show=False
                        )
                    )
                ),
                typography=quicksight.CfnTheme.TypographyProperty(
                    font_families=[quicksight.CfnTheme.FontProperty(
                        font_family="fontFamily"
                    )]
                ),
                ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                    accent="accent",
                    accent_foreground="accentForeground",
                    danger="danger",
                    danger_foreground="dangerForeground",
                    dimension="dimension",
                    dimension_foreground="dimensionForeground",
                    measure="measure",
                    measure_foreground="measureForeground",
                    primary_background="primaryBackground",
                    primary_foreground="primaryForeground",
                    secondary_background="secondaryBackground",
                    secondary_foreground="secondaryForeground",
                    success="success",
                    success_foreground="successForeground",
                    warning="warning",
                    warning_foreground="warningForeground"
                )
            ),
            name="name",
            permissions=[quicksight.CfnTheme.ResourcePermissionProperty(
                actions=["actions"],
                principal="principal"
            )],
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            version_description="versionDescription"
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        aws_account_id: builtins.str,
        theme_id: builtins.str,
        base_theme_id: typing.Optional[builtins.str] = None,
        configuration: typing.Optional[typing.Union[typing.Union["CfnTheme.ThemeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTheme.ResourcePermissionProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::Theme``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param aws_account_id: The ID of the AWS account where you want to store the new theme.
        :param theme_id: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
        :param base_theme_id: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.
        :param configuration: The theme configuration, which contains the theme display properties.
        :param name: A display name for the theme.
        :param permissions: A valid grouping of resource permissions to apply to the new theme.
        :param tags: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
        :param version_description: A description of the first version of the theme that you're creating. Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a982acbc529fecd5eb0bceef80c1cc372c6043a37702c9efb3f4ff2265e3c6a3)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnThemeProps(
            aws_account_id=aws_account_id,
            theme_id=theme_id,
            base_theme_id=base_theme_id,
            configuration=configuration,
            name=name,
            permissions=permissions,
            tags=tags,
            version_description=version_description,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__13b6797443bcd8f8cef6c390d2cd1b5f256c2254ad8da5b7fe337e6714048dbd)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e8ebfbde87206b99da23dad12f1a2eda4db5d916e8b066b4c7e0d4b22245fb41)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''The Amazon Resource Name (ARN) of the theme.

        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''The time the theme was created.

        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''The time the theme was last updated.

        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrType")
    def attr_type(self) -> builtins.str:
        '''Theme type.

        :cloudformationAttribute: Type
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrType"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionArn")
    def attr_version_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionArn"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionBaseThemeId")
    def attr_version_base_theme_id(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.BaseThemeId
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionBaseThemeId"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionCreatedTime")
    def attr_version_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionDescription")
    def attr_version_description(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Description
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionDescription"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionErrors")
    def attr_version_errors(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.Errors
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionErrors"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionStatus")
    def attr_version_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Version.Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVersionStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVersionVersionNumber")
    def attr_version_version_number(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: Version.VersionNumber
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrVersionVersionNumber"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''A map of the key-value pairs for the resource tag or tags that you want to add to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to store the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
        '''
        return typing.cast(builtins.str, jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__23c7138c389333ea25ad06021eea09d0cdcd96e622b119d2ee777ec9b7d8aee0)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="themeId")
    def theme_id(self) -> builtins.str:
        '''An ID for the theme that you want to create.

        The theme ID is unique per AWS Region in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
        '''
        return typing.cast(builtins.str, jsii.get(self, "themeId"))

    @theme_id.setter
    def theme_id(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__79b54317f889cad4e3dd36bc868b6fba421da01d22117171c57796789899f6f1)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "themeId", value)

    @builtins.property
    @jsii.member(jsii_name="baseThemeId")
    def base_theme_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the theme that a custom theme will inherit from.

        All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "baseThemeId"))

    @base_theme_id.setter
    def base_theme_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__625a3de787b6942a8b046ef0bb20fd7aca1efac63efa77e3335f578291612e02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "baseThemeId", value)

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(
        self,
    ) -> typing.Optional[typing.Union["CfnTheme.ThemeConfigurationProperty", _IResolvable_a771d0ef]]:
        '''The theme configuration, which contains the theme display properties.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
        '''
        return typing.cast(typing.Optional[typing.Union["CfnTheme.ThemeConfigurationProperty", _IResolvable_a771d0ef]], jsii.get(self, "configuration"))

    @configuration.setter
    def configuration(
        self,
        value: typing.Optional[typing.Union["CfnTheme.ThemeConfigurationProperty", _IResolvable_a771d0ef]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__57f60df16cc26a9e5d3b48a730661cdc0ce58596f41b16c0c27e70bae7a18df6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__241e09d54947304252ec8e2856e68539972fd562ad8af914e01385caa4924d97)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.ResourcePermissionProperty", _IResolvable_a771d0ef]]]]:
        '''A valid grouping of resource permissions to apply to the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
        '''
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.ResourcePermissionProperty", _IResolvable_a771d0ef]]]], jsii.get(self, "permissions"))

    @permissions.setter
    def permissions(
        self,
        value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.ResourcePermissionProperty", _IResolvable_a771d0ef]]]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__2649df1cc1fb02b94b3edebaca96647cf74e2adffa7972ed5a1080047cdd0edf)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="versionDescription")
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the first version of the theme that you're creating.

        Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "versionDescription"))

    @version_description.setter
    def version_description(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a524282f2932f086a220e5bdc191071bf4bffd02131a5d93ee5e4a3017022f6c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "versionDescription", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.BorderStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class BorderStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for tile borders for visuals.

            :param show: The option to enable display of borders for visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                border_style_property = quicksight.CfnTheme.BorderStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__dadb30e0a6ad8255563bafb4cd96f9c6a8f66b3b855caf1fcd95ab4b875246f2)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''The option to enable display of borders for visuals.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html#cfn-quicksight-theme-borderstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "BorderStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.DataColorPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={
            "colors": "colors",
            "empty_fill_color": "emptyFillColor",
            "min_max_gradient": "minMaxGradient",
        },
    )
    class DataColorPaletteProperty:
        def __init__(
            self,
            *,
            colors: typing.Optional[typing.Sequence[builtins.str]] = None,
            empty_fill_color: typing.Optional[builtins.str] = None,
            min_max_gradient: typing.Optional[typing.Sequence[builtins.str]] = None,
        ) -> None:
            '''The theme colors that are used for data colors in charts.

            The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ``#`` , for example #37BFF5.

            :param colors: The hexadecimal codes for the colors.
            :param empty_fill_color: The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
            :param min_max_gradient: The minimum and maximum hexadecimal codes that describe a color gradient.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                data_color_palette_property = quicksight.CfnTheme.DataColorPaletteProperty(
                    colors=["colors"],
                    empty_fill_color="emptyFillColor",
                    min_max_gradient=["minMaxGradient"]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__c97321d1990600c1b17e48aaaa59d7a62b39c2ce86919f10392c5441e236f456)
                check_type(argname="argument colors", value=colors, expected_type=type_hints["colors"])
                check_type(argname="argument empty_fill_color", value=empty_fill_color, expected_type=type_hints["empty_fill_color"])
                check_type(argname="argument min_max_gradient", value=min_max_gradient, expected_type=type_hints["min_max_gradient"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if colors is not None:
                self._values["colors"] = colors
            if empty_fill_color is not None:
                self._values["empty_fill_color"] = empty_fill_color
            if min_max_gradient is not None:
                self._values["min_max_gradient"] = min_max_gradient

        @builtins.property
        def colors(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The hexadecimal codes for the colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-colors
            '''
            result = self._values.get("colors")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        @builtins.property
        def empty_fill_color(self) -> typing.Optional[builtins.str]:
            '''The hexadecimal code of a color that applies to charts where a lack of data is highlighted.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-emptyfillcolor
            '''
            result = self._values.get("empty_fill_color")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def min_max_gradient(self) -> typing.Optional[typing.List[builtins.str]]:
            '''The minimum and maximum hexadecimal codes that describe a color gradient.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-minmaxgradient
            '''
            result = self._values.get("min_max_gradient")
            return typing.cast(typing.Optional[typing.List[builtins.str]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "DataColorPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.FontProperty",
        jsii_struct_bases=[],
        name_mapping={"font_family": "fontFamily"},
    )
    class FontProperty:
        def __init__(
            self,
            *,
            font_family: typing.Optional[builtins.str] = None,
        ) -> None:
            '''
            :param font_family: ``CfnTheme.FontProperty.FontFamily``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                font_property = quicksight.CfnTheme.FontProperty(
                    font_family="fontFamily"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__53375c8d6395e69b8acae64f3fb565703198d342d4411e35bdb9c80100c2072e)
                check_type(argname="argument font_family", value=font_family, expected_type=type_hints["font_family"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_family is not None:
                self._values["font_family"] = font_family

        @builtins.property
        def font_family(self) -> typing.Optional[builtins.str]:
            '''``CfnTheme.FontProperty.FontFamily``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html#cfn-quicksight-theme-font-fontfamily
            '''
            result = self._values.get("font_family")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "FontProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.GutterStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class GutterStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for gutter spacing between tiles on a sheet.

            :param show: This Boolean value controls whether to display a gutter space between sheet tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                gutter_style_property = quicksight.CfnTheme.GutterStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__64eb7c2f842be1cda829d400f3d312cb604bb36cbd2589fe9ff00407f4103be4)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''This Boolean value controls whether to display a gutter space between sheet tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html#cfn-quicksight-theme-gutterstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "GutterStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.MarginStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"show": "show"},
    )
    class MarginStyleProperty:
        def __init__(
            self,
            *,
            show: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for margins around the outside edge of sheets.

            :param show: This Boolean value controls whether to display sheet margins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                margin_style_property = quicksight.CfnTheme.MarginStyleProperty(
                    show=False
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8f65a4fdf268b41c7e2a85b103e21256b39b6be88fafbd656af630c13c4355bb)
                check_type(argname="argument show", value=show, expected_type=type_hints["show"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if show is not None:
                self._values["show"] = show

        @builtins.property
        def show(
            self,
        ) -> typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]]:
            '''This Boolean value controls whether to display sheet margins.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html#cfn-quicksight-theme-marginstyle-show
            '''
            result = self._values.get("show")
            return typing.cast(typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "MarginStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.ResourcePermissionProperty",
        jsii_struct_bases=[],
        name_mapping={"actions": "actions", "principal": "principal"},
    )
    class ResourcePermissionProperty:
        def __init__(
            self,
            *,
            actions: typing.Sequence[builtins.str],
            principal: builtins.str,
        ) -> None:
            '''Permission for the resource.

            :param actions: The IAM action to grant or revoke permissions on.
            :param principal: The Amazon Resource Name (ARN) of the principal. This can be one of the following:. - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.) - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.) - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                resource_permission_property = quicksight.CfnTheme.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__8d9024d86489caec28b2c09991ca50ecc1c652c4c6a0185a5fc75d4f5bda7431)
                check_type(argname="argument actions", value=actions, expected_type=type_hints["actions"])
                check_type(argname="argument principal", value=principal, expected_type=type_hints["principal"])
            self._values: typing.Dict[builtins.str, typing.Any] = {
                "actions": actions,
                "principal": principal,
            }

        @builtins.property
        def actions(self) -> typing.List[builtins.str]:
            '''The IAM action to grant or revoke permissions on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-actions
            '''
            result = self._values.get("actions")
            assert result is not None, "Required property 'actions' is missing"
            return typing.cast(typing.List[builtins.str], result)

        @builtins.property
        def principal(self) -> builtins.str:
            '''The Amazon Resource Name (ARN) of the principal. This can be one of the following:.

            - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
            - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
            - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-principal
            '''
            result = self._values.get("principal")
            assert result is not None, "Required property 'principal' is missing"
            return typing.cast(builtins.str, result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ResourcePermissionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.SheetStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"tile": "tile", "tile_layout": "tileLayout"},
    )
    class SheetStyleProperty:
        def __init__(
            self,
            *,
            tile: typing.Optional[typing.Union[typing.Union["CfnTheme.TileStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            tile_layout: typing.Optional[typing.Union[typing.Union["CfnTheme.TileLayoutStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The theme display options for sheets.

            :param tile: The display options for tiles.
            :param tile_layout: The layout options for tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                sheet_style_property = quicksight.CfnTheme.SheetStyleProperty(
                    tile=quicksight.CfnTheme.TileStyleProperty(
                        border=quicksight.CfnTheme.BorderStyleProperty(
                            show=False
                        )
                    ),
                    tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                        gutter=quicksight.CfnTheme.GutterStyleProperty(
                            show=False
                        ),
                        margin=quicksight.CfnTheme.MarginStyleProperty(
                            show=False
                        )
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b06f90593788fa10364ce907ccf4f893dc73a5af513b55032af625389454dd8f)
                check_type(argname="argument tile", value=tile, expected_type=type_hints["tile"])
                check_type(argname="argument tile_layout", value=tile_layout, expected_type=type_hints["tile_layout"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if tile is not None:
                self._values["tile"] = tile
            if tile_layout is not None:
                self._values["tile_layout"] = tile_layout

        @builtins.property
        def tile(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.TileStyleProperty", _IResolvable_a771d0ef]]:
            '''The display options for tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tile
            '''
            result = self._values.get("tile")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.TileStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def tile_layout(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.TileLayoutStyleProperty", _IResolvable_a771d0ef]]:
            '''The layout options for tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tilelayout
            '''
            result = self._values.get("tile_layout")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.TileLayoutStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "SheetStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.ThemeConfigurationProperty",
        jsii_struct_bases=[],
        name_mapping={
            "data_color_palette": "dataColorPalette",
            "sheet": "sheet",
            "typography": "typography",
            "ui_color_palette": "uiColorPalette",
        },
    )
    class ThemeConfigurationProperty:
        def __init__(
            self,
            *,
            data_color_palette: typing.Optional[typing.Union[typing.Union["CfnTheme.DataColorPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            sheet: typing.Optional[typing.Union[typing.Union["CfnTheme.SheetStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            typography: typing.Optional[typing.Union[typing.Union["CfnTheme.TypographyProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            ui_color_palette: typing.Optional[typing.Union[typing.Union["CfnTheme.UIColorPaletteProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The theme configuration.

            This configuration contains all of the display properties for a theme.

            :param data_color_palette: Color properties that apply to chart data colors.
            :param sheet: Display options related to sheets.
            :param typography: ``CfnTheme.ThemeConfigurationProperty.Typography``.
            :param ui_color_palette: Color properties that apply to the UI and to charts, excluding the colors that apply to data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                theme_configuration_property = quicksight.CfnTheme.ThemeConfigurationProperty(
                    data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                        colors=["colors"],
                        empty_fill_color="emptyFillColor",
                        min_max_gradient=["minMaxGradient"]
                    ),
                    sheet=quicksight.CfnTheme.SheetStyleProperty(
                        tile=quicksight.CfnTheme.TileStyleProperty(
                            border=quicksight.CfnTheme.BorderStyleProperty(
                                show=False
                            )
                        ),
                        tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                            gutter=quicksight.CfnTheme.GutterStyleProperty(
                                show=False
                            ),
                            margin=quicksight.CfnTheme.MarginStyleProperty(
                                show=False
                            )
                        )
                    ),
                    typography=quicksight.CfnTheme.TypographyProperty(
                        font_families=[quicksight.CfnTheme.FontProperty(
                            font_family="fontFamily"
                        )]
                    ),
                    ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                        accent="accent",
                        accent_foreground="accentForeground",
                        danger="danger",
                        danger_foreground="dangerForeground",
                        dimension="dimension",
                        dimension_foreground="dimensionForeground",
                        measure="measure",
                        measure_foreground="measureForeground",
                        primary_background="primaryBackground",
                        primary_foreground="primaryForeground",
                        secondary_background="secondaryBackground",
                        secondary_foreground="secondaryForeground",
                        success="success",
                        success_foreground="successForeground",
                        warning="warning",
                        warning_foreground="warningForeground"
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__578cb7cdcb9545cde16a00b488903fc7c6e4c99fbb8e511481be866f9fb93980)
                check_type(argname="argument data_color_palette", value=data_color_palette, expected_type=type_hints["data_color_palette"])
                check_type(argname="argument sheet", value=sheet, expected_type=type_hints["sheet"])
                check_type(argname="argument typography", value=typography, expected_type=type_hints["typography"])
                check_type(argname="argument ui_color_palette", value=ui_color_palette, expected_type=type_hints["ui_color_palette"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if data_color_palette is not None:
                self._values["data_color_palette"] = data_color_palette
            if sheet is not None:
                self._values["sheet"] = sheet
            if typography is not None:
                self._values["typography"] = typography
            if ui_color_palette is not None:
                self._values["ui_color_palette"] = ui_color_palette

        @builtins.property
        def data_color_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.DataColorPaletteProperty", _IResolvable_a771d0ef]]:
            '''Color properties that apply to chart data colors.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-datacolorpalette
            '''
            result = self._values.get("data_color_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.DataColorPaletteProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def sheet(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.SheetStyleProperty", _IResolvable_a771d0ef]]:
            '''Display options related to sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-sheet
            '''
            result = self._values.get("sheet")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.SheetStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def typography(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.TypographyProperty", _IResolvable_a771d0ef]]:
            '''``CfnTheme.ThemeConfigurationProperty.Typography``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-typography
            '''
            result = self._values.get("typography")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.TypographyProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def ui_color_palette(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.UIColorPaletteProperty", _IResolvable_a771d0ef]]:
            '''Color properties that apply to the UI and to charts, excluding the colors that apply to data.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-uicolorpalette
            '''
            result = self._values.get("ui_color_palette")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.UIColorPaletteProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeConfigurationProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.ThemeErrorProperty",
        jsii_struct_bases=[],
        name_mapping={"message": "message", "type": "type"},
    )
    class ThemeErrorProperty:
        def __init__(
            self,
            *,
            message: typing.Optional[builtins.str] = None,
            type: typing.Optional[builtins.str] = None,
        ) -> None:
            '''Theme error.

            :param message: The error message.
            :param type: The type of error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                theme_error_property = quicksight.CfnTheme.ThemeErrorProperty(
                    message="message",
                    type="type"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__fb6048efba70fac73bb0a644f0701fc148b43f1485474af58c91e0943d8b8461)
                check_type(argname="argument message", value=message, expected_type=type_hints["message"])
                check_type(argname="argument type", value=type, expected_type=type_hints["type"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if message is not None:
                self._values["message"] = message
            if type is not None:
                self._values["type"] = type

        @builtins.property
        def message(self) -> typing.Optional[builtins.str]:
            '''The error message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-message
            '''
            result = self._values.get("message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def type(self) -> typing.Optional[builtins.str]:
            '''The type of error.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-type
            '''
            result = self._values.get("type")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeErrorProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.ThemeVersionProperty",
        jsii_struct_bases=[],
        name_mapping={
            "arn": "arn",
            "base_theme_id": "baseThemeId",
            "configuration": "configuration",
            "created_time": "createdTime",
            "description": "description",
            "errors": "errors",
            "status": "status",
            "version_number": "versionNumber",
        },
    )
    class ThemeVersionProperty:
        def __init__(
            self,
            *,
            arn: typing.Optional[builtins.str] = None,
            base_theme_id: typing.Optional[builtins.str] = None,
            configuration: typing.Optional[typing.Union[typing.Union["CfnTheme.ThemeConfigurationProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            created_time: typing.Optional[builtins.str] = None,
            description: typing.Optional[builtins.str] = None,
            errors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTheme.ThemeErrorProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
            status: typing.Optional[builtins.str] = None,
            version_number: typing.Optional[jsii.Number] = None,
        ) -> None:
            '''A version of a theme.

            :param arn: The Amazon Resource Name (ARN) of the resource.
            :param base_theme_id: The Amazon QuickSight-defined ID of the theme that a custom theme inherits from. All themes initially inherit from a default Amazon QuickSight theme.
            :param configuration: The theme configuration, which contains all the theme display properties.
            :param created_time: The date and time that this theme version was created.
            :param description: The description of the theme.
            :param errors: Errors associated with the theme.
            :param status: The status of the theme version.
            :param version_number: The version number of the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                theme_version_property = quicksight.CfnTheme.ThemeVersionProperty(
                    arn="arn",
                    base_theme_id="baseThemeId",
                    configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                        data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                            colors=["colors"],
                            empty_fill_color="emptyFillColor",
                            min_max_gradient=["minMaxGradient"]
                        ),
                        sheet=quicksight.CfnTheme.SheetStyleProperty(
                            tile=quicksight.CfnTheme.TileStyleProperty(
                                border=quicksight.CfnTheme.BorderStyleProperty(
                                    show=False
                                )
                            ),
                            tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                                gutter=quicksight.CfnTheme.GutterStyleProperty(
                                    show=False
                                ),
                                margin=quicksight.CfnTheme.MarginStyleProperty(
                                    show=False
                                )
                            )
                        ),
                        typography=quicksight.CfnTheme.TypographyProperty(
                            font_families=[quicksight.CfnTheme.FontProperty(
                                font_family="fontFamily"
                            )]
                        ),
                        ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                            accent="accent",
                            accent_foreground="accentForeground",
                            danger="danger",
                            danger_foreground="dangerForeground",
                            dimension="dimension",
                            dimension_foreground="dimensionForeground",
                            measure="measure",
                            measure_foreground="measureForeground",
                            primary_background="primaryBackground",
                            primary_foreground="primaryForeground",
                            secondary_background="secondaryBackground",
                            secondary_foreground="secondaryForeground",
                            success="success",
                            success_foreground="successForeground",
                            warning="warning",
                            warning_foreground="warningForeground"
                        )
                    ),
                    created_time="createdTime",
                    description="description",
                    errors=[quicksight.CfnTheme.ThemeErrorProperty(
                        message="message",
                        type="type"
                    )],
                    status="status",
                    version_number=123
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__b2355f6dbd7f07d10537444b72f0b2a415d75ef5a1dc2daf3b5295eab57edc38)
                check_type(argname="argument arn", value=arn, expected_type=type_hints["arn"])
                check_type(argname="argument base_theme_id", value=base_theme_id, expected_type=type_hints["base_theme_id"])
                check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
                check_type(argname="argument created_time", value=created_time, expected_type=type_hints["created_time"])
                check_type(argname="argument description", value=description, expected_type=type_hints["description"])
                check_type(argname="argument errors", value=errors, expected_type=type_hints["errors"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument version_number", value=version_number, expected_type=type_hints["version_number"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if arn is not None:
                self._values["arn"] = arn
            if base_theme_id is not None:
                self._values["base_theme_id"] = base_theme_id
            if configuration is not None:
                self._values["configuration"] = configuration
            if created_time is not None:
                self._values["created_time"] = created_time
            if description is not None:
                self._values["description"] = description
            if errors is not None:
                self._values["errors"] = errors
            if status is not None:
                self._values["status"] = status
            if version_number is not None:
                self._values["version_number"] = version_number

        @builtins.property
        def arn(self) -> typing.Optional[builtins.str]:
            '''The Amazon Resource Name (ARN) of the resource.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-arn
            '''
            result = self._values.get("arn")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def base_theme_id(self) -> typing.Optional[builtins.str]:
            '''The Amazon QuickSight-defined ID of the theme that a custom theme inherits from.

            All themes initially inherit from a default Amazon QuickSight theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-basethemeid
            '''
            result = self._values.get("base_theme_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def configuration(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.ThemeConfigurationProperty", _IResolvable_a771d0ef]]:
            '''The theme configuration, which contains all the theme display properties.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-configuration
            '''
            result = self._values.get("configuration")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.ThemeConfigurationProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def created_time(self) -> typing.Optional[builtins.str]:
            '''The date and time that this theme version was created.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-createdtime
            '''
            result = self._values.get("created_time")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def description(self) -> typing.Optional[builtins.str]:
            '''The description of the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-description
            '''
            result = self._values.get("description")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def errors(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.ThemeErrorProperty", _IResolvable_a771d0ef]]]]:
            '''Errors associated with the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-errors
            '''
            result = self._values.get("errors")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.ThemeErrorProperty", _IResolvable_a771d0ef]]]], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the theme version.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def version_number(self) -> typing.Optional[jsii.Number]:
            '''The version number of the theme.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-versionnumber
            '''
            result = self._values.get("version_number")
            return typing.cast(typing.Optional[jsii.Number], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "ThemeVersionProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.TileLayoutStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"gutter": "gutter", "margin": "margin"},
    )
    class TileLayoutStyleProperty:
        def __init__(
            self,
            *,
            gutter: typing.Optional[typing.Union[typing.Union["CfnTheme.GutterStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
            margin: typing.Optional[typing.Union[typing.Union["CfnTheme.MarginStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''The display options for the layout of tiles on a sheet.

            :param gutter: The gutter settings that apply between tiles.
            :param margin: The margin settings that apply around the outside edge of sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tile_layout_style_property = quicksight.CfnTheme.TileLayoutStyleProperty(
                    gutter=quicksight.CfnTheme.GutterStyleProperty(
                        show=False
                    ),
                    margin=quicksight.CfnTheme.MarginStyleProperty(
                        show=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__105274364981084856d1b81067a3b72feef9bf6ea968ceb63e4ad5fb9aebd2f0)
                check_type(argname="argument gutter", value=gutter, expected_type=type_hints["gutter"])
                check_type(argname="argument margin", value=margin, expected_type=type_hints["margin"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if gutter is not None:
                self._values["gutter"] = gutter
            if margin is not None:
                self._values["margin"] = margin

        @builtins.property
        def gutter(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.GutterStyleProperty", _IResolvable_a771d0ef]]:
            '''The gutter settings that apply between tiles.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-gutter
            '''
            result = self._values.get("gutter")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.GutterStyleProperty", _IResolvable_a771d0ef]], result)

        @builtins.property
        def margin(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.MarginStyleProperty", _IResolvable_a771d0ef]]:
            '''The margin settings that apply around the outside edge of sheets.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-margin
            '''
            result = self._values.get("margin")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.MarginStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TileLayoutStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.TileStyleProperty",
        jsii_struct_bases=[],
        name_mapping={"border": "border"},
    )
    class TileStyleProperty:
        def __init__(
            self,
            *,
            border: typing.Optional[typing.Union[typing.Union["CfnTheme.BorderStyleProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        ) -> None:
            '''Display options related to tiles on a sheet.

            :param border: The border around a tile.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                tile_style_property = quicksight.CfnTheme.TileStyleProperty(
                    border=quicksight.CfnTheme.BorderStyleProperty(
                        show=False
                    )
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__cf9fdbc68fdbe60b4f0c091cda0d203d1cd0a356ca81cdbcb3ec26b51fe3fb3c)
                check_type(argname="argument border", value=border, expected_type=type_hints["border"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if border is not None:
                self._values["border"] = border

        @builtins.property
        def border(
            self,
        ) -> typing.Optional[typing.Union["CfnTheme.BorderStyleProperty", _IResolvable_a771d0ef]]:
            '''The border around a tile.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html#cfn-quicksight-theme-tilestyle-border
            '''
            result = self._values.get("border")
            return typing.cast(typing.Optional[typing.Union["CfnTheme.BorderStyleProperty", _IResolvable_a771d0ef]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TileStyleProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.TypographyProperty",
        jsii_struct_bases=[],
        name_mapping={"font_families": "fontFamilies"},
    )
    class TypographyProperty:
        def __init__(
            self,
            *,
            font_families: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnTheme.FontProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        ) -> None:
            '''
            :param font_families: ``CfnTheme.TypographyProperty.FontFamilies``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                typography_property = quicksight.CfnTheme.TypographyProperty(
                    font_families=[quicksight.CfnTheme.FontProperty(
                        font_family="fontFamily"
                    )]
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__1e80c7795e212917d762116e84e5be5123624cc6a0cae63097a92ab2d4d1fa0c)
                check_type(argname="argument font_families", value=font_families, expected_type=type_hints["font_families"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if font_families is not None:
                self._values["font_families"] = font_families

        @builtins.property
        def font_families(
            self,
        ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.FontProperty", _IResolvable_a771d0ef]]]]:
            '''``CfnTheme.TypographyProperty.FontFamilies``.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html#cfn-quicksight-theme-typography-fontfamilies
            '''
            result = self._values.get("font_families")
            return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnTheme.FontProperty", _IResolvable_a771d0ef]]]], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "TypographyProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnTheme.UIColorPaletteProperty",
        jsii_struct_bases=[],
        name_mapping={
            "accent": "accent",
            "accent_foreground": "accentForeground",
            "danger": "danger",
            "danger_foreground": "dangerForeground",
            "dimension": "dimension",
            "dimension_foreground": "dimensionForeground",
            "measure": "measure",
            "measure_foreground": "measureForeground",
            "primary_background": "primaryBackground",
            "primary_foreground": "primaryForeground",
            "secondary_background": "secondaryBackground",
            "secondary_foreground": "secondaryForeground",
            "success": "success",
            "success_foreground": "successForeground",
            "warning": "warning",
            "warning_foreground": "warningForeground",
        },
    )
    class UIColorPaletteProperty:
        def __init__(
            self,
            *,
            accent: typing.Optional[builtins.str] = None,
            accent_foreground: typing.Optional[builtins.str] = None,
            danger: typing.Optional[builtins.str] = None,
            danger_foreground: typing.Optional[builtins.str] = None,
            dimension: typing.Optional[builtins.str] = None,
            dimension_foreground: typing.Optional[builtins.str] = None,
            measure: typing.Optional[builtins.str] = None,
            measure_foreground: typing.Optional[builtins.str] = None,
            primary_background: typing.Optional[builtins.str] = None,
            primary_foreground: typing.Optional[builtins.str] = None,
            secondary_background: typing.Optional[builtins.str] = None,
            secondary_foreground: typing.Optional[builtins.str] = None,
            success: typing.Optional[builtins.str] = None,
            success_foreground: typing.Optional[builtins.str] = None,
            warning: typing.Optional[builtins.str] = None,
            warning_foreground: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The theme colors that apply to UI and to charts, excluding data colors.

            The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with ``#`` , for example #37BFF5. For more information, see `Using Themes in Amazon QuickSight <https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html>`_ in the *Amazon QuickSight User Guide.*

            :param accent: This color is that applies to selected states and buttons.
            :param accent_foreground: The foreground color that applies to any text or other elements that appear over the accent color.
            :param danger: The color that applies to error messages.
            :param danger_foreground: The foreground color that applies to any text or other elements that appear over the error color.
            :param dimension: The color that applies to the names of fields that are identified as dimensions.
            :param dimension_foreground: The foreground color that applies to any text or other elements that appear over the dimension color.
            :param measure: The color that applies to the names of fields that are identified as measures.
            :param measure_foreground: The foreground color that applies to any text or other elements that appear over the measure color.
            :param primary_background: The background color that applies to visuals and other high emphasis UI.
            :param primary_foreground: The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.
            :param secondary_background: The background color that applies to the sheet background and sheet controls.
            :param secondary_foreground: The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.
            :param success: The color that applies to success messages, for example the check mark for a successful download.
            :param success_foreground: The foreground color that applies to any text or other elements that appear over the success color.
            :param warning: This color that applies to warning and informational messages.
            :param warning_foreground: The foreground color that applies to any text or other elements that appear over the warning color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                u_iColor_palette_property = quicksight.CfnTheme.UIColorPaletteProperty(
                    accent="accent",
                    accent_foreground="accentForeground",
                    danger="danger",
                    danger_foreground="dangerForeground",
                    dimension="dimension",
                    dimension_foreground="dimensionForeground",
                    measure="measure",
                    measure_foreground="measureForeground",
                    primary_background="primaryBackground",
                    primary_foreground="primaryForeground",
                    secondary_background="secondaryBackground",
                    secondary_foreground="secondaryForeground",
                    success="success",
                    success_foreground="successForeground",
                    warning="warning",
                    warning_foreground="warningForeground"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__de50b957762075174cb676dbaa4eaf86e03e236d848e3f36976e5eb814d35a69)
                check_type(argname="argument accent", value=accent, expected_type=type_hints["accent"])
                check_type(argname="argument accent_foreground", value=accent_foreground, expected_type=type_hints["accent_foreground"])
                check_type(argname="argument danger", value=danger, expected_type=type_hints["danger"])
                check_type(argname="argument danger_foreground", value=danger_foreground, expected_type=type_hints["danger_foreground"])
                check_type(argname="argument dimension", value=dimension, expected_type=type_hints["dimension"])
                check_type(argname="argument dimension_foreground", value=dimension_foreground, expected_type=type_hints["dimension_foreground"])
                check_type(argname="argument measure", value=measure, expected_type=type_hints["measure"])
                check_type(argname="argument measure_foreground", value=measure_foreground, expected_type=type_hints["measure_foreground"])
                check_type(argname="argument primary_background", value=primary_background, expected_type=type_hints["primary_background"])
                check_type(argname="argument primary_foreground", value=primary_foreground, expected_type=type_hints["primary_foreground"])
                check_type(argname="argument secondary_background", value=secondary_background, expected_type=type_hints["secondary_background"])
                check_type(argname="argument secondary_foreground", value=secondary_foreground, expected_type=type_hints["secondary_foreground"])
                check_type(argname="argument success", value=success, expected_type=type_hints["success"])
                check_type(argname="argument success_foreground", value=success_foreground, expected_type=type_hints["success_foreground"])
                check_type(argname="argument warning", value=warning, expected_type=type_hints["warning"])
                check_type(argname="argument warning_foreground", value=warning_foreground, expected_type=type_hints["warning_foreground"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if accent is not None:
                self._values["accent"] = accent
            if accent_foreground is not None:
                self._values["accent_foreground"] = accent_foreground
            if danger is not None:
                self._values["danger"] = danger
            if danger_foreground is not None:
                self._values["danger_foreground"] = danger_foreground
            if dimension is not None:
                self._values["dimension"] = dimension
            if dimension_foreground is not None:
                self._values["dimension_foreground"] = dimension_foreground
            if measure is not None:
                self._values["measure"] = measure
            if measure_foreground is not None:
                self._values["measure_foreground"] = measure_foreground
            if primary_background is not None:
                self._values["primary_background"] = primary_background
            if primary_foreground is not None:
                self._values["primary_foreground"] = primary_foreground
            if secondary_background is not None:
                self._values["secondary_background"] = secondary_background
            if secondary_foreground is not None:
                self._values["secondary_foreground"] = secondary_foreground
            if success is not None:
                self._values["success"] = success
            if success_foreground is not None:
                self._values["success_foreground"] = success_foreground
            if warning is not None:
                self._values["warning"] = warning
            if warning_foreground is not None:
                self._values["warning_foreground"] = warning_foreground

        @builtins.property
        def accent(self) -> typing.Optional[builtins.str]:
            '''This color is that applies to selected states and buttons.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accent
            '''
            result = self._values.get("accent")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def accent_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the accent color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accentforeground
            '''
            result = self._values.get("accent_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def danger(self) -> typing.Optional[builtins.str]:
            '''The color that applies to error messages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-danger
            '''
            result = self._values.get("danger")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def danger_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the error color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dangerforeground
            '''
            result = self._values.get("danger_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dimension(self) -> typing.Optional[builtins.str]:
            '''The color that applies to the names of fields that are identified as dimensions.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimension
            '''
            result = self._values.get("dimension")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def dimension_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the dimension color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimensionforeground
            '''
            result = self._values.get("dimension_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure(self) -> typing.Optional[builtins.str]:
            '''The color that applies to the names of fields that are identified as measures.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measure
            '''
            result = self._values.get("measure")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def measure_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the measure color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measureforeground
            '''
            result = self._values.get("measure_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_background(self) -> typing.Optional[builtins.str]:
            '''The background color that applies to visuals and other high emphasis UI.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primarybackground
            '''
            result = self._values.get("primary_background")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def primary_foreground(self) -> typing.Optional[builtins.str]:
            '''The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primaryforeground
            '''
            result = self._values.get("primary_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def secondary_background(self) -> typing.Optional[builtins.str]:
            '''The background color that applies to the sheet background and sheet controls.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondarybackground
            '''
            result = self._values.get("secondary_background")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def secondary_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondaryforeground
            '''
            result = self._values.get("secondary_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def success(self) -> typing.Optional[builtins.str]:
            '''The color that applies to success messages, for example the check mark for a successful download.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-success
            '''
            result = self._values.get("success")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def success_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the success color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-successforeground
            '''
            result = self._values.get("success_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def warning(self) -> typing.Optional[builtins.str]:
            '''This color that applies to warning and informational messages.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warning
            '''
            result = self._values.get("warning")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def warning_foreground(self) -> typing.Optional[builtins.str]:
            '''The foreground color that applies to any text or other elements that appear over the warning color.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warningforeground
            '''
            result = self._values.get("warning_foreground")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "UIColorPaletteProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnThemeProps",
    jsii_struct_bases=[],
    name_mapping={
        "aws_account_id": "awsAccountId",
        "theme_id": "themeId",
        "base_theme_id": "baseThemeId",
        "configuration": "configuration",
        "name": "name",
        "permissions": "permissions",
        "tags": "tags",
        "version_description": "versionDescription",
    },
)
class CfnThemeProps:
    def __init__(
        self,
        *,
        aws_account_id: builtins.str,
        theme_id: builtins.str,
        base_theme_id: typing.Optional[builtins.str] = None,
        configuration: typing.Optional[typing.Union[typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
        name: typing.Optional[builtins.str] = None,
        permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        version_description: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnTheme``.

        :param aws_account_id: The ID of the AWS account where you want to store the new theme.
        :param theme_id: An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
        :param base_theme_id: The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.
        :param configuration: The theme configuration, which contains the theme display properties.
        :param name: A display name for the theme.
        :param permissions: A valid grouping of resource permissions to apply to the new theme.
        :param tags: A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
        :param version_description: A description of the first version of the theme that you're creating. Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            cfn_theme_props = quicksight.CfnThemeProps(
                aws_account_id="awsAccountId",
                theme_id="themeId",
            
                # the properties below are optional
                base_theme_id="baseThemeId",
                configuration=quicksight.CfnTheme.ThemeConfigurationProperty(
                    data_color_palette=quicksight.CfnTheme.DataColorPaletteProperty(
                        colors=["colors"],
                        empty_fill_color="emptyFillColor",
                        min_max_gradient=["minMaxGradient"]
                    ),
                    sheet=quicksight.CfnTheme.SheetStyleProperty(
                        tile=quicksight.CfnTheme.TileStyleProperty(
                            border=quicksight.CfnTheme.BorderStyleProperty(
                                show=False
                            )
                        ),
                        tile_layout=quicksight.CfnTheme.TileLayoutStyleProperty(
                            gutter=quicksight.CfnTheme.GutterStyleProperty(
                                show=False
                            ),
                            margin=quicksight.CfnTheme.MarginStyleProperty(
                                show=False
                            )
                        )
                    ),
                    typography=quicksight.CfnTheme.TypographyProperty(
                        font_families=[quicksight.CfnTheme.FontProperty(
                            font_family="fontFamily"
                        )]
                    ),
                    ui_color_palette=quicksight.CfnTheme.UIColorPaletteProperty(
                        accent="accent",
                        accent_foreground="accentForeground",
                        danger="danger",
                        danger_foreground="dangerForeground",
                        dimension="dimension",
                        dimension_foreground="dimensionForeground",
                        measure="measure",
                        measure_foreground="measureForeground",
                        primary_background="primaryBackground",
                        primary_foreground="primaryForeground",
                        secondary_background="secondaryBackground",
                        secondary_foreground="secondaryForeground",
                        success="success",
                        success_foreground="successForeground",
                        warning="warning",
                        warning_foreground="warningForeground"
                    )
                ),
                name="name",
                permissions=[quicksight.CfnTheme.ResourcePermissionProperty(
                    actions=["actions"],
                    principal="principal"
                )],
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                version_description="versionDescription"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__baf50d33c07375bd6f65cbb3c24b91760006a90a20c7742b37182d23ee52cb36)
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument theme_id", value=theme_id, expected_type=type_hints["theme_id"])
            check_type(argname="argument base_theme_id", value=base_theme_id, expected_type=type_hints["base_theme_id"])
            check_type(argname="argument configuration", value=configuration, expected_type=type_hints["configuration"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument permissions", value=permissions, expected_type=type_hints["permissions"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument version_description", value=version_description, expected_type=type_hints["version_description"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "aws_account_id": aws_account_id,
            "theme_id": theme_id,
        }
        if base_theme_id is not None:
            self._values["base_theme_id"] = base_theme_id
        if configuration is not None:
            self._values["configuration"] = configuration
        if name is not None:
            self._values["name"] = name
        if permissions is not None:
            self._values["permissions"] = permissions
        if tags is not None:
            self._values["tags"] = tags
        if version_description is not None:
            self._values["version_description"] = version_description

    @builtins.property
    def aws_account_id(self) -> builtins.str:
        '''The ID of the AWS account where you want to store the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        assert result is not None, "Required property 'aws_account_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def theme_id(self) -> builtins.str:
        '''An ID for the theme that you want to create.

        The theme ID is unique per AWS Region in each AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
        '''
        result = self._values.get("theme_id")
        assert result is not None, "Required property 'theme_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def base_theme_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the theme that a custom theme will inherit from.

        All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ``ListThemes`` or choose *Themes* from within an analysis.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
        '''
        result = self._values.get("base_theme_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def configuration(
        self,
    ) -> typing.Optional[typing.Union[CfnTheme.ThemeConfigurationProperty, _IResolvable_a771d0ef]]:
        '''The theme configuration, which contains the theme display properties.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
        '''
        result = self._values.get("configuration")
        return typing.cast(typing.Optional[typing.Union[CfnTheme.ThemeConfigurationProperty, _IResolvable_a771d0ef]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''A display name for the theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def permissions(
        self,
    ) -> typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnTheme.ResourcePermissionProperty, _IResolvable_a771d0ef]]]]:
        '''A valid grouping of resource permissions to apply to the new theme.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
        '''
        result = self._values.get("permissions")
        return typing.cast(typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnTheme.ResourcePermissionProperty, _IResolvable_a771d0ef]]]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''A map of the key-value pairs for the resource tag or tags that you want to add to the resource.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    @builtins.property
    def version_description(self) -> typing.Optional[builtins.str]:
        '''A description of the first version of the theme that you're creating.

        Every time ``UpdateTheme`` is called, a new version is created. Each version of the theme has a description of the version in the ``VersionDescription`` field.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
        '''
        result = self._values.get("version_description")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnThemeProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.implements(_IInspectable_82c04a63)
class CfnVPCConnection(
    _CfnResource_e0a482dc,
    metaclass=jsii.JSIIMeta,
    jsii_type="monocdk.aws_quicksight.CfnVPCConnection",
):
    '''A CloudFormation ``AWS::QuickSight::VPCConnection``.

    Creates a new VPC connection.

    :cloudformationResource: AWS::QuickSight::VPCConnection
    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
    :exampleMetadata: fixture=_generated

    Example::

        # The code below shows an example of how to instantiate this type.
        # The values are placeholders you should change.
        from monocdk import aws_quicksight as quicksight
        
        cfn_vPCConnection = quicksight.CfnVPCConnection(self, "MyCfnVPCConnection",
            availability_status="availabilityStatus",
            aws_account_id="awsAccountId",
            dns_resolvers=["dnsResolvers"],
            name="name",
            role_arn="roleArn",
            security_group_ids=["securityGroupIds"],
            subnet_ids=["subnetIds"],
            tags=[CfnTag(
                key="key",
                value="value"
            )],
            vpc_connection_id="vpcConnectionId"
        )
    '''

    def __init__(
        self,
        scope: _Construct_e78e779f,
        id: builtins.str,
        *,
        availability_status: typing.Optional[builtins.str] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        role_arn: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        vpc_connection_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``AWS::QuickSight::VPCConnection``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param availability_status: The availability status of the VPC connection.
        :param aws_account_id: The AWS account ID of the account where you want to create a new VPC connection.
        :param dns_resolvers: A list of IP addresses of DNS resolver endpoints for the VPC connection.
        :param name: The display name for the VPC connection.
        :param role_arn: The ARN of the IAM role associated with the VPC connection.
        :param security_group_ids: The Amazon EC2 security group IDs associated with the VPC connection.
        :param subnet_ids: A list of subnet IDs for the VPC connection.
        :param tags: A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
        :param vpc_connection_id: The ID of the VPC connection that you're creating. This ID is a unique identifier for each AWS Region in an AWS account.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__6bcde85be865623c80e1517b4de7487ab675b6c2fe2e98cc8896c13c35153c71)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnVPCConnectionProps(
            availability_status=availability_status,
            aws_account_id=aws_account_id,
            dns_resolvers=dns_resolvers,
            name=name,
            role_arn=role_arn,
            security_group_ids=security_group_ids,
            subnet_ids=subnet_ids,
            tags=tags,
            vpc_connection_id=vpc_connection_id,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: _TreeInspector_1cd1894e) -> None:
        '''Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__65d49377b766e5f26d61491d4aeb3617321c2d51762f46a5fe76736bc886249f)
            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(
        self,
        props: typing.Mapping[builtins.str, typing.Any],
    ) -> typing.Mapping[builtins.str, typing.Any]:
        '''
        :param props: -
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__73f6ba18f05c8ab37c670bbf4f03441dbfa9494b7f131312ceb633cf590b3081)
            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> builtins.str:
        '''
        :cloudformationAttribute: Arn
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrArn"))

    @builtins.property
    @jsii.member(jsii_name="attrCreatedTime")
    def attr_created_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: CreatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrCreatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrLastUpdatedTime")
    def attr_last_updated_time(self) -> builtins.str:
        '''
        :cloudformationAttribute: LastUpdatedTime
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrLastUpdatedTime"))

    @builtins.property
    @jsii.member(jsii_name="attrNetworkInterfaces")
    def attr_network_interfaces(self) -> _IResolvable_a771d0ef:
        '''
        :cloudformationAttribute: NetworkInterfaces
        '''
        return typing.cast(_IResolvable_a771d0ef, jsii.get(self, "attrNetworkInterfaces"))

    @builtins.property
    @jsii.member(jsii_name="attrStatus")
    def attr_status(self) -> builtins.str:
        '''
        :cloudformationAttribute: Status
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrStatus"))

    @builtins.property
    @jsii.member(jsii_name="attrVpcId")
    def attr_vpc_id(self) -> builtins.str:
        '''
        :cloudformationAttribute: VPCId
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrVpcId"))

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> _TagManager_0b7ab120:
        '''A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-tags
        '''
        return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))

    @builtins.property
    @jsii.member(jsii_name="availabilityStatus")
    def availability_status(self) -> typing.Optional[builtins.str]:
        '''The availability status of the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-availabilitystatus
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "availabilityStatus"))

    @availability_status.setter
    def availability_status(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0fc3edd9331a9a88a912961357e37a2268d75e6c27148772c3d061292f079867)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "availabilityStatus", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account where you want to create a new VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-awsaccountid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "awsAccountId"))

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1e8f2a3c20b055a182c9ecb372694a9956a54ebbdfbf494596c9d6bf7f268d7e)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="dnsResolvers")
    def dns_resolvers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of IP addresses of DNS resolver endpoints for the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-dnsresolvers
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "dnsResolvers"))

    @dns_resolvers.setter
    def dns_resolvers(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__590fcceedf86192f22c418e295aed66033f4767e5c2d28e49e224a716329bc9a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "dnsResolvers", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-name
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "name"))

    @name.setter
    def name(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__74b57e5a306a3f450c02afc04bc81367694cb7775f803535635ee05121ca63d2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN of the IAM role associated with the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-rolearn
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "roleArn"))

    @role_arn.setter
    def role_arn(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__302f113f7175dbea4c037d05da5902cb1b1a433d4c191b1dcafb3e4a8053f78c)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The Amazon EC2 security group IDs associated with the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-securitygroupids
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "securityGroupIds"))

    @security_group_ids.setter
    def security_group_ids(
        self,
        value: typing.Optional[typing.List[builtins.str]],
    ) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d658fc0d7a2030afc9e81e446212a5bc98325efec0085a663ba62fb83bf7340d)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of subnet IDs for the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-subnetids
        '''
        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "subnetIds"))

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[builtins.str]]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4e4e5de4cc795447f32a5518663b04e8354630794454d6bba85fa213db41bab6)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConnectionId")
    def vpc_connection_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the VPC connection that you're creating.

        This ID is a unique identifier for each AWS Region in an AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-vpcconnectionid
        '''
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "vpcConnectionId"))

    @vpc_connection_id.setter
    def vpc_connection_id(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__e2b2e0a6a8a31deac2ae29b156c918fc51146033029b8ca227f4b7f7ff649f7a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "vpcConnectionId", value)

    @jsii.data_type(
        jsii_type="monocdk.aws_quicksight.CfnVPCConnection.NetworkInterfaceProperty",
        jsii_struct_bases=[],
        name_mapping={
            "availability_zone": "availabilityZone",
            "error_message": "errorMessage",
            "network_interface_id": "networkInterfaceId",
            "status": "status",
            "subnet_id": "subnetId",
        },
    )
    class NetworkInterfaceProperty:
        def __init__(
            self,
            *,
            availability_zone: typing.Optional[builtins.str] = None,
            error_message: typing.Optional[builtins.str] = None,
            network_interface_id: typing.Optional[builtins.str] = None,
            status: typing.Optional[builtins.str] = None,
            subnet_id: typing.Optional[builtins.str] = None,
        ) -> None:
            '''The structure that contains information about a network interface.

            :param availability_zone: The availability zone that the network interface resides in.
            :param error_message: An error message.
            :param network_interface_id: The network interface ID.
            :param status: The status of the network interface.
            :param subnet_id: The subnet ID associated with the network interface.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html
            :exampleMetadata: fixture=_generated

            Example::

                # The code below shows an example of how to instantiate this type.
                # The values are placeholders you should change.
                from monocdk import aws_quicksight as quicksight
                
                network_interface_property = quicksight.CfnVPCConnection.NetworkInterfaceProperty(
                    availability_zone="availabilityZone",
                    error_message="errorMessage",
                    network_interface_id="networkInterfaceId",
                    status="status",
                    subnet_id="subnetId"
                )
            '''
            if __debug__:
                type_hints = typing.get_type_hints(_typecheckingstub__d64e737559dffe04b19dc157c24c7678a13e4f8a61b48175df2562153f03ae76)
                check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
                check_type(argname="argument error_message", value=error_message, expected_type=type_hints["error_message"])
                check_type(argname="argument network_interface_id", value=network_interface_id, expected_type=type_hints["network_interface_id"])
                check_type(argname="argument status", value=status, expected_type=type_hints["status"])
                check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
            self._values: typing.Dict[builtins.str, typing.Any] = {}
            if availability_zone is not None:
                self._values["availability_zone"] = availability_zone
            if error_message is not None:
                self._values["error_message"] = error_message
            if network_interface_id is not None:
                self._values["network_interface_id"] = network_interface_id
            if status is not None:
                self._values["status"] = status
            if subnet_id is not None:
                self._values["subnet_id"] = subnet_id

        @builtins.property
        def availability_zone(self) -> typing.Optional[builtins.str]:
            '''The availability zone that the network interface resides in.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-availabilityzone
            '''
            result = self._values.get("availability_zone")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def error_message(self) -> typing.Optional[builtins.str]:
            '''An error message.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-errormessage
            '''
            result = self._values.get("error_message")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def network_interface_id(self) -> typing.Optional[builtins.str]:
            '''The network interface ID.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-networkinterfaceid
            '''
            result = self._values.get("network_interface_id")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def status(self) -> typing.Optional[builtins.str]:
            '''The status of the network interface.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-status
            '''
            result = self._values.get("status")
            return typing.cast(typing.Optional[builtins.str], result)

        @builtins.property
        def subnet_id(self) -> typing.Optional[builtins.str]:
            '''The subnet ID associated with the network interface.

            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-vpcconnection-networkinterface.html#cfn-quicksight-vpcconnection-networkinterface-subnetid
            '''
            result = self._values.get("subnet_id")
            return typing.cast(typing.Optional[builtins.str], result)

        def __eq__(self, rhs: typing.Any) -> builtins.bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs: typing.Any) -> builtins.bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return "NetworkInterfaceProperty(%s)" % ", ".join(
                k + "=" + repr(v) for k, v in self._values.items()
            )


@jsii.data_type(
    jsii_type="monocdk.aws_quicksight.CfnVPCConnectionProps",
    jsii_struct_bases=[],
    name_mapping={
        "availability_status": "availabilityStatus",
        "aws_account_id": "awsAccountId",
        "dns_resolvers": "dnsResolvers",
        "name": "name",
        "role_arn": "roleArn",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "tags": "tags",
        "vpc_connection_id": "vpcConnectionId",
    },
)
class CfnVPCConnectionProps:
    def __init__(
        self,
        *,
        availability_status: typing.Optional[builtins.str] = None,
        aws_account_id: typing.Optional[builtins.str] = None,
        dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
        name: typing.Optional[builtins.str] = None,
        role_arn: typing.Optional[builtins.str] = None,
        security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
        vpc_connection_id: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Properties for defining a ``CfnVPCConnection``.

        :param availability_status: The availability status of the VPC connection.
        :param aws_account_id: The AWS account ID of the account where you want to create a new VPC connection.
        :param dns_resolvers: A list of IP addresses of DNS resolver endpoints for the VPC connection.
        :param name: The display name for the VPC connection.
        :param role_arn: The ARN of the IAM role associated with the VPC connection.
        :param security_group_ids: The Amazon EC2 security group IDs associated with the VPC connection.
        :param subnet_ids: A list of subnet IDs for the VPC connection.
        :param tags: A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.
        :param vpc_connection_id: The ID of the VPC connection that you're creating. This ID is a unique identifier for each AWS Region in an AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html
        :exampleMetadata: fixture=_generated

        Example::

            # The code below shows an example of how to instantiate this type.
            # The values are placeholders you should change.
            from monocdk import aws_quicksight as quicksight
            
            cfn_vPCConnection_props = quicksight.CfnVPCConnectionProps(
                availability_status="availabilityStatus",
                aws_account_id="awsAccountId",
                dns_resolvers=["dnsResolvers"],
                name="name",
                role_arn="roleArn",
                security_group_ids=["securityGroupIds"],
                subnet_ids=["subnetIds"],
                tags=[CfnTag(
                    key="key",
                    value="value"
                )],
                vpc_connection_id="vpcConnectionId"
            )
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__12ce6e4db6bc4193a018d80637b682965f86bfc8dad4ea1d2da029ae75f8ff04)
            check_type(argname="argument availability_status", value=availability_status, expected_type=type_hints["availability_status"])
            check_type(argname="argument aws_account_id", value=aws_account_id, expected_type=type_hints["aws_account_id"])
            check_type(argname="argument dns_resolvers", value=dns_resolvers, expected_type=type_hints["dns_resolvers"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument role_arn", value=role_arn, expected_type=type_hints["role_arn"])
            check_type(argname="argument security_group_ids", value=security_group_ids, expected_type=type_hints["security_group_ids"])
            check_type(argname="argument subnet_ids", value=subnet_ids, expected_type=type_hints["subnet_ids"])
            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
            check_type(argname="argument vpc_connection_id", value=vpc_connection_id, expected_type=type_hints["vpc_connection_id"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if availability_status is not None:
            self._values["availability_status"] = availability_status
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if dns_resolvers is not None:
            self._values["dns_resolvers"] = dns_resolvers
        if name is not None:
            self._values["name"] = name
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags
        if vpc_connection_id is not None:
            self._values["vpc_connection_id"] = vpc_connection_id

    @builtins.property
    def availability_status(self) -> typing.Optional[builtins.str]:
        '''The availability status of the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-availabilitystatus
        '''
        result = self._values.get("availability_status")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def aws_account_id(self) -> typing.Optional[builtins.str]:
        '''The AWS account ID of the account where you want to create a new VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-awsaccountid
        '''
        result = self._values.get("aws_account_id")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def dns_resolvers(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of IP addresses of DNS resolver endpoints for the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-dnsresolvers
        '''
        result = self._values.get("dns_resolvers")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The display name for the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def role_arn(self) -> typing.Optional[builtins.str]:
        '''The ARN of the IAM role associated with the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-rolearn
        '''
        result = self._values.get("role_arn")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''The Amazon EC2 security group IDs associated with the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-securitygroupids
        '''
        result = self._values.get("security_group_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[builtins.str]]:
        '''A list of subnet IDs for the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-subnetids
        '''
        result = self._values.get("subnet_ids")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def tags(self) -> typing.Optional[typing.List[_CfnTag_95fbdc29]]:
        '''A map of the key-value pairs for the resource tag or tags assigned to the VPC connection.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-tags
        '''
        result = self._values.get("tags")
        return typing.cast(typing.Optional[typing.List[_CfnTag_95fbdc29]], result)

    @builtins.property
    def vpc_connection_id(self) -> typing.Optional[builtins.str]:
        '''The ID of the VPC connection that you're creating.

        This ID is a unique identifier for each AWS Region in an AWS account.

        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-vpcconnection.html#cfn-quicksight-vpcconnection-vpcconnectionid
        '''
        result = self._values.get("vpc_connection_id")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnVPCConnectionProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CfnAnalysis",
    "CfnAnalysisProps",
    "CfnDashboard",
    "CfnDashboardProps",
    "CfnDataSet",
    "CfnDataSetProps",
    "CfnDataSource",
    "CfnDataSourceProps",
    "CfnRefreshSchedule",
    "CfnRefreshScheduleProps",
    "CfnTemplate",
    "CfnTemplateProps",
    "CfnTheme",
    "CfnThemeProps",
    "CfnVPCConnection",
    "CfnVPCConnectionProps",
]

publication.publish()

def _typecheckingstub__94713b0e25f6fb44da0e5708561fbb388ab27894952dc9180b090ad973fedb64(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    analysis_id: builtins.str,
    aws_account_id: builtins.str,
    name: builtins.str,
    definition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameters: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    status: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a277acf1bf3d5fa079c94d01280ebdfc15738a792f0755991a8e2ee749f1b617(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f8c9493ca5edcffe9b4b0ae7a2f962f5abb5196f9599a5290f4093ab8908832(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b63dd2ef2d013078cd4f95a2a87cf9df1991fb860975faba156b39fed0046087(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__973802336e8a95c38ae0fc40f7bcc9e7809bd05fe43b084a98ab3dbe08870bd3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a50f221b67eca3e3dbd4f669b01de869d050af55b0865f217b20bdf256ab7a3(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c051a165f191bcf70ebc87b79d0e99dfe367c2b1e394774b42750d0dc0c76f9e(
    value: typing.Optional[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__138e4944c872b7dc4398d7338a0a78c65becb9d6e22de7d3cd2fe4a800b1b6c5(
    value: typing.Optional[typing.Union[CfnAnalysis.ParametersProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cb1e49f31d389ff3dd53df5668dbb6443bfcf1576635017254421f73bafa43c(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnAnalysis.ResourcePermissionProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3f7da47ef2ef2a95c12c58a700b56d3e16ac66ef40b8ad7b736fe872040f86c(
    value: typing.Optional[typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6832fc6a28a99a31804550e91c2f0aaf8bc624abc6f811f49eb57914000a2aa5(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cae791aff2259aec117cab6d8f48dd161a81128a8c099068f5de1f1fd08fb97(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__441589f4166c673ce28509120a312121ac16be405fc13d820a46b6935e1e4011(
    *,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f8b4634cfd5d6e81d30d066c7f9efca5aacd2f53941db99653eff80c78786f1(
    *,
    aggregation_function: typing.Union[typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    sort_direction: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b23dd539ace7bb8ea3a8a1f8e39918514b4a2cc41cad382259dce482b4d50c89(
    *,
    default_new_sheet_configuration: typing.Union[typing.Union[CfnAnalysis.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__813a271fde414637ef85e6d924dbed35e7767836cac1126afe34b2ebb5cabe6a(
    *,
    data_set_identifier_declarations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataSetIdentifierDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    analysis_defaults: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    column_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    filter_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__311857a65fb40985dd2b496f122b3d63ce49d6673a6fab9fc013c8b49832966a(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.EntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b60bdfbf9fb7937127801dd3d259559ba7def61dbaa3009ea53909a916ee12f(
    *,
    source_template: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc261445b37c22b2efa052372f4d6884a6145c4552ef4443eb3fd587c184d308(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95dc095a7fcc6e3e17b44d7ebebb50e95cf0f215b62f256c5f7f0c51676743d1(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1be9bbfe183931af2d408c0b1bc9baf7eaf42e44d67f3694f49901b14f953a85(
    *,
    range: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e86fff568482aaa262339f111dd551a38ae4d1e7b70d839e4f06643cb1670c1(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c0d00ee9f04b734b443b76244b8119d1e50fb7e866acc3e16149f7fc2684209(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36b8b6f08fdb25056e9933f3676e2fb3531abf3dd392b388ab0c42d2c2117dee(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d2f1460463c494a752e81682025f4ce70cec155f764bdb70642c88451e51222(
    *,
    date_axis_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_axis_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d2e702dabb6aca8df1fc86ef1c4b0cbe9ad326d31328fd4b05513c94560ea4b(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e767bae7ed69b919bdd8d1b956f2c3fbab219bcb7bf4b8dd9df39ebbf60ba1ef(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tick_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86821bd5952bf93a791d8536701d852c79abbd67a509cfa32ae4859c636f48a4(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4691f428046cb1b921f216ed620f88e0e4fcb7c71a8c303936505cf2c1e8926(
    *,
    apply_to: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d6707b1563657b293d751dac569d0ed64ed8cc1b7cf5cc94e9a83222e8c385a(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__47271f1e300655bd947ec0739f62a9f56e56b49dc143118b832fa6a7766c3355(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68c90071acd0088b6b114ba5f9229973d80fe7d1ee87510afa7d204f0af2b591(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04b217598c11c2e62b2c89b9a9bd83b1ab693039b7db196aa4088373324f3c86(
    *,
    linear: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    logarithmic: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27986ae4a81a2c3b3442f97c2f5b86c0f7ce46117238c7fb51d27416796a6b6b(
    *,
    label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__612aee6195edaa64617c9fbab328c93e6fa327094e6553a6fcc711b093e9ee60(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b8c92d1acd9748578f0e84a2103d48fdd790bad5c05d6b8119f143600fb44cf(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b190d55cedffa33ec145a65b821e3cc49c5a692d13815dba1878c037a73f58f(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79416a0e477da6890fc36374497a3fc541a442ef62f4c078737f38587da5075f(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5be9c71bc4f0d654ac20a5bbe6da636d760d30d24f31ceeafa656d3740e8ebb3(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9882c44c00b98f84244934928b97576d14928fcaca4cd137de204e890787507a(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bac8aef8e91d470ad7d6600c725555358beca88d2564e0ca1989fc07d33a624(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f2e6a0e2f21010f1a21ee7a338dbf4b15b8400726bdd51f0bb565e3b3baaf02(
    *,
    content: typing.Union[typing.Union[CfnAnalysis.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b159076103ac83aeb9afe3cc5234805775e6f54de89783d4ec3965da2ecf5c0(
    *,
    layout: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80b3f66b1c8db3c0853180de2c02bdabde8dbe2f24f04345afd99d3c3212dfeb(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09401b735548bb1c8f51501cc986fbafe8b5d0eb633caa22df4fc0d9c40aea95(
    *,
    box_plot_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69f1d25071eeb04ee6a5a1ca10e199d929e70ad8d300799af42d83484921e650(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d64237c90b4cecc7a1048a1e1957642c56217ff8868c333de97cb002cb93bae(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23e21cbd1df61db249465260628453c24d3d228a4848a6cdc3b30c9cdf856875(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6151b8e00edf3a7641ba92b320d0ecff03622895ed48a30b9dc8dbd3b533ce24(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db8cce8fdf5d00ac0b647f1595cf9d506a6a284a6c8431fa47191d0a30961842(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bfd6f661b6cfd4e97f658c5d48104ad384981d9726808eea867cfe6fc0501bd(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__645312aff352ca0a79d8f2ad15df329bfae6cc0352650a11f03ba8df635d3ddb(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc6660ec97236be1685deac267e9a218f5772a5cf8a7847d5614f5961005c3a2(
    *,
    source_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1d749221df183a33fb273249f8fe0c27e23a416ee1a10fc83ed6e5ffb2488d2(
    *,
    column_to_match: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5afb72a523ea06746a9cb7709a1869f21e65ce596c0cc08e2b431a859697b40(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d70bc90ff9dff58dd8969cb388357560fbd33c712364709136e9a9e6d62a0d(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35a665e669156cdf92fba11790e51baa45536fbbbe89e15f2d09f78a13f45eba(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75a3857a59f643f7359071da924f9680251e0e60538633352c351a09c2d190c8(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filter_list_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65020b1fd7f14d714e833c65bd179182689890771c31f28f0005f36de27f12a0(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    configuration: typing.Union[typing.Union[CfnAnalysis.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2485ce955642cf1f6bca219011a24cf15c434b38b96fddba4c2ae4f3711b62d6(
    *,
    axis_label_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1da19d720a2dc7542b2198ba2d62bc53558adf9c8a6767731ad46c21aa280bf1(
    *,
    cluster_marker: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f904fbb8d2b31dcff7c4c69b07e2faad1dd0f2a233c57874638bbea6845043fb(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e5f5ec65ff51308b2e5915c41a999b23acd0e838cf4e4d6a35d6898dc34f634(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    null_value_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0279af7796959bffcf152faea87105bc5ac16303734f6389027c2794d86ac325(
    *,
    custom_colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.CustomColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8d8abf51c8bb04b77c369793bb76858a0fa26ac24580011732c1ab02bfe9113(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    colors_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__351024e921e575e48eedc8664b908d18ca08dba1b9203dabef14a74c269b7bc0(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22b5dc28b60853167659a080d0d5c8c337cb97a332ca139bb3bb120f3ee702dc(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d77c6c419ab078a54e80be4b91b5089b7101daf6dacec08cac01a93f3cc2a36(
    *,
    direction: builtins.str,
    sort_by: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e709600fba2f99734f3770c61c8184252bbb22a83375e6ad89a0c6dd2785bc7(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    aggregation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d42bdea20392b73c45d1ddcbeaf043aca91f44dda1cec880f7573ff741829b4d(
    *,
    bar_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    line_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4500b20ac9b1551eb7546d42f67e6c2e8ddad7335fb5a243b5bc4f2f6c19511(
    *,
    bar_data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    line_data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16a60f14e196fa5024649227b332a50670e171c097863cf05cab57dd488de322(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abccf99e6b0a53c6ea18786a4e53bb3bf2984d52159a625db5b6f11ecd7d63ea(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98590459d8df4f8ed5afce6680d35ca57653c9aac4b8568773fafa5612b0b8dc(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__682cef295d706e92941c15c8551c3e2c3daba0ef5e105c7228dacd26bdc90c62(
    *,
    comparison_format: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__682d99eefb4963bd6ef6176b99514a8474d96ac99665fe8dc30de337dfac4dc7(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62f64a292e536c9335c188006ca8c9f36e3903acd05eb907ebe34d9e021dc50e(
    *,
    forecast: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    growth_rate: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maximum_minimum: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    metric_comparison: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    period_over_period: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    period_to_date: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_movers: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_aggregation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    unique_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e76b611c8ca56927ac5c4865b3a3014d60ff601b9f47abc22d846009146a0aca(
    *,
    gradient: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    solid: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df3f45f65b6cf57a3561fc3bb719da73c90d809fb18ce43a8939b735120b3db(
    *,
    expression: builtins.str,
    icon_options: typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f806b1355a495734ae9e83eb07350a5f22234e77cad875cf5cd7b838fa66b969(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59843d34a1d9e56cc8102590c6f33b3fe4d4a93c9091d1c3b7b4f52b82785092(
    *,
    color: typing.Union[typing.Union[CfnAnalysis.GradientColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__239eb497ddfe4666e87b0ff9ca2c56ca71ae66ee4f0603e1d35accb913c4d572(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40bf78b1527d478f0602991f2696254ce0217b0bcc9686128bb4084a603c7ea2(
    *,
    custom_condition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    icon_set: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bebee13a63606a749964190fa5844b5bbb0ba9fbdd8f6d809f8697b86a61be10(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ce89ca867f206cf0eef0c8b1cacdae6c1ef99c284dcb85977047954a2ef6895(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d26580f9aed18e6f5b9d8ee6eebf4d3330d147fc18381aa5258ccfdce92e490(
    *,
    contributor_dimensions: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa7fe695ec288dba7d9b9fcc425613ee5401b04f66c0f9199927285202694500(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0423f6bf8e7ccb6d4c1dbdab70a3f38ec144057ea3b152bc220f3cfd8cbff603(
    *,
    selected_fields_configuration: typing.Union[typing.Union[CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target_visuals_configuration: typing.Union[typing.Union[CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6be7e44f397b511b49225a11fdaa284cfc00b5ed929ec79f8b763c141eba032a(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2a429e32dde5c07c1f8c455f0b3e620158faa6275ca16222d552bb07380a212(
    *,
    parameter_value_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1aa70755f38eee20ca627a2439faf92da4e11c82256f373e169a2f84b154021d(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8566f6a3bc8520cae7cb85a406b8beff98064a531dd65aa07565dbece414af1c(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62e8951e1d28fa8a78b6f80e13ba53e3bc46a89e076ea54f562d0d170366b63b(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccc5671c89a0456bbc22979a97553e30042ed13b4bfefc86cf5ec16ea8f3baff(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00768fad52642912baf50643607ba52dffaf992d8c8faf071bf0d252c5149010(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41118b5e69e4c03375c683ffe4f60144c69e89801e1231214b4515bd2215527f(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57f6d0fc7a75c60544b0338760d38f94cf72934df89053d710784833d2145774(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcf723c81d5d8d32f360f6ecdd30e47ea87f29e7de87e71b26b8df340ac3ea84(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2ba7731fb545cbded8dbc6e5b48904169ace796baccd5597789dfad6f354b2e(
    *,
    custom_values: typing.Union[typing.Union[CfnAnalysis.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecf40732730e24b9319a09a45bf4e3dc2176c140368f2f7783545ceb408e8b88(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90de61c177153edbd899b5825d8f7d732aa16df3542ef31ce3fd25c6dad481bd(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d441fb462d64eedbafd74716c3c06d6e4f29cf1cf44f330644af189d63c7d05f(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66e0fa2e530d1ace3b21559d4101409f15ddc2f4ff0510c1bacfaae3c8d3405a(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbc6ae98f605c19e60a88b2510ec872375ef1e56ec7644100c45528a8ac2090c(
    *,
    data_path_label_type: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_label_type: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maximum_label_type: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    minimum_label_type: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_ends_label_type: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b9d8953dccc6499b2135ceaf21c1049c06506e06d61c3e165a4860d0b5e3389(
    *,
    color: builtins.str,
    element: typing.Union[typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b09a64eceb6cb69ed5c6a955433b2d9263228e5d005de6f106862553f4a15c93(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e6b106036bc2b3ac9052f080a5219e5dd1b7412d782e555ef85e8dbde88a588(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__298e07536e948e00dbacd78d1692ac143808db0fb37aee934bec572e2f419115(
    *,
    field_id: builtins.str,
    field_value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d60a1340d7a156e8506a919181e6b3e00abdc9b650553a02eb31215d288c22f(
    *,
    data_set_arn: builtins.str,
    identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f058446b10406aee16fc1f5a5d863b779c510706b5ddbbe5bbe2b296e4614fe8(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d3c638cf4e6ad675c29276b1b7a0e7a7734850ad86761fdae0ed3d1e281ad6d(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c38a1ab2c4d2403b5f46d07fbfb4fdda6000c90556256d583f75b16b8e69c97(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7eef7426bd5a3bbba12b8015a14dc6dff0e9114ad85432497da7276516161a54(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc68cc4b44182fb270edb27691fedfe8353e7d33fc7d7164037829eff51fdffc(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rolling_date: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85473c86a1a255b90de6bc6e57417f31d7e506474c7c0a2494c682a0f43f5c28(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12bc810e2440ff358854e0e6b28638ab9f14a29b15e53e36d0cad66d0e725d2e(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__215bc3d836ba80156c1d09050fb61a4ac14687c483d1f9898b96930dd5f8c2ac(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90c38037b70752fc760d926efa18be9c7e893ed9da177445114b0ee46f29907a(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__650f02af439c5263accb9696ad579428ffb5e17b926240b4ef633f148cfa97ae(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9c1eb7bd72d4631979e43530390cd40366f425965677f236f931aa45cb6d404(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c322e0caf9e5a767d0bd137ae84120e34bfcc734a3d658620313ee14d746b2f(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d26b7eb6485113c1fdf15f502ddd91b466696e9c49265a01502e2dabe1f6d391(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__652eed12a68ef9b9b4990f823ad3a67229565474d9e1b173d0e80decad69836c(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2c0dc1ccafc3f97fdab40bb9e003a63a9ac774f79bd7789f5f0e4a2a8bdeb4a(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dad66fcbb0c7b497d09467d1b77270f6c4b6522edab3505c59c082a3fc9aca5(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95df51aca1084f074b94a4f4709af37a474cb4e9af1afaf77822a76ecc95a005(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd37d8eabc8bfec95ed4b58b81155df777ab165077b4efd54e6f1dfc04f9b3d5(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnAnalysis.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__556ea9505b528e261ec32965610d0e91b6f85015cb9c25d4ae15d47334adfb7e(
    *,
    free_form: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8911a947c977b10c2a2a68056f982f496dfd746874067609f8c6d444d1276eff(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b28bc8b0eb019bd9ccf611d0a57c4f1f632364d72ecda1bd852620509911c67d(
    *,
    section_based: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23be3dbd69b3e258c5e038afaf6d0f0c64f453022269967190b318b727557245(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__532d4f54bf744fe5b8d37880e79c350887cadae5b9ea9fa72542af3a68fb75ef(
    *,
    custom_values_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b610f908e79aaf15fa2663699448c61694ca017115bbe3a23312fc19ec0742c(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    date_dimension_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a054c60616e4456c14aadd17a0239fec854060b84e1ed909d318d0853718a10(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc51f4747a2cd1ef04ccfda67b6d10c6283180ac939f1c563ccaefdf5443e95c(
    *,
    arc_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    donut_center_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ecb6731fb1e8c725764d12b90f4a66d57279842a8d7d12f5f615007448625a2(
    *,
    category_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_range_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f51501f49b26832df8b172250adbd3de0016118dc154b557d7d710eecc93292f(
    *,
    select_all_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1754ded9164236abb5f4e07ed739f4a6e1fb4706dd2d278dbbaaf1d32c16270c(
    *,
    default_value_column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    group_name_column: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    user_name_column: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93bab7069456b6fc2704172867034473cfddbc2f5c84a6d617caca914dbf52f4(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e984d6b504bbbc522408ebf5a05a3ca55554f3a7466d8181ef9662471b5a2e10(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce759234b535c1eca0eea5fd23dbbfc67639d262b6c795f78d10bb537e90bbb3(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2480a5070d15fd21023f9d3b134d410bf3c98ad768d30d8fa19a4266dc6740b8(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b831e64c60237dcfc735e6a15fe88d2b2a014337863495585f80d09c33df4f9f(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8012ead27d550c0980c4ccbb1883e73749204435b06c49145606a132fe3830ae(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de1a8481c168e03c44d6ce8ffccf3b4b4a153ce2a8400ee7c8b9641eddbb042d(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__beb0832639b263b4c786585563c24c8227a0ea2ad8542b29ec38917ca8bccb1f(
    *,
    column_sort: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_sort: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FieldSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cad1ad95d7c8278bb57d2ae388569b2fc47fc4a0e4c9b70da73804123dc40f5(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d49b7f6119094b47d7c3f702dc3a09a681617dc75e3c8b7121f7fe130154b3fc(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ddc61cc5ed05bea21b9556c9a4edb59718aab29a9f70189a4ecc27726188199(
    *,
    geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__892c5cd415731015d172e9510780d0cfb2949109c4ae12679a06229db3d6f3d4(
    *,
    shape: typing.Union[typing.Union[CfnAnalysis.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b23f41a632049ca35c080b29bc38536e01cd184ebc8e373acd3943695d5dccd(
    *,
    conditional_formatting_options: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1632e9f6701ac65e9bab30f541852434d3af064352024f1ec60c7e3d2281e98(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_style_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    window_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bf27367e7b552317f2584b4a66ab9a7640ea058c7820d8c52bbde9aef1b1fb8(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c63bac9d23e36f661fd998066e4a8d228db192a93b6d0d824e6c105271d62af2(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2bccda02cff591eaec2d68cc09c6f38991b0a584cff334e067227a58d72806d2(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce04807350b7e095877a3bb608d4661f077f6b2e6070f06c3361b9759eca187b(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2fe2227bad93bd042d834f88099cd07e5ac4c742a3dffd833afaf7601cf09c8(
    *,
    date_time_picker: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    dropdown: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    list: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_date_time: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    slider: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_area: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af1310e52f1fe058fe6864e5c686c953d0bfe5bd870c9c6450843edcb6be192a(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__894a7482d4620719c3e5c37e5b3354bf6ba7e6b13407f045ce033b3829c6db50(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0cad743a793c8938913f7296b9b44e64305ce8e4ebacc534f49fe92867dfbcb(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    scope_configuration: typing.Union[typing.Union[CfnAnalysis.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd242678159eae1db6298e77984712eff2126d709601f844e5b5a82940fc3278(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f05e5432f01b720471b698ee317bef523bc0fd233680ea3a02ba6ee02d2260d6(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da8225524d681f79d86c40f7f34f6536eb74cb837e28f4a1f6de4a10f7ed14c6(
    *,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd3ddb0f83f2fcb19b265f1f209a8143d47cf88909ee824f3c5d16d76cc49d80(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4adc43c90ecbe9167d209e3a5dda471c694ba167e1b994985c17fb610dfb4510(
    *,
    category_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_range_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_dates_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_equality_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_range_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_filter: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1419b1e1dc95b6b8bd0d44a95ab71dbb2cd55ab54918f9a06878935f588fd7f2(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e52317128bb33fb4d030bfb601ad11d86e19228e9824be1fb4d6821a56805a9b(
    *,
    selected_sheets: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__588b56f04c6a4481108ee74544d1c0cc9d60ae5d83889e49891b7497b18f8c16(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__640851d91ec07732a2a822be542adcb96fc6251b53208fb577aadafe482230b3(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35ba14eb21d1758a62c8b39419901e47a41169a72a0a6ca951a568628845f91f(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f9848fb8f7cfed636317939402fb560b21fd710769007a6339352eee5689282(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff292b59f91cdecd5d8b04ace2132873679de34d29f798dc62a5783102e4ca4c(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontSizeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontWeightProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__411edb61c9362aeaee9a4091af90cc20542d3b666284c34838a03cec6c4bb42d(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c1b2a9aa6bb3d687bcd0169fb03f34ca0fdfcf645101e0974a8d97f69a95ad3(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f565280044f0435704d45e9ad5a88e94868f5206d156de896e57dfcf07a0d542(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa60baf7b756220760f00d8fac6a78fc80cabe9fde935f87f3c867df31f9fd24(
    *,
    forecast_properties: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scenario: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d65ce0dec6eab3e3eabd565a21e513ec56e250c822180474bc6278096b0665af(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7f892a89f8b7f4bab1995d12b95f22a697d6b152000702a161fb8dae024df42(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    string_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8256a6c9379474c289275e0900e25b2639cce3839a683606966ada2bbd9feaf7(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d8c9190438b56832176295290920e07dba3b5cf17f71eb698ada5bf9f625155(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c201e761738bfa24ea2246e4322018d2033440178bfef4262f512148a2696de6(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__877d3ec0c7b38dd958df159597169252cfcf484c5580aeab44c705d2e6597b29(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fd740a8b63e82a6063cc7b5d61e01d714922deb79cc177bdb68e3550294c91e(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    border_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    loading_animation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rendering_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    selected_border_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9b2fcd65cc44705d5f024a8732b2fba67ff1a87216d9438f1ce599bbde2144c(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3420223f38c7519fd61e1e6887bd491271e2536dbf7285207d6134cc3fd93f1(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2933bdc1dea07007617576d8a4f5cf6a6f373b190358b785757716429e221b50(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3945152b6a7a4ca1827ea7fe83f4c8e8032f486da046f3897a84b0e666258888(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14fe6d244a0b386f413e8942ca91aa67dfbc803bb47692efa5b7434d963ce34b(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8a414747eb2f1fbd3c5b194cbe49662c2177d6ab79da32cd9885ae81020cedb(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6dc8cdb1531ae382e2f7bbfb83f495b137a29a2984dbed08fc6a592d8058f3b(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d816303d366cfe2ff8314a6e844322076e8645c3e525d3de55602180fab1215(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c3fa62a14e6e214db7be498151486eeda9b906f7c6e64939fc4a2a3d0f13c22(
    *,
    foreground_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e86ea78440a51da451a5763e4417ae8eecb9164d3ddde2b3555c5de835e9251a(
    *,
    arc: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d275515ebd3a341f8748b13cb49b24877bbf483c1d2346700a09ea427c0d2f34(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d80c970544a22d7bf778955ad32cf57017f72bb7a468a9e24de7e34f7b301adb(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    gauge_chart_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f758fbc36e0cb888a922b977ed89082c0122722999188b0440a912f4496db99c(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f46b192dbfe22619341a75f9e4746458d8a28d84aa81a94e39f20e4cbb283527(
    *,
    arc: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    arc_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    comparison: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7fa5c30d8fd436ee37ea535aa08069bfeec82d3a1ed05dc5e7b7a8feeff71164(
    *,
    icon: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d98982b6ebe2494ea2c36af3f6ae0b796496069c456d197787af1a3ec9ddaa45(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02333dc189af20f712cd5bbf2b3255523578efceda7a3cdd05c8ba2812e6c076(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76dba5af45784ec2dd551fc875a34c13059ff95c36bb0d37962f48485e23761c(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3b362d91fa9343feee3a01a06f46caf5d15bd851901933c4231d26cd9956288(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_style_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    point_style_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    window_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecce52236a28a16d71cbf639780d05e3d382234b062997aa802ca2e63f852684(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e430915449a89989ea2c21470dd0ae53fc61708a07e47c3932a2b7cca30ae62(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cbc319112c0c441e1ef1a3cca707bcf5d01743f300a1497825a00438293bcbd(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ec5903443c5ff711d384260e886d4f650c86f361f5ba87ff242fcd484be2fe4(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04fcffa2217c2f3743e4dc6f7aecf3b11eb2cc588b0e50af8e615e24884a360c(
    *,
    bounds: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8155fd68f28f9430f87d73a687b0afe29327e6e7467d3fe7b6fc97430090f3a0(
    *,
    side_specific_border: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    uniform_border: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00a735f8edd0fb593aad9b3315f3321ae115ec4c45630e92208e5ccdc9d3583b(
    *,
    stops: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.GradientStopProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6fccd8dcb764e31e23d89ca6cb7131d866e2f1490512d4b179a315a75f241b4(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af7a6713a39bf8fc0cdff25aaa609f84189527234a7e191a8f1f6d29939fe733(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9ab8ea8bc5a1d472d11e9a461b8f033b789db6f839a00252cbacace4f0464d1(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ad24404aa2878c80858f4f1de3c30e67a2d9adbf7cf7792a485de35d87c5008(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91ce74986bc59019fd3ac6a1f475bdddeb6894ff7bfa5458b4883a2393a17d79(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9423e946bbd45a2a6283b00d7771dc7bb8844aae578c9f4c3e976a14de2b3b93(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e3cea29b7336b509b93191dfac0fd832d2c191d1b6cd0541d34156792d43ec6(
    *,
    layout: typing.Union[typing.Union[CfnAnalysis.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__215a381413cbf86cbf3543c40c76148cde251896d980d58c42b82f2b3c197c99(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f579c2d814c01729dec18d52a8696e1e23cc2dbdd84a4625b947cd12aab3645(
    *,
    color_scale: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45d9cd75868764cfdb40dd52dc0962b783ec39bdf1988e8c8db23b60958ce7d6(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b126166e544643a33201e1a043799ab91762b3636d845100839cdc378f760c3(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b168fca3b7ab01dc4c3e1b2bccf10ed988c1b719627c201665866a890760e518(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3daa060ee9cc8312c472ca370953aae68813c235fdf3bb9413124d5c7cb4007(
    *,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5019cb990a3a1f70353f91139b3ac1257d8e404a35edd4db4da8ff1e4c5a8dc2(
    *,
    bin_count: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    bin_width: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a54b563b48da23bdc9d671134bda86143896565c2f4fecf3c4e53201f07a42cd(
    *,
    bin_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5561572424a2f728f3c8526ab3ad13cdc48d835d784327351ac32170cc6e7854(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ef5c52194094d79ff91e4847f5b3803faefda163605f0bae98ddf060e165d9e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e99716ac0d8901aed28d2f14a53c2c228771bcda558fa896d5e56a331ead1e85(
    *,
    computations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    custom_narrative: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__87be197f1b8ddc00ddee843af95c500f3691c83c18279f319c73b3f4e9af3612(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    insight_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be8cd521f7fadad88e20e1059f4d2a41535fefd8da90f16cb536955184c993f4(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bf525c201063a19747a5e1797e139c1a14f211de809356872e7f2c68f00dea1(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e5658f80863f15a78ea397efb6e375a57b8582cf08b46140c79153452ce1c07(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27ff0fb7edc54d24385911265e11bc5f5495724278fba79cc95dab00cd2a341e(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e51a0f5aa6922d5fe928fedf21e9f73bc04f48ad3b9d07186c64aaf2a734c636(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__417dbc6cf68856a089b9865d7db129b5a3b990db90ed98a98c26350b1f26f957(
    *,
    primary_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    progress_bar: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__639d31d517c2ccefe2aaa4b42519e66c63401e77855ebffafc034779bc395aff(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd72ecad4ca14cd031e822265c96c00b6aac2a2c24d33fbe8e68d5e3e667c7c1(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    kpi_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__438e6598a83da91d5b1647fdf99d9f89e3dd1ec74ea5210525cc9e0463820257(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    trend_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0086e5ad4f12b3d38df98a4d4b35000f0a83ba1c151592e5b875324cf1e0846d(
    *,
    comparison: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    progress_bar: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    trend_arrows: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28b4b072f48698e88384ebb6a4b482131a4cae2e6bb8f59342ff52d24836ba05(
    *,
    icon: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6aeb9f101d9fda4aef98f8deb1c966b8a920c6738c0b6556e1a66c130151ab5(
    *,
    foreground_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e95a2be833aac9177a3dc61cdf2f6b73af942e358d3ccef7b7e057687ab4c74b(
    *,
    trend_group_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__049ac2f0f73aace01ae9537bdff4c09cfa4fa497012fe41cb394fcceae32eeba(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69bc668401cbdac94031184eed05ef1d6615cf2cf0e4a6cd218a20ac5c1a2ad2(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d910114ac6b35b763696775fb943168f337e2dcba3a670dadca6ed67acb5fc7(
    *,
    free_form_layout: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid_layout: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    section_based_layout: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__161fd02786fb24ad982328bde216dd1aed4821f4931682a9b978ac86df412bf9(
    *,
    configuration: typing.Union[typing.Union[CfnAnalysis.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__147c5a9c400ba3c744a07cf5fc319a9236bbb47fbe2d26c58d61c60a497844ca(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5c55a7d483e6c06130495e9fc8b2c5cde7054f59b6af57a656912eb8f188bb1b(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52cdfe8ce1226c104752c7cda292d3d38a62a435b229c207e089664c0af5750e(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    default_series_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    forecast_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    series: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__532f101ba59b6ae500421a96edd2253fa287fb029083b4a563c2ff810889d5bd(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    marker_style_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3824f70a439f1d6054f49ec93e76ecd231c4bd5d4fc2e755543015abdb82ec0(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f73139b3e75d78825269f0ce460d33b3518101781a6f4d76c15473dc10561e91(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__425352a4700680287a24d341a398f5a75b982c8fcab574d455bae844333e50e7(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__996bf8cdb08f1f86264f9fc9c1bcdb8854c9200086785feacf03d84659ca72b0(
    *,
    line_style_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    marker_style_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__190cba373e078cab131ac042a82935bf348b4d6c795058ad20b988ec29838a42(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1170f6d9a3bf20455146f69c585396abe87561411c24c18b731a77048840ad4(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2302f0b46bff1f5c9e446d0d4ac051b141993001095b996bdb1b423592b56aa(
    *,
    axis_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f10289047022a7f828518d52af4ced380e632f244c6b363fcdcf6001ddaba74c(
    *,
    search_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b67dfb7d1f03aaaff7f88639feb1894972a0d76266bb603e9c67a9c8ad3ac5b8(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a1c0626c3cb2d7a4257e96fe1718006a4b42e6c612f0db6f5a62e76a428df1c(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd830ca7ead0f4493c80ab9a601c222384021ef1fa35dfa5f897519e853b2838(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da87290757fa719668a3dffb9c28299808825fbe461b4e19db3f7d467ae016ec(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69bd96f2d4a96b2084086d87b49b9f1cde967370756b047fdbd292bc7f730276(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e35916c7a4e35ca4db751bbff9ccf32d0964841ff6ae843441ae11c32a4ceaba(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16653aa16e239e0c7c9ac20fe3ec68e87d59863bbbfa03e318ec051358f63d5f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__54884ebef2e6b170d447ec5cc31ca484fc66be31f854d92c6be0421382c4181d(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e83ef96400cffcba5b395f1bb9748cfd07bec1227dc1a3d3fb7cde42edb10b6c(
    *,
    calculated_measure_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    categorical_measure_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    date_measure_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numerical_measure_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbe1df5c0b5c82f535456b96aef811b16c21d69a214d3f219b5c4d7220be3006(
    *,
    computation_id: builtins.str,
    from_value: typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target_value: typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34d1c26c06a1371c70b32906d0c70ecb615aa68027628d49e107feea60549df1(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a743eb1150f9cba0a92cd3c03d082c9789239bc203e6408df1c40c70d1f742f(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__364c822c55d87fda32eddb927358c05290a3e37899b5292121f94fa89712ceaa(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7d44813a127a7e6d24ced9e8e8a843eee3845908d7ca6fafcf20e7b30171a63(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ba87f731fc70065fe71c83dd0e51448a2340f44cc0d0f2cce91019779053b9c(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e85bee9b9a9c6778f2a8625b12da9959db137c08188b191948ed8d27bec3f6e(
    *,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73ecad0da270316ab79b7505243f7ee26f198fdc7936908258452bf6cbb91fc0(
    *,
    range: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scale: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b7899b4fc311359c5bc341d680e0156997a0e2249cb08251561e5b75e11602b(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__193cdd7fba9a7cef83319ba94f6196936a20b1c5e325a2dbcb14ccd09a0d3676(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac78401a9ec97451087c4578c7106b555dfe71bd7fcc847de1da54adcc42c9e7(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__952507b15807956513dc092a796bb026503ec28fe31e4ef9cc0eea64eecad459(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    range_maximum: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_minimum: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2783b823c83cc0a81211a8d12015ff4946619b069518a15034c17bde78d94244(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__632e0dde8ea6790c62878c84f1117e8c0387b58d886cd303f240287226a814a4(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b35daecccd1437373a11df8c4f1c38c38c97ab3e9839b303b2ed45e3f831f8dd(
    *,
    percentile_aggregation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__352e5d243884b93609022264f578c2b39b4d7977690bb52c9f10a0def16b133a(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc2064cdd5bb3b1a1f9e5113c61efbd77714f104078bdd92e4dc17756a4f3668(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afa5b7e930b8eba6edf1680d6cb7f238cbfa2a0cdcf0d4b192491b5902ac1bef(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd84aaf59f81c5bfa25ab92df6498f23e62e9044f83c6fea5094e158c96cc46e(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6f7bde8af8efd8c89de68569cb6197c006a823bcaf0717519c7a5076cb051e3(
    *,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7dfed7e92137787a1ece7e0ec4cdb30be0e01446501cc7291862b2eaa90f47ca(
    *,
    date_time_picker: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    dropdown: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    list: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    slider: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_area: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c1a61a415a63db6ff976e3da9eb5961660a4e6b4b0b7c06dcbac5948d8fe067(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fe1b456c49135ec684218a76c87c87ce32e51db10319ace5b90544d4e05aa3a(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__532b3ad5ff674f8e8bdbb90eff53fa26907e020acde5dce444b32aefebb88907(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca2a22d5725cc20c31c2ad89ae9177e76fb89e6e73f6c9345facdef45666f695(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c10a2ae83981b7ca1a0e814c85f6000c36b36fbd14f49435d21f4305ef0b903(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6e0697bccbec7ec50e5370ed3eaf459b57a4a4a453d149ccdffe83ba93ddbd5(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0fda00d2eb32c8c3fe4848eeb136d6676dcd03da02def16e371dce62d533bd6(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9e1763bab130ffccfc174a927be70f2e66f3993efe2ce822255d6e048169bb6(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56ebac68d7cd0e8036f4d0cf9c38b190cc2af4c3a1a87e6dcb1b327baa5f4d7c(
    *,
    date_time_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DateTimeParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    decimal_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DecimalParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    integer_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.IntegerParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    string_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.StringParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cba9c68e60004055ab8416ffe8c535e2d5ef9d0e92b03c2e4b3cd96c873120f(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccc0fcae130d2f938c090b03ebf67529d5a22107fbb4b1f60d615da3be9f1f55(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9eb88081dccf9506c2ae987ebe5cdd92d8438f0712ffa0d2bada5abab4a1c6ce(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50b08f6cef9d625a0a4eb097a1daa6f6b0fb8bcac7daf5be676a1e6783da2b81(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afba38e5252a8b699247da21cd33d38070d510e660b723ac6e6ae143ddf6e098(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e4c58cbd0c609435ec3b756fd52769c90ed28345648f41ed74755a099bd099e(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__219e9d716153a7802293c53c16c03f4547ff41e892906f7fce84798cda96c063(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    donut_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0c538053967fd93d94a9626b140bdc0716614a01d10c900322f2cb19f3cab9d(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c20836e677e6bb054210a41451e5a3fdd644e5fa6fa27c9ff80bb716b01c023d(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc054670c55f2c22cf66e74c17d09225bf1b769db66f98ade0760541ab55cca7(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3c895d7781478a8a40540913cd7c5a446c1f604f55fb0eb997bdd176a24a2f7(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[typing.Union[CfnAnalysis.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86e9ce0c938f72344bbb7a8f4b5dca8b5e9ab0461533fdb29d878fedd3d86272(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c128688b80c54f9a62e73b255029d85b26f9c17b7ffb1a76bd4abbdedb632e1f(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_format: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b834876c9934a0c861b6105ef2ca0fc86d63eccfb245987a04347614704656f3(
    *,
    cell: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df727ea8b81f33b8718158593865e60472593b52da1d108a8670a2ae83071a04(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99f8e464c7a1a83265b0554ebc053b3f8855d0d864acbf5569a48fa23534bc6f(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5d01745eb35692c6eed2d28885b60b3a1fcb8640ecec50f02021f470403c39b(
    *,
    field_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_report_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3c6f8c74fc4fb2358e91e0e64a404139f38e4e4d627ac2b7cd987ccc1f89581(
    *,
    data_path_list: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0f536fe09ef699a9be2b2db62c17da033b565f608f5d810db87a4e444d9dbda(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dbf232ee14d267be6dc7b906c544685a1e04f3bd7983c99ee3aa51e4000c5aa(
    *,
    data_path_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__165ac908689e0067085aba2425489c14564bb770f0fc7727eeaf0f908becd25d(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__866fca67731086e83489bf24678d9b184e71493efaf2f6393d2e3ca4a78e8554(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fab3e43a29d518629fb1e161e91f2b250a2401844822d1dd16868d8eddbc3cc(
    *,
    cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_header_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_field_names_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_header_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4ee0fe1710f284707423c79bdae4867698da34304564beeeab822a92e81f911(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__497446937ab59022572ad0e0b7c3978b30b79c37f89cac9c1a02c95440e82265(
    *,
    column: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_path: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FieldSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7642afcb3aba8d176e79420145ebcd9c0e683035dca5d990b3c36fb1f109422d(
    *,
    field_sort_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2d5d390f6e62d3ad9661f28f4b15527cc795cdd2f422b48e4edf831f9485ba8(
    *,
    column_subtotal_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_total_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_subtotal_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_total_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb0a7a7ab8f5ae247cf0de31f213288dc0a3123ae83b455a5657577cf8c64771(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf01a7d8c012b1bd3780c58beb57469765ffc03f4dd02a9e2a840343380b1f47(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b93c78dd2c080fa1445c5be44254e98d787bbc09da580bc1a61cbc77f9e4696b(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23291cba3a82cdcf381ddd80b04bd309e2dea2c1b9da0f52aca1baee41acfb44(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e81223821459860adad268dcdaaa93bca49816d94cc9a130994f8984199cd1f(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__613682b582ee5ec2b853ec66b98d24ccda843526b886bde043165944ef844363(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fee252f1be91d868b6e1ee6cf8f11245b8625f40afe4c616746cc159c55b48e(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_axis: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17e44a0ac8c70d8308e28bdd7c9fc5dd388c33c6cc0283b8d2ce40ec1f83b300(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f3b4d982004d14d06b3b7d4cde2c23c76830f0f6cec3684c792750a2fb2adaf(
    *,
    area_style_settings: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9288bc257596ce3da15434f695f590e4e6878fb9a20031bd447ccbfddd0de9a2(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__239c38d68955efbd10f72b79fdfb21aa562d87ad7ecb0a684f87914ec7baffb5(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6b625b07a9d04e03513e4f702bf251d2b0195f68b81b1d6230f84022e510cdc4(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ace008ca4f454a1ebcf34d52f19d88866c1d1ff168dfa04df362476a3c6ee0f(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5488889e805168f64fe1fbaeefed2d2d6be4c256a62f6e640d40010d8ca0a9d0(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__437413ee6a3ea5ba0dede6fba33e08b02930c647b5072cf08b1aff23c159ea73(
    *,
    calculation: typing.Union[typing.Union[CfnAnalysis.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    measure_aggregation_function: typing.Union[typing.Union[CfnAnalysis.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d716700f7216b94eb6fef27203ecb4efbb6a1db0fe87ca8d0e87bee6869fa26d(
    *,
    custom_label_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__274a1bf16c18c921b81b95e77acbb45afbe1cd93ce5560721a62b287ac90c9a8(
    *,
    data_configuration: typing.Union[typing.Union[CfnAnalysis.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    label_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33f0917fd7d4ec916f826043eb91bfbeab575247ea4991bd306c87fa771fb003(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__629ebe691af875b072acbdb07ff54759a24aaebb7d752b9af502bc3c002068b5(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25f385f53197390a715c2e542993550e4ee18effe61827f5a612c5d081860b9d(
    *,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9575afcc1c75b947752590e754af898d8f90399c981a4911537b7eb4fd874db4(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21e75b815de00654daecbabd669a86b1b43eb2c711cf04a45a76c9c7378ef8cc(
    *,
    anchor_date_configuration: typing.Union[typing.Union[CfnAnalysis.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6897ba3012b1fd8b2d83e273fd6da84b371f95de34d0e852c4ea8fd24a96e21b(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0886436ce2d1906d81da56dea91198353e26f65965f9b7f869a040dbeff3585(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5b3fed424058253841db2086923c23815d62c4ada6254cfaad30e1f0e059b48(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__50bc6d74645a12142bb9eb097c1ede5ab0a710a8bdadf3d7ef2fcbb163c7354c(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f558ae96887355362bff4b411c669526df2e8fef593b3506b16aa5aeadb0cb6(
    *,
    destination: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    weight: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__208aee0c9685573a83b0456b188de02e981fbc0abf683295e4314250121dffc3(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7727d5ddd7be0e2aa40e66bd0c9b44d2bf853c34fe93ebf06d17b2d8df5db60f(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ebe0ea3ea55270302f8ce415fc45d4f3b3dc07c802f9aa50e35caea48a8eaf3(
    *,
    destination_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    weight_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2df527e0d29a27455c9cc9ba1d1dab814dae012e024db5631cf728b816a466a(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e7a43361693799fdde90c59fbb3ee9c785d28b441d9c03aa34b8e830a591328(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8aaf6a2959f0296e4bccec059f5909770f7ac447992828d7f36e003d5c5d7d2e(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2002f09c27b11c3de76b46732021204b5372dba4a6d3210d4d434c025d19f990(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ab8d48162530a7fd9e608b82bf571cb620a4ddce14c26ceb28d2f872b1145eef(
    *,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c17e7cbaf237a61875e6f3c8dda6803d6fb3e4e7ced7a297b1b8b2d13fe57a43(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94d5311f418b22de54b0eb18bcb66cebb2667fd60b3cb17127d3573f5122ed62(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3070510bdd41c9d6776beb4ac47d7d9af2e727361f036f935ae12f8312ad0ced(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f5e1a8c73583eeaaf95af7c15ae410b0855c64e3a50b3d389abf6f6d31d251f(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18affa96795b2cd847f5977ea054d4d222173dd13085d855138cf15e66402c80(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a544e966caf4b8ffb472ff244840de3e86628dbcdd1ee266f4f8ca828f9f4db(
    *,
    body_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Union[typing.Union[CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    footer_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    header_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3a59846c9ad2cb43b837ddf0addf7cd1547ab93cdf35b690fa7c7bd969f9871(
    *,
    paper_margin: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SpacingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0f399d3e7683998f2ea0418053524d6cce3d06ebd2179acfecf8058476dd412(
    *,
    free_form_layout: typing.Union[typing.Union[CfnAnalysis.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b57148f369645b54e8525641e9aa97fd949e4366e7c718cd6138b2722981f700(
    *,
    after: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc2f1233dc87e151cc24908940d97aef0e30def0490c3a49fbefaa9a5e572183(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SpacingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3117840ba0958c5c1758d533ebfcdbc6719fdf58818ced7ce210e62e13f859c5(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a88cb81b68976094f39d27ef75882dc6ba29cbbaecbf1c7f389c3ba206e96595(
    *,
    data_field_series_item: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_series_item: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a04c41f5bb6dcaca0538e8d8bcd49d38d5756cc8069514f67be80ce6f7885ada(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[typing.Union[CfnAnalysis.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f33f126166bad9cd596ef5482693a2ee91f15b567cf9f0c0f1643c695f854b59(
    *,
    background_color: typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d61a0584dbd3aaac4a3049fde1d227ab86b40cb15ad684d6372966de0d3e8a3a(
    *,
    grid_layout: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2882a2bdb9e1ff422a89f32132a7bf43ccc9d10918361938c1902f29bd73245d(
    *,
    configuration: typing.Union[typing.Union[CfnAnalysis.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c938711f4b1a7ecbcd3ab129fa90aa5f7d1e72c74d756b8da5b59aab5d2331b2(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FilterControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.LayoutProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    text_boxes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f88b26dd8bede76a00044fe70ec4b4b4b0e3a941eb8365140ebe2891046242f7(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__776469b8ca93494164bbfe31c4b905a79719ecb6acddf7d35bb0951256abde2a(
    *,
    configuration_overrides: typing.Union[typing.Union[CfnAnalysis.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d0e6bd491de28ac37746a6ee8aee65fee5e1447bf3d354db401dcc7b5e1c2c(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae89e881a9d98552f36327e627cb97237db168efb57ca3acd42ca7be5cf63137(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2e67fea2caad222df15bf152adc485d70ddcb54dc7dab458423539b34b3b5a3e(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__05abaa7584f60d2a5535faf62da8319ff1f296c8fe3cdedd1f3bc4db82edbaa9(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__21bba48f9b74e416c8596a8890169cf2b5d7721072d9d3bd592352b3c2f80059(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__29fcf100cb934fb3a833f67140ba57d03a873282a2111679e9b6b7ea281b4004(
    *,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ffcc1353f8affc1bbf60db1171f0033d801c0a0ce4c5e58a8e6c7b0f35e470a(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76b927838a9ba986419c6c750d0e51c475c5aa65441dca1f7885612a63c7aec9(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f5f340694f1eb76364e7de966d37683de9b4614f45bb7e0f90b75ec038a8ef(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f785535dc9be68f484596402e37946dd3c7d1e5f22d3918f6dd8a010e4389c86(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d26cf1640385cfba0488d55dfe24bbb7d698e6b2bad6e3708f5d71c974a35665(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnAnalysis.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnAnalysis.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19f65aae86dae49e938d248e6b07771ea752541529f7ca57e7c16c9c1b0d2252(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__107b895aedb4ecaa8b75bc69ce9949190b0e1aa935facadeb37f573d89ceee7e(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__338ee318c9fb13ddd20547af794a565272672327db516d9b90c62dc2db1ed347(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f734855f249d26e634d74a03cc13e1c4f298d8ecf2aad9d6784053c71d0af4ed(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e66e0c38a5aba6363cc88a55866813c70f90770b949329975539d14239100eaf(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8bc87e2466575ed3745b58bd8c4e858bc91fcf15a022accc9aeb92cbbd146dd2(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0e3c765906d193385c188f50a9cb1eca4b270bae9e1ac4f8d91d3be35ccf9f7(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b3757384d39ed8826423df69c7221eb7655efe4d89772ef1f163c9a937e8195(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b2fba82af742d00ecd079121eb54810d9e1a026bf9c7d3912ad6319c6243706(
    *,
    cell: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6aabe436667164f9894460569ccd0f43739212ebc339d4bee5fb71938531b58d(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b24619e8da18e43e613b5a1283c32b54c7cc7f75fae764928220566bde74310(
    *,
    field_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_report_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    table_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6c7e79826f7211413ba2d02ddb4e164438f612b2ef17fdcb7d2f5c50d10f2aa(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e90bb67b5e3ef2a957699ae94eb90056fca87ca02fe7d0bb2ed0091d1835f301(
    *,
    font_configuration: typing.Union[typing.Union[CfnAnalysis.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e0373553ea502c66bda7dc4ef05a6377333ffca4faf6c44efe05ae72d25c436(
    *,
    sizing_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cf8e7b80eb6fe6e27ee26401e4e5d4bd51ec99a6ec637b4b058dd35ff466110(
    *,
    content: typing.Union[typing.Union[CfnAnalysis.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__457a45f82c594eed34f71cd0e30760a7722e2b104ee494288ccae739c59e8091(
    *,
    custom_icon_content: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_text_content: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13090dc6d2bfa86d8713dfdfd4b995356d87113fe44a0ca264696c887f6cc0bb(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__821c0cec1facd5049897b1301aa0443074ef99aed58a818a706f6b5a8d1ad205(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a186bacbec76d84ff2f56a0c350721a0b4daae06a348bffe349acd62ede6c6ee(
    *,
    image_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    link_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e38efb8a30e02e7ad3fe1fe0c3701ca4c2d5504eb32e10019f7b81623bc6b267(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62c5d046bcd293681b865db46fc2d73ad944afebe5fb87d6b5cf5340129d1eff(
    *,
    data_bars: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce6aa4ab792489a3cdab9047788a943d52dd2f54b9fba078a7a797193754cc21(
    *,
    cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    header_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74c449074a522c02c06062cd89d5276ca2e7bff65e3f2c380fd19412bcc408a(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c81e088cdfa4caa973e79cee4499ca1ee8ebc47b51d3b53d2083b6084b7dcdb0(
    *,
    background_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86d2a2be9b4ae6e64dee62f5dfa82aa2b6f4215027bf139cf153e4a3dae85574(
    *,
    bottom: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    inner_horizontal: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    inner_vertical: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    left: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    right: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2926875694cfa970f79b095c8f2e8eea85c1c0b48114d68b3bd202ed52f0fd72(
    *,
    pagination_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a217d901fcb5e3e5c553c55bd2c7342537d80324a2784475637e59b7580ffa10(
    *,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ca6f5164b5f0871a8050093137a20978c938ff65d9e350995679baaaa6174ca(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e75a97f6ce9564ef15860e3fc60a7a277638b0fe57fad98ae085f81bf2cdc8b9(
    *,
    placeholder_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65f1208b58152dc9f5d5774adb04a8dffb8cfd9a8d3d12516d3bbb45318ac318(
    *,
    background_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    icon: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc1c35467b00ada0611d774551a4a3f50f55fe2fe8316bccbd2ccdaea5cefd3c(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9074e2f647df15f22a97cb177cb95f394d82b84dde9b6a863f4170715048ba39(
    *,
    placeholder_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e072e282014fda925c195d701db9d1d66e6fc4f7a8e592ef7523fa0de3267458(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ff58cf9c9036a37099e184deac523183e4baebc1581a0c2db372604c45c4f46(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61968e68213059f8344a79ebf7804d236291a32ee491834b70c9b74615e27c13(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b2356da4f991bfefdfbdc8d478acef795e4cb5c7f2c5eafdfa9f7f5bcbe9ef0(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a23cfd561aee781b2ed78435b340afa511642db6498cac8ffd26ef9629a3c5ea(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    range_maximum_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_minimum_value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24211c9c3d9786fc4071a486b5514e83b6ea5bff916c8b192201c2c5996a87e0(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d0a621a3b4653d8fcc166f294edb897d7f289ce0eb7373b2d4aa8b71a2fb9a7c(
    *,
    column_tooltip_item: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_tooltip_item: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__399683125ff09870e7531b585cf93e480ef91abee0318095e6d0d52c966b51df(
    *,
    field_based_tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63690b00a9dd0d167013f694baef776de83b34cf58d54c8b31ff12d0cf6192a2(
    *,
    aggregation_sort_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02bcc5a57bb72f7f33f46f02efce9b62e8e401cb5231400add400ecf639d48ec(
    *,
    category: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    type: builtins.str,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65d3249a90e066a14a046d15d937e11856695f615268c90f1210277fcb987a7e(
    *,
    category: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a917d26488177956053494c5696a161d0fa419bc4d4ce486b54e3ab0bb17b1d(
    *,
    computation_id: builtins.str,
    value: typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2780192ddc65888b0f5824bdc533b55d3c512dcbe86b0421f76b7ada4912c23d(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd1f777f858822f88ad835727962ca85d81400cdb26135346db6d5a07f188dc(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sizes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27238c47817beaed571aefade8d051f4505788530c4dda97ddffcacc273b675e(
    *,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_scale: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    group_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    size_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08a5bfe2ff1a99de5efcdcb240057efac677f483f2b95c2f47a548d74b635871(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e9300467063bcb7de264bfa0d0d40c038722b50a6ea8a94d41317be28e4fb45(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tree_map_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c6132041dee279f6a22af8d31dcd138da06d50c2d76ed754e91fd925b34f5c8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43aa43188ebb4a9aa6944fe6a5713779910284d75dd38d6485af31a1ab53213f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6391f4830118bb541e0db8923d50f0d6cbdaa6f8583af4c20a3a220bceb56ad(
    *,
    column: typing.Union[typing.Union[CfnAnalysis.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bb762812fc5e23f3f0d1a0b91eb54b28721289e6738482ed3f7badc5cc07a1a(
    *,
    category: typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d1490552a5edd0682ea5b270b662493a9257e14e5882eb15010b986be15eebd(
    *,
    percent_range: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70aec55c7b812db55a0d43b7fbcdec8738ee109e86eb5642de46c7cbbc5c87b6(
    *,
    filter_operation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    navigation_operation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    set_parameters_operation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    url_operation: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__148280f0f28dee637dd7053bdefead99b00168e1839619c7bb571c5146bfcb40(
    *,
    action_operations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1423958e6a9d35ff96d3892a67fb230ba945a317e0ba5f287b48e50d0953921c(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee3896991a5a3394b7bb38ff5a1d4180def07a73decaac035f10f14d4f048f5d(
    *,
    bar_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    box_plot_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    combo_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_content_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    empty_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filled_map_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    histogram_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    insight_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    kpi_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    line_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    pie_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    pivot_table_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    radar_chart_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TableVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tree_map_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    waterfall_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    word_cloud_visual: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a8eda71327018da4bafcbc45018ceb497e8c83cdf654085488271b051d977df(
    *,
    format_text: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__000bba8127c60b03afa9f7c6cc0e4d11142a6ad0322398bfb5c4ab002816d4b8(
    *,
    format_text: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1770292d4307ae2952af012a35cef2cb9eef5a8791f2ae22269004d69a121dc5(
    *,
    breakdowns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    categories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__566294a268f3641186c4eff014e8be36a935671aad4e3cf9b1d703e3ac1a9716(
    *,
    category_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnAnalysis.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnAnalysis.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__17414ad40bdb603c1550765f7afa200c6742643f7a721c4d7c02054cdab536b6(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5bab4a9e82562095a50159cfc83b11b133c763c15c39e5dffd5342d11e06226(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b61f1e46b7a0f42f445726a8df6f36743506eca0511b0928ce1babf4d2a67a1(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04cbff721f654c7c4df1caad6820ec7b376222d32b6301eeb8928be9ce23a881(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7502d0273db4b5c5befa524ba7a3234c314dba26b0a93305148657455d5dd8e3(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__543473df3c38c0970331f7446f5fe7622e643dd02e5f49995d552df8449bf151(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f3b6de738b2d9f56fb47f74ca8a418d00c2175473f7f6911f1f523f884c37dc(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__754ae217b5eb8be3a592db2009f7d6942e32a9ead6f368c3322575b785a5d7dc(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    word_cloud_options: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75f82c42bb93b7a150d1f2c4343016d5e5fc0572ca3b84cf6a3ad559fb7d186c(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f39ff21005933d4d221060cbb8c8f02a5102f355eafbbf934a2941aa5998bba0(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec316243b676233d9ea1a7521def4480000048110539f4065f4a3c0d79d765b7(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa70dc6910bb90a5405f5af23bcf089a8f8615839a457c9f2e10559c9989a32c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnAnalysis.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnAnalysis.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__650e13e8507f010a1e2263cfb168e2f149f581434bd73b1fdb42e2073bac1cbc(
    *,
    analysis_id: builtins.str,
    aws_account_id: builtins.str,
    name: builtins.str,
    definition: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameters: typing.Optional[typing.Union[typing.Union[CfnAnalysis.ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnAnalysis.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity: typing.Optional[typing.Union[typing.Union[CfnAnalysis.AnalysisSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    status: typing.Optional[builtins.str] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__680eeb61bf68aab9f7efc5447530f7aec64a0ee6b8b8811232cc7ea9282be91b(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    dashboard_id: builtins.str,
    name: builtins.str,
    dashboard_publish_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    definition: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameters: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cccc46154085828872a1b942f1bbefba592fe7597f95bf8ae4cb065bf2581dbf(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2aa8c5650bc3211ff1db5b0ae262e9333ac94b28c04c8a8b39558575f6eba359(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a33bd4b7d61cae8176a478b9c40a4ae74b2f2542e973521f41ca0b1b0c5c572a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5301c495ef1da983fed04f9a79dafdfcdbcf5f93d9b80a95ec40d4bbce9f96de(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__730a11f7cdb02ebc45d7edd30fc4a772ba1242c7d725576629010c388a0cf799(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7396ee87e03c05a902bfe34113d6e73b88d00551f37146130baff454c2f3d0dd(
    value: typing.Optional[typing.Union[CfnDashboard.DashboardPublishOptionsProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ddce7b891f3ac7f46f2d165695fb3dd5e32db8045c36cdc937497a871fc245(
    value: typing.Optional[typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31f151d03ebda269486f5636f6a6ad053c6dfd6ee31f857e760a5ba0380a4ca5(
    value: typing.Optional[typing.Union[CfnDashboard.ParametersProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92d106ff1b2a25daaf75374f6e6573c1247a1ecb92d1342051148ed7723ca312(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDashboard.ResourcePermissionProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b29cacfc7182ab6363c0bf43ef88f2e8030f3de4d7db7bffab801daa62cecc2(
    value: typing.Optional[typing.Union[CfnDashboard.DashboardSourceEntityProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a9ac3ccaa022efa1cac072700176ccb4dacaef3b71b97da0396d3679162a21c(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4eb8035f2879f71edfb344180e4670c1330ed0f81ee294235d43810a64247224(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4dfa1ef920e589a2e4fbc13091836f2392b639a09fa1a645a8b144420e99a65(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cb97c0064165f20ffab51850ae4862d72198efb0f3410728190476990f398396(
    *,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6b9bfda7e713b8da572198869bfab194434e51f68501f1fc94e77aae04aa4c0(
    *,
    aggregation_function: typing.Union[typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    sort_direction: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c84a70192ae99e55472eaf0ef9de90eaf8afab6d8451bf2101614c1e4164d78e(
    *,
    default_new_sheet_configuration: typing.Union[typing.Union[CfnDashboard.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__909cb3e8f99bbd4b88258264751547e5aebc6c3cf22a39b28c199c9059be7af3(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7f3b231df90c9e5461604f0c44004c92c724bd08249cd9cd4adc7cc27b9682c(
    *,
    range: typing.Optional[typing.Union[typing.Union[CfnDashboard.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8bac5787083212b62f824c94e42420d0fbf2b6900fbbf1d812b3b0f45614566(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a02e331dea32aac051c4e773d7427bd8d1b8a700306d83b29127d8101c100c45(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb92c9ab08d08f855601355a00a3767c200bd757c4a1c683e885680fb7de773b(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fe905cb4eec44ae877753b58706b183a29a35b34228851a0396b90b96569081(
    *,
    date_axis_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_axis_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a4b0f4c4dcfcf51b93952d7b5c224e95448f0b170e796a4dbfee7b30151200f(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e96376beae3f8fdc5bf6e2c819a38e7bac549ee0cf77f0f2cc9762f3dcb8c69(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tick_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d54500a0be4d2d2d38ee59011faff429f3f52f54e43c1302840b2ecb0346ee66(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec616a0c4183cc3e0cfef5a259dc2ee67d1bf74fc5e22f45169517a90ae1a25b(
    *,
    apply_to: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebd6114268b78fb7f73113055f755a6ade3d3994fd6870bb792075befa1bead8(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e73da89bbf26c0741917b0f0fc3debe5644233f626d9e2f4fc31a704bf645c80(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0a79903b0b74b55b9283b4c4f3c713dec760534188a08f13507f44d5bcddd9b(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e1f05a0d27fed41c8676ca0bbd6640dcf334b8eb901853ba5a5a6e5ae902a6c(
    *,
    linear: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    logarithmic: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99f8d4dfbed10bf2df8879ec1fda99532fd137630cacfec7f5330870283b7496(
    *,
    label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4654c555a5e72d37b2de0dfbc87c5387ac27a3e7d68bd6d05abebbff6bb30fa4(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22514ea70cb51894c2e9751cba44a306bcaa090fbcc774991de12a812297adff(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55170086347690041cc9c79d7e96dc02cdb90af9b495ba326c4d801ce19e992e(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__647fa37868b0610cea0d4ecf9b811af20335bd80f0c9b7ae7c404bb5333bed28(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d372b2339c4765cc558d57d4fd2a13fbbafdc5afa56a7eb1fa2c9fc25d5f550f(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb1e06c1c2bdc3845f0ac1cd695aabecd7f296e936a44659395d8721897d0ed2(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__379db281a6d09f9856995b7e2b0d1aa61e435c83657dd6962252102ec4daa6c5(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6142ff2269d23575bf404a5b436d0dbec950b79d5bbc1754cc1c30a6736980d(
    *,
    content: typing.Union[typing.Union[CfnDashboard.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    style: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fde9ba053987101020efcb8eca96eda01d034eb9b9358e7ac42e7a90dfd7e730(
    *,
    layout: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67625cc6a51178f2526ac4a5a2067bc2cb4304ef72229dc85ec9004c2e5ca4ac(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3a25cd7bb4b6ad6a56cc903abc0f68a11bc62908e120fa2320e877623dd87b8(
    *,
    box_plot_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__301dd661aeeab3012053b6c6642da9909e4b194786997f5ee4dffdd44b8ee86d(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ee06140e0a2d02984b6c3a00e9f8d9d7f013cf158dfd50e639770ee664f08bb(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b06cd4e7ac52a30564cb4f8a9f5a7faed6b818cd5d0f058ca558db6c7965f0a(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da2f3994884ebc6f952c0f2967194d8d660e370e5ab587c58c4b0837f5dcaf5c(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9105639d730530a60e1af79cb946b2d032926c53dcf1268b07083a923b2ee871(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__332a55157515a42a181ebc3bdad830321797d88781ac76fe6b51cde8a6d3a645(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0095e20a5495ebf932f1a63e3cb0de46e6c94f92a7d415eab217cd4895e394a2(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c65623178b2ff4db29478d3cd2f6d6221e33638765800bb224dbe8b54ee23119(
    *,
    source_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5bcbd104426d13db3612d853aaad48eab3730a80c9ab7e424f549999f488f987(
    *,
    column_to_match: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d6b2b1515dd7ef57aad2be08b4029d22704d37d48938f9edbee52d01628b1487(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6da96a77134fcac6237a980856bddb24526d6ec0de070b60f7f3a30e735c2691(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b01c5fbad36c204f197c990d62d65e9d0c2c4bc602ef4c4374605dee29e55f8(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f9d07b256a4b37a411e6cc0fe869f67003cf02c57581fd5ef45605129e9ac9c(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filter_list_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1de37bd80db27a90003f8108e43a7aab75c0a2c53a1fdbd6455a03a984f40923(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    configuration: typing.Union[typing.Union[CfnDashboard.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99dac514cea0a1491ea4b4adbfd7953ddb28d8c78ac2148de8c8cb4a9f936f71(
    *,
    axis_label_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23bd85afa1dfb517f88840b0c80cf50332722e5c0d23fcaacf9d243fe805b57c(
    *,
    cluster_marker: typing.Optional[typing.Union[typing.Union[CfnDashboard.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa062eb55e634c336431d3c096682ae95112d0349bf0957f1c8753a42d57956c(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[typing.Union[CfnDashboard.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6e1e23d89d50d95b98fa8dd6f596ee1ba35ddbe113cf9021276f03368188c46(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    null_value_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c25d31f5f6d13b184b20d84d346505a64e943bd5aef472be2efeca2d48df4e48(
    *,
    custom_colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.CustomColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7981e3cbc6fe90b5523bee80b128b0181ec43755b2dcb4059e25a334ecebb564(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    colors_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b340863e3ced361fe48b2bacc3838348804ad403b1d49e11fe727c1a12cbf913(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[typing.Union[CfnDashboard.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[typing.Union[CfnDashboard.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__beab3a1ed755be578788c099d8f74ba209e4e24def4550b2b8ae0e8198db39a1(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dda260e997e7560a75707e65303e2be908461401ef5126a83c64bb838d66861(
    *,
    direction: builtins.str,
    sort_by: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__782e799a1646956f02a2971525b76e9c925fba9aceae6cf968588bd8e3c772e9(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    aggregation: typing.Optional[typing.Union[typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7cb3d6d39fdba781f0f190529dc8f746b1b58a17ba7ee4360d5b96a8d1e5f22(
    *,
    bar_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    line_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f36bda3941656469a40e83aebfb537492008f380eefdf05bee66715f7f3c5a9d(
    *,
    bar_data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    line_data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be2181c82ce78a39b10a5ae695ebbb80bb0eb5aae8349f15aa8fb33e162565b9(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff98fa6b0c8fb2e67a127adde960b8c028920d511d35aad1ec6265fa0bf35cba(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e0dc16849294861b5d6e86d271d8bce76ce85506bb130654547837799389f11(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45a3c815b98791aa8322f230091c3d047176d34646febad79bad448f25ea0e0a(
    *,
    comparison_format: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c6f707ad6ec02c67d02c131935d1d8b50023bfe4ae5487861af59774f42f7ae(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc628ca1b0b5a5527e515f0164330ad2fc08ee65cc484e12f998eeda6c327db7(
    *,
    forecast: typing.Optional[typing.Union[typing.Union[CfnDashboard.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    growth_rate: typing.Optional[typing.Union[typing.Union[CfnDashboard.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maximum_minimum: typing.Optional[typing.Union[typing.Union[CfnDashboard.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    metric_comparison: typing.Optional[typing.Union[typing.Union[CfnDashboard.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    period_over_period: typing.Optional[typing.Union[typing.Union[CfnDashboard.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    period_to_date: typing.Optional[typing.Union[typing.Union[CfnDashboard.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_movers: typing.Optional[typing.Union[typing.Union[CfnDashboard.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[typing.Union[CfnDashboard.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_aggregation: typing.Optional[typing.Union[typing.Union[CfnDashboard.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    unique_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__203eb2943ec82b0c26a7fba45cef47f33ac0635d522cf58ef4a7c0ce4521191f(
    *,
    gradient: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    solid: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80c0bdc03af4bb1bbde14503d2fb6e1d802415013c6391cdbf7421e3c951f200(
    *,
    expression: builtins.str,
    icon_options: typing.Union[typing.Union[CfnDashboard.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__294b301119aba6f233c6f86ad6a8ad2beb5f50a726c3bf45442d2ed4f82c246e(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4036a7f599e9157c62b518b185dc1466e18cedd9e4e8f7ea431899b21a6909d0(
    *,
    color: typing.Union[typing.Union[CfnDashboard.GradientColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03f4179bcef46c0d291fbbb5e1d54dc19d0fb38b2cdebcfb7b8ee6ec9d959a70(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__466b512fa9803770ce0c883b94a51b01507b07a73e170fd7f3041ebd07e39b62(
    *,
    custom_condition: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    icon_set: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ff2a07e962756bac81335cd1384fe375d579e3ac032d9b2eb1857df4b5d51af(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bbbbc6881f46b06edc10bcdedf51a79690625c8a047b4d557fa0235e23f2ab4e(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ceecae11ac13c6fe0f286e7b2805578aa405c0ca7d689d9a2c1e9a8111cdf496(
    *,
    contributor_dimensions: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea6cddf33ff223ebf71e6a6a3244e598f8593cd3667e41a5cd7ce3b15e3ea42e(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26c4b80cb587a8fa2ca1e2abde36a92317c1f2fdfa5401ddc628ce4bf2573e53(
    *,
    selected_fields_configuration: typing.Union[typing.Union[CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target_visuals_configuration: typing.Union[typing.Union[CfnDashboard.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2015ff32afac777991b1c982d7dd76e0566f211be49c9fb4a0f877e0a173f798(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52afd365c2620982c04a8b0c19dc7cacc4b06aef3e35fabffd3bdc361fff85f8(
    *,
    parameter_value_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ad65d3b8348c9a010276bc1dbeb9dba3b69ddfd44e931ab961cf81102546e20(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c4e10b508766abaf50cee10ecb1b3a2a209234d26095dc829eb93f8c05b3ccd(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aae4658560321c2237342cc32ddd3586a9e9697361d5858b42738ddea71e57e2(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3de8b5270a6e1feac0da7879f22737e3e6590939819dcca70b5eea7b33e4a31b(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d87f4f67fd255186f1dc0a6a3feca38c02d78c48da2481218e329ce80accf574(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c6acae590190d5b37bfe6f336517f7255ae2af5c457cdc915261d1495c68b80(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__466714a1e3d97920b747f1ce3bfa45c5bb06ba8a6f7369b1fe4825f125053e68(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93ef0df1e627e28a49ffa7ddd2e44b9297e40851aabcdb11966471f9ced0e46f(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__044590f84959517e71beaed79a72965a66e66df79acf8a43a2103842188d7013(
    *,
    custom_values: typing.Union[typing.Union[CfnDashboard.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd6ca68139cd35a4db90289be255630ee376ee0f40a607ee72673b356fd8ec61(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.EntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c3a6c9494c32821db96d3fdf49fb81da1fd383bf02d74a853fe0cef4d778c84(
    *,
    ad_hoc_filtering_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.AdHocFilteringOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_point_drill_up_down_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataPointDrillUpDownOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_point_menu_label_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataPointMenuLabelOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_point_tooltip_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataPointTooltipOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    export_to_csv_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.ExportToCSVOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    export_with_hidden_fields_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.ExportWithHiddenFieldsOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sheet_controls_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.SheetControlsOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sheet_layout_element_maximization_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.SheetLayoutElementMaximizationOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_axis_sort_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualAxisSortOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_menu_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualMenuOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_publish_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardVisualPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39726a9b37c0f1dc57a7bd3725141ceb75cfadeff237d0e329d881f67f7457ae(
    *,
    source_template: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6a1b846dad44daf0d4bec8ad0b5511357e5b2ec6138a75bb837e3867381ec68(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f66c531b006e8f2c1f3d9294751f7827408a6a649a8eead3cd7e6eacc00b9aa6(
    *,
    data_set_identifier_declarations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataSetIdentifierDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    analysis_defaults: typing.Optional[typing.Union[typing.Union[CfnDashboard.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    column_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    filter_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7580ee893f6e5d4a22ac976da4dcfc6406c522ca02e7de52dc025a237b2cbeb(
    *,
    arn: typing.Optional[builtins.str] = None,
    created_time: typing.Optional[builtins.str] = None,
    data_set_arns: typing.Optional[typing.Sequence[builtins.str]] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DashboardErrorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SheetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity_arn: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55c64a9e491a2365c239883fb37285f7f550e5f5813b03d7959552afaf238a77(
    *,
    export_hidden_fields_option: typing.Optional[typing.Union[typing.Union[CfnDashboard.ExportHiddenFieldsOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__464cd8d977d96f9d8f3e4db49098939610214545f65a24f06025c931de7daa13(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13b5ca3eb1fd0eb0345670fbc12e717bbf57fbb373be90568f43750445bd7b21(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1584286faefe4ac26a2f6d4d95236cf1e64ea2936e0020774dfeefd670d266aa(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc9545d20ae409b550d5f7246e22703fa6d2e0417e49e39ff6f156ab1a736257(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a97e2d2d81f7f4f2eeb4b434b0dada11b17a95d5364558ffbadc6a034ffb5a70(
    *,
    data_path_label_type: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_label_type: typing.Optional[typing.Union[typing.Union[CfnDashboard.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maximum_label_type: typing.Optional[typing.Union[typing.Union[CfnDashboard.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    minimum_label_type: typing.Optional[typing.Union[typing.Union[CfnDashboard.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_ends_label_type: typing.Optional[typing.Union[typing.Union[CfnDashboard.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe0f00f480cbd95e72189b8bd774c765c7599628c24e18704730bf6e2c33f11c(
    *,
    color: builtins.str,
    element: typing.Union[typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6be538534e9017e8ac77b16ab36757837dcea7aa8a5e46b9392912e1e1b8791(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9e179ad44baf293818f66556620c9ea26ec5c96029b5eb6ef923131795efdb6(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f88b6be41f412a9800d8b5184cccc5a2cc69b18503db99b58fd978a0583d55c(
    *,
    field_id: builtins.str,
    field_value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0dfa9ba0356ecb84544788e9c5f03f5cfe7634c5db2bdf23075c1f3c1b17d6a3(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__023e8ff9b25cb8b15b81e56dc3eba2b94eca82b74b0a14cfc76393669e1c16cd(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f53a732000e256f6382e5f58403845aa0a7719ed62f6331ca8c10dc5951cf57(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ae6b64b9549272f16ba254badd0b21210ac1dcff489a3c162e45330654762d3(
    *,
    data_set_arn: builtins.str,
    identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2eb234144a9937a14d19def75f13d9f0a852eb199955dbe50fde7eace02ea21d(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__83e96253ad4aebe41bdb92e11f0d48bab81e073d6d585835e24398600eee9290(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4692a12c87c142bd49ff468c44a0cc208c8b119c92f29f8809eef693f33cb824(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee0d3d361b488060844440835aa31c1944b209ba488e76595f1dedff06af830f(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bff2fb5d78bf46a8502db54f20556ec93eb43790bb8580cd3a332913cbf6d822(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rolling_date: typing.Optional[typing.Union[typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d7478eac1cf8912f31a3d58f6c6fe4748a397e18c53f8cff625a3049d131a79(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79497bc0ea6253b57e4f671e8a2b464cbd320ab32dd7588217ca1c508ffa7cd7(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40aa516db65bb8d3e90b2a458fb21df4217f599ef6bd88e3b9818bd7d0fcbd43(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb026332bec7ec64fe0f887c6a63a5296c2cf72652b67d0c839655c2b1d83ff6(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7618a09fdc2c58a1d1fd7fcadebbf8bf5e8bcbfd8da889c6c5af35314bad7d15(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f20b97a0db742876e6d8b15a5177052a134d2b6bafa97def2d98681d485a82a2(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8b5f812bf7bc4bc9eb5f859fec9a42aaec048111d62ed4e23cacc6ad3bc125b(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9ca1704d4072c274375f7d9437dd82a302eb7e96e773e9cfa60029a0ef02905(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnDashboard.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b8e87c3a859f2bbb8c9003de951405ccef486558d2c95c60b705c3b457b6b0c(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdb415a94a3ac797c79cbdc078a3d3ae0ec49fcb22e88cba01c69f835791927c(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b94d5f109373e082e48686e8ef6ac6691828463ee8009b8760e3790ea3d79719(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e76c84c139ffdbb84448c45734af8c0a66361b4e2d838bed16b64f49489b1af(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95d1c243322644cdaff58559f14f6c05f82e9bcc98470f0d4e792d787e99b37a(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnDashboard.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__284b72e4f40970c9b808e43512ef33f2997aeb49008a6dfb7b69d5c722d6494d(
    *,
    free_form: typing.Optional[typing.Union[typing.Union[CfnDashboard.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid: typing.Optional[typing.Union[typing.Union[CfnDashboard.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3004525863e9a26d930df3d8bda9f68e93eeac4119623a61c6277a87e5cd2883(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78d0bd4b8f293d49bcfac1d526b54657b4eddae2a000cb6a2b8410fb2a22cb4b(
    *,
    section_based: typing.Optional[typing.Union[typing.Union[CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__321c3c08e48c3bbc7485ce4fb9440a0097fd99ecb6922bb8fd2d3c85d76a45d4(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc6c411f2b79d74f7f1ae6b104874f291559f2fbc60b16664c5c3683d705023a(
    *,
    custom_values_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa15123818f77ef8b4d47a100507852a39bf676c45a625274c5df8f507d718d9(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    date_dimension_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ba4e76b341b3f96471878057c14bbf23743cfccdd25f20854ec9d077375c086(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68e99558d4574a646fea1f646125c781a3bf8da7f8e6362b96971d83591e4667(
    *,
    arc_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    donut_center_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e398680d721680a1b466c38938c36aa9cc59aa4035e3f7f75a421b974630a0e6(
    *,
    category_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_range_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea14f6ae736847ad8c9fb08710ba146e70aeb8fe0dc78eda2f7f105f40b5b89c(
    *,
    select_all_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa8d06534bb0820dee9864fcbba040114f61039591942a7085bc2497f5a995a1(
    *,
    default_value_column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    group_name_column: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    user_name_column: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24c5d8ef55044b7bc4810cda64b382c269c76eaaf38149a587158566c68cc97c(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__369484222b46d1c1fd4fb62921a2ffb5bb71194c52a8075628f4cfdf193733c0(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94145f177864a6da2ad4ad0bf3af76247e12335ec765ce9159fb235f9193436b(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da502deb6cec56e03027d0bc0a5d765d925a0ccc654709300042d9fad23b5f24(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__214b9407a763201e64be927eba92d09537e3a783569a761786be2496f19c23d8(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__98e3ce4232751b841f7f54e1206c6d61bdce27dceb2ff556f50ac722ad74f738(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d466da139eb10c8ccbd6e211551275bef3a142a2537713c93572d07d52a0db25(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42a97ff83c322ad22ed18be4a6b56a736b8084706b7ed08d93d166bfd3d11a6c(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a896dfb7d29f27aea47bad79ae0ddc866d150e8c1d4ae48bf62b70d680381a7(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04f0620e2fce3adc894cf018a4dd6fae2564012cb6e56663025287f1a560d525(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e487c84cb5581fe0ee1fd868a7d07526c63e2b57b2568d2809b80386aa38c07(
    *,
    column_sort: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_sort: typing.Optional[typing.Union[typing.Union[CfnDashboard.FieldSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92f7ee6479b7b085d7cb0497112a77d4ef7c9966e96d819d50d960b65f443348(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a945d83f3ae21a829eb21d0d1ed69fcf449f1088c8047b9e608f0f7c8a6ad11f(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b8c25847cbf75d8cb69e5533c6a1a29687acd673e8d3a06c7bc1afa5878072f(
    *,
    geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42df908330aa80e775821384f0a01c16bf0cea39dc6e0157d7f9aa869264e323(
    *,
    shape: typing.Union[typing.Union[CfnDashboard.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__56d00a4acf2d3088c84de39958a82fe5b1f17a23166b08bd82bdee3fcd42c091(
    *,
    conditional_formatting_options: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f4c016ecc0f4b8a4eec5285792b7a93350a3e43ea7fa8eba14792d203d608f1b(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_style_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    window_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7df08a812066d3fbfcf249a996bd731dc4adf13b24bdd0c256f395ab91a85d58(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0c98899b30ab082c88f84c0f257111284657e06df7ee8aeffba91faa2dd8622(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[typing.Union[CfnDashboard.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__68d929ccfe29f81f2e07de2ba2dcbeae853891c5dc51d188b680902936d93b5e(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c031f0558a39ec4824e6d6c94e4402a5427b13372eac305657f67d556c33ae18(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae921f66543607d38dd79849e7df9bc376fabb3a48ed2049c0f966d0644e3f85(
    *,
    date_time_picker: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    dropdown: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    list: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_date_time: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    slider: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_area: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27891625d7cbee4b39fb2ab4df0360a910de89d952f7f6db1c92d38b56e0277a(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0910ded494fe652a4dd90bf06df06415cba52a280cf1fd08c0768982f458a65f(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9b83febb4cc40934033261498866c40a2459dd1bae7d418f0fe1346e054be8d(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    scope_configuration: typing.Union[typing.Union[CfnDashboard.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad9a094c897f8c44c5dc2d38b0a4f4bfb92016c8792e5a351f59c80a72c93d5f(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04aa975de765c4423d87a5139288f8a92be971f0ed1146cd2336930a2ecaa6c1(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8289ef69aa90a688cfb84a55a66af851befa54121fc3985490e3a55c0bebc89c(
    *,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dcc3e7151dd691d54f83af31561fe3da7953ab2d79a6976d20804929e47c8cd7(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__58d4946db4d17934af163074abbd44624db96d2fee773d027f0f59e34ba3e5c9(
    *,
    category_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_range_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_dates_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_equality_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_range_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_filter: typing.Optional[typing.Union[typing.Union[CfnDashboard.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76f7372800126f162f57efb0ba11499ee0a22c6b61b261884a9e9097046a71c7(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8914e82cd83f372c2190c84c8b0c1bd69d449c5a9396e12fb239cbf613e54fed(
    *,
    selected_sheets: typing.Optional[typing.Union[typing.Union[CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5c1bd7002191cd53fe4de3657f0785748ae988e0c9dc31047913a4276176800(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__211a0f265a0fc447e1c624c316293f49c0e2a7c6791ce3fa0c58c22c3d489080(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__33cce4dc7f51913d18af84e78f5b96afe7d3aa4a5092ae98ad34bcc2ca90c87c(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d9952d797b174d8f0fcfdb503727ace1605a99401d0d839e977b0a56c4dc887(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cf7c19afe99d3fd9ae8f1ec8ed6113d4b150955477a7a861d70b6bba46c3ee8(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontSizeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontWeightProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ace1daa73e7c850880aa6c73a3a9f0cb5d0530281f475c36f95cc61a7250e0ac(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdcdcd920af4b771cdcd8dbd51ee33afb89148742503470da12cdfc0d9433484(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0ab327581270923726606bc135dcae4a1fb775d8b466e2860373128207ac9a7d(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e7e39e043a95201422af709df7dee5a0ee18411ff5f3a3c1887dfc5575d013e(
    *,
    forecast_properties: typing.Optional[typing.Union[typing.Union[CfnDashboard.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scenario: typing.Optional[typing.Union[typing.Union[CfnDashboard.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__113601ebf0cd4d87f695ef8c8f059417cf87c5f7a49925b01efacfa3f9e5e8ab(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[typing.Union[CfnDashboard.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[typing.Union[CfnDashboard.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__655434acdee81e21d53d6c5ef89f281dbcf975d4dcb9d246ac627a055196274a(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    string_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__273a7c9d5b9cc2a3450f8060a06c34e9fea7c4eef5428cc62130ac6ca4adac26(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a168ac4829034f015945d4355743aac98a6f783e87b608f73ad242bd591c068a(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e268c71d17932d16dacc61e1e1b4572127fbc50ea4da5b0d0d46f70a1dc66f43(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e66030c3cfc47717fa70cb063577196f5fe2c39438f410488e6764eb4eb9965(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4664d105991a276ced4910380c196569856ab8d6d0cac9aedc5848ae8ee63338(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    border_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    loading_animation: typing.Optional[typing.Union[typing.Union[CfnDashboard.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rendering_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    selected_border_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__998388d3281adbe21ea2fd0d3b7c8f355a8bdd62f35e2a776f57a84874f4c919(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94f267c052f257ff9dd32a8b444035b736a6135a75ee1d70d50e589950b7074c(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a7ec8f5fcc9ee585283d90a9ca204fdd93eef67d29373b692607d5f7e119802(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7ae1bc1e8e865de2d1143b431076e54909009372a8b4f5b7271137eb4c62820(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1d60e8feb7de908f5a44ef72392ce967c2fff1f51273f8ead85c1a1d0eebdd0(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2562679f303074e83bc2b69486884e6aa0d282d512014470451f9597efe38a80(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bad249b8eee47bc3c16ae390fc14663b62c492f20b8e53b860743db48e2dcd7(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f55a8e0794985991874c971cb1ef0e30f3f84a03f57b2e9f09cc260ee2cf720b(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f9969c77a22bfd625bda85665a12630487f1c2e1755bc0953fe7f76aace3f08(
    *,
    foreground_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b75db91915d0dff52e1b8ea5f0c3a59bd53bd59cff5016792e787247b94a405c(
    *,
    arc: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2f08e38536c310bd2182a7eb14969c5bce6cda2946c2865d5c4d9f53bfd71df7(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b77c6878b54fbd5a59716dea5c206551676700b3aaea57710a56ebd51dde8a63(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    gauge_chart_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac94d46fb8214c53f5db9b5f39a297ea28bcdf8b9ff0fddd51b899bb0ec437c5(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e2d17382ec22517b13f6defe92f08dd7e3201f03ee79d28421c35fcc7732959(
    *,
    arc: typing.Optional[typing.Union[typing.Union[CfnDashboard.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    arc_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    comparison: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7e490d0b9342491c4372b2fc2409e8b5322b086d8b68c786ea7838b1d010b87d(
    *,
    icon: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f64fee1aff2d39e1324d0c6b3aaca722b1a781f086d95710495f11ffde8c0cc1(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2ef5e2cee6abd7d31901cf9fbf450fc76a069c90bd4d4980ffa86d7bc361bfe(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eca225165efff16ba2176fee887433d40c473b2cc88227f0b0372e5b719ad80b(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6272bec17d4d2a17c3e0b8b4b6eccfedf9a1938a266a226f6b1f9c935de197cc(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_style_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    point_style_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    window_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc93e3cbcf8a1b05f5f403935eadb1f26954308adf4571c964a91090b86a6742(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__316c10e17654415076ebccfae9eb4214d247a648b5d7619c300f968443743da7(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4ac264b095cda6d04cfde43a8814409cdeb18d49463db5eab9d4fd5ac193393(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8006474291c9e5471db8588b96c0c50c84da0e98750f548d3eaedbf2e38db620(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__618a75f7371b07fa8098fecf95bb8926ce8e4e6c56425eb042fb882acdc52599(
    *,
    bounds: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b2a072f23fe83386faec836c361bb6d4a5c044ab34a06d1d6a1de3d09fc50b2(
    *,
    side_specific_border: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    uniform_border: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__472a762c58bb317cd53ea7447becfc6e26bbb481db3506fda7a7da8a09b3ebb6(
    *,
    stops: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.GradientStopProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e70b76d76824a5731e135874bc91aef9dfa215b6c03b2b0ae0a28e5a9c930d6(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__efe688d577c9460cf9f7f7eb3b74ef05461ef8707eb01c7b0a1a303f0cda316c(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e92528f2e7c78b1f690ecd1f105a16ef71d62d57ac73983db9a6ab5b8dddc9a9(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f448575cfb2433f867ce96360104e09f3c0f08e6a2e4ef361235724b7b6e8032(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2b9682d1c79667291cdbca6d7604aa1176ebc194fee087bfc292816c61ef03f3(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a719fd3755736f2983d85b2caac35e327c0b9bd63683e5326b99ecd1cfcd3ce(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0175a8094fd6d612a882eb905fa340ea6573b1be4061e6ceae62cdf370fe6645(
    *,
    layout: typing.Union[typing.Union[CfnDashboard.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77d0446ccfc721e42706f5a73a2a292bf2803012a6aaac1c8a7944ad4675ba83(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f14cbf0beace22ffd494a2df5a26d5050b882f8c0e2302099c8469a1ff1c0568(
    *,
    color_scale: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0409983cf1f5381c1822256a9308f9d2aa43710b562e516f1082fc15d4c21a1(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6930fb580b33bcaf12196109bd462af4880945ac2b98e4c65764b0f19561d4e(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12b67e77b83f973c465e11cea6df42ac19a48904b87818d2100d889946531a11(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aaa7ecf1cfe0e73e580ed900bade5f2e9f5c44c5495ba06ce0aaadfcbc835b5(
    *,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b6849cedb2dcd6e479622c9a145e62d88ead4f6a6e63a3302e679e98c495865(
    *,
    bin_count: typing.Optional[typing.Union[typing.Union[CfnDashboard.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    bin_width: typing.Optional[typing.Union[typing.Union[CfnDashboard.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3dfdbf8c97ed1570a4b38ae3650e8b879632fe3b3dd48fe3969bfbcfb111cb69(
    *,
    bin_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce826bbb34cf249b52fadfa269ddcb10b226899e3683322d7feb2b20c43940b3(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3804785ef2f8b5cc7c89fe2a792661ed0ed7af661b39096b4acd770cad93d251(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c31552059474b99ea44467658cc00b95e1f6996bec23eca4a0c78bb6564e6e2(
    *,
    computations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    custom_narrative: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5d59b667df321aaa8408409152b268f259ea5e75b1448f02be596aad6daec7a8(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    insight_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99365b6a3e45ef898387d762176aba3c5ac9306fa99c37b9e5e3be8b6eb133ce(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9389a1c806416a68084069200423dc181d17492f4414449200f3b678bc900b55(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnDashboard.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5916d02f946a87a88b80cb5cf11ce661663175e8657e87533d04a6e1e5f4eb81(
    *,
    name: builtins.str,
    values: typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9079003123fa0d98277321803ad546fd4701ae09a7617c7cb859b92abad3e5f5(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43ef20f7dd725832b1ccb6af1067bb1f05f93ec424d3e3f2ec4464d4af0e9c79(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__812844b2ea4b74d16fc026f177234b326c51c4597ab0dc586923f6b895a65eb9(
    *,
    primary_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    progress_bar: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a9cfe2b8997e0d9b2458bf5aff94de13383fb7ea798f6102bf89707f5f1a88e(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ee290d5344f07d1c2e70b74b1726168db9e7b44113c7e0cb295634c77f9eb38(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    kpi_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__400488f7d37c7fa5b780c31f212ffd467a46311b3a59bc6410fb28fc95ddc9c6(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    trend_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d010ed4cc652fc89265f592d8e4c61a82ba7aa2e77fd4aa16eba1d45033efe2(
    *,
    comparison: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    progress_bar: typing.Optional[typing.Union[typing.Union[CfnDashboard.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    trend_arrows: typing.Optional[typing.Union[typing.Union[CfnDashboard.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3077fb20abed1802274b5e003e021440fb4f90b9feeff7e4286990a08053bba(
    *,
    icon: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3bc4924d18d4ca627fec69ac66628ca8bcf8f66f89b530f48e66365de4a0337f(
    *,
    foreground_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90d4a1142143fb394c15dbf4922173e5c9a8ab445972d97de48571b684e6c375(
    *,
    trend_group_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e11c189c87d06752e74f0f1a1d33773c83c531a6472251caad117d96afef8c2d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02007f9c8a3871e92afa3f45d4736b3e14c085c7423b800684aaf1ef118de396(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8dafed9ee6b32937e3e666c8b9ce8ae1e8599084660848dc5eae742195f28c84(
    *,
    free_form_layout: typing.Optional[typing.Union[typing.Union[CfnDashboard.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid_layout: typing.Optional[typing.Union[typing.Union[CfnDashboard.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    section_based_layout: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f3162b344c55cbadbb8bf8cdeedd746e7b52ee9b5ac12d2ba20725c8cf55c00(
    *,
    configuration: typing.Union[typing.Union[CfnDashboard.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__928b8daf4dc3b6c6023b3a2d95bcbba624fa46f6fd94597d9e7aea053f333bd7(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aeac59af946eaf684d058336e30a4eb2a05aa0eafb74f37a3fa2edd9528fb70d(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42471dd9822b7efbb5f74e757e7063562b5afd311dfc50ae90cdd91e26cc95cf(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    default_series_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    forecast_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    series: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b147f074bf4775f54e6811424b1c2f38b0c6727663879586e66ae2a69361be06(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    marker_style_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__597b61ca3d4c76d8ec4d8cb6c5555f5b385f420f5efbe5e0b70731cf3456553a(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dff237aa0db879fc8fa0cbdad496482eedc243b3fd13ae964be03f738ddaba52(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07ca1a21bea8e38da220af18349691be15d1570118982ac84415d918e221181c(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31d8fd577612650db1c955670b227633fb216889508e267bbd195e4fea69fe0c(
    *,
    line_style_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    marker_style_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e943ce1b7ecda86d7595d504b4ccf51447b20ad8606b875026e9e2333ff8bac(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43ceb6d361459fb47804a3ed56df3021bf3da7c7697a73cc85e2829c5669014c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da1f16efd2ced0bc1cb18450435ac23b7c754c6ef5b6a49a5fc16027bcb12a7c(
    *,
    axis_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffc7adaf2859930497df79f63941fda09bdfa0d356bc9ee188a6a9ad5661853b(
    *,
    search_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ea3df2085362951d5cff8570eb4833e8a517f86ab5498064eba83493e6d29c6(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b45b545b6c3f274d771af3c7f4d06c5227e7f97abd6d868bc274c2371b7e737(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b930afb047b4044b93e8dab6457815a74a7b6440a5f230e702231e94e8d7df5d(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6175ce87546f7d162cf70c33e7f0260d6d73c7297692a17088e6cd52996093a(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce3f60d75db9ee77370abde96035b2000a715f4a0876ed3850d9c7bec773d536(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fdfa4a7d687326b2dc6a02283b573f378f0e2cb07815e8651da8241efc2c1f09(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7372af3732d172d087e0ad56a64185adf1f8f5ff7cf1e00c2c7fe68b1af3b2e(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c5ed25edc74ea8f0e487c4e7e6fc21aeb7e3afc38996bb1131f24d618e7b0ef(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7247c2ffa8ba32a7fa54226a54c5fbc9706b2973f0a96c81bd400efa4571eee1(
    *,
    calculated_measure_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    categorical_measure_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    date_measure_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numerical_measure_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73f26ab5746e842646439b3fad2c45a293dc5be46c646b44bb4a9389829120f8(
    *,
    computation_id: builtins.str,
    from_value: typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target_value: typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e9a220c2448d9b6851be4a6f94a861e3f07a8fe9252c17398174f12ed1542f2(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0c6b4227849b1baf5ae270e3748102ab27bc8bf2a2500f474d1a9a4e470d0032(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__873fa89b2b2516ed4c11b9604620c3c2e3430463da6374af7b0db31589394b2b(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfa3f23da0a7fa1261d31cf8efb5a75983dacd6fadca3d7c54796ba77815fe2f(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84d64a6c89fe377034d29c5f46b1c5b6b270fdbf62e7a8dc1ebbcda5a6ca4f48(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86d266c00b603a86d32494b895681ab20310ab4ef65c9a1836ea445c11c9832d(
    *,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df08285efa551ddedc720f8ccfb061d9088021ddb1c329dd790de70089d77a54(
    *,
    range: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scale: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08c5d2a02bc6a4d03fd77069cec8c69125041bd3c669e753ca85f605402372e0(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22a36d8ea54614feaa652e2187823346f13d132e31069bde6d5706016e0438be(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d82485e4871006424a7af399c15b8d22350769e52c1a8e0f8124d0a503219740(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__990348a625c5c27e41c7214952bd968547d0b672d008265fe2c12c22ef498576(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    range_maximum: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_minimum: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45965f45a3415e5f023aea91341efe3e81295c90cb9f9dcb31a399b0e5fae6bc(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd3834de16bb1a3523af87ed66b2734ed82d36e0d59ce1b5ed1d970dcd7bd86d(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[typing.Union[CfnDashboard.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a291e6cb1dc48ecccc07c6ac04e696d07880240efe27d2e2684dc67710f4b14(
    *,
    percentile_aggregation: typing.Optional[typing.Union[typing.Union[CfnDashboard.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4c4bd7ae907f91f51facbcebc6b6631671cadb3cf6ae29ad236789eb6b8fa6f(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14662c336a174a816ebf6f1f46a8a13df7c715b7be804c20eb7bd89e0b26ee51(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a655d7a7e02f15bb7fb8e2a6432c24041b8276e1f6f9a76da07ad8b71429c92(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4cd6719580c552440b185c3ec3a30425ec390d28dcf41e27565c5d6962cf0d32(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffa6c3710dbc99b205887c20919f9fbb1f115a967a3f16a0759b029204db3f6f(
    *,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9a617c861fee66c2f12ab5d86dc60954b3e96d7742ec58f1f6b4d5dd31f2018(
    *,
    date_time_picker: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    dropdown: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    list: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    slider: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_area: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_field: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1c4ff74d3f1c3059beb424c94eda0f0b1a24e88b608b85cc0df0607aff0eb71(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0a113dcfc753dcee3562339eb40824b4980fffd9188b592abbc50c390d40b35(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnDashboard.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnDashboard.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0e2d499ed1c4e455157a7ed9337cbb2c047a9378394f5063dfcdfd90204ec32(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ddce4ec54b04db2ca4c161e425bd033dfc0b3003f1ad8da126436edefbcb4269(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fadb802f2e1912f59acbbecc2ce3db818bdc5630fc26e349c4695724b4c520d1(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43f62462e4fe8b08e49c740ca9cf6026e8927a3a02014ffaefbf03c75ea3605b(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dafa50892a8d3ae1b4ca0ac169ae253837176077bea1b0fe34f0169807658593(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62eeefe8979b4ccad3a1592b656ce26ff20d5db0fefc0090b7c05f05389abe98(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52e775d8109de32284839d05033897d7123c509fbf0ed766ca22e27cd8fc56a3(
    *,
    date_time_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DateTimeParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    decimal_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DecimalParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    integer_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.IntegerParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    string_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.StringParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3956dead6fafc1c7f68969bc969b840dea1f36b2c3cfdcd8de39026a5bcfa77f(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2cc544278e73c2e83091b7d50ea938246d6907bbbdf38ca0ff1cdf4506cdc8a(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ce6445deba68d26de2797a542dabddeb043f19f954bd9d7c26116aebb083900(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c6d427e3d4cacf415a4d7f8879f34f47362c20db781865c3a8dc6790d9fc7e6(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cdf09f7f9a743f7677477d39756a8ff5981ffc3245ac11cb211530143b9c27f(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8eb20135e320550c2948156da6a9ee4aee697e879e19c6e062d514b6213763b(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80fe2576e84705ed5b5bf97a3a4ccc2f49ed8c1cb6dd5449656696bc0848001f(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    donut_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2dd3508674ab9aee1b60484025570cf54ae768543a524236d5b8f5e94abd6b0(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8342ea26f85c14f4dcb113cbf7c26c606750f4dc668fc6613eb89eebabd188b0(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92f40e0ca1aef3ef70adee671248d03591b8d5ed05ed5a17474edcee68251ff5(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d2059ce187c24ecec1a3f45b0152ecd8641adfafdc1f0038f50660783d279863(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[typing.Union[CfnDashboard.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eca7718db8eccf93d456cbe9c95f480113c0944160ecc7fb6bd989557cd6d5e3(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b85439eb5f33ccfb4310fa3cef8675219f5f4c46f9fbb1b3de369cfe5f8d815(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_format: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0823a36ffa9d075a97f265c62a86e93ed14fa80ae1245ee121c674730f39d841(
    *,
    cell: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96d5779d7832f322dc641cc6f4efe1fba7f0ccd516ed12a2cfa53d4af392ac52(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e6699d21aa448f479781cd663975c339d64e201af9dd2cbcad518ec2b021363(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__373f98cff3775f1a4c6634eacef0fef18d147ee1df75509c901c44e393e55222(
    *,
    field_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_report_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae52fdbfa784afd98a84e03cde8df424aa16060aa5e379c9899e06784e41b2b2(
    *,
    data_path_list: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75a75bf865fd94860ecd4ecd341a72a89e9def1da643c4a43318166ef2335f75(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0004eae82cfd0b10c26900e942790e914ac2e20923f876fd1b41b8c1d643b65d(
    *,
    data_path_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__28f079f6d337a4e3dfeba2410667382f40b4176f50c6b45832c702cfb83ea3d2(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5162a07e7817035cbbf09d6ec5598e6d6acf9e8004aa5b2e79515a8b96eac261(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__152307a7f993a32a79b36cccc31a3a6d5d7d6bc5fc8e80723cb9335f15d7c2ff(
    *,
    cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_header_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_field_names_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_header_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ded43d2a0663600a898caf6ee9591e0ca6b99495a2db26b76d3fd4d40d4a36d(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3444ae471bb4d45db7f476cf427657f4513a34f2304790591ce9ba7a5065a04f(
    *,
    column: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_path: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field: typing.Optional[typing.Union[typing.Union[CfnDashboard.FieldSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69bfce39de1ccc1ad64cfed28e2af3ec9c0ec1ecdce79d0a4cbb0e518288ce87(
    *,
    field_sort_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fae7c10caaacfad3129d3e5b847598d0527e9d2143f9470d3cd85de0d0adb4c2(
    *,
    column_subtotal_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_total_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_subtotal_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_total_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3c7117647ca6efee05167dc0a39a7b0f6b839f8cca72ffd2d3c843bd4815116b(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__950dae094993a7c1e36361fcb586f4089e6ee69d22012ef1e2fe13aa11381fb6(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f438e55bdb2db4c5b4a89462ab3991f7ecaf138c507a3437d348d41afb871f9(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1e53022020db9de733e0454f9b7cc18ffeb4fd51075617d392ad1ccd0aed65a(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b3945a32d2258b423c2984606a8faa41c3cbc13ebe9b0ae8a1dc0ee41d676b2(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afe33d192148a7bc3c6ff522ed41994d2bee49fa1331af216a40442a8732673f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2549cfe32010077318b6072599c75789900322117b1ad34eb540b4b5586dea4d(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_axis: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__26c893dfe60075c78b4437d8cd530a8dd7f954cab0067f55e48933db169aa628(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d8d06de7d0459adb93d5ab41925aebcace67ccb323b3e2ce62e9c1fcb9bd9c3(
    *,
    area_style_settings: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bc7709f889d3c24581dc107f985f3e0f5ef4be5661f466ab92adf7834e52dfe(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae49eb9e85d732bc5959aed038b8289395f181a716c17e964b299458ffd3ad7a(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__896328ed23dccf2bb2b1c6ca31a3cfff1bdd7eff65c5830245a67a2bb6b5bae7(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3ffb8eef413e4c670baa75d50ad9648d3fd7289017556923e383c312d6843c(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53086df30d0259e4d7f96a1b56649201d816829675aff6ced451c9104cd82ed7(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cedff3003733e8f3fdd5557c9ff4c4c5678dea55607ff4629d539c120b9d473b(
    *,
    calculation: typing.Union[typing.Union[CfnDashboard.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    measure_aggregation_function: typing.Union[typing.Union[CfnDashboard.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ef1d80440ee79185f2dd599f9fdb41ebe9359ad08733560ba1cd6944eeac38a7(
    *,
    custom_label_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f58ff203d6f12d047b1db6068e93903587097aa6ecebf40704047e48b8216669(
    *,
    data_configuration: typing.Union[typing.Union[CfnDashboard.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    label_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7cb1537e30050dff3aa6f5edde07e335024d89319fcbee7775d7f5b7c4ebe4d(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__708a787be5b608e354cb9e82c90d925ad6a3591286d62e02fed7eb415813abc6(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75bbd70c28bfb100237d2931830fe0e8e705d9780572b6ad3d768e9e37d0b757(
    *,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3677b52f6645b670be38dac1097361fb8193c9e7d053d46494974f3d559098ca(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e951d875ede35c3b89d905eda69b2d14f933c420e5ddb3f0c68981a6bf59f4d(
    *,
    anchor_date_configuration: typing.Union[typing.Union[CfnDashboard.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e309cc8aae3956e65ad8c02b9e5c3f4d2b0e0a396bd903871c83c3308f86c4f(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08b33f83126e62dc8daf6e91b213f73ff7439a4c7703a1fd75135509b0819e56(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de3ec1e8b3f951afbbb7d94265c067b6ffb54d16735b31e44160c362a325081b(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d338e70265dc4293c3d45ff92969c3c17d622d5a23eb9eb8c4741103e19fc775(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__328265bd28f011b21a33a8abf290a63ccf33420361868726ddde7aebb12512ac(
    *,
    destination: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    weight: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad2da31e4b7f1f401ba152b02f1cf3e8e908cf6d64a54d0233c5857e8762aa87(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73309b74fcebd042e21631d22f14b6fa27b0b7d9f09e3c7b593d6843937391c8(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8b89fc445d140ffc81194bcff5050f6ff432aa65eba9fd8713df63b5c061efc(
    *,
    destination_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    weight_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1a66d5616fdd1db9a5ea64776a02e2a1f36c60ed91483ed8835dc963edfcc1e0(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63c0b78e43424003a24bc9ed0c070bd98c74da2ab5d71ce16e17ac95d1e20937(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e747c35c798df5aa07e1e4f42c1b12ec5777f1043707a1678cca347f657e29a(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a6a8ab688bdc514b909a688049be101be768fc3b0b721484acae06102b0a478(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81c33bd62c6b12f0690e6f678fa7f902901bb8a52ac39912500638e8a8c8e600(
    *,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__073adbeda85fa5796988ca1e62c71c12cbb82cf10c44aa4f4a432c2b8c607f96(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6a739b9e6e107e34f37757ac307b8d4896d3515273b93150a9ecb1016cd721d(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e03c3e307cc3c6013309ff8c618f468161d60f537db8f9f5ec1435e2b3d22dca(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7cb67a1dbad4d8903eda03761e784b361e1901e392abef30629e20d8990c3fa6(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8e88e5e0e9e7c11880c8014e06b2f06c0c511fd0494a01dc21920d2a20a22862(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e85dde91c61578758a93856ad8f0079c6fa485c901e1a2be6e872559bb710f15(
    *,
    body_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Union[typing.Union[CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    footer_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    header_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bff00978b8c784c267d159ebd238be6484bdf9f09d8767edf6b44ed71105aab(
    *,
    paper_margin: typing.Optional[typing.Union[typing.Union[CfnDashboard.SpacingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a6dfd7a687e23c20720e8413f4dca9b8325617775704819313512cb36f8e44f(
    *,
    free_form_layout: typing.Union[typing.Union[CfnDashboard.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e51c2617c2088a5e2f258fac141b62b8b2fa5d1aa3b940c476fabc70bcd2df4c(
    *,
    after: typing.Optional[typing.Union[typing.Union[CfnDashboard.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4e7e96c484d1cbd0203836ae4e0243c64cef9bbde3263ebea15a8d85b361ede(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[typing.Union[CfnDashboard.SpacingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a2117f965c7d115c31ac9fd6fb999827f581c1cff4a09665e6210fa71bec1a6c(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8547b662e1fad8933d9001e65abfc928c97c09570033f42d5183aa5023ff21ca(
    *,
    data_field_series_item: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_series_item: typing.Optional[typing.Union[typing.Union[CfnDashboard.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0bf26bec0af81d8c8cc1b73dd79c00452b7547f3bdf21add1f60bbf994b6b2aa(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[typing.Union[CfnDashboard.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4bfd5addb0b5da38cedf0efc5b8502b813ea98a04573e5461fa225eb682c9d4a(
    *,
    background_color: typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2431ca72e23c19e7cfc662f6be5d4f59d1bb600a1c10c097909416f029303dfc(
    *,
    grid_layout: typing.Optional[typing.Union[typing.Union[CfnDashboard.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__896bf953305117e4cdd98cdbb7680e9b05069be6b10d66c78ce893a1c6449d4f(
    *,
    configuration: typing.Union[typing.Union[CfnDashboard.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9cb9b42f4a076983e84b169fab3a39b5349ed6e3a3a03bc68f3a1144f8d8008a(
    *,
    visibility_state: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__020cf2b4b69a5460645b7cc4d5324efe862b83badae9fc2693bf24ade70578dd(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FilterControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.LayoutProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    text_boxes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48756b5654512d03796f9c2414ee40b2b0db6a9a8b8e5b8ff7e4f0e6a5784bfb(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57db451d902c87db172455713b235623fe5217d6d8975228a53df1037906e893(
    *,
    configuration_overrides: typing.Union[typing.Union[CfnDashboard.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__719e9089e375d1d64531920e903e67864f920242422908e09cb4b223892d639e(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d6d59f5fe93c16a00919ab6a0bc76f614901ae3b7d69f35f14169990c66ab7b(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23aeb0481c97cedc4da6275dca763ad7d18f7d1f4d634caebeb130beb344fd2d(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f2c58ac12165b73a342d572cd83695deb81ad759dba8a8b4fc5cfb58ee16ff92(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95e596e0f40b5ab6bdbbda45417ea041a9573bcd260018abd566e38963d8223a(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b38fdd017ed52e8a6a493bdc890158e2a485095a2e247f7ce360ba99b1b08581(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8db8e355270eec563b362be52f8ed49d42485e52ff1c781ac263cdd959213c98(
    *,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfae266922ae624a9ca6d9e2cad17241146763b037acd7febdb6bdb71f2df49f(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96b4daf4ec49b681615ad44c019a67df1ac1ed982778aff74b6f2a66dbf1f747(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0d863dde28c64b9dc3f3fc513b5fc751a040238e8bda71f92051ad80e3d8b5d2(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6c18759cba640870d2bd9976762093dfebecf84b71d2ec032118de17f4dfa5df(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__021813ea7bfadd46e078e8c0332522d462b0b41ac86ca17f48d8c61f03b9ccff(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnDashboard.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnDashboard.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af3a7e4414148b116d2e183f6c8f37c7cf57ee7451c6976d8d0ad0fdd0574883(
    *,
    name: builtins.str,
    values: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85a41bc1f8f2e7dbdf1c3f74c9ca21610c881a5acaf48f08596e359ca13e4b28(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__81c3651688a90b74f699473efd65f49f25957c41992b54c31c34715d526ec977(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fe979ba8d7d76724e62f44aa28cf7fc52839f8262e9379ffea0c8467b716462d(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96aedadb12a6966208378fe88556425bec4817da816985750e12d3a02521c143(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a13f77aa4859fd82c7df72f06004c0f9524e2860538c9a7a7eaeeb0d7bde6564(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__300441a2cbac00103ce5b3e31357dccdcd506413008cd82284d8c635d79cea69(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0c500b7d11c6b483e5b9f05d1b8a867798bee63d6df307872ed9362b11acf75(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[typing.Union[CfnDashboard.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ccb2cfe4b8fb0c8e2f856692cbd58cf0519caa5b95342e906aa7cd0abf4e703(
    *,
    cell: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8feef7bc7e986824d5c97a3acebc724a41fe28f32af3fd1db48dd3413fd74db3(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c92b93f58dfc88fd9d219f151cba291f47e6d3cdccc44e3cd34b5d9e4a0af95(
    *,
    field_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_report_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    table_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__150ad661ef2008b2b50e7d9bbe255855e510658ef4194203f72adfc2ba7da7fd(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9990b3e37412caa22f32fae936de93c7d82e69ad54e111a19a636fbdf8663379(
    *,
    font_configuration: typing.Union[typing.Union[CfnDashboard.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b595631d6553fc1e25569b2efc6867e9d07cdc52830dc6de0f6577c9358ac03(
    *,
    sizing_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de12363331cf146e3dc6e217d9acf22d461c8fa8e95a9f0cab2749d03659b565(
    *,
    content: typing.Union[typing.Union[CfnDashboard.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39cce4765754411ef3997661ee9367314704e8cb7f47d60611cd4e71de55c170(
    *,
    custom_icon_content: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_text_content: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d064ba63021496823fc8cab4556e6b685a4a0908b5151a863388a1b1c6b46865(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7130615f1c634c9a6baa475d6089b1d943618d96e057b0081fafb973287e174(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36c23de3a1f143cd6e8a7809b4f55b6fa215c791c1b769a7490be7a712c4a126(
    *,
    image_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    link_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9bd2087f8c31b3758cead5592c0d50d37d2bf276cf18e5ba2599b05ef81ba3e0(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0977e0f57370f96c3c0077802bc54db5fcb42d821c4f667d1db7974d042e8419(
    *,
    data_bars: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__66b3e13956cc195d9d20de0c2b0460edcfbb49bb7248b03eb2632c96c049eff2(
    *,
    cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    header_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3f00f777a4874b314485a28d7f9e99a52b0c377e8b27effdf1191a56863d946(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7caa0da8eb152e4e6e64e61a51d9af5749dbbeec791c75d7f8e79a70ca27c47(
    *,
    background_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cc9296ff5d4d8e2feae335f0765bb95ba0291fda2f24160f017cc84182fa8721(
    *,
    bottom: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    inner_horizontal: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    inner_vertical: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    left: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    right: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10fad85e8529c45258d6ac02db479a63a3a98c646741466e78920f8c530c4f3a(
    *,
    pagination_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1baf2b9731032dd6c21168a5bade4dfae2d0f1b228b2a2e3d1d582520521f61d(
    *,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a005115d8a4ba2d7151179a1241dfe5b19d7d9d46a130f7395db84fd8726f14(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a63bb4c5454f5f48ef6eeccea62873f1f7c990596f0ad3e2acff542650ef0e8d(
    *,
    placeholder_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72ab17708dd4dee29aa983156e49fa72ee78451c0f7935e17deb58e96109656c(
    *,
    background_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    icon: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnDashboard.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__41f405ea637d759b60db54ea7eda5609943d8a6c80384f83df8521ff89ac7450(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f9f3eac431ea49b3781df1f2e40ce1978e4e4e8d86320feced47bbbfd983123(
    *,
    placeholder_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a36e0ba3c505ab3ee0f0d7861740b5d7a816f361f0af3323170e479cffa649d(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6a15c622796a233590565499ab65a75f4c69efffadf3bfc9df99b39b22e23426(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12d66de9019ed735e5d081b8947ac743c29a70fbd46932fff3f3ed993ab28297(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4dd290a8c6ec0276bbf3e7c41585deb78351a97999b46606f038f141f2930ea4(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__02c8916a44f48330497e18ae421848c832b390cbc65a75cd05407f438a5089a0(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    range_maximum_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_minimum_value: typing.Optional[typing.Union[typing.Union[CfnDashboard.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7b2f5dc4bca8c6441bf8ba53afbfbbcf7c8f2760c0df37fa85b54e54a313ec01(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[typing.Union[CfnDashboard.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d5d5dd527540a63b14fcf2d27f002487579970e3ea82c8a6bf0af36b2f5ba041(
    *,
    column_tooltip_item: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_tooltip_item: typing.Optional[typing.Union[typing.Union[CfnDashboard.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1bfb1517d4e1ccfa913cedb9145d45666fc0d9a70e57d183d35cec6dbc6f6627(
    *,
    field_based_tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8d564333c80900dc8b12da7f344f243c281f188d85f0506de738bb42fc7bf96(
    *,
    aggregation_sort_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c2074ad4c57e3231956c39923abd6a13addc6b18b5a0c4cc273ee86712697d7(
    *,
    category: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    type: builtins.str,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3077b8c8184d185ecb682e9252fad228a9eb1a90105eec2bb392554e7e4e4a3(
    *,
    category: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44126bbbacfbcf1115ffbcaa393d1db8ba0a4050407354ebd1eb9a2e8b9214f8(
    *,
    computation_id: builtins.str,
    value: typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5171e2179a4a266cc6183009076fc35c282e8de36a06bdaa4533d72bede45ee3(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b134b11cca592b9e123baa45a8b9158272a73b4cde7a54c4cf9b557bb8e28a2d(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sizes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f7352915f4f203593150c38509289a3795a8ebdcac702ca2aea383d74401bc86(
    *,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_scale: typing.Optional[typing.Union[typing.Union[CfnDashboard.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    group_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    size_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnDashboard.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f8eda1c6d8d738dc12ed9bb767a04230a94e398225a46fbe4789779e946e4920(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__805f74245fbddda8aebf7a90f662735f840c800ce55870e429732b2d4fd69f6e(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tree_map_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__34fb93c3438cbfd21ae4daa667130c3e49bb5ff4aac72ca0dd76162fd3413484(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7c0ee04f5ee87ded27a6bd61efa93fae5e69d7ddb9c3106966207f995b73bd02(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__09331dab911bea1630cf2567d5ecdade692a3690a26bee03c32817da82df1788(
    *,
    column: typing.Union[typing.Union[CfnDashboard.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdf9dd380ae2350cc581664ab6036b5046cd90251796b9efc6a6622b9019fdb3(
    *,
    category: typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__569c4d2c981838210bb312bf601c11974f9c36df953a07ab9345a6e07e486412(
    *,
    percent_range: typing.Optional[typing.Union[typing.Union[CfnDashboard.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d0389cd0147a14c97a8f6b64aa597974ef8456753650ae5f497d59f6a18951(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9515c611ac5aadf7aeb6f4ad74868aa5f3c37f075be10ba23d7b4a76b92a32b(
    *,
    filter_operation: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    navigation_operation: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    set_parameters_operation: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    url_operation: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c94c1a76ebd0c0a784a1871e16d0cbfaf0fd402530a5264b3cbd00ac4064ff95(
    *,
    action_operations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9fc6237cd2688d1a34fcfa178eb08f6afe91c29011bc5dbe49c5ab850eecdc33(
    *,
    availability_status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a13354d788a1706289a18ef978f07b669108d63afe1c73361563163e6dd429d6(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77b257a645791fc2723570ed78b8820ae80a690735dcae5e6a265cffb5803969(
    *,
    bar_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    box_plot_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    combo_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_content_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    empty_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filled_map_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    histogram_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    insight_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    kpi_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    line_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    pie_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    pivot_table_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    radar_chart_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.TableVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tree_map_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    waterfall_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    word_cloud_visual: typing.Optional[typing.Union[typing.Union[CfnDashboard.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d324159738a94304717aa9d18ad46ff3b645f88ea8c97cc8c7583c6c1c27aad(
    *,
    format_text: typing.Optional[typing.Union[typing.Union[CfnDashboard.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22c5ef3884f3bc69d37991a34d5590174f5721acb49b2b430e6ef592c581e535(
    *,
    format_text: typing.Optional[typing.Union[typing.Union[CfnDashboard.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49da1f8c7efba1a102086854a1547844188dc619cc9465df9ecff76b3df6cba5(
    *,
    breakdowns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    categories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fdfbe74bfcb18f664c0b448e72342667aa8486c3ac9d6f4b94a302a1152437c(
    *,
    category_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnDashboard.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnDashboard.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7a8a320421fd11c1f667fff2c9d675b952bc7dbf2a18c1218f78294d452907ae(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8075fb40171eafc6a3b8af3cd23ccadb989723518cabed8b31fdb6a71cb223e7(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__985cdf8e234eead907a9bfb933c3d707136b6c6cdb900103553373d9ccbb9ec5(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2655d5d49d56236d793ed55ae210dda69a9a61186fb2c8c633185d8e873f2162(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8001e7d3a93a99ec24c1340ac090b7aea45a69cb45fef5d7036abf4ea90833c8(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04cd97185b81f2bd03969cae156e186d0e632ee5c078315353ac1acad2445f74(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c841f9ac1766b3816026f5f382f94ce9ca34b6c48a057b163dcdae2849e4da6(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20277e3c2ac23f49f297e85fd9dd01e18b5f6556465eca80a7fc222a296ce453(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    word_cloud_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d1ea487c1080559810b49efbe90c14185b0e360f95c6634fb3984f67454130d(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnDashboard.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8014a12c4168127505af278ae22ab39e0306d347901f8f46aeb7ab430d723773(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fd34d9fc66fd9c9ae8f0257e93c923525b8553ce125936ef1ac7d120d7b2f83d(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnDashboard.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__366cc762d04d6163a5c3e4685d59f3530490b7bc0a4bf2fa6334ff99d1c3b3ec(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnDashboard.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnDashboard.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1c5f47033d3be30ea201ea35806c795f22fd1f45141bd91eca2b64943ccb53c(
    *,
    aws_account_id: builtins.str,
    dashboard_id: builtins.str,
    name: builtins.str,
    dashboard_publish_options: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardPublishOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    definition: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameters: typing.Optional[typing.Union[typing.Union[CfnDashboard.ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDashboard.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity: typing.Optional[typing.Union[typing.Union[CfnDashboard.DashboardSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd11e145935e0211dba109da996b2da1ef7e71f77cc5012e8715f3bd18eb5d3d(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    column_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    data_set_usage_configuration: typing.Optional[typing.Union[typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_folders: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    import_mode: typing.Optional[builtins.str] = None,
    ingestion_wait_policy: typing.Optional[typing.Union[typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    logical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    physical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    row_level_permission_data_set: typing.Optional[typing.Union[typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f834fea75017aaa47ad47a1ca0050e6997abb857cbebc532644732deb86b683f(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e4bcab09466f01e8f47c5e8afb9b9ccb4f30708f368ae23f5cfa26cc396a634f(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7bfc59e353345266263342468ce002a92a314e25b41ca904324530cdc35b9251(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a92a6ce66bf0e80a19c6892e6fd6b41269a0863dfe5ad5bad1836a737a588ef3(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ColumnGroupProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49163173a9f78d624847e51d6108ab4e75dbda7c492aef2dc2b5465d4d483325(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a9bcbcbb180cf5ddc389365ec10ac941e017fd17bfca2eb1542307c187b36eec(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3b4f53517b4449ce367428883aebb1985c966f53d0c273fca981a1aa2b03a9a(
    value: typing.Optional[typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45de91a5495ae4ed8be8aa5a5240c2db72ca295aeba28e2dbd44739b47739e62(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.FieldFolderProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f496b1d8d947319a8220da6be1829eb5e0ba9a59e524381e265ea6f9f414ed65(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__49d08894bb1c5bac6a95f7f1f7128f75385f43b6503dae147a24cc8a93d42a00(
    value: typing.Optional[typing.Union[CfnDataSet.IngestionWaitPolicyProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db02ffa36fe42cfaea221c52e29dade9c36d32de68e6bf35349900076d57795b(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.LogicalTableProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccbc9e7093c77506258bbfd6ab73fa9cd08c88716b1000921612f11ef765f050(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5ca93b474b9b3702d7384799311679de696eaef73b4172c3c6bc7ba56bba00e(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSet.ResourcePermissionProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b52277d883cfee428b386ea5894d95d0d4a6d282d61a8e83e291a747c5a8f2b(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[CfnDataSet.PhysicalTableProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff933d5f2d76d5c5c30bb738e162a7791efe35a8852e59ff70be07204211a340(
    value: typing.Optional[typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__273d9c1517ec57c54104d8e12f3337e6fc766a017a53abf21e9dc9e333d88f1a(
    *,
    column_id: builtins.str,
    column_name: builtins.str,
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0c37aa63040b20ffe67347ac979961687ead12949f409c27407ded70b1c82ab(
    *,
    column_name: builtins.str,
    new_column_type: builtins.str,
    format: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf78338548d16a11097287f452fa1a933c1407e5e3289b5e3d308c4628afebf4(
    *,
    text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f44659e7be31e0ef281eb3ffa819f6d714017dbcb82f533c0ab50f2e03c70a5e(
    *,
    geo_spatial_column_group: typing.Optional[typing.Union[typing.Union[CfnDataSet.GeoSpatialColumnGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3894be355eacdc3448c425eec38910d2a554920ab53215cf383bf2cd4b16839(
    *,
    column_names: typing.Optional[typing.Sequence[builtins.str]] = None,
    principals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bffcbd16fd78bf2462fb30c2a38020c604d66a5bbdfaa3cc7671acae68249bc6(
    *,
    column_description: typing.Optional[typing.Union[typing.Union[CfnDataSet.ColumnDescriptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_geographic_role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6662289fef1c1e529ada7353abde8c207b58451878bf1047c24d0bbe48989dbd(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.CalculatedColumnProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03337b785de389917354b8e9ffcbd236038adf31364d6aaef63d43021d67e5f6(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    data_source_arn: builtins.str,
    name: builtins.str,
    sql_query: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9a61679b0b9a90f5a1cadb5cdf5101897357c43f96d2199521083310fb1cf1e1(
    *,
    disable_use_as_direct_query_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    disable_use_as_imported_source: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e972acba05605e616fda082940f19ffca023db514fc472b1ab6ce9729b30fa5(
    *,
    columns: typing.Optional[typing.Sequence[builtins.str]] = None,
    description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43f07171648b89ffa1f88e36967ec2cb710581eb1b210401a3992b4f0a7852a1(
    *,
    condition_expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5c8c2d28e8087e6d90159f21e796dcb3a4483be61c93189e2dec80c5f3b6098(
    *,
    columns: typing.Sequence[builtins.str],
    name: builtins.str,
    country_code: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4602efa8eaf5b2a029c3b3760ed4afeaa5fe5238fecea6e8092cb21f136f20ef(
    *,
    ingestion_wait_time_in_hours: typing.Optional[jsii.Number] = None,
    wait_for_spice_ingestion: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0598042b5c66c6b948f015dc719bca7669607d6cfea8745643d2ca91465970f7(
    *,
    name: builtins.str,
    type: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1fe516329c08faf5f63956a5acdb1cd9e20cf21cb63275c725f51b0d4a702293(
    *,
    left_operand: builtins.str,
    on_clause: builtins.str,
    right_operand: builtins.str,
    type: builtins.str,
    left_join_key_properties: typing.Optional[typing.Union[typing.Union[CfnDataSet.JoinKeyPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    right_join_key_properties: typing.Optional[typing.Union[typing.Union[CfnDataSet.JoinKeyPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2156edf8f3ae29c2acab57117244c4387798c5b6b998c9f0fd4ee218ddeb94b(
    *,
    unique_key: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94306fc7c9d318604ae92c12e40802746bbf86d136b1fa13b6ea56c2245635c4(
    *,
    alias: builtins.str,
    source: typing.Union[typing.Union[CfnDataSet.LogicalTableSourceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    data_transforms: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.TransformOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8b25a41e07acf10c2de1e0afbfa76e2a8a16b7094e4851ecb64e7fc8fc8e5e2d(
    *,
    data_set_arn: typing.Optional[builtins.str] = None,
    join_instruction: typing.Optional[typing.Union[typing.Union[CfnDataSet.JoinInstructionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    physical_table_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd32814175c01598390d3b875a9d6b05215f17b4a4666f60a3ccadfc5f6ce5ee(
    *,
    description: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a16da72220d436aa413517ea6d04e9c3d388f5212e733ba67b64d15ff5774e3(
    *,
    custom_sql: typing.Optional[typing.Union[typing.Union[CfnDataSet.CustomSqlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relational_table: typing.Optional[typing.Union[typing.Union[CfnDataSet.RelationalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    s3_source: typing.Optional[typing.Union[typing.Union[CfnDataSet.S3SourceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ee639269184eca513d6b65b98ccaecb34a42d3b8daf0be4e76d81dcf3e881bec(
    *,
    projected_columns: typing.Sequence[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0179718a192849bb93683be25c659d6642cb937317d8078a21adbdb61477d00d(
    *,
    data_source_arn: builtins.str,
    input_columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    name: builtins.str,
    catalog: typing.Optional[builtins.str] = None,
    schema: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__698ec42086cd55af0f1b6e1bc26312487d56a137e000617859ed49422d3c3957(
    *,
    column_name: builtins.str,
    new_column_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b924a98dee9d4b67e66def0da89ea10a6d932fd65a6209e5b2019948917d039a(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__046ce17827977938f1ceec9a2f17911e6d411cf5f37f6746381cbed51153fbd5(
    *,
    arn: builtins.str,
    permission_policy: builtins.str,
    format_version: typing.Optional[builtins.str] = None,
    namespace: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1025cb40fbbb056e3530fbe86d11aed2d2b6be309d34b206817850a67efa7b78(
    *,
    data_source_arn: builtins.str,
    input_columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.InputColumnProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    upload_settings: typing.Optional[typing.Union[typing.Union[CfnDataSet.UploadSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9b36407e47dd52ddd00c96c86a6a745dd8101af3ffb395d6cec041547051d5a(
    *,
    column_name: builtins.str,
    tags: typing.Sequence[typing.Union[CfnDataSet.ColumnTagProperty, typing.Dict[builtins.str, typing.Any]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39eeed8ab5362d331fad437a1db05a40f9462e67d2c60e079c57ba6c4a48674d(
    *,
    cast_column_type_operation: typing.Optional[typing.Union[typing.Union[CfnDataSet.CastColumnTypeOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    create_columns_operation: typing.Optional[typing.Union[typing.Union[CfnDataSet.CreateColumnsOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filter_operation: typing.Optional[typing.Union[typing.Union[CfnDataSet.FilterOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    project_operation: typing.Optional[typing.Union[typing.Union[CfnDataSet.ProjectOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rename_column_operation: typing.Optional[typing.Union[typing.Union[CfnDataSet.RenameColumnOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tag_column_operation: typing.Optional[typing.Union[typing.Union[CfnDataSet.TagColumnOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ff525119003c83ef161e831fad888a599a4f68ce862e396c9dcaa2b7a0124c5(
    *,
    contains_header: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    delimiter: typing.Optional[builtins.str] = None,
    format: typing.Optional[builtins.str] = None,
    start_from_row: typing.Optional[jsii.Number] = None,
    text_qualifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64ec39b807cc879ea1450bd3114d0c18167529bce23e812bd109bbcdacbc3e7d(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    column_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ColumnGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    column_level_permission_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ColumnLevelPermissionRuleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    data_set_usage_configuration: typing.Optional[typing.Union[typing.Union[CfnDataSet.DataSetUsageConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_folders: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.FieldFolderProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    import_mode: typing.Optional[builtins.str] = None,
    ingestion_wait_policy: typing.Optional[typing.Union[typing.Union[CfnDataSet.IngestionWaitPolicyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    logical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.LogicalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSet.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    physical_table_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Mapping[builtins.str, typing.Union[typing.Union[CfnDataSet.PhysicalTableProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    row_level_permission_data_set: typing.Optional[typing.Union[typing.Union[CfnDataSet.RowLevelPermissionDataSetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a7c53922691ab39dd1b021a3e30bf67046272ed2c896c058e9c51c75f7b24ac7(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    credentials: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_source_id: typing.Optional[builtins.str] = None,
    data_source_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    error_info: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    ssl_properties: typing.Optional[typing.Union[typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    vpc_connection_properties: typing.Optional[typing.Union[typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ee1fb159cc6b8cc0bc67cd55e6d6d66359157eacd2e3a2d9f123e087cf80c7d(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7179296e6dc01e4678af405d91a94fcf856b7bf6300b244bceab58490660f8a1(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1b0816db7c39cd9db3c8b3078bf61f117bf251d82b252a64f0ed5d432dd596dd(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSource.DataSourceParametersProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__86b21f206c80d8e14f5273917a89fb864cecfaa6d00bcc5d80b652fea34c3002(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a9a0595c38b1ddf4f7b48c7b632a5c528d44fb306facad9a1e1c58a5bd08f7e(
    value: typing.Optional[typing.Union[CfnDataSource.DataSourceCredentialsProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aabbb5f63bf58c14637689d3cd5d6e33804c1a6c7eeaefc6785c22a0a62de436(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f6f6439b5e9a8a21df2d26a45ca721ffb274503a57ab546077e68c0eacfd3774(
    value: typing.Optional[typing.Union[CfnDataSource.DataSourceParametersProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e99a6c9c6baf50107afb1c0e73ed267fbc0af2d005365feef2f15f5ba1a5380(
    value: typing.Optional[typing.Union[CfnDataSource.DataSourceErrorInfoProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25c63184b9e48cf6560b413d7ffc6e0646a490d01ead4de626bebcae288e5cae(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d938c60ffa7f9c40aa8974443884b021b831dc4a72dbd5fb03126d3c4b6d98f7(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnDataSource.ResourcePermissionProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ca7a9aadfc4174e97adcc5ee078b87d8e91bea513e8997dbc5eaf8da4147b74a(
    value: typing.Optional[typing.Union[CfnDataSource.SslPropertiesProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c53248f590f6132fb3072daa03741d6e291f03e09dcf57c49507521ebf9d83eb(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7db4a56893b5c3e49e9997efe8bb08d5efe6508f29ab0c4c961a8fcc8d2cbd6c(
    value: typing.Optional[typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0713c768f4967c02a66768f543d77cf272acf7c12ed68bdf2d2d350f78b5c3e1(
    *,
    domain: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ffcb56d73bc925a49945582aeca6efe82ebb2e9bb85734685d28fba0d7129f7(
    *,
    domain: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55871c8c64b72ed559f3c4682ecaafb157503cae3b32ea010aaf723bffb1e6fb(
    *,
    work_group: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f602d9aa381bf2cecc2fdb2a111f3618af1612d2245f01c1036efd28ae8878be(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b1091b4ef26fde3a2fd9403fec9511387f871c562e5d9d4a64af30d118da432f(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0b7b580fc1e20721676afeb23765acb8eb8a2fe2ab8078b4ce2f7057e4002e2(
    *,
    password: builtins.str,
    username: builtins.str,
    alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5dbea4a00d0551805bb3fea09ca0480db769ea71896d37ca0c86109cda08efe0(
    *,
    copy_source_arn: typing.Optional[builtins.str] = None,
    credential_pair: typing.Optional[typing.Union[typing.Union[CfnDataSource.CredentialPairProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secret_arn: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a85ba8b5593d942655cf1a6c754ee156401119e0beb21fedb7a4e7556a702fb(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90db356a882e890618e0a242f815c83fce513ed33cffd59bb2ac7bfe39ed9dfd(
    *,
    amazon_elasticsearch_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.AmazonElasticsearchParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    amazon_open_search_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.AmazonOpenSearchParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    athena_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.AthenaParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    aurora_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.AuroraParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    aurora_postgre_sql_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.AuroraPostgreSqlParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    databricks_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.DatabricksParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maria_db_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.MariaDbParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    my_sql_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.MySqlParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    oracle_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.OracleParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    postgre_sql_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.PostgreSqlParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    presto_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.PrestoParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rds_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.RdsParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    redshift_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.RedshiftParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    s3_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.S3ParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    snowflake_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.SnowflakeParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    spark_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.SparkParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sql_server_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.SqlServerParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    teradata_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.TeradataParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b94e11c88398b55ace7936b2d79553efd6867932364ced9f504fa9f5970440b(
    *,
    host: builtins.str,
    port: jsii.Number,
    sql_endpoint_path: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da51ed98eb626db1b2fb46039a1a507b288e80a0769ab12c5327f6375a5977d9(
    *,
    bucket: builtins.str,
    key: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__be3b31ea0873feba21927daa4f9822cc75eeff4e97f1bdf4c1a2973537eb6373(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__949a9d305a46722ed2684a273a58c9fc4673894e14d306bf9fb6fa66528a06d0(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__122af4d0adcdda159b17c0e6de101f1077f9ecccbe4d2d9e01c502203d9709bb(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9289c9c8d412ef412498f69f97cdb57d46a9aac6c4849032cb71410ef593bf4e(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9d296fcfbcb689fd276cccacc82918f7f20d166eaf1dd94ae523d668d7a92b5(
    *,
    catalog: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f62c76a31e25da9e67e8ab77a08b73b8fdcb2ebfb750d7ba7f18e15abf1b846a(
    *,
    database: builtins.str,
    instance_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d681dc5c2b5906e42f74a3d74d81d8fdc22b644d9d898effe4191cae18d0968a(
    *,
    database: builtins.str,
    cluster_id: typing.Optional[builtins.str] = None,
    host: typing.Optional[builtins.str] = None,
    port: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d8ba2637641ae79129ccc101dedb746820207e3e6771202fcb6053bf798fc1c(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2220bc18a3b550bd8bbe9884783e7dcc70a6d97fa288c61ef81e81c7e218abd6(
    *,
    manifest_file_location: typing.Union[typing.Union[CfnDataSource.ManifestFileLocationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cd90d69c367729964c97dbdd087458e1cf75795a6ee637c2f247e1f75a4c75e(
    *,
    database: builtins.str,
    host: builtins.str,
    warehouse: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f0fb62f442d8b8e6f75b1f480fd2e88b6cac336309c3524b6f59fc03dfd15dd8(
    *,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac01cba832bc02b452cf6a71bb3db3d8378dd4fbba57dd250e691fd23739fdaf(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8b4cdd1a954c0db9fa5845dd75420a9ef237bd66cf3f657e106c4ad8ae12557(
    *,
    disable_ssl: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__08bcc91fd1330bd9ae822b9d535599fcb0daabd309c89eb18b2dcf886d8c5c7c(
    *,
    database: builtins.str,
    host: builtins.str,
    port: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf4d4dcdc5ae539af50f23da19ba530dc5ec59840155436251424130b5bcd2e0(
    *,
    vpc_connection_arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc0aa356c3689030299b81aad1fcec24aec9ccd94c8ed08f7a5d309a2402678a(
    *,
    alternate_data_source_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    credentials: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceCredentialsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_source_id: typing.Optional[builtins.str] = None,
    data_source_parameters: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceParametersProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    error_info: typing.Optional[typing.Union[typing.Union[CfnDataSource.DataSourceErrorInfoProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnDataSource.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    ssl_properties: typing.Optional[typing.Union[typing.Union[CfnDataSource.SslPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    type: typing.Optional[builtins.str] = None,
    vpc_connection_properties: typing.Optional[typing.Union[typing.Union[CfnDataSource.VpcConnectionPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2cb98577ae0aa5fa792462e9b70cd9e6244aef13c152842e033a79d126e5ed49(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    schedule: typing.Optional[typing.Union[typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cedca9f24cc89ee50e4bcb185db3fa7e33511058aae57df76fd6979709a3130f(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a613aedd91cf4c27b92b858b2778574c61520dfbb1055d1f9646fbe195f333b9(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6dcda8ff88ed183aa8a9f876be4110750dce0d9207db65e4758537f4cb0c7bde(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f2432e0f85abc089d7642bf01eae839cd8befc96b6ac1cedc64c1294ccdca5f(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__126e6a64cbde64eebc0cd5b7e30bcbae9ebaee18670b88c858d354c5fdea6288(
    value: typing.Optional[typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afba7e37a976d3acd9ed3ae5b0019ddc7ae613723af911fee427edf967f4a0a6(
    *,
    day_of_month: typing.Optional[builtins.str] = None,
    day_of_week: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bdbba0c66aa208f475da2eccc8b33c90f217300dc3acd2a62838794ae59cbb08(
    *,
    refresh_type: typing.Optional[builtins.str] = None,
    schedule_frequency: typing.Optional[typing.Union[typing.Union[CfnRefreshSchedule.ScheduleFrequencyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    schedule_id: typing.Optional[builtins.str] = None,
    start_after_date_time: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04f6ba7ad2f0fff1eaa90fd7b374909c222d4545d0fdf370bcc096978077ea00(
    *,
    interval: typing.Optional[builtins.str] = None,
    refresh_on_day: typing.Optional[typing.Union[typing.Union[CfnRefreshSchedule.RefreshOnDayProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_of_the_day: typing.Optional[builtins.str] = None,
    time_zone: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea32cc2d0bb94e945c49fd8ec5363a4703069033ad264025a5a966ac11f7d302(
    *,
    aws_account_id: typing.Optional[builtins.str] = None,
    data_set_id: typing.Optional[builtins.str] = None,
    schedule: typing.Optional[typing.Union[typing.Union[CfnRefreshSchedule.RefreshScheduleMapProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c4084f68e91f3572eab4f41fd7ae4ba2d978302797741b347ca022b7c4f2b268(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    template_id: builtins.str,
    definition: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f434abfce74fa9db644d0cdb158fc4d477f3195b7547ebbd0c6a6beac8bfa468(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__69f3549d4979025b08bcafac59dd4f61e8c1b5202351c2754e35a19d1999eecc(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e87cf21a3226da5edc284966da8cc60b0955f3d8985f51a9e116c4393ada70c(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd72d25d1868a71c8a014f6df04e9732ff666709d3657be269b917f6684156fa(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__52b656d928c8196c5277586852abb25e7ef493b0791b877ce4f5b949f35f547c(
    value: typing.Optional[typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c6be0670201afea3006abaab464bf3165bd4ecb2d4c115ca74a16a410ad8aa3(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__398a1395b884bedc1e304f6a693e4015f76baf9cb79f766789eedd537b279992(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnTemplate.ResourcePermissionProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3442f652ffc3117b277a39aa52f6750ace3d44bd0baed921ce633c78ff1bf2d9(
    value: typing.Optional[typing.Union[CfnTemplate.TemplateSourceEntityProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__636062ca9a7cb9788d19bb62fa92dcace11ecde08bb509f69b30c2f41ec8cca3(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1bdccf1f0dcd5bd9bcf4f53f1908aecf55fb8632ac968542ad9ee6e3a6c5665(
    *,
    categorical_aggregation_function: typing.Optional[builtins.str] = None,
    date_aggregation_function: typing.Optional[builtins.str] = None,
    numerical_aggregation_function: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18a0d31e2b2f0002dacf73bdd15e71d4247ea285a4611f98680e8f5996b94c88(
    *,
    aggregation_function: typing.Union[typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    sort_direction: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f10853e1006ca2badbc4299fb0b8f0e7a4506d94142a85cbeceb83d99ceb5669(
    *,
    default_new_sheet_configuration: typing.Union[typing.Union[CfnTemplate.DefaultNewSheetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20be54004759a6aa92d19fa29de2fc07af124cc330cf2532f1150d4d012618aa(
    *,
    anchor_option: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__18b10f73dc38e4053a4531bb5a8482499cade0f259cd01430c3dbc1470e640b2(
    *,
    range: typing.Optional[typing.Union[typing.Union[CfnTemplate.ArcAxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reserve_range: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__62f6e1a9d8aac070cc5e158f9317886e34b0f0d497327952dc68136e971e2c45(
    *,
    max: typing.Optional[jsii.Number] = None,
    min: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77de119c90dc6ba2a062c588003bca92c3b71e773a42569448a90b654691b8ba(
    *,
    arc_angle: typing.Optional[jsii.Number] = None,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc0811c9cfb7816023854b1ea9bb883826372ca532b95874475751ddce5ecc9c(
    *,
    arc_thickness: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfb1c97b40be91160807bf4b49d709ec27830a05f1b10512e5bd6c09fb947947(
    *,
    date_axis_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_axis_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericAxisOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f3f6d84656f78abc74fc514401551e83d638c829bfaff00c48e6f9aa2ff3f69e(
    *,
    maximum: typing.Optional[jsii.Number] = None,
    minimum: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fe1eaca5b226525925c17234fe4b739ccf632902ebe9b9bf1b58c313e55587c(
    *,
    axis_line_visibility: typing.Optional[builtins.str] = None,
    axis_offset: typing.Optional[builtins.str] = None,
    data_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDataOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid_line_visibility: typing.Optional[builtins.str] = None,
    scrollbar_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ScrollBarOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tick_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisTickLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24e901885d9106af77d2d29866a49259ae74fb93b0396d99ed1ca314e380410d(
    *,
    data_driven: typing.Any = None,
    min_max: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayMinMaxRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6cbd43f2b9505f14714c944ba6992a8032c5df3dfab606e6512123f1b0bec122(
    *,
    apply_to: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisLabelReferenceOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22276746e68baf66ceb6c3c35a812be33a6863226f9ddf8c60251007476ecae0(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd52f6ca8ba88f59ef9aacaf9219e39df02db598199a578ec9483fb611b7a6a9(
    *,
    step_count: typing.Optional[jsii.Number] = None,
    step_size: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07851c3a73e1ee39155acb28217c43ede081fe5692f81bb7276ff636c805b7af(
    *,
    base: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__00219b67351dfde76642e0aee1ee541183be99929ece3d64ed1b84c763f4fc5b(
    *,
    linear: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisLinearScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    logarithmic: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisLogarithmicScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__82f154a04ad11f8e09877e6d05a3a223513b0d9ac1411da770aa6bf9866addcb(
    *,
    label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rotation_angle: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b82dff70bd87c3d3385a4298ffee85c687bcf9e2508e907cadd74d72d6ba235(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__169a7c867586c038eef0332b0659ed70146d9ed9fe662e75dd2487823108c69e(
    *,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.BarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    orientation: typing.Optional[builtins.str] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.BarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__756fa076bd6e83208a6f665863c9b33d066c89d803544653816cc47443201666(
    *,
    bar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.BarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71cb0d75d58325803e6870b0f6631c3b13d205cc9aa9c1f5666ba17ee6b604d8(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32c54f780a85fa4229aec418a20f60ddb7b5b674bbb5a302c5b72dac6de275cf(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.BarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90048ed633a0e6a782fc21039b508d81512c87d9d9b87fb3fb8751464b29ddfe(
    *,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4617f3dacdfb99eb1ef5442fb799bbeb72b687299c31e5ae5fbcf9bc5c465e5c(
    *,
    bin_count_limit: typing.Optional[jsii.Number] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__978cba332a167e332ea6ca3bc3e43f00c5a3cb0679e1ae81ef7cacfaedb5da50(
    *,
    content: typing.Union[typing.Union[CfnTemplate.BodySectionContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    section_id: builtins.str,
    page_break_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionPageBreakConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    style: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebe06d9b1a380c53f29828799ecde6f950060ba022ffe3802fc06bef1df342eb(
    *,
    layout: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__623ee8b2624567b44113291afc9ed116dd3b14ea92a8485e4f5831ac37e9fa39(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3a971963c7b8a89f1df9de38c2af8f42dc4908164b782451efc2bd444759b4d(
    *,
    box_plot_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2efdc8f9cf941d1fb67cb15dc0c00dcac5fc6b80b4172156ad8cb98a78fc6061(
    *,
    box_plot_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f0574041ce16a651e9aba0d583026c831c1a3f83c906405b87ea8e4342e5433(
    *,
    all_data_points_visibility: typing.Optional[builtins.str] = None,
    outlier_visibility: typing.Optional[builtins.str] = None,
    style_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af0047edd4030a082d44f1812b08435bdd2793f707bfada697c2252cf19dc62f(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    pagination_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__31517b77ca1d87776729ad911f29d8b4ff5259018ed78d6f5ed6621b37338b29(
    *,
    fill_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ada8c50e0520ecc1facf0825a19ead96fbe8f075266112220b9f2a081b4f219c(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d80e60b47dff9fc916edfd94ff6acade3daa915f355d88e14f1c23dc5742dd6(
    *,
    data_set_identifier: builtins.str,
    expression: builtins.str,
    name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c8b4d5dbf8933105264735a82d3d99dbbed01e475102d9e879aca428dd46d1e(
    *,
    expression: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8a3fdf89cc814adfed4942092c61c9300af359d64533b17e12c6cbc0e4147889(
    *,
    source_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.CascadingControlSourceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9f374555628e115730297f1b43598d4eff98c741834513c6574b9dd9c276811d(
    *,
    column_to_match: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_sheet_control_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5f85d04e830cfc56c2bd1c055734954195c245511f7e862893798eb9ac3e0b9c(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff19b999a517a69a5ad081871747de13768e9cf092ab6ade1f2eb5591a2b4fbd(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2fbc8244ddf3971b442d55ee4205b3ea263402bf9e2d26f74f9e9e8d48010f53(
    *,
    category_values: typing.Sequence[builtins.str],
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ab5d93814532835c22d56dab1f142039e031cf0a1f0be1c68681ae99e142456(
    *,
    custom_filter_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_filter_list_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomFilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filter_list_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterListConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57ba3e3132bed5edb713c5f99ffe0d4603cf2d46cabe2b0792684eccc6bb11c1(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    configuration: typing.Union[typing.Union[CfnTemplate.CategoryFilterConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1a714a6a5ccbc8ebc5f5f0b0096505434c14bd0207fbd40c9b7fb19d317ae69(
    *,
    axis_label_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.AxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sort_icon_visibility: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e98eab85cccee16e53081a3818f15dd21b809a945a95dcbef74a93c6164eca50(
    *,
    cluster_marker: typing.Optional[typing.Union[typing.Union[CfnTemplate.ClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__256c9d54654730809d0f1dfb61f99dc567baabea7c3262581aaa3749c3e613a1(
    *,
    simple_cluster_marker: typing.Optional[typing.Union[typing.Union[CfnTemplate.SimpleClusterMarkerProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0264786e888f069bee84d1f3191f798abbbb0aa5e22f9504e75d4472c798545e(
    *,
    color_fill_type: builtins.str,
    colors: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    null_value_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f161fa9fdef505501305e6433b4515eeb17d8dc4aff78b67987a6a979feb3d45(
    *,
    custom_colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.CustomColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d82280f69aea32af27cc84aa7902f26b59bb940a69f35e601b53ac9876150f0b(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    colors_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColorsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__506d905c100729d69bdae500232bc0bd89c7016746913c23e50347f24a6c97d4(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac23fa70b74f2047de958b13a0f894548d2c9a3e67c93e1d539e5e87e030df38(
    *,
    column_group_column_schema_list: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnGroupColumnSchemaProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d246238c318494ab7a26a7340e8e3320bcee2d3ca2c0604b03d8046f0cdadd9(
    *,
    date_time_hierarchy: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    explicit_hierarchy: typing.Optional[typing.Union[typing.Union[CfnTemplate.ExplicitHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    predefined_hierarchy: typing.Optional[typing.Union[typing.Union[CfnTemplate.PredefinedHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8f236457ce439d56bdbd0a89c81d38c7c0dd468446bbfde02a51e4ed0626dff(
    *,
    column_name: builtins.str,
    data_set_identifier: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c8cf0ece2a5a56135ab6eb46bd57677089eedc347b11dbe731753b58685f9682(
    *,
    data_type: typing.Optional[builtins.str] = None,
    geographic_role: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c57f121512b4c7afd669afb5b99aee4cf2f76a9949c8d4bf0583511b05bb75aa(
    *,
    direction: builtins.str,
    sort_by: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b41ed4d55ff8c0ed5880b82efa1096ba5a9c710bc606968e8a6bba18d5937d9e(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    aggregation: typing.Optional[typing.Union[typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9d647ddb42b44df7f2589fd90dfd84b6daf5f5c8e16cef7a15ffa1b1f3656bc(
    *,
    bar_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    line_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63cf08e84abd6e9afe0bd22fa596aad5415f2edb124ad713ba383cf0044159e0(
    *,
    bar_data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    bars_arrangement: typing.Optional[builtins.str] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComboChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    line_data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComboChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__845f3fd8dfc3e680d27e3ef393f3702ae13ede1f98517802cb2aebc3d488288c(
    *,
    combo_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComboChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4041bcd7db2d510690e6ce8507b997be79cd49152f0243d3e13b7ac5380f564e(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__340a51b9c529cf83d209d4a6d3c73810fa12b4b8acdda6834f2fa7c09a83a9e8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComboChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d676d92e6b025637a3e679b6679df5fff865843308be939813c58012a525f37d(
    *,
    comparison_format: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComparisonFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    comparison_method: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b67a9d63f186589bc5fb65a14057c3fe7b50181eb5824ee35ab1bc5ef2ed5d63(
    *,
    number_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e33ba0a3d73109d9db95fd1759ab20d4b280b0e0858b87908c3616efdb18ce1(
    *,
    forecast: typing.Optional[typing.Union[typing.Union[CfnTemplate.ForecastComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    growth_rate: typing.Optional[typing.Union[typing.Union[CfnTemplate.GrowthRateComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maximum_minimum: typing.Optional[typing.Union[typing.Union[CfnTemplate.MaximumMinimumComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    metric_comparison: typing.Optional[typing.Union[typing.Union[CfnTemplate.MetricComparisonComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    period_over_period: typing.Optional[typing.Union[typing.Union[CfnTemplate.PeriodOverPeriodComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    period_to_date: typing.Optional[typing.Union[typing.Union[CfnTemplate.PeriodToDateComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_movers: typing.Optional[typing.Union[typing.Union[CfnTemplate.TopBottomMoversComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_ranked: typing.Optional[typing.Union[typing.Union[CfnTemplate.TopBottomRankedComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_aggregation: typing.Optional[typing.Union[typing.Union[CfnTemplate.TotalAggregationComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    unique_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.UniqueValuesComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6efa7f716a5738db35c84dcfd4de6d74b2ffaa0f6ee4b018235bfa4d3de02bd3(
    *,
    gradient: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingGradientColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    solid: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingSolidColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__93e5a9717c2f4c5c6594b365b4c3ed2d796a9dd177ea5da9a4c1d8db8bd550dc(
    *,
    expression: builtins.str,
    icon_options: typing.Union[typing.Union[CfnTemplate.ConditionalFormattingCustomIconOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    color: typing.Optional[builtins.str] = None,
    display_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__edad2c40db5a0cace45c0a9df530f2cdf80f4eb84a235a1a93c406b0d208fdb7(
    *,
    icon: typing.Optional[builtins.str] = None,
    unicode_icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff6e6910a8cbe09d1b3e059793315f22c282618fa095e32555dadc9e9d4d1ee0(
    *,
    color: typing.Union[typing.Union[CfnTemplate.GradientColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c321b2cda2a82240d3a9d8ca1058657d3ff4804ede4c9e8b87809dc59d6bdc33(
    *,
    icon_display_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__96cc9f5a292a048d175fdbaba70b3aab075324f9bde49346f2d7f598f4c7e82a(
    *,
    custom_condition: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingCustomIconConditionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    icon_set: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingIconSetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__71c6a063e0355e7b953e9cc5a6f7e4f05c885de1a30011fb7f50b0aec934acef(
    *,
    expression: builtins.str,
    icon_set_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a121c9abd82cee9b0530695102ba22533fe26d2cf39544e35fae46ef5405c662(
    *,
    expression: builtins.str,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9998cd42f4e0f58e97f9627cdf0c7caf8e76895d69abcffdf2489406c33878c(
    *,
    contributor_dimensions: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    measure_field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3e86c22a94b30c396ce686c483b1fe162ecc0ab38f9c375d8241c0881be5142b(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
    symbol: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cace275b7c7d44a022bb514197953afc61c423c388b5e7afc6d392d96877284a(
    *,
    selected_fields_configuration: typing.Union[typing.Union[CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target_visuals_configuration: typing.Union[typing.Union[CfnTemplate.FilterOperationTargetVisualsConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27cdd2e733696e06935d84fb6cb13b9c7898e22ee0ab59fa00b5ee3f7ee81a43(
    *,
    local_navigation_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.LocalNavigationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ac54c582e1334b5129d225f4bfa0448ed94c50379ee02611475ce29f72a06e0(
    *,
    parameter_value_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SetParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c71dc93060b26ed857331e9657aaeeffc215596a19c577dcb854405b4552f98(
    *,
    url_target: builtins.str,
    url_template: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a0a6acdf73ffeb1e8e4a3af9d3563f0252e0a215b6a32b9d75898da5bbb06e20(
    *,
    color: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    special_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3afe7425cdf869aa20d275d5a14ad190e9affc2d505bcad72aa4d3ba920b8654(
    *,
    content_type: typing.Optional[builtins.str] = None,
    content_url: typing.Optional[builtins.str] = None,
    image_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f615e7edd8c5109452d4f4f1ad56747e54ab09d2da739c962f166469a7308df(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__92bbd515c230d4b2b9a8cb7499081b25a3c07186a6f3aad185f13d902e3aa935(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_value: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__431403adcf325cabd39d04c21f24949e163aaf3e6e5e54293d2475c788127a54(
    *,
    match_operator: builtins.str,
    null_option: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dfe7a6364bdaaed3fa6b8d896134d30802613f9b256f9697be85d814a826bf9d(
    *,
    narrative: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__36986c27bc4546a328c54c5b12879b4f7da33ba2ed7689252d97d5036697b8fb(
    *,
    date_time_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    decimal_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
    integer_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
    string_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eabd0aca81507c133d6486d84578cc85a26fc6f01c7816843f61c042b8258195(
    *,
    custom_values: typing.Union[typing.Union[CfnTemplate.CustomParameterValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    include_null_value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c23a9173cc7177e64bb59473d0e58e4f622116d4f2826d8226c0b0a7e2eee2ce(
    *,
    field_id: builtins.str,
    negative_color: typing.Optional[builtins.str] = None,
    positive_color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__986eea6f6c76b2441c634de131d267bb31ba7e216b8581691ce1bd19692ca6ee(
    *,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70c94c837cbe0ae029c805075a977f29055d8d4fff62307419a5f32c511f9378(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    field_value: typing.Optional[builtins.str] = None,
    settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cbd9343b78cb83ee2a284bfee56760b84e318c328dca65c16588944be15f69ff(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    data_label_types: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_content: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    overlap: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__febe3c79ae1b0c6a205c53ae5c35e4e494a9db28db27a4f7bd1af9673f24786b(
    *,
    data_path_label_type: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataPathLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_label_type: typing.Optional[typing.Union[typing.Union[CfnTemplate.FieldLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    maximum_label_type: typing.Optional[typing.Union[typing.Union[CfnTemplate.MaximumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    minimum_label_type: typing.Optional[typing.Union[typing.Union[CfnTemplate.MinimumLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_ends_label_type: typing.Optional[typing.Union[typing.Union[CfnTemplate.RangeEndsLabelTypeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e842b713fb756bfbe6337496050eac4eb09ca12cdaea7e2f3c9934571401093f(
    *,
    color: builtins.str,
    element: typing.Union[typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d226641d81b40091940e06f14b381489aba89bd4c47494daba4ab092d38a7fb4(
    *,
    field_id: typing.Optional[builtins.str] = None,
    field_value: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__10cdcef6faad4a75e47c795d59dd1857c32028b147b3986ecee0d5285f097562(
    *,
    direction: builtins.str,
    sort_paths: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd6d9c393096edd469072d3bc2ae3b2624beff74a3ee250971977866f7629bb9(
    *,
    field_id: builtins.str,
    field_value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7867b3344600a6488acaa336311720a3b05e4259e8c1593e8cd749c38a78d22(
    *,
    column_group_schema_list: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnGroupSchemaProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_set_schema: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataSetSchemaProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    placeholder: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__517acdef00db34d17d00e274f0affbb1b12358f698ffd023fa8bce130d0346ed(
    *,
    data_set_arn: builtins.str,
    data_set_placeholder: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4c92bec9d7d4a5d5cf43399514bd4dd19809d1a0c0dc7003405fbe8f4efd3a3b(
    *,
    column_schema_list: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnSchemaProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6646c080b7a746259ebfd2512c72d65573c0e27626d2819f0d0f09505799dad1(
    *,
    missing_date_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fde5ff8bff3c09eb3cc22fb9915e51148329caafeedbed0e7c4613eb46c2bc8(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    date_granularity: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4445a2ee955472c0fbc679f3cb85c13dcf7316e8d96ca69cd010b04457940e1(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[builtins.str] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7d5c6f15bd5b678baa42ec568addd68bab04fff9be7986c01f044690ec60a504(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rolling_date: typing.Optional[typing.Union[typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2574cc1c98bed3f4a6f3d310622d54f5a0ca6fbfc7483e773cb1cc71c06081d9(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b64e331b652b216d9e17685aebf0e893960ca460662e015be59fbbf04c1df37d(
    *,
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__85c2334cfd0267e41bbf4939f0ff02249edc9ea90e9819a961e7e3aebda37ac5(
    *,
    name: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6e4b6b9cc3eae35f1b0420f446d9792823aeb10bceac0d6c45f3b7f3ffd5e955(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__687ffdf3d337150dacaca7b508aa52f36cb245ec5328c9a4039369abca507dcb(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a63d1a98df9b8bb3a5c4e6e10768c93161729c62da0b600c1d1b4f82c72fe8d(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3495cb1258be244fe9de2ff4d45814a512b6ed48d89de7307b7bf8472a00962(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.DecimalDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnTemplate.DecimalValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9421c25ef79e8b07b8e60532343e0c3b01568bd4a03a2e672cd423e9c48228fb(
    *,
    decimal_places: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1af1b98f4866a5688c72943bf30ac6c06a0cce452e2a430e638e5b84745fb585(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4a4c18f003a7916d475aa6e2dde0a9c67afbdbe5da45e2c3239f487d6b170b37(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c41d313b83eaf358d8111f70033c77d13f5e35df5d6785fc7d2d9f901e308ec(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnTemplate.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ece5753659e12015dc0b5f01760988487a7e8fd36dbd93a244847cc980f3b05a(
    *,
    free_form: typing.Optional[typing.Union[typing.Union[CfnTemplate.DefaultFreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid: typing.Optional[typing.Union[typing.Union[CfnTemplate.DefaultGridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4113d983c50491bcd143f148aa44a22cb1ab0c48cdc2444f12da537d903cce08(
    *,
    interactive_layout_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DefaultInteractiveLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_layout_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DefaultPaginatedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sheet_content_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__399e9696b83e0c3677fff2fe5778c16e6963255ca18b8843415114ef9603ffaf(
    *,
    section_based: typing.Optional[typing.Union[typing.Union[CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7aeee674423bd0120cd29e2e13dc5241d9dbd2d7eebf7dcf39eb89d4335e61d5(
    *,
    canvas_size_options: typing.Union[typing.Union[CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ff618ac2310368210449f7e6dbcef555152246d58c93a92b9a8aa20499acc315(
    *,
    custom_values_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomValuesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_value_options: typing.Optional[builtins.str] = None,
    source_field: typing.Optional[builtins.str] = None,
    source_parameter_name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b968e9abb6cdb63dc546b14a28e092b37d4d91b14a7609bcea9efeb901dc629(
    *,
    categorical_dimension_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.CategoricalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    date_dimension_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numerical_dimension_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericalDimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__16d07d8eb8f08198c8e73efb46aa7e61f5980c8762629d2fa2e1089f0d698b81(
    *,
    label_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f162daf32a440d32c14d0ab1b4382ae53271fd98bfe720fa8286474172854cbc(
    *,
    arc_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ArcOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    donut_center_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DonutCenterOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3f19f7f523b71b0aed17616e55be4efee20f4f81ca5a7ca85cee04537296046e(
    *,
    category_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.CategoryDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericEqualityDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_range_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.TimeRangeDrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3958cee17b6ba78e3f08ed694e20fe2959d6bed5118ccb03850b8cdc87dc098(
    *,
    select_all_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b531afbf9e163e0b94cb3d523eacd67630ca0acb0ee5989a6023bf6d282caafa(
    *,
    default_value_column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    group_name_column: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    user_name_column: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3439b3b58b64299ffbe03514dbb2c0c1111229aea0d250c4e2ca8c94b951412(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35bbd61bd39c8fbf0c7d1701694f75a43d49ec5b06186de709eb3b8068ed5bcd(
    *,
    path: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f90c41e10426b2b2163f788a29630672fec9efef3beadab5458d00dda3db8c66(
    *,
    amount: jsii.Number,
    granularity: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b8afe23c4b3549b89f81e20f8c65924ce77a844879cc02b15c5cbb43f67bcd1a(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3cb71b0237d587e0960bd535e81d80a5d62e841e7049842b21d98acf062312d7(
    *,
    aggregation_visibility: typing.Optional[builtins.str] = None,
    tooltip_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.TooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    tooltip_title_type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a78dda34e070c463968746ffa0b6db48b21ff4bc1b29d563613bd1746fbb24b(
    *,
    field_id: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__655400cc9a8d3ddafffdbff970e7fe07f487e727f7695864857c2f11f07ab613(
    *,
    axis_binding: builtins.str,
    field_id: builtins.str,
    settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__91fa599a6a19a78991e1577ed44c063b414dd383736a03bdfa48143d247fd150(
    *,
    column_sort: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_sort: typing.Optional[typing.Union[typing.Union[CfnTemplate.FieldSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df95c7ae16d080166819aeb029fbedcc31e68e5e08714f0ebf149d792ec45a21(
    *,
    direction: builtins.str,
    field_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11357835ce4d1e05bc029e9e2f155819ef12044b432b32bdf0ef8f102ce5a05f(
    *,
    field_id: builtins.str,
    label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bed6f4e08fc9987bdad3c6138a0d78f0a83736775d4c5fe033686ed031f04e5f(
    *,
    geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e7f890cf306784b86a0ae39e2fc11f52b416fcca8ea84a522a8d51417f846e9(
    *,
    shape: typing.Union[typing.Union[CfnTemplate.FilledMapShapeConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6412f0ce73e461ce7531504c120b2e6000c5a1aac2e0af5dee82ea16e9299b88(
    *,
    conditional_formatting_options: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FilledMapConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bd2e26a82ccc8b908754ea11b287c2d96ccb965f17209efa0867745e159030d7(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilledMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_style_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilledMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    window_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc3c00c9229e2a92bd2792b41c201b812241182543c4ab65353fc9f0d6269034(
    *,
    filled_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilledMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5e3fd0aec1db2cd6b609dc7ef753c1351491e4518fb862857619536341e5e529(
    *,
    field_id: builtins.str,
    format: typing.Optional[typing.Union[typing.Union[CfnTemplate.ShapeConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1213c455eb989f68b5559fedae3ccad00e65da67b87c336abe46a79270af9ff(
    *,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d50769b122efc97da1fd28c8ade51b0d77c814c7176b35fa4fd7cb70ecba6a53(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilledMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilledMapConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc2ef27050d0448639b1c9e5c17d996d7e0bd34f43d727ec848b5dbee34cb5e5(
    *,
    date_time_picker: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    dropdown: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    list: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterListControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_date_time: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterRelativeDateTimeControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    slider: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterSliderControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_area: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97b6f734a43d2db830c340a5ba9e0a308bea43af57467cb43f214b04eb1633ac(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94444478a15e6db1c44f47cc2149bc35dd3038f4f0b613068c41b599720bf7b2(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__820fa6732867ae4c1e44cebd665eeb0465b9d25b7f5eeffa5fb2e10b2e0a1570(
    *,
    cross_dataset: builtins.str,
    filter_group_id: builtins.str,
    filters: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    scope_configuration: typing.Union[typing.Union[CfnTemplate.FilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eb3f3118841e0d23065259d0bc4c4f3c1f9fad5e0c24e3b3279e4d4e50a3b18f(
    *,
    match_operator: builtins.str,
    category_values: typing.Optional[typing.Sequence[builtins.str]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7ccecf28d291f90710f7b4b831ce88bb318f399bc2c6d270206fc61bedaf1872(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d931f120dcad043887575fb1b8ecab312f00d3315d9c9e13b0709fbcdd803b6e(
    *,
    selected_field_options: typing.Optional[builtins.str] = None,
    selected_fields: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cfe868786332ac3d55e21706495ca7466f0585ad84376cd457a031403cb75830(
    *,
    same_sheet_target_visual_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.SameSheetTargetVisualConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ac47c33acdd391847c98dd2d53e2776dd35cbee59cf60485b88a1a140511a29(
    *,
    category_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.CategoryFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_equality_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_range_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericRangeFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_dates_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.RelativeDatesFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_equality_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.TimeEqualityFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_range_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.TimeRangeFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top_bottom_filter: typing.Optional[typing.Union[typing.Union[CfnTemplate.TopBottomFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0a84c57b168371a2b5f6c287e1df1f93908c7f9143f6bbe0c3933e3cb97666f3(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ffd0c0b1b6a2fcb037e574bda4bb942b8d0fef73a9d7d9b6d97f6e9ecb7a2962(
    *,
    selected_sheets: typing.Optional[typing.Union[typing.Union[CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2c73f0193a2b4ac8a122ae22272b26d25076e1e3aa867473002ce12d9984b936(
    *,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9b374ed79c9cbd0892752aaa152d42078d5f46b5780059515327263dfab51a31(
    *,
    filter_control_id: builtins.str,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    source_filter_id: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a1afdfdc90f9e67fd2760502a24fedd006f01d92fd3c5397af63bf0b81299354(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4323424946d47926768625cd653528845a977556c9d321371d89f1b10f894915(
    *,
    filter_control_id: builtins.str,
    source_filter_id: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__11056436016ade194f96da4855855153ae841cf02be1852bab6112f9b461620f(
    *,
    font_color: typing.Optional[builtins.str] = None,
    font_decoration: typing.Optional[builtins.str] = None,
    font_size: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontSizeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_style: typing.Optional[builtins.str] = None,
    font_weight: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontWeightProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__67262f15dc7af7d69e9cc22c2041a9b2505f2111a885506eef640569443ba39b(
    *,
    relative: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ab620fc7850dc312fc90ed18d0910e4fd86d053961bdc7ba0f60cc90cbdf7a6(
    *,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebc5681a6b1d537ae9dce93f223424895da55d6bbeb66f40f407dd3bffd5d9d7(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    custom_seasonality_value: typing.Optional[jsii.Number] = None,
    lower_boundary: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[builtins.str] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa33914fac5e7e808f4dc5c9ac3e4213a0e934b32660920724398a8be6bdb47e(
    *,
    forecast_properties: typing.Optional[typing.Union[typing.Union[CfnTemplate.TimeBasedForecastPropertiesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scenario: typing.Optional[typing.Union[typing.Union[CfnTemplate.ForecastScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__598d2cd7c47ba5f83e59db98d5c0e7b0b8333291e2c0d9704ca37a99014697be(
    *,
    what_if_point_scenario: typing.Optional[typing.Union[typing.Union[CfnTemplate.WhatIfPointScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    what_if_range_scenario: typing.Optional[typing.Union[typing.Union[CfnTemplate.WhatIfRangeScenarioProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f12ab8249a1d8e0ce750539979eeaee82eb1bc3d21e6b147e5b564e73b490ab(
    *,
    date_time_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    string_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.StringFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7b114c854beab8b22946a7799b84ad2cc87aea8373ecf471d41fb43bb31af52(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__084c64bd95f9881469ac15b2be2bce930df0cb5a0a3f81e4d81068043e2c233e(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a07ab7b072aec45a8553007a82f562ba5798a2a04d4b59a8d4f923c3c3f373c1(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7aac355a0ce9265f6f7a63fe84ec48db62c97e5df17e18312c8f82b5984da46(
    *,
    color: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75d0de9941a75a2af6e9b15199d3ad7820f6f6af98b0e76818cfd9d304526b16(
    *,
    element_id: builtins.str,
    element_type: builtins.str,
    height: builtins.str,
    width: builtins.str,
    x_axis_location: builtins.str,
    y_axis_location: builtins.str,
    background_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    border_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    loading_animation: typing.Optional[typing.Union[typing.Union[CfnTemplate.LoadingAnimationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    rendering_rules: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SheetElementRenderingRuleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    selected_border_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutElementBorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__972621417721a29edd24e84ce54cb0a1b655367ac4a013b1636bb08af6f2e57e(
    *,
    optimized_view_port_width: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2d3cd5e56683bd63ddc5da92da247da4e8162ced1c924a6910211c89f1d5f562(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0870b8bf7791e1b6da61b39d4d11947e604483f1ef2cd5da654d61db09828029(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__807b480191d11edd66af1f8633c5b8b8d2acc0353c9392b6a2d9a56d6cde0319(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.FunnelChartDataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.FunnelChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FunnelChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__474bd70423e770ff2330d5730e78fdd594b4519f6b080c1fa9524bd20f8f27d5(
    *,
    category_label_visibility: typing.Optional[builtins.str] = None,
    label_color: typing.Optional[builtins.str] = None,
    label_font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    measure_data_label_style: typing.Optional[builtins.str] = None,
    measure_label_visibility: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__da17c9d0c7302116e672650fc49aa156d44aca52bd1c6ba6b28e5ba9b0ab0d35(
    *,
    funnel_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.FunnelChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4bbba75d3122a55ca5bbf9d4913d0a70f78d49574a4814efe328752820ddb6a(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f0c5b85b18013bb225f6053a0102821de77dcba293c4618ae867c0f5f589ba3(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FunnelChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__963e9df0d828a42e486124395f4f7acb75db90a94e98a2625657a83735d62000(
    *,
    foreground_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8510330bbb1483018cb23aa19bc018b66ed1dc013bf6efe00f693fd8c1b2c86a(
    *,
    arc: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartArcConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b6a461052ae994106ab67bd24d116469f2f54aec60cb34839905c82a0ca53cae(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.GaugeChartConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e20a21a32656654aaa1e2012cbd79ae29c4e51ff0a83ee22d53c261a8504fca2(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    gauge_chart_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4401a773fbcb50a9a8f4ab7be4cb70f9accc011877324276042c4d955de63db(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43b6129318c8258bd6274c88b028a2b33493761808cc6c1ab26a3cb2d8f5b178(
    *,
    arc: typing.Optional[typing.Union[typing.Union[CfnTemplate.ArcConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    arc_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.ArcAxisConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    comparison: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b53889f5419839873ce8f21b111f9029495e73e095212979f53f6d33442a958c(
    *,
    icon: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7beabdab608b18f5afad3c5780af7a316410134772f2d78e43be87dc95c4ae34(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__516bd7b5341d6059cd6adced219da15398447e0a0a2d8a43203b676317c11f86(
    *,
    east: jsii.Number,
    north: jsii.Number,
    south: jsii.Number,
    west: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d5710c2cda26a9cd102e6063b8fc093b1a7463c7434c0ff1c32b508fd4d4f2(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    geospatial: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d275e7a7b8ac35bae52c7a5eadb523f50d665220d8a1f77d26472152a6cffad(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_style_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialMapStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    point_style_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialPointStyleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    window_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialWindowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f43c9d3f29bfb089f3483cd8d8889febd6a39553d8f75ba04e4241076e3772ce(
    *,
    geospatial_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0ad55b13c9bd3403cbe9999dc11596762fd20f5af63e58159bc60ef98ee223e(
    *,
    base_map_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d4aff519fe76c3159473fea305f7524c8b896b0f11faadab06d311668c82c714(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d9f9ed1162f3d6136bd0f345a06419110f39d851811c102db1eff924e94f040b(
    *,
    cluster_marker_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ClusterMarkerConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_point_style: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f3e47a0324cd7679cca980562032826519a0dc53adc4137f7905ec9e588a78d(
    *,
    bounds: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialCoordinateBoundsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    map_zoom_mode: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e035b7e8786fe1aade478e81f11c4ef0aee40801f59b958635a60f9a7e64052d(
    *,
    side_specific_border: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableSideBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    uniform_border: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3023c66802cd6873588984dd9fdb6bf027ea256b0da63ab588685edaccaa32c(
    *,
    stops: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.GradientStopProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1cc5770ba3abcd68192f034694a880768c75a3ba29d9cbc8b507c5bfc5eaeda6(
    *,
    gradient_offset: jsii.Number,
    color: typing.Optional[builtins.str] = None,
    data_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__78c86eec2ab21a179e9dfe6ea705e8e7a6e6a48cf8dcca022a973ba345c2efc2(
    *,
    screen_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2946eede0323e9965f493d53681e8c48650de1ed5050f14e2d7092e00f06190a(
    *,
    elements: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.GridLayoutElementProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.GridLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e84d041b92ec1815aa5816dcac73802553589a363ec9fc8a22b3fae7bfbcb8a(
    *,
    column_span: jsii.Number,
    element_id: builtins.str,
    element_type: builtins.str,
    row_span: jsii.Number,
    column_index: typing.Optional[jsii.Number] = None,
    row_index: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__980a898eb1fd9df145843e5551f39dfd2379957c54cd1b647b1b4bd6a077d292(
    *,
    resize_option: builtins.str,
    optimized_view_port_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d665bcdf0b1d9fca7a1ed1a78dbe4623d00e7635b39b988833b3dadf858b2ae(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    period_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6b0d9e407ed91524f824c775e39889b2e7f3e111847d40ff83dc33658f928c9(
    *,
    layout: typing.Union[typing.Union[CfnTemplate.SectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    section_id: builtins.str,
    style: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af23009d190c734de496e3cee0bad14c51a9dc4f83817588e46f21274768a15f(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7096f07208f22005baa66805c7992bfade1170e4b23cf6ada2127397994e8f9f(
    *,
    color_scale: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.HeatMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.HeatMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d74dfdd511bd241fd78bab7c6bb6052b7fbbaf54f4ff74bc2840cecb4ac94557(
    *,
    heat_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.HeatMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8cc70f417887305f61d5e22af6caf91f228d6737698ea60b291990bff6055485(
    *,
    heat_map_column_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_column_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    heat_map_row_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e74e90e54c6a55837f5cde04895c55b5f712403c72ffbaa792fe2fef42d76f95(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.HeatMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__abf03f119215c08941333c006ea4989eb59ac54501c14cea4f31ba7d43d336a4(
    *,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dad86f8b692d74fcf0f80f3bd77897862a96fe4a98f7a16227c437ce92a540ce(
    *,
    bin_count: typing.Optional[typing.Union[typing.Union[CfnTemplate.BinCountOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    bin_width: typing.Optional[typing.Union[typing.Union[CfnTemplate.BinWidthOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_bin_type: typing.Optional[builtins.str] = None,
    start_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6fe2c6fea6c98fa485252a851f62f2e12cf1e9b3c65336baae8119479d367bb2(
    *,
    bin_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.HistogramBinOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.HistogramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32a39293db042892cdd3e62d4573206c65395c099d4f32e8ede8338f1bd7cd27(
    *,
    histogram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.HistogramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eec91f5a2d0470d5d88168312bdbbf133128273d8027d5b77225c05f368e288e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.HistogramConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ad0a2fe0c078b2ec333dcfdcb9f8a1d6d8470adce30e18c983ef9810812ea2d8(
    *,
    computations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ComputationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    custom_narrative: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomNarrativeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0da04957de9f36c20499971f9fb9c255bf5c27df7884a69ee06a2d443a6594ab(
    *,
    data_set_identifier: builtins.str,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    insight_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.InsightConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__27eea6a1f5e5507de8b0cd121abfdce49a3a9bdd752a56d3e9692f6e5b91e0bc(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[jsii.Number]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e11a10d8b1ed6efcb216a9e0a01a53a71fec4383aaac2fbde564de1ec399e9f8(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.IntegerDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnTemplate.IntegerValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06efa9152e8b90b8866f7902b0edd0ac8df943aaea861535914cf799bbf60a30(
    *,
    custom_value: typing.Optional[jsii.Number] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__957778ce9e752fc8ead5ba0eadfa9af0c08de7be548fcd1a347fd02c3d55ef3c(
    *,
    items_limit: typing.Optional[jsii.Number] = None,
    other_categories: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f9362857ed11194af5faa248daab97baef140433eccf60ede2c58a3ec4c65376(
    *,
    primary_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIPrimaryValueConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    progress_bar: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIProgressBarConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a646abbf0dcb1675f34f399d0fa352f7f199eaecc7522b204632b75a17762eee(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.KPIConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ac167d937fd51f11fae318fa636ee47ea95f17c9b70ff0e11224232bc137b891(
    *,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    kpi_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPISortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c211579ac63d2209518031a73400d003fee5302cbe2a5ae66b6cc0f0d365e1e4(
    *,
    target_values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    trend_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__718b0519543d0a84b8e415033dfab96e4440358db575e02f60fcdd9ad63c9517(
    *,
    comparison: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComparisonConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_value_display_type: typing.Optional[builtins.str] = None,
    primary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    progress_bar: typing.Optional[typing.Union[typing.Union[CfnTemplate.ProgressBarOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.SecondaryValueOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_value_font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    trend_arrows: typing.Optional[typing.Union[typing.Union[CfnTemplate.TrendArrowOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cacbbabccb4050782cee7574d81be780e5a0d9dc4d01dccb16695d05da046951(
    *,
    icon: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5e1c49f4402f15b8fce01210cfeb48e47e338a85cf1cf5e0efca67f5d4ed32b(
    *,
    foreground_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea107a2dab5c2cfbffd84a25e4921a770e7d0b84c1af0f7a643292930ea3c1ac(
    *,
    trend_group_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f67a6c809b1127cd232db69b92fc4b69abf2dddcf29db1e6f22aa28a2d3ffd32(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1d6dd7b3b7e59fca518f04b92335ef66bede6442f72f80c3f81e92ba67df114e(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6abce898bb6b7fd713e79a0ff77f08521d605f449aff83f223f793dd180e3f1b(
    *,
    free_form_layout: typing.Optional[typing.Union[typing.Union[CfnTemplate.FreeFormLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    grid_layout: typing.Optional[typing.Union[typing.Union[CfnTemplate.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    section_based_layout: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionBasedLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c3d74c79a897c9be0797b3e262950526b724df7c902cb34229c0a35959c44633(
    *,
    configuration: typing.Union[typing.Union[CfnTemplate.LayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__230106ba299b65e567940bc8c1da0c4424077dc479b60bfe2843690c82232b1d(
    *,
    height: typing.Optional[builtins.str] = None,
    position: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97325fed1f49ba6661f5d76b1e21b976240c9961e1c7564cc31fa839087ffa02(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce00e91b2e0273efa7f488476a6ca606dde3dd6c3df4dc2f080898ef6feb850d(
    *,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    default_series_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartDefaultSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    forecast_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ForecastConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    reference_lines: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ReferenceLineProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    secondary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineSeriesAxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    secondary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    series: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dd0a4ad0d8ecf9e7b4ceb62daccb27521aafd05724de04f66cc600137948a118(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    line_style_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    marker_style_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__773c6ee424454a3a867fcf8087f930b9e99629eaa8104af75b49fed4087d42a3(
    *,
    line_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4479b5bb96503d17c6b198947c616b6ecdf1c728eee49486598bfae33ac47438(
    *,
    line_interpolation: typing.Optional[builtins.str] = None,
    line_style: typing.Optional[builtins.str] = None,
    line_visibility: typing.Optional[builtins.str] = None,
    line_width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__88187e0520828ef737dcac79a4c49221dc6225ddcc6d484b1c6d9220e7cc6eac(
    *,
    marker_color: typing.Optional[builtins.str] = None,
    marker_shape: typing.Optional[builtins.str] = None,
    marker_size: typing.Optional[builtins.str] = None,
    marker_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea3e1f29c15813053ba8e64422a0c85d6d7723053ac36a25465e04c6854e8e18(
    *,
    line_style_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartLineStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    marker_style_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartMarkerStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d1fb0e3f33db0e1f24f906b4bc7588f2c9a01b34c2cf3e6b2a365ff583a90fa7(
    *,
    category_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3302a68a6315e39ac388fac306c3f931d0723317725a94872d2da0f71d5da2de(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6fd5ff40696ef5dc99f8141015b86015a51cac71b8ede4a47f14ab48ea57afd(
    *,
    axis_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    missing_data_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MissingDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5a76a36283a3e7755835f4eee93e2df973db932318ec5f77b9a66b6070b7583(
    *,
    search_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ListControlSearchOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ListControlSelectAllOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1aafab5629b0926c5cf0c6175d8facb5cfa68e684749eae908789184745c78d8(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ef0224e7a7db39313b61c850a4b2d310beac8f8122ea8946becdc08a2c9f792(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__55276ecdb065195b6afeea5dd56ba41348cebac2403a0d4961a3d91ba7cefba1(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4ea7513d1f0dd882ce23d615414df3a0310b954109702922fd28c7e6b5753af9(
    *,
    target_sheet_id: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ebbc8579983e7d941d07a18fc367f90ed578e3b52dd5bf1db4ac000ee2d737cd(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5a322202f16b0e713afb56736eba521b5c6867d1a2959b564149b6004f1615f(
    *,
    data_set_identifier: builtins.str,
    data_set_parameter_name: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40a22e4fb77c723c872211f1b40f5d73cee77072471b29021713754d574fb67f(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40c3082c448762bace42a05f1f9e69877a8c86d6d974ce25c7887993ea40780b(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0e39517333acce9fc6b26b166973f73d647589ecf6d86a37ac66415e7a99f236(
    *,
    calculated_measure_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.CalculatedMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    categorical_measure_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.CategoricalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    date_measure_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numerical_measure_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericalMeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d71686d3ac844f0e1e109a36818cdb06b6ff3703d5ebacfa60a594f8451b8b32(
    *,
    computation_id: builtins.str,
    from_value: typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target_value: typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__822180053d07f7c50506eb6bf0c37fa0d7d0f57524556871e4ba4d6307babe98(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aa70ffdd0ab9c7a7e1b8692ef1b140c093f46c70e3265c77160262b1beb8c42d(
    *,
    treatment_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7b409915d9d3e410b97354e6dfdd2867c30b902f115b9f4dee6788b88c43a80(
    *,
    display_mode: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d60606b9890f4d356572754fc97bb61c697ccbcddbf881bbe37a4f321381814e(
    *,
    null_string: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ecec9364323a52b1c3b9ff51d6c3bba93d0a2cc387ec0d75147b3079ef9875fc(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_scale: typing.Optional[builtins.str] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__826ea14d3b384e916b601719aa1a9828b9883a7537a9c7cf03b2941c5ad5aec2(
    *,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__76d9d6aea9530a5d9677e0d601d8208e12d3d72ace4c68f69e5c8377c9c5572f(
    *,
    range: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scale: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c41aa855415455add09354b255788b0b552d7e399de243e05e15c2d0da4bc157(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e9b30831f8b245c660eb0b00bb22dc15ebd0e8cdabb6ef37529574a5d2c68a34(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    match_operator: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    select_all_options: typing.Optional[builtins.str] = None,
    value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__22186dcdd432d647fbeaaf11f5713da136819e2aa8864310f5197189237cba33(
    *,
    currency_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CurrencyDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    number_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumberDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    percentage_display_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PercentageDisplayFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1641cb3e0fb0d12ca5d95be7bc10afd3dcdfbff09adc404ff3f12e96d1b7288e(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    range_maximum: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_minimum: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    select_all_options: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4fa733ddc1880e87ee44941008d434496ea33fd3229c862b436f36a96afb7586(
    *,
    parameter: typing.Optional[builtins.str] = None,
    static_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23d06eeeb121e6ebed4d33696647f1ed0ec353ab1663a67d2a50a5c5c937c3ef(
    *,
    decimal_separator: typing.Optional[builtins.str] = None,
    thousands_separator: typing.Optional[typing.Union[typing.Union[CfnTemplate.ThousandSeparatorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f63a80fd9bb96ba5fcc7cf3c21e8fcc7c806f6a37f0e51b2602a0e6162416069(
    *,
    percentile_aggregation: typing.Optional[typing.Union[typing.Union[CfnTemplate.PercentileAggregationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    simple_numerical_aggregation: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__75897c00e01583650bd2984eb65fa1bd4a1d50b1d9285a1b161213b89d2f9b36(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    hierarchy_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__240bf88d3ee3f4a21d92a240b49bf7b1ebcf54d6a0432f3d7a935ca51fc2c8e5(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    aggregation_function: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumberFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14d7fdff301a97171850c2c041104b5de8b4d577d64cec65d460a0742e6857ee(
    *,
    page_number: jsii.Number,
    page_size: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__70a689bf9b4731a849a5f70df019d5a3b4fcd9f1b9aba0e398e614235e317fd9(
    *,
    background_color: typing.Optional[builtins.str] = None,
    background_visibility: typing.Optional[builtins.str] = None,
    border_color: typing.Optional[builtins.str] = None,
    border_style: typing.Optional[builtins.str] = None,
    border_thickness: typing.Optional[builtins.str] = None,
    border_visibility: typing.Optional[builtins.str] = None,
    gutter_spacing: typing.Optional[builtins.str] = None,
    gutter_visibility: typing.Optional[builtins.str] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.PanelTitleOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2641f1a67716eb9cf30379e8959df63aa7b7e9dfb79aa59a12b005017a9026d4(
    *,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__396295915be75fdc058e865040099f34c6ec453bb1bef199646c14e5eb0453de(
    *,
    date_time_picker: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterDateTimePickerControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    dropdown: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterDropDownControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    list: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterListControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    slider: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterSliderControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_area: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterTextAreaControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_field: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterTextFieldControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5a3e4f9161a8843d5ca64f3161ca10eb65397e0084b75fa1507e053edae4f595(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimePickerControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e7aad8c39ed03ee1add3c898da798cf1dbd8fe419249c5a02385e065b3870d1a(
    *,
    date_time_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DateTimeParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    decimal_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DecimalParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    integer_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnTemplate.IntegerParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    string_parameter_declaration: typing.Optional[typing.Union[typing.Union[CfnTemplate.StringParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bdcebfdc50faf2d44afea4892cdfe797a86aba6c6912b7262aaa5df1e4e5596(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DropDownControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6f5a9099c35f924313309536c2c861ac2e3403ce692f2ce03eb72e1ef141f989(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    cascading_control_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.CascadingControlConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ListControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selectable_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.ParameterSelectableValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6d163b40a27bc5052061bce9e5ae3a18e896a2e85b94118d83166b12e4d918ac(
    *,
    link_to_data_set_column: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4b9c6c2314175ed0813841ac33e09bf051ddaee013f3a23483a091c5a62d3832(
    *,
    maximum_value: jsii.Number,
    minimum_value: jsii.Number,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    step_size: jsii.Number,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SliderControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c6f7ac2ff9305f9c628e61069c64ab6fae40f856c895366322138aad1d3047a6(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    delimiter: typing.Optional[builtins.str] = None,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextAreaControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e3a8d48212e6725d84903277722488b6168e79c99c1d3f3fdbba00f4b5f3f887(
    *,
    parameter_control_id: builtins.str,
    source_parameter_name: builtins.str,
    title: builtins.str,
    display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextFieldControlDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ce357b09d36a3d94cc05335b7dc503a22e89aa36fd1c7a6792f2948bf30489e1(
    *,
    from_: typing.Optional[jsii.Number] = None,
    to: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a6751189570be48744e4e9d216262a7eb1a84b6b1f1567597da50cc1ee02ead0(
    *,
    decimal_places_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.DecimalPlacesConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    negative_value_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NegativeValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    prefix: typing.Optional[builtins.str] = None,
    separator_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericSeparatorConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    suffix: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7336e8802535f497b0040ea68a2755a5774735cd661e25a74f911aa841407e1(
    *,
    percentile_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__72a6cdd81d2c42dc2cf1486df94ec27d161023dfcec0e0e9afca4890e457b9ee(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4533291348f707825df21d81075de06f67bc048e69dde1c005bfe03e9f02294c(
    *,
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
    period_time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59e6f7e22b5e83a9ee64d49b13df156139f158e8b287366fd0c146a799cf08f3(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f63c73fce52600a7a5a603b1e6b79d732048aee8b58eaf98edb95ec05770237f(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    contribution_analysis_defaults: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ContributionAnalysisDefaultProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    donut_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.DonutOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.PieChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SmallMultiplesOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PieChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    value_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1392e2748877570455c789a35979721836bb8f36e589d26b9865351d441f5e18(
    *,
    pie_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.PieChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__258b94810c4949283d60ecbe96bbacfa1e57060bdd78afbe3438da757c4b62fd(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    small_multiples_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    small_multiples_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__484f898738d720f8ba5ddf81dacf9716454281e64a6f079c419cd1a9060cb103(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PieChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0d1d7a7334d8a22926502c46d94b1ffcbe22f4df62c42960b1f85a0ccc1648e(
    *,
    field_id: builtins.str,
    sort_by: typing.Union[typing.Union[CfnTemplate.PivotTableSortByProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__019cc3cde72aea556c1456eab3896187926f7ce0964a69b29c3f54855e5aa3bc(
    *,
    columns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    rows: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c93f0b5d6128b95297aad7cf47f84bfa99608a57aa6b0a30aaf550dc1b887b8c(
    *,
    field_id: builtins.str,
    scope: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableConditionalFormattingScopeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_format: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80b222f1aed39172290a2b7cc288932bbd7ab4cebdabfbb807b2b8f52c36aa59(
    *,
    cell: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__19aabb6249d1472b4a1301897a83c223e7a741ab60aba39e8afc74889cb1ec5d(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.PivotTableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f5286404d6bfaf5b250f226c045d8f5808738762a451dd65bef57ce3dffedda2(
    *,
    role: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0682fadc20d329733736fc847b4ce0508e386a261423d3b2d6acab4881d62081(
    *,
    field_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_report_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c334748c26ab8545db66e0882d5cd23969244e95be73a4e1392fb4daf4e2f2e0(
    *,
    data_path_list: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataPathValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__45ee6adaa725e3bb050c8e88116258f24b8f24d6439c992314544978f886b79c(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc3409b1ee60d6140b84924f3ca452ab6d13c8691a7380125fc0bff7c1312436(
    *,
    data_path_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.PivotTableDataPathOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.PivotTableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9065f682585dea451d886827a4989ce4055ef04b4d837aef2ccdbdc688b05d9b(
    *,
    field_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__316ce79d995d0da4a72bb01600678e5cb7877715e5c8ba9b2037de23e6dd2a06(
    *,
    pivot_table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bc7ab4a9ea37e2a0063e0559bcff578b6db5561c436bf1a50bcf157bdf91dbfa(
    *,
    cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_header_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_names_visibility: typing.Optional[builtins.str] = None,
    metric_placement: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_field_names_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_header_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    single_metric_visibility: typing.Optional[builtins.str] = None,
    toggle_buttons_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0cc6b0252252f5165950ea28c17b40cf553ae73cbba16d8e8d0b86ff78ffd769(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c9e298b5278188613b23deba6d44c28187e8671e2ecbf92a4f0e15e32a754a07(
    *,
    column: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_path: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataPathSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field: typing.Optional[typing.Union[typing.Union[CfnTemplate.FieldSortProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2721ce42be0555d18b59c4e326933bc5afad1b0a32a39ab4336a1e895b444d54(
    *,
    field_sort_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.PivotFieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__440063153b2ad790eb50991280a57a253ffc0bbc6eadd3736a53aa71e3091b73(
    *,
    column_subtotal_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_total_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_subtotal_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_total_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7688455583ae144e4cddb7c0a95757017674f296811ae288ecdcbe266c820872(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6ef062a6f520dd5159d5454bb36b77fcb1a7505ded9c1576dceb8a74237c2e43(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    metric_header_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0b9156ad9629cb9cbd5070cfe99faa63d7ff7a126beb8518e20a8aed1faaa70b(
    *,
    columns: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    hierarchy_id: builtins.str,
    drill_down_filters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DrillDownFilterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec1599bf05c00e6452ae23b28f733acd9b05eb3acb089eb7b6a0e9224e6d5c97(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae11c12a0fd778e0910635b0a0ac8e90a1e738f10c6cb40e64430f6c946fc8fa(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b92cd2267ea4265f4c1703783cdbfd13e8a9a0cf7d28afcc1f30f5d804b90f56(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c5a513d03d2f4c49dea455f10ce3bd3a2de6636fbc171d703312e9bf1f5ea76b(
    *,
    alternate_band_colors_visibility: typing.Optional[builtins.str] = None,
    alternate_band_even_color: typing.Optional[builtins.str] = None,
    alternate_band_odd_color: typing.Optional[builtins.str] = None,
    base_series_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartSeriesSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_axis: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    shape: typing.Optional[builtins.str] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    start_angle: typing.Optional[jsii.Number] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9c299c59542dbcf90a2d0b2f05ee53a05844949542f37ed6819dfc0f083f2d0c(
    *,
    radar_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9d28083216f435f2d7aa4c98a4d6b69535a06f5739a96e56d98b7819814469e1(
    *,
    area_style_settings: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartAreaStyleSettingsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a5234eefadc2ba491ce61af720e36fe1f564fb83e2201e73e75d472e4573cb46(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    color_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f840d103e53f8f3b60595e706028c8d7b5844aa5550a747c2ade1e9b95bc79e8(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b856fe4a6efec297f4bd1389a388d3bf153b48fa6973c56b890ea4fca8787714(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c409cd751599789325825de6bfa0afdb155e1fd992d4bbb5f28bdadb21b1f3dd(
    *,
    custom_label: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2388691a8a698b422b60a84c6a8436f92659bfc6eb1fb075f34164ee6c7287b(
    *,
    axis_binding: typing.Optional[builtins.str] = None,
    dynamic_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ReferenceLineDynamicDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ReferenceLineStaticDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__faa458224cec5a714c1834af17b8f421e33ebca7f4a9ae372dfc8e913a825d87(
    *,
    calculation: typing.Union[typing.Union[CfnTemplate.NumericalAggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    measure_aggregation_function: typing.Union[typing.Union[CfnTemplate.AggregationFunctionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__780ad04db854fd9e38df2adb2467e3e541803120555cca130543e575ffe2416b(
    *,
    custom_label_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ReferenceLineCustomLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_color: typing.Optional[builtins.str] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    horizontal_position: typing.Optional[builtins.str] = None,
    value_label_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ReferenceLineValueLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    vertical_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5ac42280f628c152d05f5664d0e60d61caabc5f9bcbd6bbe4398816bfd9f811b(
    *,
    data_configuration: typing.Union[typing.Union[CfnTemplate.ReferenceLineDataConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    label_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ReferenceLineLabelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    status: typing.Optional[builtins.str] = None,
    style_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ReferenceLineStyleConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__20421cb296491d768f685e5dfbe585fcf57b5b9fb09ff2c522ba4038511ef013(
    *,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a848471f06e2cbd5b402e73e912570cc743305a8bf0c3caa7ba0748666458b11(
    *,
    color: typing.Optional[builtins.str] = None,
    pattern: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2ee8893fb1f7a392927c231f49a205e587827c53918150e5e2d3ccfd93256296(
    *,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    relative_position: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15e7af4c70cab3f4442f2eba8e6bca381ecf3b3ac9e8d8820abd3ce4b0fc21cc(
    *,
    date_time_format: typing.Optional[builtins.str] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c83a559811e709351dfb6a8650617b32ce8acdb833a7b994c1d5cef026643023(
    *,
    anchor_date_configuration: typing.Union[typing.Union[CfnTemplate.AnchorDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    relative_date_type: builtins.str,
    time_granularity: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    minimum_granularity: typing.Optional[builtins.str] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    relative_date_value: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1ff6430548217f9089a9a350cbf73c66fb163d392075fcef7a00103036a2ecaa(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
    resource: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d29077dddbcb62416e6841b85a183cc0f59445ab150ce1304b260ba5b0306528(
    *,
    expression: builtins.str,
    data_set_identifier: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e73e2cfa65aa4a6b4e49615c8e50f4ceac04731dda528a25495d5aea6b8b1f6b(
    *,
    row_alternate_colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3d13aeec0e248717d86b9e07563c3be59f967ae12210991ea38f388e87480a11(
    *,
    target_visual_options: typing.Optional[builtins.str] = None,
    target_visuals: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f95fd1cdc70ca8227a677e24cf553a61d2b6beb020dc8a8d267f31ecac8cf2be(
    *,
    destination: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    weight: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8eeb3c58381a9a3f36cab09ced8e9a51fb9216a6ac4b999b7b4e56e2c3f8b782(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.SankeyDiagramFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.SankeyDiagramSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0afb30f3ec96d06b1b86fbcf84101c0b0b4f1ad834c24414961cd9f9ce22889d(
    *,
    sankey_diagram_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44800cc25e017dcb20243245eaa0f1cca1e99fb13598cca0023bf4c82d5eaa61(
    *,
    destination_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    weight_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__431d4dc736cd0bab0fdd0f2e3bcee972d0164fae76e0fdd87078dcfde474399b(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.SankeyDiagramChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f67d4e7b5612ffa4d1eb34e0c52cd31c3d208a8ad3647541ae3494e930b4f99a(
    *,
    category: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af3129626a0c8154487e94949dd76f182e5ae5b6b1759cf19280d9f70c06dfe4(
    *,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.ScatterPlotFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    x_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7e18ca0c45b5c4f195b9d848deba88fe93baf5d39e57b5375fdb92670d910e9(
    *,
    scatter_plot_categorically_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scatter_plot_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e6da0071f34f86441c5cfd7ade0bf1dc86669895e46728822e0611c14a357301(
    *,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    x_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    y_axis: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e2cfffa0f11fc9b582c2def47b161daa58832b0ab19653a356c6bd9b51467bf(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ScatterPlotConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__597f06604243680c5657e0bd55d57b001c399c027bbabbbaa6bb3c4115d024ba(
    *,
    visibility: typing.Optional[builtins.str] = None,
    visible_range: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisibleRangeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b86703e96b8aed8bc1d15c8a2357c20c3cab9dcea5882ed3eb92fd52a2f451cb(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3ae09674090d4970a7c060d817eb027655bcf531c10268581befd007f7aac9c7(
    *,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c7370d14d5ed68080fce67a384ae68d0c9f6b759a75f6e0acec5bb367f475a2d(
    *,
    paper_canvas_size_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d7d9faf77550be6a08d42ca185e22c621f006a12df2a6018e68c46f347b488ab(
    *,
    body_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.BodySectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    canvas_size_options: typing.Union[typing.Union[CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    footer_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    header_sections: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.HeaderFooterSectionConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__af1adc7a1547747b87439607ca1a153ee0c400f47418d024500bb9205b7639ee(
    *,
    paper_margin: typing.Optional[typing.Union[typing.Union[CfnTemplate.SpacingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paper_orientation: typing.Optional[builtins.str] = None,
    paper_size: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80d2effb016f398c078d293b2ba169416d278ee26bed2410a3158dcb31c69741(
    *,
    free_form_layout: typing.Union[typing.Union[CfnTemplate.FreeFormSectionLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4f1527de7feb066312165189d4fe52974c352bf29871dc3798b0ba17fe8dabb5(
    *,
    after: typing.Optional[typing.Union[typing.Union[CfnTemplate.SectionAfterPageBreakProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ed389426823a71b8fcf4cb3578c0670eeab713bc07401ea3ed397edacf03b8c9(
    *,
    height: typing.Optional[builtins.str] = None,
    padding: typing.Optional[typing.Union[typing.Union[CfnTemplate.SpacingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3a7f004f34d534e28a219305232ccb459cd436481d06286472c4eaecc23fec31(
    *,
    sheet_visual_scoping_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SheetVisualScopingConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2865d448e94d60fd22ac5a77717d0aac446b58a72984101d64e214a71192bcfa(
    *,
    data_field_series_item: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataFieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_series_item: typing.Optional[typing.Union[typing.Union[CfnTemplate.FieldSeriesItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95891fa670c7ec3582c2ea3cc192527e219bd9658b92490a692d24fecffdfca5(
    *,
    destination_parameter_name: builtins.str,
    value: typing.Union[typing.Union[CfnTemplate.DestinationParameterValueConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__931fb7c9aeac54d49d1c2e7a7d7249b003383c683ff411a13fbc4d516dd5e9d2(
    *,
    background_color: typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__24819c5cec526f244999ea2e44a7954d943c256004094d0e3d15b9e3c2c225ac(
    *,
    grid_layout: typing.Optional[typing.Union[typing.Union[CfnTemplate.GridLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43fbaf712b3b0af39f246561d11aa60ab1606076e0bce5cf54b14c8e6cba1785(
    *,
    configuration: typing.Union[typing.Union[CfnTemplate.SheetControlLayoutConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d3c2388c54f3eb0eb16485b8231a94ec9e339da522fc53b161d751ae268865ff(
    *,
    sheet_id: builtins.str,
    content_type: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    filter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FilterControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.LayoutProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    name: typing.Optional[builtins.str] = None,
    parameter_controls: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ParameterControlProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheet_control_layouts: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SheetControlLayoutProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    text_boxes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SheetTextBoxProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    title: typing.Optional[builtins.str] = None,
    visuals: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__609d2714de6bdfd164ed82e4be65b6c7c806b5ea28d06c70f36210a1060245ab(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__95bdc41317bf034d261033a63b891e00f7f519faf138a89b0562fa00d2978877(
    *,
    configuration_overrides: typing.Union[typing.Union[CfnTemplate.SheetElementConfigurationOverridesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    expression: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13431325516d7446ffd9b89a46bb91b7886a4aa19137e691ff062cc3cfa6863c(
    *,
    name: typing.Optional[builtins.str] = None,
    sheet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__feebdfac4e6a5217ababbc67186e88114897b2b5fe3707c240b7d4fb888dccac(
    *,
    sheet_text_box_id: builtins.str,
    content: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aef298c0d76678fdfb3c9a233fc81dc62aea75581d13135b057b8472fffd1cb6(
    *,
    scope: builtins.str,
    sheet_id: builtins.str,
    visual_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74416675a375741e0f6f8bcacdbd55b491680721b286e91c2fbcd9b5ca17430d(
    *,
    plain_text: typing.Optional[builtins.str] = None,
    rich_text: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__14fe75e7fe06c2f622ff0e3fbb7ac7afa770ff9cd4d526c30e1e36101719570b(
    *,
    color: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3051774ccc64ec8cd7034b3dfb4a1ec421b53f465d7e7282029f06dd8b2a1c81(
    *,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa471a005a76e8aed5cf36f792ee1d19d4295d00de3834b48cf7c55546265c40(
    *,
    max_visible_columns: typing.Optional[jsii.Number] = None,
    max_visible_rows: typing.Optional[jsii.Number] = None,
    panel_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PanelConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40d47f29115b0666b48caa9d9a86b20c4896cc2121d502d3106adb8202a02e31(
    *,
    bottom: typing.Optional[builtins.str] = None,
    left: typing.Optional[builtins.str] = None,
    right: typing.Optional[builtins.str] = None,
    top: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b502b5911121fe34c752b20829b7d2ad49b939b3a204dfd4b13d125c03c0eec8(
    *,
    dynamic_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.DynamicDefaultValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_values: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e5ad39465dba0b7bb1e7aeb0c81a75e3a57533ae9c921405d41cf78893619160(
    *,
    null_value_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NullValueFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    numeric_format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.NumericFormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43d4f54b2e2d185aaed02141d1bc638d668650c6c95a21b4f3930271a04eee2a(
    *,
    name: builtins.str,
    parameter_value_type: builtins.str,
    default_values: typing.Optional[typing.Union[typing.Union[CfnTemplate.StringDefaultValuesProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    mapped_data_set_parameters: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MappedDataSetParameterProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    value_when_unset: typing.Optional[typing.Union[typing.Union[CfnTemplate.StringValueWhenUnsetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9750e619dc3fc3653ba8b6825bf995d751ac7498aa5ef9ae53e72b7825b2e3e7(
    *,
    custom_value: typing.Optional[builtins.str] = None,
    value_when_unset_option: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__25637467992b08ed4a2143af45b0248cf65bf6a8c96faeec7fe2547b82acc206(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    field_level: typing.Optional[builtins.str] = None,
    field_level_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.PivotTableFieldSubtotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    metric_header_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
    value_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bf88db58b984dafd9082574706809c5473b03068f51be626a1094c5f0effbe9(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a3d34f5e00aa0280afb90650141aafc67eb6d2523e5a6e711628ed296d5cd53c(
    *,
    color: typing.Optional[builtins.str] = None,
    style: typing.Optional[builtins.str] = None,
    thickness: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__343f90498bda661f85f9cc2c79aed3b1877ad20cab9e2ad481c0364352f92d59(
    *,
    field_id: builtins.str,
    text_format: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextConditionalFormatProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__651627002517c298a33646aae0d7a8c19906ba12de4aa6996f7d7b9b79fb8d3e(
    *,
    table_cell_image_scaling_configuration: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f03c41c114767413af09f68dc96cc84fd5e899b9379cfe49332102d522a67e06(
    *,
    background_color: typing.Optional[builtins.str] = None,
    border: typing.Optional[typing.Union[typing.Union[CfnTemplate.GlobalTableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    font_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    height: typing.Optional[jsii.Number] = None,
    horizontal_text_alignment: typing.Optional[builtins.str] = None,
    text_wrap: typing.Optional[builtins.str] = None,
    vertical_text_alignment: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__07cab96eb9136d38195d0f22eaef0c1713a99e64da908c8a233260ec5d34f063(
    *,
    cell: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableRowConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__32207839f10375641ac945cd8fd36fd6f7f5d8e469b40c4ebf46fa6048233d40(
    *,
    conditional_formatting_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.TableConditionalFormattingOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d72e9dc405ca60ff0649ce15c1de6858be05d764db9ce1a50f39aba3912e106c(
    *,
    field_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    paginated_report_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TablePaginatedReportOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_inline_visualizations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.TableInlineVisualizationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    table_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    total_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TotalOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__80f6817e78ddde2fb2957ce3b71b3cfe31d96c4e5c417d4a32bb899df1c84e06(
    *,
    icon: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__eadea6b07304dc10bd64be9c2333b048a2fb8ebf431c1ca448fe9d3d68594d13(
    *,
    font_configuration: typing.Union[typing.Union[CfnTemplate.FontConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__40381889cf4ff57ea8b0528bdb2d3853258cf132ae7fba80491c72e3d171b778(
    *,
    sizing_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellImageSizingConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e58b6f323af95174dcbbe38e7edb3c8905ef3c0c0c2eb3941df00cbdf6cbe84d(
    *,
    content: typing.Union[typing.Union[CfnTemplate.TableFieldLinkContentConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    target: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0f785ab48b0a5c8614c90c381cd3e391c4e07d4af8d010ba88a89f3e0070ee6f(
    *,
    custom_icon_content: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldCustomIconContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_text_content: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldCustomTextContentProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__acc3d1173a9fe4fdd861909143887bd068a0cbedc7f7cca385cc4cb572b35078(
    *,
    field_id: builtins.str,
    custom_label: typing.Optional[builtins.str] = None,
    url_styling: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldURLConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
    width: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ccb24c61d22fb761617d0113c7f5d21b0718f06bb64a508d948e0862b47716f5(
    *,
    order: typing.Optional[typing.Sequence[builtins.str]] = None,
    selected_field_options: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.TableFieldOptionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3247d37ef0f1fdb2638e98a6593bd820f6062d2013a65371339157b6dfe43e08(
    *,
    image_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldImageConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    link_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableFieldLinkConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__04c89356da465bc9c6713f635671c73b8528747dbab836989fe2a98eeca25d8d(
    *,
    table_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_unaggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableUnaggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbbbb0ba202416974b12502a0f94e5acc5490b28a2d04fb84d183cabf598a401(
    *,
    data_bars: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataBarsOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63d1aa579b8a90bdee8de5b3a01094fa74f5da0ef47e5b241ed704e4e855cd4a(
    *,
    cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    header_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    orientation: typing.Optional[builtins.str] = None,
    row_alternate_color_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.RowAlternateColorOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c87416104b5860548bc9a5516e7975895712cc93a8f7d91e7080000d191a3c93(
    *,
    overflow_column_header_visibility: typing.Optional[builtins.str] = None,
    vertical_overflow_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f1c9e911c37af79e2d25562395fa0ee62ba9e93b10a66dbdd5ee049463bc377d(
    *,
    background_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0965815ba024c08dbc7db699ef33a9768e98d2c8838a25bd3abb7fe6ad6b58f3(
    *,
    bottom: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    inner_horizontal: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    inner_vertical: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    left: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    right: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    top: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableBorderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a81b8941b69efac22fd8c63bad6f8b7876271ce625e4acf918d0b8027472f49a(
    *,
    pagination_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.PaginationConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    row_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f0cae29d6b26026c4831d4976d084a40e531d8ae78548f69ccb6aa728b42323(
    *,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.UnaggregatedFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35e7ac5eab300d766411990183b82c2f155c103d8cf5f16a5abe9a257ba2329e(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    conditional_formatting: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableConditionalFormattingProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__500a085582bc48e9c1f14845ca9df8136fc9c5b47eac0dc8108c7a9ea3b185f2(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
    violated_entities: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.EntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79021f944eca1eb229847b8d82f047f4dcc81486945010cb7bbb725ff1124818(
    *,
    arn: builtins.str,
    data_set_references: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataSetReferenceProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b152ab3c446928c2cc5b99951b6308a6ccce5abab28050d0cd3024fb946bffb1(
    *,
    source_analysis: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateSourceAnalysisProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    source_template: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateSourceTemplateProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1986494b19f109bde16feff032d3456b79cb02303508959f8e28b7372d2825d6(
    *,
    arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__39510fb860e6add8b350bfe679475ea355edafb2f190a845f987566e3d64f3fc(
    *,
    data_set_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataSetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    analysis_defaults: typing.Optional[typing.Union[typing.Union[CfnTemplate.AnalysisDefaultsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    calculated_fields: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.CalculatedFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    column_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    filter_groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FilterGroupProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    parameter_declarations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ParameterDeclarationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SheetDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ea5d025f8c385f6d90fb2ad675905cd3b5e93d7b90a4f1557cd594fcdafbeef4(
    *,
    created_time: typing.Optional[builtins.str] = None,
    data_set_configurations: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataSetConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.TemplateErrorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sheets: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.SheetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity_arn: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    theme_arn: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__84375717581db366e1324c0bdde09a17f42ef288567c38fe8edf01196dedf4fd(
    *,
    placeholder_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9ba043d8664f9ca678ed3ce58c48bea9b4bb06fe69a96534464ad0beabc71b2c(
    *,
    background_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    icon: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingIconProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    text_color: typing.Optional[typing.Union[typing.Union[CfnTemplate.ConditionalFormattingColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__61429e252c541a6c92e4690ced62509dff79b4692f3ae9fcdee3e55789b2fd56(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a8817efaca677f6538e3b73bfb422383f72bbb94342f50506bc54c30faef30f9(
    *,
    placeholder_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.TextControlPlaceholderOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.LabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3434f8795252f1a77b51f10bc1712aba04373e47413f4b160c924abe4d32a91d(
    *,
    symbol: typing.Optional[builtins.str] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bfad9cea026b1373063e417f507f22e467e93bdab69c3e3d25fac59c1974de8b(
    *,
    lower_boundary: typing.Optional[jsii.Number] = None,
    periods_backward: typing.Optional[jsii.Number] = None,
    periods_forward: typing.Optional[jsii.Number] = None,
    prediction_interval: typing.Optional[jsii.Number] = None,
    seasonality: typing.Optional[jsii.Number] = None,
    upper_boundary: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c2a5ed4b017cab5872752cdb9b970986cfe28b000b4455fe28660f90e5675ec8(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
    value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__259141eece1493a338b143fab066ab513cbaeecded382919e1c363db3721bf94(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    range_maximum: builtins.str,
    range_minimum: builtins.str,
    time_granularity: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__42fa666fe82e0e32a1787640e349ea1df8bf0eada07733c1d4ba8b3b1f6dc4c0(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    null_option: builtins.str,
    exclude_period_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ExcludePeriodConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    include_maximum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    include_minimum: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
    range_maximum_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    range_minimum_value: typing.Optional[typing.Union[typing.Union[CfnTemplate.TimeRangeFilterValueProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__df85e43accecb39b61d7577981c426ff58c439ab6e806417024c054dda7f204e(
    *,
    parameter: typing.Optional[builtins.str] = None,
    rolling_date: typing.Optional[typing.Union[typing.Union[CfnTemplate.RollingDateConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    static_value: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fa3dbf4c785b155bbd05f0995562211f248d32e220b854cca0d7a32f967182cc(
    *,
    column_tooltip_item: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColumnTooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_tooltip_item: typing.Optional[typing.Union[typing.Union[CfnTemplate.FieldTooltipItemProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fc163338ed93c143a54bfff923aa0f35010ca88b668ceb1c546c90d2ddd932b1(
    *,
    field_based_tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.FieldBasedTooltipProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    selected_tooltip_type: typing.Optional[builtins.str] = None,
    tooltip_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b82d66d58cc3cdc2b303a5ca47f0074c043c93555779b4831ddd6bb377f970e4(
    *,
    aggregation_sort_configurations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.AggregationSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    filter_id: builtins.str,
    limit: typing.Optional[jsii.Number] = None,
    parameter_name: typing.Optional[builtins.str] = None,
    time_granularity: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__35a2bc6605b57061fc281317a286e02c39af296d2becc23dd40deab5252838cc(
    *,
    category: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    time: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    type: builtins.str,
    mover_size: typing.Optional[jsii.Number] = None,
    name: typing.Optional[builtins.str] = None,
    sort_order: typing.Optional[builtins.str] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__f06cccc833743502c9273ea3480c495d9010a97dfb890564886aecb4f8cc4b3f(
    *,
    category: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    type: builtins.str,
    name: typing.Optional[builtins.str] = None,
    result_size: typing.Optional[jsii.Number] = None,
    value: typing.Optional[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1da23c68bc7b866a8aebcc515aa8acee8bbd331a311077cbe1cce72cdf6accef(
    *,
    computation_id: builtins.str,
    value: typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__77f70c87fbd5a17b4c8d53c5faba9ef1e0a30d31f5d0bce1c37a700a4da7cb09(
    *,
    custom_label: typing.Optional[builtins.str] = None,
    placement: typing.Optional[builtins.str] = None,
    scroll_status: typing.Optional[builtins.str] = None,
    total_cell_style: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableCellStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    totals_visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0799d2a10999c554883420d55e3654fe53787d60bf97a077811c459bd1015811(
    *,
    colors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    groups: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    sizes: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf43d1f9d98fbf96d0e19e6416a76a06a0ed81b7a441ec8fa583e15a939f27e7(
    *,
    color_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    color_scale: typing.Optional[typing.Union[typing.Union[CfnTemplate.ColorScaleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.TreeMapFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    group_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    size_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.TreeMapSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tooltip: typing.Optional[typing.Union[typing.Union[CfnTemplate.TooltipOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c1b2ba59f4c84a6caf6d7d113b158fce4271c974f6af8652ecc7d116130ddc09(
    *,
    tree_map_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.TreeMapAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5fef032760b84daddeaa241c474db09ca40fb86d3c671e81749a28512e204a4a(
    *,
    tree_map_group_items_limit_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tree_map_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e0ebbc2ef9e9216782b8b43fd0f9240d3ffd0fca5a3669f9261198b3c3f4b21d(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.TreeMapConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cd0c9deb823f37938a63190938562cfabc4fb931938e88c6ced3933c391bd8d1(
    *,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__9e68d03489fd85df88cc0e5849a53f11f02329c61a1f7556d6383345a748d4e3(
    *,
    column: typing.Union[typing.Union[CfnTemplate.ColumnIdentifierProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    field_id: builtins.str,
    format_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.FormatConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__747aefde26fdc00cda7e0e6af6b685d813baa009692cfa560ba21ec6db251122(
    *,
    category: typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
    computation_id: builtins.str,
    name: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__03a4fc1688e4f8fd2ec3a1fe27c0fc1238bd26aca6223f3a3923468dcd30f289(
    *,
    percent_range: typing.Optional[typing.Union[typing.Union[CfnTemplate.PercentVisibleRangeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c23b57f7f8292971b61c601ce1e570d5305846e31cb58905c4003198ae5b2bce(
    *,
    filter_operation: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomActionFilterOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    navigation_operation: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomActionNavigationOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    set_parameters_operation: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomActionSetParametersOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    url_operation: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomActionURLOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64021c4826100f0b98bce59890fb62530b0431ee697e8f4bfee7a816bfef907b(
    *,
    action_operations: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionOperationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
    custom_action_id: builtins.str,
    name: builtins.str,
    trigger: builtins.str,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8ec6c97ac1a08df779754feb8ecf25fe730c240e21457d73ac1f2a97547dcc65(
    *,
    chart_color: typing.Optional[builtins.str] = None,
    color_map: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DataPathColorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__94617066dac431d6d1e9cc4cc969863ddd38f9d3baed868407524d9b482e111f(
    *,
    bar_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.BarChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    box_plot_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.BoxPlotVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    combo_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.ComboChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    custom_content_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.CustomContentVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    empty_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.EmptyVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    filled_map_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.FilledMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    funnel_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.FunnelChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    gauge_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.GaugeChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    geospatial_map_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.GeospatialMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    heat_map_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.HeatMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    histogram_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.HistogramVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    insight_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.InsightVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    kpi_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.KPIVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    line_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.LineChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    pie_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.PieChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    pivot_table_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.PivotTableVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    radar_chart_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.RadarChartVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sankey_diagram_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.SankeyDiagramVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    scatter_plot_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.ScatterPlotVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    table_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.TableVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tree_map_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.TreeMapVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    waterfall_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.WaterfallVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    word_cloud_visual: typing.Optional[typing.Union[typing.Union[CfnTemplate.WordCloudVisualProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ec0457fd4f894e454f189fd73e7dd67b571dff3bc026a28388230b40bd065fdf(
    *,
    format_text: typing.Optional[typing.Union[typing.Union[CfnTemplate.LongFormatTextProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__99d156a534868d61dffa0b770f962b2ac7bdcce87b038bee4085ecf9700bafcb(
    *,
    format_text: typing.Optional[typing.Union[typing.Union[CfnTemplate.ShortFormatTextProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visibility: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fae73bd55d45c795e1b57adaa16088621aacf974d1781c1d779a41b5a86350bd(
    *,
    breakdowns: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    categories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    values: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b7770c9ee5b6f7cad35e8fa10aa668bf90463319caf6a5d77f19918d58775cc6(
    *,
    category_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    data_labels: typing.Optional[typing.Union[typing.Union[CfnTemplate.DataLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.WaterfallChartFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    legend: typing.Optional[typing.Union[typing.Union[CfnTemplate.LegendOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_display_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.AxisDisplayOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    primary_y_axis_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.WaterfallChartSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    visual_palette: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    waterfall_chart_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.WaterfallChartOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__44aa950d675113619606f670b6d66af14eda5977c5431dc0a07ed1993f36c026(
    *,
    waterfall_chart_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.WaterfallChartAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b3d4450fccecebae263839daa7cecc84ac23bd7e4599c0b872382593aa77b92f(
    *,
    total_bar_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4d07b0596770d9530fdfa5f95b993ecb1a4a2de93bff84ad7d9c12481c25f5c2(
    *,
    breakdown_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__349931aa27d35e365adafc4ecf5d589c25992ee8dafcd6cb2436e1d2843a6ab9(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.WaterfallChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__db466a8f201bac80314ce2aa6052fd09f80de7a3dc33c514a0e204828dde66ed(
    *,
    date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b4e75f5d566010e31b97cb53ad3f77cf4cc5d6eb86a0ffbf18dd8cba73bcdc85(
    *,
    end_date: builtins.str,
    start_date: builtins.str,
    value: jsii.Number,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2a894ae8004f4a15e1255485902243a214aa76ba738111b84c923876f263d5e2(
    *,
    group_by: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.DimensionFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    size: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.MeasureFieldProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__90eea703566cd49cbfbb1bc905a08243b9a7da7f9f36bd5e9bd33397cbbf6bfe(
    *,
    category_label_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.ChartAxisLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.WordCloudFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sort_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.WordCloudSortConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    word_cloud_options: typing.Optional[typing.Union[typing.Union[CfnTemplate.WordCloudOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a10a28e8deeca1e1d0db3b5c40903878c7824a172b9b9a0784598da367c85c47(
    *,
    word_cloud_aggregated_field_wells: typing.Optional[typing.Union[typing.Union[CfnTemplate.WordCloudAggregatedFieldWellsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__59de0ecf1a2d393a508663c061e016f99705f118c32f5e96179eed6539faf04b(
    *,
    cloud_layout: typing.Optional[builtins.str] = None,
    maximum_string_length: typing.Optional[jsii.Number] = None,
    word_casing: typing.Optional[builtins.str] = None,
    word_orientation: typing.Optional[builtins.str] = None,
    word_padding: typing.Optional[builtins.str] = None,
    word_scaling: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daf26766c1808f1a3d31f5f2e6b376b85037677e1754584dd891a789cd12d670(
    *,
    category_items_limit: typing.Optional[typing.Union[typing.Union[CfnTemplate.ItemsLimitConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    category_sort: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.FieldSortOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dbba2b5b96dd68e2ea09ffee22657fa4f8dcec50ad9e048ecc43f2aa9711dc38(
    *,
    visual_id: builtins.str,
    actions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.VisualCustomActionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    chart_configuration: typing.Optional[typing.Union[typing.Union[CfnTemplate.WordCloudChartConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    column_hierarchies: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ColumnHierarchyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    subtitle: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualSubtitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    title: typing.Optional[typing.Union[typing.Union[CfnTemplate.VisualTitleLabelOptionsProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b9126e0fc1cd990180f181ea366ec8684272453b6f2ffad0d170394314326e46(
    *,
    aws_account_id: builtins.str,
    template_id: builtins.str,
    definition: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateVersionDefinitionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTemplate.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    source_entity: typing.Optional[typing.Union[typing.Union[CfnTemplate.TemplateSourceEntityProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a982acbc529fecd5eb0bceef80c1cc372c6043a37702c9efb3f4ff2265e3c6a3(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    aws_account_id: builtins.str,
    theme_id: builtins.str,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__13b6797443bcd8f8cef6c390d2cd1b5f256c2254ad8da5b7fe337e6714048dbd(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e8ebfbde87206b99da23dad12f1a2eda4db5d916e8b066b4c7e0d4b22245fb41(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__23c7138c389333ea25ad06021eea09d0cdcd96e622b119d2ee777ec9b7d8aee0(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__79b54317f889cad4e3dd36bc868b6fba421da01d22117171c57796789899f6f1(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__625a3de787b6942a8b046ef0bb20fd7aca1efac63efa77e3335f578291612e02(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__57f60df16cc26a9e5d3b48a730661cdc0ce58596f41b16c0c27e70bae7a18df6(
    value: typing.Optional[typing.Union[CfnTheme.ThemeConfigurationProperty, _IResolvable_a771d0ef]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__241e09d54947304252ec8e2856e68539972fd562ad8af914e01385caa4924d97(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__2649df1cc1fb02b94b3edebaca96647cf74e2adffa7972ed5a1080047cdd0edf(
    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnTheme.ResourcePermissionProperty, _IResolvable_a771d0ef]]]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a524282f2932f086a220e5bdc191071bf4bffd02131a5d93ee5e4a3017022f6c(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dadb30e0a6ad8255563bafb4cd96f9c6a8f66b3b855caf1fcd95ab4b875246f2(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__c97321d1990600c1b17e48aaaa59d7a62b39c2ce86919f10392c5441e236f456(
    *,
    colors: typing.Optional[typing.Sequence[builtins.str]] = None,
    empty_fill_color: typing.Optional[builtins.str] = None,
    min_max_gradient: typing.Optional[typing.Sequence[builtins.str]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__53375c8d6395e69b8acae64f3fb565703198d342d4411e35bdb9c80100c2072e(
    *,
    font_family: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__64eb7c2f842be1cda829d400f3d312cb604bb36cbd2589fe9ff00407f4103be4(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8f65a4fdf268b41c7e2a85b103e21256b39b6be88fafbd656af630c13c4355bb(
    *,
    show: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__8d9024d86489caec28b2c09991ca50ecc1c652c4c6a0185a5fc75d4f5bda7431(
    *,
    actions: typing.Sequence[builtins.str],
    principal: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b06f90593788fa10364ce907ccf4f893dc73a5af513b55032af625389454dd8f(
    *,
    tile: typing.Optional[typing.Union[typing.Union[CfnTheme.TileStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    tile_layout: typing.Optional[typing.Union[typing.Union[CfnTheme.TileLayoutStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__578cb7cdcb9545cde16a00b488903fc7c6e4c99fbb8e511481be866f9fb93980(
    *,
    data_color_palette: typing.Optional[typing.Union[typing.Union[CfnTheme.DataColorPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    sheet: typing.Optional[typing.Union[typing.Union[CfnTheme.SheetStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    typography: typing.Optional[typing.Union[typing.Union[CfnTheme.TypographyProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    ui_color_palette: typing.Optional[typing.Union[typing.Union[CfnTheme.UIColorPaletteProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__fb6048efba70fac73bb0a644f0701fc148b43f1485474af58c91e0943d8b8461(
    *,
    message: typing.Optional[builtins.str] = None,
    type: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b2355f6dbd7f07d10537444b72f0b2a415d75ef5a1dc2daf3b5295eab57edc38(
    *,
    arn: typing.Optional[builtins.str] = None,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    created_time: typing.Optional[builtins.str] = None,
    description: typing.Optional[builtins.str] = None,
    errors: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTheme.ThemeErrorProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    status: typing.Optional[builtins.str] = None,
    version_number: typing.Optional[jsii.Number] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__105274364981084856d1b81067a3b72feef9bf6ea968ceb63e4ad5fb9aebd2f0(
    *,
    gutter: typing.Optional[typing.Union[typing.Union[CfnTheme.GutterStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    margin: typing.Optional[typing.Union[typing.Union[CfnTheme.MarginStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__cf9fdbc68fdbe60b4f0c091cda0d203d1cd0a356ca81cdbcb3ec26b51fe3fb3c(
    *,
    border: typing.Optional[typing.Union[typing.Union[CfnTheme.BorderStyleProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e80c7795e212917d762116e84e5be5123624cc6a0cae63097a92ab2d4d1fa0c(
    *,
    font_families: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTheme.FontProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__de50b957762075174cb676dbaa4eaf86e03e236d848e3f36976e5eb814d35a69(
    *,
    accent: typing.Optional[builtins.str] = None,
    accent_foreground: typing.Optional[builtins.str] = None,
    danger: typing.Optional[builtins.str] = None,
    danger_foreground: typing.Optional[builtins.str] = None,
    dimension: typing.Optional[builtins.str] = None,
    dimension_foreground: typing.Optional[builtins.str] = None,
    measure: typing.Optional[builtins.str] = None,
    measure_foreground: typing.Optional[builtins.str] = None,
    primary_background: typing.Optional[builtins.str] = None,
    primary_foreground: typing.Optional[builtins.str] = None,
    secondary_background: typing.Optional[builtins.str] = None,
    secondary_foreground: typing.Optional[builtins.str] = None,
    success: typing.Optional[builtins.str] = None,
    success_foreground: typing.Optional[builtins.str] = None,
    warning: typing.Optional[builtins.str] = None,
    warning_foreground: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__baf50d33c07375bd6f65cbb3c24b91760006a90a20c7742b37182d23ee52cb36(
    *,
    aws_account_id: builtins.str,
    theme_id: builtins.str,
    base_theme_id: typing.Optional[builtins.str] = None,
    configuration: typing.Optional[typing.Union[typing.Union[CfnTheme.ThemeConfigurationProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
    name: typing.Optional[builtins.str] = None,
    permissions: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnTheme.ResourcePermissionProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    version_description: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__6bcde85be865623c80e1517b4de7487ab675b6c2fe2e98cc8896c13c35153c71(
    scope: _Construct_e78e779f,
    id: builtins.str,
    *,
    availability_status: typing.Optional[builtins.str] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    role_arn: typing.Optional[builtins.str] = None,
    security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    vpc_connection_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__65d49377b766e5f26d61491d4aeb3617321c2d51762f46a5fe76736bc886249f(
    inspector: _TreeInspector_1cd1894e,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__73f6ba18f05c8ab37c670bbf4f03441dbfa9494b7f131312ceb633cf590b3081(
    props: typing.Mapping[builtins.str, typing.Any],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0fc3edd9331a9a88a912961357e37a2268d75e6c27148772c3d061292f079867(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1e8f2a3c20b055a182c9ecb372694a9956a54ebbdfbf494596c9d6bf7f268d7e(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__590fcceedf86192f22c418e295aed66033f4767e5c2d28e49e224a716329bc9a(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__74b57e5a306a3f450c02afc04bc81367694cb7775f803535635ee05121ca63d2(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__302f113f7175dbea4c037d05da5902cb1b1a433d4c191b1dcafb3e4a8053f78c(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d658fc0d7a2030afc9e81e446212a5bc98325efec0085a663ba62fb83bf7340d(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4e4e5de4cc795447f32a5518663b04e8354630794454d6bba85fa213db41bab6(
    value: typing.Optional[typing.List[builtins.str]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__e2b2e0a6a8a31deac2ae29b156c918fc51146033029b8ca227f4b7f7ff649f7a(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__d64e737559dffe04b19dc157c24c7678a13e4f8a61b48175df2562153f03ae76(
    *,
    availability_zone: typing.Optional[builtins.str] = None,
    error_message: typing.Optional[builtins.str] = None,
    network_interface_id: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    subnet_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__12ce6e4db6bc4193a018d80637b682965f86bfc8dad4ea1d2da029ae75f8ff04(
    *,
    availability_status: typing.Optional[builtins.str] = None,
    aws_account_id: typing.Optional[builtins.str] = None,
    dns_resolvers: typing.Optional[typing.Sequence[builtins.str]] = None,
    name: typing.Optional[builtins.str] = None,
    role_arn: typing.Optional[builtins.str] = None,
    security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    subnet_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
    vpc_connection_id: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass
